<?php
/**
 * Metabox fields.
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


/**
 * Add assistive text to text input.
 */
function levelup_meta_box_text_assistive_text( $field_html, $field, $meta ) {
	if ( !empty($field['assistive_text']) ) {
		$field_html .= '&nbsp;<small>' . $field['assistive_text'] . '</small>';
	}
	return $field_html;
}
add_filter( 'rwmb_text_html', 'levelup_meta_box_text_assistive_text', 10, 3 );

/**
 * Add some classes to meta box wrap.
 */
function levelup_meta_box_classes( $begin, $field, $meta ) {
	$classes = array(
		'rwmb-input-' . esc_attr( $field['id'] )
	);

	// compatibility with old scripts and styles
	switch ( $field['type'] ) {
		case 'radio':
			foreach( $field['options'] as $option ) {
				if ( is_array($option) ) { $classes[] = 'rdy_radio-img'; break; }
			}

			break;
	}

	if ( !empty($field['show_on']) ) {
		$begin = str_replace('class="rwmb-field', 'data-show-on="' . esc_attr(implode(',', (array) $field['show_on'])) . '" class="rwmb-field hide-if-js', $begin);
	}

	if ( !empty($field['top_divider']) ) {
		$begin = '<div class="rdy_hr rdy_hr-top"></div>' . $begin;
	}

	// divider
	if ( !empty( $field['divider'] ) && in_array( $field['divider'], array( 'top', 'top_and_bottom' ) ) ) {
		$begin = '<div class="rdy_hr rdy_hr-top"></div>' . $begin;
	}

	return str_replace('class="rwmb-input', 'class="rwmb-input ' . implode(' ', $classes), $begin);
}
add_filter('rwmb_begin_html', 'levelup_meta_box_classes', 10, 3);

/**
 * Add some classes to meta box wrap.
 */
function levelup_meta_box_classes_end_html( $end, $field, $meta ) {

	// divider
	if ( !empty( $field['divider'] ) && in_array( $field['divider'], array( 'bottom', 'top_and_bottom' ) ) ) {
		$end .= '<div class="rdy_hr rdy_hr-bottom"></div>';
	}

	if ( !empty($field['bottom_divider']) ) {
		$end .= '<div class="rdy_hr rdy_hr-bottom"></div>';
	}

	return $end;
}
add_filter('rwmb_end_html', 'levelup_meta_box_classes_end_html', 10, 3);


function levelup_meta_box_before_html( $before_html, $field ) {
	static $saved_show_on_template = array();

	$open_template = '<div class="rwmb-hidden-field hide-if-js" data-show-on="%s">';
	$close_template = '</div>';

	$field_show_on_template = isset( $field['show_on_template'] ) ? $field['show_on_template'] : array();
	if ( !is_array( $field_show_on_template ) ) {
		$field_show_on_template = explode( ',', $field_show_on_template );
	}
	$field_show_on_template = array_map( 'trim', $field_show_on_template );
	sort( $field_show_on_template );

	$result_html = $before_html;
	if ( empty( $saved_show_on_template ) && !empty( $field_show_on_template ) ) {
		$saved_show_on_template = $field_show_on_template;
		$result_html .= sprintf( $open_template, implode( ',', $saved_show_on_template ) );

	} else if ( !empty( $saved_show_on_template ) && empty( $field_show_on_template ) ) {
		$saved_show_on_template = array();
		$result_html = $close_template . $result_html;

	} else if ( !empty( $saved_show_on_template ) && !empty( $field_show_on_template ) ) {

		$saved_string = implode( ',', $saved_show_on_template );
		$field_string = implode( ',', $field_show_on_template );

		if ( $saved_string != $field_string ) {
			$saved_show_on_template = $field_show_on_template;
			$result_html = $close_template . $before_html . sprintf( $open_template, implode( ',', $saved_show_on_template ) );
		}

	}

	return $result_html;
}
add_filter( 'rwmb_field_before_html', 'levelup_meta_box_before_html', 10, 2 );