<?php
/**
 * Override for some meta-box fields.
 */

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }

# Meta-boxes classes
//require_once RDY_CORE_DIR . "/inc/ext/meta-box/inc/helper.php";
require_once RDY_CORE_DIR . "/inc/ext/meta-box/inc/core.php";
require_once RDY_CORE_DIR . "/inc/ext/meta-box/inc/field.php";

/**************************************************************************************/
// Radio field
/**************************************************************************************/

if ( ! class_exists( 'RWMB_Radio_Field' ) ) {
    class RWMB_Radio_Field extends RWMB_Field {
        /**
         * Get field HTML
         *
         * @param string $html
         * @param mixed  $meta
         * @param array  $field
         *
         * @return string
         */
		static function html( $meta, $field ) {
			$html = '';
			$tpl = '<label %s>%s<input type="radio" class="rwmb-radio" name="%s" value="%s" %s /> %s</label>';

			if ( empty( $field['images_base_dir'] ) ) {
				$theme_uri = LEVELUP_THEME_TEMPLATE_URL;
				$admin_images_uri = $theme_uri . '/inc/admin/assets/images/';

			} else {
				$admin_images_uri = $field['images_base_dir'];

			}

			$hide_fields = !empty($field['hide_fields']) ? (array) $field['hide_fields'] : array();

			foreach ( $field['options'] as $value => $label ) {
				$class = '';
				$image = '';
				$checked = checked( $value, $meta, false );

				if ( $checked ) {
					$class = 'class="act"';
				}

				if ( !empty($hide_fields[ $value ]) ) {
					$checked .= ' data-hide-fields="' . implode( ',', (array) $hide_fields[ $value ] ) . '"';
				}

				// radio image
				if ( is_array($label) ) {

					if( !empty($label[1]) && is_array($label[1]) ) {
						$image_meta = $label[1];

						$image = sprintf(
							'<img src="%s" class="hide-if-no-js"  style="%s" width="%d" height="%d" /><br />',
							esc_url($admin_images_uri . 'blank.gif'),
							"background-image:url('" . esc_url($admin_images_uri . $image_meta[0]) . "');",
							absint($image_meta[1]),
							absint($image_meta[2])
						);
					}

					$label = current($label);
				}

				$html .= sprintf(
					$tpl,
					$class,
					$image,
					$field['field_name'],
					$value,
					$checked,
					$label
				);
			}

			return $html;
		}

        /**
         * Filter before html.
         */
        static function levelup_filter_begin_html( $begin, $field, $meta ) {

            if ( !empty($field['hide_fields']) ) {
                $begin = str_replace('class="rwmb-input', 'class="rwmb-input rwmb-radio-hide-fields', $begin);
            }

            return $begin;
        }
    }
    add_filter('rwmb_radio_begin_html', array('RWMB_Radio_Field', 'levelup_filter_begin_html'), 10, 3);
}


/**************************************************************************************/
// Select field
/**************************************************************************************/

if ( !class_exists( 'RWMB_Select_Field' ) ) {
	class RWMB_Select_Field extends RWMB_Field {
		/**
		 * Enqueue scripts and styles
		 *
		 * @return void
		 */
		static function admin_enqueue_scripts() {
			wp_enqueue_style( 'rwmb-select', RWMB_CSS_URL . 'select.css', array(), RWMB_VER );
		}

		/**
		 * Get field HTML
		 *
		 * @param string $html
		 * @param mixed  $meta
		 * @param array  $field
		 *
		 * @return string
		 */
		static function html( $meta, $field ) {
			$html = sprintf(
				'<select class="rwmb-select" name="%s" id="%s" size="%s"%s>',
				$field['field_name'],
				$field['id'],
				isset($field['size']) ? $field['size'] : 0,
				$field['multiple'] ? ' multiple="multiple"' : ''
			);

			$html .= self::options_html( $field, $meta );

			$html .= '</select>';

			return $html;
		}

		/**
		 * Get meta value
		 * If field is cloneable, value is saved as a single entry in DB
		 * Otherwise value is saved as multiple entries (for backward compatibility)
		 *
		 * @see "save" method for better understanding
		 *
		 * TODO: A good way to ALWAYS save values in single entry in DB, while maintaining backward compatibility
		 *
		 * @param $meta
		 * @param $post_id
		 * @param $saved
		 * @param $field
		 *
		 * @return array
		 */
		static function meta( $post_id, $saved, $field ) {
			$single = $field['clone'] || !$field['multiple'];
			$meta = get_post_meta( $post_id, $field['id'], $single );
			$meta = ( !$saved && '' === $meta || array() === $meta ) ? $field['std'] : $meta;

			$meta = array_map( 'esc_attr', (array) $meta );

			return $meta;
		}


		/**
		 * Save meta value
		 * If field is cloneable, value is saved as a single entry in DB
		 * Otherwise value is saved as multiple entries (for backward compatibility)
		 *
		 * TODO: A good way to ALWAYS save values in single entry in DB, while maintaining backward compatibility
		 *
		 * @param $new
		 * @param $old
		 * @param $post_id
		 * @param $field
		 */

        static function save( $new, $old, $post_id, $field )
        {
            if ( ! $field['clone'] )
            {
                parent::save( $new, $old, $post_id, $field );

                return;
            }

            if ( empty( $new ) )
                delete_post_meta( $post_id, $field['id'] );
            else
                update_post_meta( $post_id, $field['id'], $new );
        }

		/**
		 * Normalize parameters for field
		 *
		 * @param array $field
		 *
		 * @return array
		 */
		static function normalize_field( $field ) {
			$field = wp_parse_args( $field, array(
				'desc'=> '',
				'name' => $field['id'],
				'size' => $field['multiple'] ? 5 : 0,
			) );
			if ( !$field['clone'] && $field['multiple'] )
				$field['field_name'] .= '[]';
			return $field;
		}

		/**
		 * Creates html for options
		 *
		 * @param array $field
		 *
		 * @return array
		 */
		static function options_html( $field, $meta ) {
			$html = '';

			// std
			if ( empty($meta) ) {
				$meta = $field['std'];
			}

			$option = '<option value="%s" %s>%s</option>';

			foreach ( $field['options'] as $value => $label )
			{
				$html .= sprintf(
					$option,
					$value,
					selected( in_array( $value, (array)$meta ), true, false ),
					$label
				);
			}

			return $html;
		}
	}
}