<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


define( 'WP_LESS_COMPILER', 'lessphp' );
define( 'RDY_LESS_CSS_IS_WRITABLE', true );


if ( ! function_exists('levelup_get_dynamic_stylesheets_list') ) {

    function levelup_get_dynamic_stylesheets_list() {

        static $dynamic_stylesheets = null;

        if ( null === $dynamic_stylesheets ) {

            $template_uri = LEVELUP_THEME_TEMPLATE_URL;
            $template_directory = get_template_directory();

            $theme_version = wp_get_theme()->get( 'Version' );

            $dynamic_stylesheets = array();

            $dynamic_stylesheets['levelup_custom'] = array(
                'path' => $template_directory . '/assets/css/custom.less',
                'src' => $template_uri . '/assets/css/custom.less',
                'deps' => array(),
                'ver' => $theme_version,
                'media' => 'all'
            );

        }

        return $dynamic_stylesheets;
    }

}


if ( ! function_exists('levelup_generate_less_css_file_after_options_save') ) {

    function levelup_generate_less_css_file_after_options_save() {
        $css_is_writable = get_option( 'levelup_less_css_is_writable' );

        if (empty($css_is_writable)) {
            $css_is_writable = 1;
        }

//        if ( ! ( ( isset( $_POST['action'] ) && 'birdy_ajax_save' == $_POST['action'] ) || ( isset( $_GET['activated'] ) && 'true' == $_GET['activated'] ) || ( isset($_GET['settings-updated']) && $_GET['settings-updated'] == 'true' ) )
//             || ! $css_is_writable ) {
        if ( ! $css_is_writable ) {
            return;
        }

        $dynamic_stylesheets = levelup_get_dynamic_stylesheets_list();

        foreach ( $dynamic_stylesheets as $stylesheet_handle=>$stylesheet ) {
	        levelup_generate_less_css_file( $stylesheet_handle, $stylesheet['src'] );
        }

        if ( $css_is_writable ) {
            add_settings_error( 'birdy-wp-less', 'save_stylesheet', _x( 'Stylesheet saved.', 'backend', 'LEVELUP' ), 'updated fade' );
        }

    }

    add_action( 'levelupredux/options/levelup_options/saved', 'levelup_generate_less_css_file_after_options_save' );
    add_action( 'levelupredux/options/levelup_options/reset', 'levelup_generate_less_css_file_after_options_save' );
    add_action( 'levelupredux/options/levelup_options/section/reset', 'levelup_generate_less_css_file_after_options_save' );
}

/*
if ( ! function_exists('birdy_generate_less_css_file_after_switch_theme') ) {

    function birdy_generate_less_css_file_after_switch_theme($redux, $force = false) {
        global $birdy;
        global $pagenow;

        if ( get_option('birdy_init_levelup_theme') === 'activated' || $force === true ) {
            update_option( 'birdy_init_levelup_theme', 'init' );
            $dynamic_stylesheets = birdy_get_dynamic_stylesheets_list();

            foreach ( $dynamic_stylesheets as $stylesheet_handle => $stylesheet ) {
                birdy_generate_less_css_file( $stylesheet_handle, $stylesheet['src'], $force );
            }

        }
    }

    add_action( 'redux/loaded', 'birdy_generate_less_css_file_after_switch_theme' );

}


if ( ! function_exists('birdy_after_switch_theme') ) {

    function birdy_after_switch_theme() {
        $option_name = 'birdy_init_levelup_theme';

        if ( !get_option($option_name) ) {
            update_option($option_name, 'activated');
        }
    }

    add_action( 'after_switch_theme', 'birdy_after_switch_theme' );

}


if ( ! function_exists('birdy_switch_theme') ) {

    function birdy_switch_theme($oldname, $oldtheme=false) {
        update_option('birdy_init_levelup_theme', '');
    }

    add_action( 'switch_theme', 'birdy_switch_theme' );

}
*/

if ( ! function_exists('levelup_generate_less_css_file') ) {

    function levelup_generate_less_css_file( $handler = 'custom.less', $src = '', $force = false ) {

        require_once( RDY_CORE_DIR . '/inc/ext/wp-less/bootstrap-for-theme.php' );

        if ( class_exists('WPLessPlugin') ) {
            $less = WPLessPlugin::getInstance();
            $less->dispatch();
        }

        require_once( RDY_CORE_DIR . '/inc/less-functions.php' );

//        if ( $located_file = locate_template( 'inc/less-vars.php' ) ) {
        if ( $located_file = RDY_CORE_DIR . '/inc/less-vars.php' ) {
            include_once( $located_file );
        }

        $config = $less->getConfiguration();
        if (!$force && !wp_style_is($handler, 'registered') ) {

            if ( !$src ) {
                $src = get_template_directory() . '/assets/css/custom.less';
            }

            wp_register_style( $handler, $src );
        }

        // save options
        $options = levelup_compile_less_vars();
        if ( $options ) {
            $less->setVariables( $options );
        }

        WPLessStylesheet::$upload_dir = $config->getUploadDir();
        WPLessStylesheet::$upload_uri = $config->getUploadUrl();

        return $less->processStylesheet( $handler, true );
    }

}


if ( !function_exists('levelup_make_relative_image_path') ) {

    function levelup_make_relative_image_path( $content = '' ) {

        if ( !get_option( 'levelup_less_css_is_writable' ) ) {
            return $content;
        }

        $content = str_replace( set_url_scheme( content_url(), 'http' ), '../../../../..', $content );
        $content = str_replace( set_url_scheme( content_url(), 'https' ), '../../../../..', $content );

        return $content;
    }
    add_filter( 'wp-less_stylesheet_save', 'levelup_make_relative_image_path', 99 );

}


if ( ! function_exists('levelup_enqueue_dynamic_stylesheets') ) {

    function levelup_enqueue_dynamic_stylesheets($force = false){

        $dynamic_stylesheets = levelup_get_dynamic_stylesheets_list();

        foreach ( $dynamic_stylesheets as $stylesheet_handle=>$stylesheet ) {

            $stylesheet_path_hash = md5( $stylesheet['path'] );

            $stylesheet_cache_name = 'wp_less_stylesheet_data_' . esc_attr( $stylesheet_path_hash );
            $stylesheet_cache = get_option( $stylesheet_cache_name );

            // regenerate less files if needed
            if (
                ( defined('RDY_ALWAYS_REGENERATE_DYNAMIC_CSS') && RDY_ALWAYS_REGENERATE_DYNAMIC_CSS )
                || ! $stylesheet_cache ||
                ( $stylesheet_cache && ( ( isset($stylesheet_cache['target_path']) && ! file_exists( $stylesheet_cache['target_path'] ) ) ) )
            ) {

	            levelup_generate_less_css_file( $stylesheet_handle, $stylesheet['src'] );

            }
            $stylesheet_cache = get_option( $stylesheet_cache_name );

            // enqueue stylesheets
//            if (!$force)
	        levelup_enqueue_dynamic_style( array( 'handle' => $stylesheet_handle, 'cache' => $stylesheet_cache, 'stylesheet' => $stylesheet ) );

        }

        do_action( 'levelup_enqueue_dynamic_stylesheets' );

    }

}


if ( ! function_exists('levelup_enqueue_dynamic_style') ) {

    function levelup_enqueue_dynamic_style( $args = array() ) {

        $stylesheet = empty( $args['stylesheet'] ) ? array() : $args['stylesheet'];
        $handle = empty( $args['handle'] ) ? '' : $args['handle'];

        if ( empty( $stylesheet ) || empty( $handle )) {
            return;
        }

        $stylesheet_cache = empty( $args['cache'] ) ? array() : $args['cache'];

        // less stylesheet
        if ( get_option( 'levelup_less_css_is_writable' ) && isset($stylesheet_cache['target_uri']) ) {

            $stylesheet_src = set_url_scheme( $stylesheet_cache['target_uri'], is_ssl() ? 'https' : 'http' );
            wp_enqueue_style( $handle, $stylesheet_src, $stylesheet['deps'], $stylesheet['ver'], $stylesheet['media'] );

            // print custom css inline
        } elseif ( !empty($stylesheet_cache['compiled']) ) {

            $inline_stylesheet = $stylesheet_cache['compiled'];
            if ( is_ssl() ) {
                $inline_stylesheet = str_replace( site_url('', 'http'), site_url('', 'https'), $inline_stylesheet );
            }

            wp_add_inline_style( 'levelup_main', $inline_stylesheet );
        }

    }

}


if ( ! function_exists('levelup_filter_wp_less_source_path') ) {

    function levelup_filter_wp_less_source_path( $path = '', $stylesheet = null ) {

        if ( $stylesheet ) {
            $dynamic_stylesheets = levelup_get_dynamic_stylesheets_list();
            $handle = $stylesheet->handle;
            if (
                array_key_exists( $handle , $dynamic_stylesheets )
                && ! empty( $dynamic_stylesheets[ $handle ]['path'] )
            ) {
                $path = $dynamic_stylesheets[ $handle ]['path'];
            }
        }

        return $path;
    }

    add_filter( 'wp-less_stylesheet_source_path', 'levelup_filter_wp_less_source_path', 10, 2 );

}
