<?php
/*
Plugin Name: LEVELUP Core
Plugin URI: http://puzzlerbox.com
Description: LEVELUP Core Plugin for Puzzlerbox Themes
Version: 1.1.15
Author: Puzzlerbox
Author URI: http://puzzlerbox.com
*/

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

if ( ! defined( 'LEVELUP_THEME_TEMPLATE_URL' ) ) {
	define( 'LEVELUP_THEME_TEMPLATE_URL', get_template_directory_uri() );
}


if( ! class_exists( 'LevelupCore_Plugin' ) ) {
	class LevelupCore_Plugin {

		const VERSION = '1.1.15';
		protected static $instance = null;

		private function __construct() {
			add_action('init', array(&$this, 'init'));
			add_action('admin_init', array(&$this, 'admin_init'));
		}

		function init() {

		}

		function admin_init() {

		}

		public static function get_instance() {

			if ( null == self::$instance ) {
//				self::$instance = new self;
			}

			return self::$instance;
		}
	}
}

// Init the plugin
add_action( 'plugins_loaded', array( 'LevelupCore_Plugin', 'get_instance' ) );


function load_levelup_core_text_domain() {
	load_plugin_textdomain( 'LEVELUP', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}

add_action( 'plugins_loaded', 'load_levelup_core_text_domain' );


register_activation_hook( __FILE__, 'levelup_activationHook' );

if (!function_exists('levelup_activationHook')) {

	function levelup_activationHook(){
		do_action( 'levelup_core_activation_hook' );
	}

}


require_once dirname(__FILE__) . '/post-types.php';

function levelup_get_current_page_name() {

	if ( isset( $GLOBALS['pagenow'] ) && is_admin() ) {
		return $GLOBALS['pagenow'];
	} else {
		return false;
	}

}


/**
 * Customizer Visual Composer
 */
function levelup_core_before_visual_composer() {
	require_once dirname(__FILE__) . '/vc_extend/shortcode-class.php';
	require_once dirname(__FILE__) . '/vc_extend/vc_params.php';

	require_once dirname(__FILE__) . '/vc_extend/fields/rdy-img-set-param.php';
	require_once dirname(__FILE__) . '/vc_extend/fields/rdy-param-heading.php';
	require_once dirname(__FILE__) . '/vc_extend/fields/rdy-postlist.php';
	require_once dirname(__FILE__) . '/vc_extend/fields/rdy-taxonomy.php';
	require_once dirname(__FILE__) . '/vc_extend/fields/rdy-responsive.php';

	require_once dirname(__FILE__) .'/vc_extend/shortcodes/shortcodes-animation.php';
	require_once dirname(__FILE__) .'/vc_extend/vc-extend.php';

	/*if ( function_exists( 'vc_set_default_editor_post_types' ) ) {

		$list = array(
			'page',
			'post',
			'product',
			'rdy_project',
			'rdy_portfolio',
			'rdy_team',
			'rdy_testimonials'
		);

		vc_editor_set_post_types( $list );
		vc_set_default_editor_post_types( $list );

	}*/


	$is_backend = is_admin() || levelup_is_login_page();
	$current_page_name = levelup_get_current_page_name();

	$levelup_shortcodes = array(
		'rdy_portfolio',
		'rdy_portfolio_list',
		'rdy_team',
		'rdy_testimonials',
	);

	if ( $levelup_shortcodes && ( in_array( $current_page_name, array('post.php', 'post-new.php', 'admin-ajax.php') ) || !$is_backend ) ) {
		foreach ( $levelup_shortcodes as $shortcode_dirname ) {
			include_once( dirname(__FILE__) . '/vc_extend/shortcodes/' . $shortcode_dirname . '.php' );
		}
	}

	require_once dirname(__FILE__) . '/vc_extend/shortcodes/shortcodes.php';

	if ( function_exists( 'vc_set_shortcodes_templates_dir' ) ) {
		vc_set_shortcodes_templates_dir( dirname(__FILE__) . '/vc_extend/vc_templates' );
	}

}


function levelup_core_enqueue_scripts () {
	if ( class_exists( 'Vc_Manager', false ) ) {
		wp_deregister_script( 'isotope' );
	}
}


if ( ! function_exists( 'levelup_core_setup' ) ) {

	function levelup_core_setup() {

		define('RDY_IS_LEVELUP', ((defined('LEVELUP_THEME_NAME') && LEVELUP_THEME_NAME == 'LEVELUP') || wp_get_theme() == 'LEVELUP' || wp_get_theme() == 'LEVELUP Child') ? true : false);

		if ( RDY_IS_LEVELUP ) {
			add_action( 'vc_before_init', 'levelup_core_before_visual_composer' );
			add_action( 'wp_enqueue_scripts', 'levelup_core_enqueue_scripts', 14 );

			require_once( dirname( __FILE__ ) . '/theme-init.php' );
		}

		add_filter('widget_text', 'do_shortcode');

	}

}
add_action( 'after_setup_theme', 'levelup_core_setup' );


if ( ! function_exists( 'levelup_redux_register_custom_extension_loader' ) ) {
	function levelup_redux_register_custom_extension_loader( $LevelupReduxFramework ) {
		$path    = dirname( __FILE__ ) . '/redux-extensions/extensions/';
		$folders = scandir( $path, 1 );
		foreach ( $folders as $folder ) {
			if ( $folder === '.' or $folder === '..' or ! is_dir( $path . $folder ) ) {
				continue;
			}

			$extension_class = 'LevelupReduxFramework_Extension_' . $folder;
			if ( ! class_exists( $extension_class ) ) {
				// In case you wanted override your override, hah.
				$class_file = $path . $folder . '/extension_' . $folder . '.php';
				$class_file = apply_filters( 'levelupredux/extension/' . $LevelupReduxFramework->args['opt_name'] . '/' . $folder, $class_file );
				if ( $class_file ) {
					require_once( $class_file );
				}
			}
			if ( ! isset( $LevelupReduxFramework->extensions[ $folder ] ) ) {
				$LevelupReduxFramework->extensions[ $folder ] = new $extension_class( $LevelupReduxFramework );
			}
		}

	}

	add_action( "levelupredux/extensions/levelup_options/before", 'levelup_redux_register_custom_extension_loader', 0 );
}


if ( ! function_exists( 'levelup_wbc_importer_after_page_import' ) ) {

	function levelup_wbc_importer_after_page_import($data, $page) {
		global $wpdb;

		$first_key = key($data);
		$theme = $data[$first_key]['title'];
		$directory = $data[$first_key]['directory'];

		if( class_exists('UniteFunctionsRev') ) {
			$rev_directory = LEVELUP_BASE_DIR . '/inc/demo-data/' . esc_attr( $directory ) . '/revsliders/';

			foreach( glob( $rev_directory . '*.zip' ) as $filename ) {
				foreach ( $page['revslider'] as $slider ) {
					if ( strpos( $filename, $slider ) !== false ) {
						$filename = basename($filename);
						$rev_files[] = $rev_directory . $filename;
					}
				}
			}

			foreach( $rev_files as $rev_file ) {
				$slider   = new RevSlider();
				$response = $slider->importSliderFromPost( $updateAnim = true, $updateStatic = true, $exactfilepath = $rev_file, $is_template = false, $single_slide = false, $updateNavigation = true );
			}

		}

	}

	add_action('wbc_importer_after_page_import', 'levelup_wbc_importer_after_page_import', 10, 2);

}

