<?php
/**
 * Extension-Boilerplate
 *
 * @link https://github.com/ReduxFramework/extension-boilerplate
 *
 * Radium Importer - Modified For ReduxFramework
 * @link https://github.com/FrankM1/radium-one-click-demo-install
 *
 * @package     WBC_Importer - Extension for Importing demo content
 * @author      Webcreations907
 * @version     1.0.2
 */

// Exit if accessed directly
if ( !defined( 'ABSPATH' ) ) exit;

// Don't duplicate me!
if ( !class_exists( 'LevelupReduxFramework_extension_wbc_importer' ) ) {

    class LevelupReduxFramework_extension_wbc_importer {

        public static $instance;

        static $version = "1.0.2";

        protected $parent;

        private $filesystem = array();

        public $extension_url;

        public $extension_dir;

        public $demo_data_dir;

        public $wbc_import_files = array();
        public $wbc_import_pages = array();
        public $wbc_import_pages_data = array();

        public $active_import_id;
        public $active_import;
	    public $active_page_id;

        public $part_final = '';

        public $wbc_import_images = '';
        public $demo_is_options = '';

        public $demo_single = false;
        public $demo_single_ids = array();
        public $is_page_import = false;

        public $demo_media_ids = array();


        /**
         * Class Constructor
         *
         * @since       1.0
         * @access      public
         * @return      void
         */
        public function __construct( $parent ) {

            $this->parent = $parent;

            if ( !is_admin() ) return;

            //Hides importer section if anything but true returned. Way to abort :)
            if ( true !== apply_filters( 'wbc_importer_abort', true ) ) {
                return;
            }

            if ( empty( $this->extension_dir ) ) {
                $this->extension_dir = trailingslashit( str_replace( '\\', '/', dirname( __FILE__ ) ) );
	            if( ABSPATH == '//' ) {
		            $this->extension_url = site_url( $this->extension_dir );
	            } else {
		            $this->extension_url = site_url( str_replace( trailingslashit( str_replace( '\\', '/', ABSPATH ) ), '', $this->extension_dir ) );
	            }
                $this->demo_data_dir = apply_filters( "wbc_importer_dir_path", $this->extension_dir . 'demo-data/' );
            }

            //Delete saved options of imported demos, for dev/testing purpose
            // delete_option('wbc_imported_demos');

            $this->getImports();
            $this->setImportsPages();
            $this->setImportsPagesData();

            $this->field_name = 'wbc_importer';

            self::$instance = $this;

            add_filter( 'levelupredux/' . $this->parent->args['opt_name'] . '/field/class/' . $this->field_name, array( &$this,
                    'overload_field_path'
                ) );

            add_action( 'wp_ajax_levelupredux_wbc_importer', array(
                    $this,
                    'ajax_importer'
                ) );

            add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_files', array(
                    $this,
                    'addImportFiles'
                ) );

            add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_media_ids_js', array(
                    $this,
                    'getMediaIDsJS'
                ), 10, 2 );

            add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_xml', array(
                    $this,
                    'getXML'
                ), 10, 2 );

            add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_main_id', array(
                    $this,
                    'getMainID'
                ) );

	        add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_pages_array', array(
		        $this,
		        'getPagesArray'
	        ), 10, 1 );


	        add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_pages', array(
		        $this,
		        'getImportPages'
	        ) );
	        add_filter( 'levelupredux/'.$this->parent->args['opt_name'].'/field/wbc_importer_pages_data', array(
		        $this,
		        'getImportPagesData'
	        ) );


            //Adds Importer section to panel
            $this->add_importer_section();


        }

        /**
         * Get the demo folders/files
         * Provided fallback where some host require FTP info
         *
         * @return array list of files for demos
         */
        public function demoFiles() {

            $this->filesystem = $this->parent->filesystem->execute( 'object' );
	        if( gettype($this->filesystem) != 'object' ) {
	            return;
	        }
            $dir_array = $this->filesystem->dirlist( $this->demo_data_dir, false, true );

            if ( !empty( $dir_array ) && is_array( $dir_array ) ) {

                uksort( $dir_array, 'strcasecmp' );
                return $dir_array;

            } else {

                $dir_array = array();

                $demo_directory = array_diff( scandir( $this->demo_data_dir ), array( '..', '.' ) );

                if ( !empty( $demo_directory ) && is_array( $demo_directory ) ) {
                    foreach ( $demo_directory as $key => $value ) {
                        if ( is_dir( $this->demo_data_dir.$value ) ) {

                            $dir_array[$value] = array( 'name' => $value, 'type' => 'd', 'files'=> array() );

                            $demo_content = array_diff( scandir( $this->demo_data_dir.$value ), array( '..', '.' ) );

                            foreach ( $demo_content as $d_key => $d_value ) {
                                if ( is_file( $this->demo_data_dir.$value.'/'.$d_value ) ) {
                                    $dir_array[$value]['files'][$d_value] = array( 'name'=> $d_value, 'type' => 'f' );
                                }
                            }
                        }
                    }

                    uksort( $dir_array, 'strcasecmp' );
                }
            }
            return $dir_array;
        }


        public function getImportPagesData() {
        	return $this->wbc_import_pages_data;
        }

        public function setImportsPagesData() {

	        if ( ! empty( $this->wbc_import_pages_data ) ) {
		        return $this->wbc_import_pages_data;
	        }

	        $this->wbc_import_pages_data = array(
		        'blog' => array(
			        'ids' => array(
				        4623,
				        4619,
				        4616,
				        1628,
				        1632,
				        1633,
				        1631,
				        1630,
				        1627,
				        1629,
				        4613,
				        1626,
				        1637,
				        1634,
				        1635,
				        4657,
				        1636,
			        ),
			        'images' => array(
				        7740,
				        4622,
				        4617,
		                4603,
	                    5285,
				        7744,
		                5379,
				        5678,
				        5383,
				        4605,
				        4626,
				        4611,

			        )
		        ),
		        'testimonials' => array(
			        'ids' => array(

			        ),
			        'images' => array(
				        5327,
				        5325,
	                    5326,
				        5333,
			            5330
			        )
		        ),
		        'team' => array(
			        'ids' => array(
				        9300,
				        9299,
				        9298,
				        9293,

				        4371,
						4369,
				        4307,
				        4306,
				        4305,
				        4304,
				        4303,
				        4296,

				        2265,
				        1439,
				        1438,
				        1437,
				        1436,
				        1435,
				        1434,
				        1433,
				        1432,
				        1431,
				        1429,
				        1417,

//				        2689,
//				        2680,
//				        2677,
//				        2676,
//				        2675,
//
//				        2674,
//				        2673,
//				        2682,
//				        2683,
//				        2684,
//				        2685,
//				        2681,
//				        2678,
//				        2679,
//				        2688
			        ),
			        'images' => array(
				        9296,
				        9297,
				        9295,
				        9294,

				        4373,
				        4374,
				        4302,
				        4300,
				        4301,
				        4299,
				        4298,
				        4297,

				        2266,
				        5334,
				        5333,
				        5332,
				        5331,
				        5330,
				        5329,
				        5328,
				        5327,
				        5326,
				        5325,
				        5324,


//				        2708,
//				        2703,
//				        2705,
//				        2698,
//				        2701,
//
//				        2697,
//				        2704,
//				        5965,
//				        2710,
//				        2699,
//				        2696,
//				        2692,
//				        2695,
//				        2693,
//				        2702
			        )
		        ),
		        'portfolio' => array(
			        'ids' => array(
				        2689,
				        2680,
				        2677,
				        2676,
				        2675,

				        2674,
				        2673,
				        2682,
				        2683,
				        2684,
				        2685,
				        2681,
				        2678,
				        2679,
				        2688,

				        3560,
				        3558,
				        3556,
				        3554,
				        3552,
				        3549,
			        ),
			        'images' => array(
				        2708,
				        2703,
				        2705,
				        2698,
				        2701,

				        2697,
				        2704,
				        5965,
				        2710,
				        2699,
				        2696,
				        2692,
				        2695,
				        2693,
				        2702,
				        5510
			        )
		        ),
		        'client_list' => array(
			        'dark' => array(
				        850,
				        851,
				        852,
				        853,
				        854,
				        855,
				        856,
				        857,
				        858,
				        859,
				        860,
				        861,
				        862,
				        863,
				        868
			        ),
			        'light' => array(
				        898,
				        899,
				        900,
				        901,
				        902,
				        903,
				        904,
				        905,
				        906,
				        907,
				        908,
				        909,
				        910,
				        911,
				        912,
			        ),
		        ),
		        'slider_images'=> array(
			        # header_demo
			        2111,
			        2112,
			        2103,
			        2140,

			        # portfolio_slider
			        7487,
			        7497,
			        7498,

			        # home_business
			        7814,

			        # classic_agency
			        8002,
			        7558,
			        8082
		        )
	        );
        }


        public function getImportPages() {
        	return $this->wbc_import_pages;
        }

        public function setImportsPages() {

	        if ( ! empty( $this->wbc_import_pages ) ) {
		        return $this->wbc_import_pages;
	        }

	        $this->wbc_import_pages = array(
		        7778 => array(
			        'id'        => 7778,
			        'group'     => 'Home',
			        'title'     => 'Home – Digital Agency',
			        'preview'   => 'hp_01.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-digital-agency/',
			        'portfolio' => true,
			        'slides'    => true,
			        'images'    => array(
				        7859
			        ),
			        'revslider' => array(
				        'home_business'
			        ),
			        'client_list' => true,
		        ),

		        7887 => array(
			        'id'        => 7887,
			        'group'     => 'Home',
			        'title'     => 'Home – Design Studio',
			        'preview'   => 'hp_02.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-design-studio/',
			        'images'    => array(
				        7965
			        ),
			        'revslider' => array(),
			        'portfolio' => true,
		        ),

		        7960 => array(
			        'id'        => 7960,
			        'group'     => 'Home',
			        'title'     => 'Home – Classic Agency',
			        'preview'   => 'hp_03.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-classic-agency/',
			        'images'    => array(
				        8002,
				        8082,
				        7558
			        ),
			        'revslider' => array(
				        'classic_agency'
			        ),
			        'portfolio' => true,
			        'testimonials' => true,
		        ),

		        8267 => array(
			        'id'        => 8267,
			        'group'     => 'Home',
			        'title'     => 'Home – Barber Shop',
			        'preview'   => 'hp_04.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-barbershop/',
			        'images'    => array(
				        8270,
				        8275,
				        8277,
				        8278,
				        8279,
				        9303,
				        8304,
				        8328
			        ),
			        'team' => true,
			        'revslider' => array()
		        ),

		        8817 => array(
			        'id'        => 8817,
			        'group'     => 'Home',
			        'title'     => 'Home – Application',
			        'preview'   => 'hp_05.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-application/',
			        'images'    => array(
				        8953,
				        8817,
				        8401,
				        8411,
				        8412,
				        8876,
				        8970,
				        8973,
				        8004,
				        8928,
				        8929,
				        8927,
				        8926,
				        8925,
				        8924,
				        8965,
				        8465,
				        8466,
				        8464,
				        8462
			        ),
			        'revslider' => array()
		        ),

		        9429 => array(
			        'id'        => 9429,
			        'group'     => 'Home',
			        'title'     => 'Home – Software as a Service',
			        'preview'   => 'hp_06.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-saas/',
			        'images'    => array(
				        9479,
				        9482,
				        9535,
				        9580,
				        9624,
				        9625,
				        9626,
				        9627,
				        9628,
				        9629
			        ),
			        'revslider' => array(),
			        'testimonials' => true
		        ),

		        8983 => array(
			        'id'        => 8983,
			        'group'     => 'Home',
			        'title'     => 'Home – Product Promo',
			        'preview'   => 'hp_07.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-product/',
			        'images'    => array(
				        8985,
				        3704,
				        8999,
				        9008,
				        9046,
				        9053,
				        9054,
				        9055,
				        9056,
				        9057,
				        9058,
				        9059,
				        9060,
				        9061,
				        9062,
				        9063,
				        9319
			        ),
			        'revslider' => array()
		        ),

		        9144 => array(
			        'id'        => 9144,
			        'group'     => 'Home',
			        'title'     => 'Home – Financial Services',
			        'preview'   => 'hp_08.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/home-financial-services/',
			        'images'    => array(
				        9203,
				        9206,
				        9208,
				        9209,
				        9211
			        ),
			        'revslider' => array(),
			        'team'      => true
		        ),

		        9874 => array(
			        'id'        => 9874,
			        'group'     => 'Home',
			        'title'     => 'Home - Power Your Business',
			        'preview'   => 'hp_power.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/power-your-business/',
			        'images'    => array(

			        ),
			        'revslider' => array(),
			        'blog'      => true,
			        'team'      => true,
			        'portfolio' => true,
			        'client_list_light' => true,
		        ),


		        2050 => array(
			        'id'        => 2050,
			        'group'     => 'About',
			        'title'     => 'About Us Business',
			        'preview'   => 'about_01.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-us-business/',
			        'images'    => array(
				        7168
			        ),
			        'revslider' => array(),
			        'team' => true
		        ),

		        2054 => array(
			        'id'        => 2054,
			        'group'     => 'About',
			        'title'     => 'About Us Business v.2',
			        'preview'   => 'about_02.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-us-business-v-2/',
			        'images'    => array(
				        6341
			        ),
			        'revslider' => array(),
			        'team' => true,
			        'client_list' => true
		        ),

		        2052 => array(
			        'id'        => 2052,
			        'group'     => 'About',
			        'title'     => 'About Us Business v.3',
			        'preview'   => 'about_03.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-us-business-v-3/',
			        'images'    => array(
				        6466
			        ),
			        'revslider' => array(),
			        'team' => true,
			        'client_list' => true
		        ),

		        2039 => array(
			        'id'        => 2039,
			        'group'     => 'About',
			        'title'     => 'About Us Business v.4',
			        'preview'   => 'about_04.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-us-business-v-4/',
			        'images'    => array(
				        6468
			        ),
			        'revslider' => array(),
			        'client_list' => true
		        ),

		        2043 => array(
			        'id'        => 2043,
			        'group'     => 'About',
			        'title'     => 'About Us Creative',
			        'preview'   => 'about_05.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-creative/',
			        'images' => array(
				        2196,
				        6088,
				        6098,
				        6110,
				        7423
			        ),
			        'revslider' => array()
		        ),

		        2151 => array(
			        'id'        => 2151,
			        'group'     => 'About',
			        'title'     => 'About Me',
			        'preview'   => 'about_06.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-me/',
			        'images'    => array(
				        2274
			        ),
			        'revslider' => array()
		        ),

		        2277 => array(
			        'id'        => 2277,
			        'group'     => 'About',
			        'title'     => 'About Me v.2',
			        'preview'   => 'about_07.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/about-me-v-2/',
			        'images'    => array(
				        6121,
				        6174,
				        6175,
				        6182,
				        7226
			        ),
			        'revslider' => array(),
			        'client_list' => true,
		        ),


		        6413 => array(
			        'id'        => 6413,
			        'group'     => 'Services',
			        'title'     => 'Our Services',
			        'preview'   => 'service_01.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/our-services/',
			        'images'    => array(
				        854,
				        857,
				        859,
				        863,
				        851,
				        850,
				        852,
				        868,
				        6447
			        ),
			        'revslider' => array(),
			        'testimonials' => true,
			        'clien_list' => true,
		        ),

		        6470 => array(
			        'id'        => 6470,
			        'group'     => 'Services',
			        'title'     => 'Our services v.2',
			        'preview'   => 'service_02.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/our-services-v-2/',
			        'images'    => array(
				        6555,
				        6464,
				        6468,
				        6450,
				        6341,
				        6447,
				        6451,
				        6452,
				        6453,
				        6463,
				        6466
			        ),
			        'revslider' => array(),
			        'testimonials' => true,
		        ),

		        6582 => array(
			        'id'        => 6582,
			        'group'     => 'Services',
			        'title'     => 'Our services v.3',
			        'preview'   => 'service_03.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/our-service-v-3/',
			        'images'    => array(
				        6610,
				        6642,
				        6463,
			        ),
			        'revslider' => array()
		        ),

		        6579 => array(
			        'id'        => 6579,
			        'group'     => 'Services',
			        'title'     => 'Our services v.4',
			        'preview'   => 'service_04.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/our-services-v-4/',
			        'images'    => array(
				        6451,
				        6463,
				        6655,
				        6464,
				        6447
			        ),
			        'revslider' => array()
		        ),


		        2048 => array(
			        'id'        => 2048,
			        'group'     => 'Contact',
			        'title'     => 'Contact Minimal',
			        'preview'   => 'contact_01.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-minimal/',
			        'images'    => array(
				        5294
			        ),
			        'revslider' => array()
		        ),

		        5076 => array(
			        'id'        => 5076,
			        'group'     => 'Contact',
			        'title'     => 'Contact Minimal v.2',
			        'preview'   => 'contact_02.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-minimal-v-2/',
			        'images'    => array(
				        5077
			        ),
			        'revslider' => array()
		        ),

		        6757 => array(
			        'id'        => 6757,
			        'group'     => 'Contact',
			        'title'     => 'Contact Minimal v.3',
			        'preview'   => 'contact_03.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-minimal-v-3/',
			        'images'    => array(
				        6757
			        ),
			        'revslider' => array()
		        ),

		        2063 => array(
			        'id'        => 2063,
			        'group'     => 'Contact',
			        'title'     => 'Contact Bussiness',
			        'preview'   => 'contact_04.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-bussines/',
			        'images'    => array(),
			        'revslider' => array()
		        ),

		        5124 => array(
			        'id'        => 5124,
			        'group'     => 'Contact',
			        'title'     => 'Contact Bussiness v.2',
			        'preview'   => 'contact_05.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-bussines-v-2/',
			        'images'    => array(),
			        'revslider' => array()
		        ),

		        2067 => array(
			        'id'        => 2067,
			        'group'     => 'Contact',
			        'title'     => 'Contact Bussiness v.3',
			        'preview'   => 'contact_06.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-bussines-v-3/',
			        'images'    => array(
				        5031,
				        2067,
				        2112
			        ),
			        'revslider' => array()
		        ),

		        2065 => array(
			        'id'        => 2065,
			        'group'     => 'Contact',
			        'title'     => 'Contact Bussiness v.4',
			        'preview'   => 'contact_07.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-business-v-4/',
			        'images'    => array(),
			        'revslider' => array()
		        ),

		        2069 => array(
			        'id'        => 2069,
			        'group'     => 'Contact',
			        'title'     => 'Contact Bussiness v.5',
			        'preview'   => 'contact_08.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/contact-business-v-5/',
			        'images'    => array(
				        5047,
				        6085
			        ),
			        'revslider' => array()
		        ),


		        2689 => array(
			        'id'        => 2689,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study One',
			        'preview'   => 'portfolio_01.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/simplicity/',
			        'images'    => array(
				        4798,
				        4806,
				        4800
			        ),
			        'revslider' => array()
		        ),

		        2680 => array(
			        'id'        => 2680,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Two',
			        'preview'   => 'portfolio_02.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/good-wine/',
			        'images'    => array(
				        4841,
				        4842,
				        7593,
			        ),
			        'revslider' => array()
		        ),

		        2678 => array(
			        'id'        => 2678,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Three',
			        'preview'   => 'portfolio_03.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/branding/',
			        'images'    => array(
				        4865,
				        5311,
				        5310,
				        5309,
				        5308,
				        5307
			        ),
			        'revslider' => array()
		        ),

		        2676 => array(
			        'id'        => 2676,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Four',
			        'preview'   => 'portfolio_04.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/elegant/',
			        'images'    => array(
				        4878,
				        4879,
				        4880,
				        4881,
				        4891,
				        4892,
				        4893,
				        4894
			        ),
			        'revslider' => array()
		        ),

		        2674 => array(
			        'id'        => 2674,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Five',
			        'preview'   => 'portfolio_05.jpg',
			        'preview_url'   => 'http://puzzlerbox.com/levelup/portfolio/swiss-chocolate/',
			        'images'    => array(
				        4954,
				        7559,
				        7560,
				        7558,
				        7561,
				        7562,
				        7563,
				        7564
			        ),
			        'revslider' => array()
		        ),

		        2679 => array(
			        'id'        => 2679,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Six',
			        'preview'   => 'portfolio_06.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/beauty-story/',
			        'images'    => array(
				        5800,
				        5802,
				        5803,
				        5804,
				        5805,
				        5807,
				        2701
			        ),
			        'revslider' => array()
		        ),

		        2673 => array(
			        'id'        => 2673,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Seven',
			        'preview'   => 'portfolio_07.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/happiness/',
			        'images'    => array(
				        7399,
				        7398,
				        7397,
				        7396,
				        7395,
				        7400,
				        7407
			        ),
			        'revslider' => array()
		        ),

		        2682 => array(
			        'id'        => 2682,
			        'group'     => 'Portfolio',
			        'title'     => 'Case Study Eight',
			        'preview'   => 'portfolio_08.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/portfolio/sq-logo/',
			        'images'    => array(
				        7486,
				        7488
			        ),
			        'revslider' => array(
				        'portfolio_slider'
			        )
		        ),

		        1417 => array(
			        'id'        => 1417,
			        'group'     => 'Person Page',
			        'title'     => 'Person Page One',
			        'preview'   => 'person_page_01.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/rdy_team/william-laboy/',
			        'images'    => array(
					        5335
			        ),
			        'revslider' => array()
		        ),

		        6185 => array(
			        'id'        => 6185,
			        'group'     => 'Person Page',
			        'title'     => 'Person Page Two',
			        'preview'   => 'person_page_02.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/person-page-two/',
			        'images'    => array(
					        6186
			        ),
			        'revslider' => array()
		        ),

		        6202 => array(
			        'id'        => 6202,
			        'group'     => 'Person Page',
			        'title'     => 'Person Page Three',
			        'preview'   => 'person_page_03.jpg',
			        'preview_url' => 'http://puzzlerbox.com/levelup/person-page-three/',
			        'images'    => array(
					        6214,
					        5326
			        ),
			        'revslider' => array()
		        ),

	        );

        }

        public function getImports() {

            if ( !empty( $this->wbc_import_files ) ) {
                return $this->wbc_import_files;
            }


	        $demo_data = array(

		        'Main Demo'                            => array(
		        	'slug' => 'Main',
			        'preview' => 'http://puzzlerbox.com/levelup/'
		        ), // 0
		        'Award Winning Agency'                 => array(
		        	'slug' => 'Award_Winning_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo2/'
		        ), // 2
		        'Branding Agency'                      => array(
		        	'slug' => 'Branding_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo7/'
		        ), // 7
		        'Film Promotion'                       => array(
		        	'slug' => 'Film_Promotion',
			        'preview' => 'http://puzzlerbox.com/levelup/demo8/'
		        ), // 8
		        'Creative Agency'                      => array(
		        	'slug' => 'Creative_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo12/'
		        ), // 12
		        'Digital Agency'                       => array(
		        	'slug' => 'Digital_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo1/'
		        ), // 1
		        'E-commerce / Shop'                    => array(
		        	'slug' => 'Ecommerce_Shop',
			        'preview' => 'http://levelup-shop1.puzzlerbox.com/'
		        ), // shop1
		        'Creative Director & Graphic Designer' => array(
		        	'slug' => 'Creative_Director_Graphic_Designer',
			        'preview' => 'http://puzzlerbox.com/levelup/demo5/'
		        ), // 5
		        'Slides / Photo Agency'                => array(
		        	'slug' => 'Slides_Photo_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo3/'
		        ), // 3
		        'Law Firm'                             => array(
		        	'slug' => 'Law_Firm',
			        'preview' => 'http://puzzlerbox.com/levelup/demo4/'
		        ), //4
		        'Fitness'                              => array(
		        	'slug' => 'Fitness',
			        'preview' => 'http://puzzlerbox.com/levelup/demo10/'
		        ), // 10
		        'Architectural Bureau'                 => array(
		        	'slug' => 'Architectural_Bureau',
			        'preview' => 'http://puzzlerbox.com/levelup/demo11/'
		        ), // 11
		        'Design Boutique'                      => array(
		        	'slug' => 'Design_Boutique',
			        'preview' => 'http://puzzlerbox.com/levelup/demo13/'
		        ), // 13
		        'Freelancer'                           => array(
		        	'slug' => 'Freelancer',
			        'preview' => 'http://puzzlerbox.com/levelup/demo16/'
		        ), // 16
		        'Coaching'                             => array(
		        	'slug' => 'Coaching',
			        'preview' => 'http://puzzlerbox.com/levelup/demo15/'
		        ), // 15
		        'Photographer'                         => array(
		        	'slug' => 'Photographer',
			        'preview' => 'http://puzzlerbox.com/levelup/demo6/'
		        ), // 6
		        'Slides / Creative Design Agency'      => array(
		        	'slug' => 'Slides_Creative_Design_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo9/'
		        ), // 9
		        'Slides / Design Agency'               => array(
		        	'slug' => 'Slides_Design_Agency',
			        'preview' => 'http://puzzlerbox.com/levelup/demo18/'
		        ), // 18
		        'Coming Soon'                          => array(
		        	'slug' => 'Coming_Soon',
			        'preview' => 'http://puzzlerbox.com/levelup/demo19/'
		        ), // 19

	        );


            $imports = $this->demoFiles();

            $imported = get_option( 'wbc_imported_demos' );

            if ( !empty( $imports ) && is_array( $imports ) ) {
                $x = 1;

                foreach ( $demo_data as $name => $val ) {
	                $item = $val['slug'];

                    if ( !array_key_exists($item, $imports) ) {
                        continue;
                    }

                    $import = $imports[$item];

                    if ( !isset( $import['files'] ) || empty( $import['files'] ) ) {
                        continue;
                    }

                    if ( $import['type'] == "d" && !empty( $import['name'] ) ) {
                        $this->wbc_import_files['wbc-import-'.$x] = isset( $this->wbc_import_files['wbc-import-'.$x] ) ? $this->wbc_import_files['wbc-import-'.$x] : array();
                        $this->wbc_import_files['wbc-import-'.$x]['directory'] = $import['name'];
                        $this->wbc_import_files['wbc-import-'.$x]['title'] = $name;
                        $this->wbc_import_files['wbc-import-'.$x]['preview'] = isset($val['preview']) && $val['preview'] ? $val['preview'] : '';

                        if ( !empty( $imported ) && is_array( $imported ) ) {
                            if ( array_key_exists( 'wbc-import-'.$x, $imported ) ) {
                                $this->wbc_import_files['wbc-import-'.$x]['imported'] = 'imported';
                            }
                        }

                        foreach ( $import['files'] as $file ) {
                            switch ( $file['name'] ) {
//                                case 'content.xml':
//                                    $this->wbc_import_files['wbc-import-'.$x]['content_file'] = $file['name'];
//                                    break;

                                case 'content.data.xml':
                                    $this->wbc_import_files['wbc-import-'.$x]['content_file'] = $file['name'];
                                    break;

                                case 'content.media.xml':
                                    $this->wbc_import_files['wbc-import-'.$x]['content_media_file'] = $file['name'];
                                    break;

                                case 'content.nav.xml':
                                    $this->wbc_import_files['wbc-import-'.$x]['content_nav_file'] = $file['name'];
                                    break;

                                case 'theme-options.txt':
                                case 'theme-options.json':
                                    $this->wbc_import_files['wbc-import-'.$x]['theme_options'] = $file['name'];
                                    break;

                                case 'widgets.json':
                                case 'widgets.txt':
                                    $this->wbc_import_files['wbc-import-'.$x]['widgets'] = $file['name'];
                                    break;

                                case 'screen-image.png':
                                case 'screen-image.jpg':
                                case 'screen-image.gif':
                                    $this->wbc_import_files['wbc-import-'.$x]['image'] = $file['name'];
                                    break;
                            }

                        }

                        if ( !isset( $this->wbc_import_files['wbc-import-'.$x]['content_file'] ) ) {
                            unset( $this->wbc_import_files['wbc-import-'.$x] );
                            if ( $x > 1 ) $x--;
                        }

                    }

                    $x++;
                }

            }

        }

	    public function getXML( $directory, $type = 'data' ) {

        	foreach ($this->wbc_import_files as $value) {
        		if($value['directory'] == $directory) {
        			if ( $type == 'media' ) {
        				$filename = $value['content_media_file'];
			        } else {
				        $filename = $value['content_file'];
			        }
					return $this->demo_data_dir . $value['directory'] . '/' . $filename;
		        }
	        }

	        return false;
        }

	    public function getMediaIDsJS( $directory ) {

        	foreach ($this->wbc_import_files as $value) {
		        if ( $value['directory'] == $directory ) {
			        $media_ids_file = $this->demo_data_dir . $value['directory'] . '/media_data.txt';
			        $media_ids = @file_get_contents($media_ids_file);

			        if ( $media_ids ) {
				        $media_ids_chunks = @array_chunk( @array_map( 'intval', @explode( ',', $media_ids ) ), 8 );

				        if ( count( $media_ids_chunks ) ) {
					        return json_encode( $media_ids_chunks );
				        }
			        }
		        }
	        }

	        return false;
        }


	    public function getPagesArray( $directory ) {

		    foreach ( $this->wbc_import_files as $value ) {
			    if ( $value['directory'] == $directory ) {
				    $file      = $this->demo_data_dir . $value['directory'] . '/pages_data.txt';
				    $pages_ids = @unserialize( @file_get_contents( $file ) );

				    return $pages_ids;
			    }
		    }

	        return false;
        }

        public function getMainID() {

        	foreach ($this->wbc_import_files as $key => $value) {
        		if($value['directory'] == 'Main') {
					return $key;
		        }
	        }

	        return false;
        }

        public function getPagesIDs() {

	        if ( $this->active_page_id && isset( $this->wbc_import_pages[ $this->active_page_id ] ) ) {
		        $page = $this->wbc_import_pages[$this->active_page_id];

		        $ids = (array)$this->active_page_id;
		        if ( isset( $page['portfolio'] ) && $page['portfolio'] && isset( $this->wbc_import_pages_data['portfolio']['ids'] ) ) {
			        $ids = array_merge( $ids, $this->wbc_import_pages_data['portfolio']['ids'] );
		        }
//		        if ( isset( $page['client_list'] ) && $page['client_list'] && isset( $this->wbc_import_pages_data['client_list']['dark'] ) ) {
//			        $ids = array_merge( $ids, $this->wbc_import_pages_data['client_list']['dark'] );
//		        }
		        if ( isset( $page['team'] ) && $page['team'] && isset( $this->wbc_import_pages_data['team']['ids'] ) ) {
			        $ids = array_merge( $ids, $this->wbc_import_pages_data['team']['ids'] );
		        }
		        if ( isset( $page['testimonials'] ) && $page['testimonials'] && isset( $this->wbc_import_pages_data['testimonials']['ids'] ) ) {
			        $ids = array_merge( $ids, $this->wbc_import_pages_data['testimonials']['ids'] );
		        }
		        if ( isset( $page['blog'] ) && $page['blog'] && isset( $this->wbc_import_pages_data['blog']['ids'] ) ) {
			        $ids = array_merge( $ids, $this->wbc_import_pages_data['blog']['ids'] );
		        }

		        return $ids;
	        }

	        return false;
        }

        public function addImportFiles( $wbc_import_files ) {

            if ( !is_array( $wbc_import_files ) || empty( $wbc_import_files ) ) {
                $wbc_import_files = array();
            }

            $wbc_import_files = wp_parse_args( $wbc_import_files, $this->wbc_import_files );

            return $wbc_import_files;
        }

        public function ajax_importer() {

	        remove_action( 'template_redirect', 'rest_output_link_header', 11, 0 );

            if ( !isset( $_REQUEST['nonce'] ) || !wp_verify_nonce( $_REQUEST['nonce'], "levelupredux_{$this->parent->args['opt_name']}_wbc_importer" ) ) {
                die( 0 );
            }

            if ( isset( $_REQUEST['type'] ) && $_REQUEST['type'] == "remove-demo-media" ) {
            	$this->remove_demo_media();
				echo 'remove-demo-media';
				exit();
            } elseif ( isset( $_REQUEST['type'] ) && $_REQUEST['type'] == "import-demo-content" && array_key_exists( $_REQUEST['demo_import_id'], $this->wbc_import_files ) ) {

                $reimporting = false;

                if ( isset( $_REQUEST['wbc_import'] ) && $_REQUEST['wbc_import'] == 're-importing' ) {
                    $reimporting = true;
                }

                $this->demo_page_id = $_REQUEST['demo_page_id'];
                $this->active_import_id = $_REQUEST['demo_import_id'];
	            $this->wbc_import_images = ( isset( $_REQUEST['wbc_import_images'] ) && ! isset( $_REQUEST['demo_page_id'] ) ) ? esc_attr( $_REQUEST['wbc_import_images'] ) : '';
	            $this->demo_is_options = isset( $_REQUEST['demo_is_options'] ) && $_REQUEST['demo_is_options'] ? true : false;

	            $this->demo_single = ( isset( $_REQUEST['demo_single'] ) || isset( $_REQUEST['demo_page_id'] ) ) ? true : false;

	            if ( $this->demo_single ) {
		            $reimporting = true;

		            $ids_array = array();

		            if ( isset( $_REQUEST['demo_page_id'] ) ) {
		            	$this->is_page_import = true;
			            $this->active_page_id = $_REQUEST['demo_page_id'];
			            $this->demo_single_ids = $this->getPagesIDs();

			            #$this->demo_single_ids = array( $_REQUEST['demo_page_id'] );
		            } else {
			            if ( isset( $_REQUEST['post'] ) ) {
				            foreach ( $_REQUEST['post'] as $key => $single_id ) {
					            $ids_array[] = $single_id;
				            }
			            }

			            if ( isset( $_REQUEST['page'] ) ) {
				            foreach ( $_REQUEST['page'] as $key => $single_id ) {
					            $ids_array[] = $single_id;
				            }
			            }

			            if ( isset( $_REQUEST['rdy_portfolio'] ) ) {
				            foreach ( $_REQUEST['rdy_portfolio'] as $key => $single_id ) {
					            $ids_array[] = $single_id;
				            }
			            }

			            if ( isset( $_REQUEST['product'] ) ) {
				            foreach ( $_REQUEST['product'] as $key => $single_id ) {
					            $ids_array[] = $single_id;
				            }
			            }

			            if ( isset( $_REQUEST['part_type'] ) && $_REQUEST['part_type'] == 'data' && sizeof( $ids_array ) ) {
				            $ids_array             = array_unique( $ids_array );
				            $this->demo_single_ids = $ids_array;
			            }
		            }

	            }

                $import_parts        = $this->wbc_import_files[$this->active_import_id];

                $this->active_import = array( $this->active_import_id => $import_parts );


	            if ( isset( $_REQUEST['part_type'] ) && $_REQUEST['part_type'] == 'media' ) {
		            $content_file_xml = $import_parts['content_media_file'];

		            if ( isset( $_REQUEST['media_part_ids'] ) ) {
		            	$this->demo_media_ids = explode(',', $_REQUEST['media_part_ids']);
		            }

	            } else if ( isset( $_REQUEST['part_type'] ) && $_REQUEST['part_type'] == 'nav' ) {
		            $content_file_xml = $import_parts['content_nav_file'];

	            } else {
		            $content_file_xml = $import_parts['content_file'];

	            }

	            if ( isset( $_REQUEST['part_type'] ) && $_REQUEST['part_type'] != 'data' ) { //  && isset( $_REQUEST['part_last'] ) && $_REQUEST['part_last'] == '1'
		            $this->part_final = 'skip';
	            }

	            $this->wbc_import_files[$this->active_import_id]['current_file'] = $content_file_xml;

                $content_file        = $import_parts['directory'];
                $demo_data_loc       = $this->demo_data_dir . $content_file;

	            if ( file_exists( $demo_data_loc . '/' . $content_file_xml ) && is_file( $demo_data_loc . '/' . $content_file_xml ) ) {

//                    if ( !isset( $import_parts['imported'] ) || true === $reimporting ) {
                        include $this->extension_dir . 'inc/init-installer.php';
	                    ob_start();
	                    $installer = new Radium_Theme_Demo_Data_Importer( $this, $this->parent );
	                    $errors = ob_get_clean();
	                    wp_send_json_success( array( 'msg' => __( 'Demo content was imported.', 'LEVELUP' ) ) );

//                    }else {
//                        echo esc_html__( "Demo Already Imported", 'LEVELUP' );
//                    }
                }

                die();
            }

            die();
        }

        public static function get_instance() {
            return self::$instance;
        }


		public function remove_demo_media() {
			global $wpdb;

			$s_string = $wpdb->esc_like( '(demo media)' );
			$s_string = '%' . $s_string . '%';
			$sql = "SELECT ID FROM $wpdb->posts WHERE post_title LIKE %s";
			$sql = $wpdb->prepare( $sql, $s_string );
			$matching_ids = $wpdb->get_results( $sql, OBJECT );
			foreach ($matching_ids as $key => $value) {
				wp_delete_attachment($value->ID, true);
			}

		}
		
        // Forces the use of the embeded field path vs what the core typically would use
        public function overload_field_path( $field ) {
            return dirname( __FILE__ ) . '/' . $this->field_name . '/field_' . $this->field_name . '.php';
        }

        function add_importer_section() {
            // Checks to see if section was set in config of redux.
            for ( $n = 0; $n <= count( $this->parent->sections ); $n++ ) {
                if ( isset( $this->parent->sections[$n]['id'] ) && $this->parent->sections[$n]['id'] == 'wbc_importer_section' ) {
                    return;
                }
            }

            $wbc_importer_label = trim( esc_html( apply_filters( 'wbc_importer_label', esc_html__( 'Demo Importer', 'LEVELUP' ) ) ) );

            $wbc_importer_label = ( !empty( $wbc_importer_label ) ) ? $wbc_importer_label : esc_html__( 'Demo Importer', 'LEVELUP' );

            $this->parent->sections[] = array(
                'id'     => 'wbc_importer_section',
                'title'  => $wbc_importer_label,
                'desc'   => '',
                'icon'   => 'rdy-icon import',
                'fields' => array(
                    array(
                        'id'   => 'wbc_demo_importer',
                        'type' => 'wbc_importer',
                        'full_width' => true,
                    )
                )
            );
        }

    } // class
} // if
