<?php
/**
 * Extension-Boilerplate
 * @link https://github.com/ReduxFramework/extension-boilerplate
 *
 * Radium Importer - Modified For ReduxFramework
 * @link https://github.com/FrankM1/radium-one-click-demo-install
 *
 * @package     WBC_Importer - Extension for Importing demo content
 * @author      Webcreations907
 * @version     1.0.1
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

// Don't duplicate me!
if ( ! class_exists( 'LevelupReduxFramework_wbc_importer' ) ) {

	/**
	 * Main ReduxFramework_wbc_importer class
	 *
	 * @since       1.0.0
	 */
	class LevelupReduxFramework_wbc_importer {

		/**
		 * Field Constructor.
		 *
		 * @since       1.0.0
		 * @access      public
		 * @return      void
		 */
		function __construct( $field = array(), $value = '', $parent ) {
			$this->parent = $parent;
			$this->field  = $field;
			$this->value  = $value;

			$class = LevelupReduxFramework_extension_wbc_importer::get_instance();


			if ( ! empty( $class->demo_data_dir ) ) {
				$this->demo_data_dir = $class->demo_data_dir;
				if ( ABSPATH == '//' ) {
					$this->demo_data_url = site_url( $this->demo_data_dir );
				} else {
					$this->demo_data_url = site_url( str_replace( trailingslashit( str_replace( '\\', '/', ABSPATH ) ), '', $this->demo_data_dir ) );
				}

			}

			if ( empty( $this->extension_dir ) ) {
				$this->extension_dir = trailingslashit( str_replace( '\\', '/', dirname( __FILE__ ) ) );
				if ( ABSPATH == '//' ) {
					$this->extension_url = site_url( $this->extension_dir );
				} else {
					$this->extension_url = site_url( str_replace( trailingslashit( str_replace( '\\', '/', ABSPATH ) ), '', $this->extension_dir ) );
				}
			}
		}

		/**
		 * Field Render Function.
		 *
		 * @since       1.0.0
		 * @access      public
		 * @return      void
		 */
		public function render() {

			$nonce = wp_create_nonce( "levelupredux_{$this->parent->args['opt_name']}_wbc_importer" );

			?>
			<div id="levelup_importing_overlay">
				<div class="levelup_importing_overlay_wrap">
					<div class="levelup_import_box">
						<div class="import_loader"><img
								src="<?php echo LEVELUP_THEME_TEMPLATE_URL; ?>\admin/assets/images/loading.svg"
								width="40" height="40"></div>

						<div class="import_error_notices">
							<p><?php esc_html_e( 'Oops, something has gone wrong! ', 'LEVELUP' );
								esc_html_e( 'The critical mistake has arose, which has interrupted the procedure of demo import.', 'LEVELUP' ); ?>
								<span></span></p>
						</div>

						<div class="import_logs">
							<p style="display: block"><?php _e( 'The import of content is in process.', 'LEVELUP' ); ?>
								<br><?php _e( 'This procedure could take some time to complete.', 'LEVELUP' ); ?></p>

							<p class="levelup_import_part_media"
							   data-text-importing="<?php _e( 'Importing media data... <span></span>', 'LEVELUP' ); ?>"
							   data-text-done="<?php esc_html_e( 'Importing media data - Done.', 'LEVELUP' ); ?>"></p>
							<p class="levelup_import_part_data"
							   data-text-importing="<?php esc_html_e( 'Importing content data...', 'LEVELUP' ); ?>"
							   data-text-done="<?php esc_html_e( 'Importing content data - Done.', 'LEVELUP' ); ?>"></p>
							<p class="levelup_import_part_refresh"><?php esc_html_e( 'Wait a few seconds before refreshing a page.', 'LEVELUP' ); ?></p>
						</div>
					</div>
				</div>
			</div>

			<div class="environment" style="background: #f3f3f3; padding: 20px">
				<div class="col-8">
					<p class="description"><?php echo esc_html__( 'On this page you will be able to import with one click both separate pages from Main Demo (our main demo site), and the Pre-build Demos and Pre-build Pages which are prepared for using right after the import.', 'LEVELUP' ); ?></p>
					<br>
					<p><b><?php esc_html_e( 'Important!', 'LEVELUP' ); ?></b></p><br>

					<ul class="info">
						<li><?php esc_html_e('Please reassure that technical requirements for normal work of LEVELUP theme are performed.'); ?></li>
						<li><?php esc_html_e('We recommend to import demo content on clean installation of WordPress.'); ?></li>
						<li><?php esc_html_e('In case you plan to import of the Shop Demo, before that it is necessary to install and to activate plugin WooCommerce.'); ?></li>
					</ul>
				</div>

				<div class="col-4">

					<div class="rs-dash-widget">
						<div class="rs-dash-title-wrap rs-status-green-wrap">
							<div class="rs-dash-title">System Requirements</div>
						</div>
						<div class="rs-dash-widget-inner">
							<span class="rs-dash-label"><?php esc_html_e( 'WP Memory Limit', 'LEVELUP' ); ?></span>

							<?php
							$text_err = '';
							$memory = levelup_size_to_num( WP_MEMORY_LIMIT );
							$text = esc_html('Currently: ', 'LEVELUP') . size_format( $memory );

							if ( $memory < 134217728 ) {
								$text_err = '<div class="se_error">' . sprintf( wp_kses( __( '%s - We recommend setting memory to at least 128MB. See: <a href="%s" target="_blank">Increasing memory allocated to PHP</a>', 'LEVELUP' ), array(
										'a' => array(
											'href'   => array(),
											'target' => array()
										)
									) ), size_format( $memory ), 'http://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP' ) . '</div>';
								$icon = 'revredicon eg-icon-cancel fa fa-close';
							} else {
								$icon = 'revgreenicon eg-icon-ok fa fa-check';
							}

							echo '<i style="margin-right:20px" class="' . $icon . '"></i><span class="rs-dash-strong-content">' . $text . '</span>';
							if ( $text_err ) {
								echo $text_err;
							}

							?>

							<?php
							if ( function_exists( 'ini_get' ) ) {
							?>

							<div class="rs-dash-content-space-small"></div>

							<span class="rs-dash-label"><?php esc_html_e( 'Server Memory Limit', 'LEVELUP' ); ?></span>
								<?php
								$text_err = '';
								$memory_limit = (int) substr( @ini_get( 'memory_limit' ), 0, - 1 );
								$text = esc_html('Currently: ', 'LEVELUP') . esc_attr( $memory_limit ) . ' MB';

								if ( $memory_limit < 128 ) {
									$text_err = '<div class="se_error">' . sprintf( wp_kses( __( '%s MB - We recommend setting memory to at least 128MB. See: <a href="%s" target="_blank">Increasing memory allocated to PHP</a>', 'LEVELUP' ), array(
											'a' => array(
												'href'   => array(),
												'target' => array()
											)
										) ), $memory_limit, 'http://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP' ) . '</div>';
									$icon = 'revredicon eg-icon-cancel fa fa-close';
								} else {
									$icon = 'revgreenicon eg-icon-ok fa fa-check';
								}

								echo '<i style="margin-right:20px" class="' . $icon . '"></i><span class="rs-dash-strong-content">' . $text . '</span>';
								if ( $text_err ) {
									echo $text_err;
								}

								?>

							<div class="rs-dash-content-space-small"></div>

							<span class="rs-dash-label"><?php esc_html_e( 'Maximum execution time', 'LEVELUP' ); ?></span>

								<?php
								$text_err = '';
								$max_execution_time = (int) @ini_get( 'max_execution_time' );
								$text = esc_html('Currently: ', 'LEVELUP') . esc_attr( $max_execution_time );

								if ( $max_execution_time < 120 ) {
									$text_err = '<div class="se_error">' . sprintf( wp_kses( __( '%s - Recomended min value 120. See: <a href="%s" target="_blank">Maximum execution time exceeded</a>', 'LEVELUP' ), array(
											'a' => array(
												'href'   => array(),
												'target' => array()
											)
										) ), esc_attr( $max_execution_time ), 'https://codex.wordpress.org/Common_WordPress_Errors#Maximum_execution_time_exceeded' ) . '</div>';
									$icon = 'revredicon eg-icon-cancel fa fa-close';
								} else {
									$icon = 'revgreenicon eg-icon-ok fa fa-check';
								}

								echo '<i style="margin-right:20px" class="' . $icon . '"></i><span class="rs-dash-strong-content">' . $text . '</span>';
								if ( $text_err ) {
									echo $text_err;
								}

								?>

							<div class="rs-dash-content-space-small"></div>

							<span class="rs-dash-label"><?php esc_html_e( 'Maximum input vars', 'LEVELUP' ); ?></span>

								<?php
								$text_err = '';
								$max_input_vars = (int) @ini_get( 'max_input_vars' );
								$text = esc_html('Currently: ', 'LEVELUP') . esc_attr( $max_input_vars );
								if ( $max_input_vars < 5000 ) {
									$text_err = '<div class="se_error">' . sprintf( wp_kses( __( '%s - Recomended min value 5000.', 'LEVELUP' ), array(
											'a' => array(
												'href'   => array(),
												'target' => array()
											)
										) ), esc_attr( $max_input_vars ) ) . '</div>';
									$icon = 'revredicon eg-icon-cancel fa fa-close';

								} else {
									$icon = 'revgreenicon eg-icon-ok fa fa-check';
								}

								echo '<i style="margin-right:20px" class="' . $icon . '"></i><span class="rs-dash-strong-content">' . $text . '</span>';
								if ( $text_err ) {
									echo $text_err;
								}

								?>

								<?php
							}
							?>

						</div>
					</div>

					<table class="import_requirements" style="max-width: 800px;display: none;">
						<thead>
						<tr>
							<td style="font-size: 16px"><b><?php esc_html_e( 'Server Environment', 'LEVELUP' ); ?></b></td>
							<td></td>
							<td></td>
						</tr>
						</thead>

						<tr>
							<td><?php esc_html_e( 'WP Memory Limit', 'LEVELUP' ); ?>:</td>
							<td class="help"><?php echo '<a href="#" class="help_tip" data-tip="' . esc_attr__( 'The maximum amount of memory (RAM) that your site can use at one time.', 'LEVELUP' ) . '">[?]</a>'; ?></td>
							<td><?php
								$memory = levelup_size_to_num( WP_MEMORY_LIMIT );
								if ( $memory < 134217728 ) {
									echo '<mark class="error">' . sprintf( wp_kses( __( '%s - We recommend setting memory to at least 128MB. See: <a href="%s" target="_blank">Increasing memory allocated to PHP</a>', 'LEVELUP' ), array(
											'a' => array(
												'href'   => array(),
												'target' => array()
											)
										) ), size_format( $memory ), 'http://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP' ) . '</mark>';
								} else {
									echo '<mark class="yes">' . size_format( $memory ) . '</mark>';
								}
								?></td>
						</tr>
						<?php
						if ( function_exists( 'ini_get' ) ) {
							?>
							<tr>
								<td><?php esc_html_e( 'Server Memory Limit', 'LEVELUP' ); ?>:</td>
								<td class="help"><?php echo '<a href="#" class="help_tip" data-tip="' . esc_attr__( 'This is actually the real memory available for your installation despite the WP memory limit.', 'LEVELUP' ) . '">[?]</a>'; ?></td>
								<td class="real-memory">
									<?php
									$memory_limit = (int) substr( @ini_get( 'memory_limit' ), 0, - 1 );

									if ( $memory_limit < 128 ) {
										echo '<mark class="error">' . sprintf( wp_kses( __( '%s MB - We recommend setting memory to at least 128MB. See: <a href="%s" target="_blank">Increasing memory allocated to PHP</a>', 'LEVELUP' ), array(
												'a' => array(
													'href'   => array(),
													'target' => array()
												)
											) ), $memory_limit, 'http://codex.wordpress.org/Editing_wp-config.php#Increasing_memory_allocated_to_PHP' ) . '</mark>';
									} else {
										echo '<mark class="yes">' . esc_attr( $memory_limit ) . ' MB</mark>';
									}
									?>
								</td>
							</tr>
							<tr>
								<td><?php esc_html_e( 'Maximum execution time', 'LEVELUP' ); ?>:</td>
								<td class="help"></td>
								<td class="">
									<?php
									$max_execution_time = (int) @ini_get( 'max_execution_time' );
									if ( $max_execution_time < 120 ) {
										echo '<mark class="error">' . sprintf( wp_kses( __( '%s - Recomended min value 120. See: <a href="%s" target="_blank">Maximum execution time exceeded</a>', 'LEVELUP' ), array(
												'a' => array(
													'href'   => array(),
													'target' => array()
												)
											) ), esc_attr( $max_execution_time ), 'https://codex.wordpress.org/Common_WordPress_Errors#Maximum_execution_time_exceeded' ) . '</mark>';
									} else {
										echo '<mark class="yes">' . esc_attr( $max_execution_time ) . '</mark>';
									}
									?>
								</td>
							</tr>
							<tr>
								<td><?php esc_html_e( 'Maximum input vars', 'LEVELUP' ); ?>:</td>
								<td class="help"></td>
								<td class="">
									<?php
									$max_input_vars = (int) @ini_get( 'max_input_vars' );
									if ( $max_input_vars < 5000 ) {
										echo '<mark class="error">' . sprintf( wp_kses( __( '%s - Recomended min value 5000.', 'LEVELUP' ), array(
												'a' => array(
													'href'   => array(),
													'target' => array()
												)
											) ), esc_attr( $max_input_vars ) ) . '</mark>';
									} else {
										echo '<mark class="yes">' . esc_attr( $max_input_vars ) . '</mark>';
									}
									?>
								</td>
							</tr>
							<?php
						}
						?>
					</table>
				</div>
			</div>




			<?php


			$main_pages = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_pages", 'Main' );

			$main_pages_data = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_pages_data", 'Main' );

			$media_ids_js = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_media_ids_js", 'Main' );

			$this->field['wbc_demo_imports'] = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_files", array() );

			$main_pages_array = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_pages_array", 'Main' );
			$main_demo_id     = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_main_id", array() );

			echo '<fieldset class="levelupredux-field wbc_importer wbc_importer_main">';

			$defaults    = array(
				'id'         => '',
				'url'        => '',
				'width'      => '',
				'height'     => '',
				'thumbnail'  => '',
				'full_width' => true,
				'overflow'   => 'inherit',
			);
			$this->value = wp_parse_args( $this->value, $defaults );

			echo '<h3>' . esc_html__( 'Import Main Demo', 'LEVELUP' ) . '</h3>';
			echo '<div class="theme-browser"><div class="themes col-4">';

			if ( ! empty( $this->field['wbc_demo_imports'] ) ) {

				foreach ( $this->field['wbc_demo_imports'] as $section => $imports ) {

					if ( empty( $this->field['wbc_demo_imports'] ) || $imports['directory'] != 'Main' ) {
						continue;
					}

					$extra_class    = 'not-imported';
					$imported       = false;
					$import_message = esc_html__( 'Import Demo', 'LEVELUP' );
					$parts          = '';
					$parts_array    = array();
					$media_ids_data = '';
					if ( isset( $imports['content_media_file'] ) ) {
						$parts_array[] = 'media';
					}
					if ( isset( $imports['content_file'] ) ) {
						$parts_array[] = 'data';
					}

					if ( ! empty( $parts_array ) ) {
						$parts = implode( ',', $parts_array );
					}


					if ( isset( $imports['content_media_file'] ) ) {
						$media_ids_js = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_media_ids_js", $imports['directory'] );
						if ( $media_ids_js ) {
							$media_ids_data = ' data-media_ids="' . $media_ids_js . '"';
						}
					}


					echo '<div class="wrap-importer theme ' . $extra_class . '"  data-demo-id="' . esc_attr( $section ) . '" data-demo_main="' . ( $imports['directory'] == 'Main' ? 1 : 0 ) . '"  data-nonce="' . $nonce . '" data-parts="' . esc_attr( $parts ) . '" id="' . $this->field['id'] . '-custom_imports"' . $media_ids_data . '>';

					echo '<div class="theme-screenshot">';
					if ( isset( $imports['image'] ) ) {
						echo '<img class="wbc_image" src="' . esc_attr( esc_url( $this->demo_data_url . $imports['directory'] . '/' . $imports['image'] ) ) . '"/>';

					}
					echo '<span class="more-details">' . $import_message . '</span>';
					echo '</div>';


					echo '<h3 class="theme-name">' . esc_html( apply_filters( 'wbc_importer_directory_title', $imports['title'] ) ) . '</h3>';

					echo '<div class="theme-actions">';
					echo '<div class="wbc-importer-buttons"><span class="spinner">' . esc_html__( 'Please Wait...', 'LEVELUP' ) . '</span><span class="button-primary importer-button import-demo-data">' . esc_html__( 'Import', 'LEVELUP' ) . '</span></div>';
					echo '</div>';
					echo '</div>';

				}

			} else {
				echo "<h5>" . esc_html__( 'No Demo Data Provided', 'LEVELUP' ) . "</h5>";
			}

			echo '</div>';
			?>


			<div id="dialog-import-single-confirm" title="<?php esc_html_e('Selective Import of Main Demo', 'LEVELUP'); ?>">
				<p><?php echo wp_kses( __('<b>Important!</b> If you have already set up your site but want to import additional pages or other elements, be attentive with the setting Тheme Options!<br><br> If Тheme Options is chosen, while importing demo content the settings of importing pages will <b>rewrite the current theme settings.</b>', 'LEVELUP') , array( 'br' => array(), 'b' => array() ) ); ?></p>
			<br>
			</div>
			<div id="dialog-import-confirm" title="<?php esc_html_e('Import Demo', 'LEVELUP'); ?>">
				<p><?php echo wp_kses( __('<b>Important!</b> If you have already set up your site but want to import additional pages or other elements, be attentive with the setting Тheme Options!<br><br> If Тheme Options is chosen, while importing demo content the settings of importing pages will <b>rewrite the current theme settings.</b>', 'LEVELUP') , array( 'br' => array(), 'b' => array() ) ); ?></p><br>
			</div>
			

			<div class="themes col-4">
				<span
					class="levelup_import_images_settings_title"><?php esc_html_e( 'Media files settings for Main demo and Selective Import', 'LEVELUP' ); ?></span>
				<span
					class="levelup_import_images_settings_desc"><?php echo wp_kses( __( 'Use these settings for choosing the import variant of «heavy» demos,<br> namely Main Demo.', 'LEVELUP' ), array( 'br' => array() ) ); ?></span>
				<span class="levelup_import_images">
				<select class="demo_importer_images noUpdate">

					<option value="placeholder"><?php esc_html_e( 'Placeholders', 'LEVELUP' ); ?></option>
					<option value=""><?php esc_html_e( 'All media data include', 'LEVELUP' ); ?></option>

				</select>
				</span>
			</div>

			<div class="themes col-4 delete-media">
				<div class="border">
				<h3><?php esc_html_e('Delete Demo Media', 'LEVELUP');?></h3>
				<p><?php esc_html_e('For quick cleaning of downloaded demo media files use the button "Delete Demo Media". All the media files that were downloaded while demo content import will be deleted. It saves your time and speeds up the work.', 'LEVELUP');?></p>
				<br>
				<br>
				<input type="submit" name="levelup_demomedia_delete" id="levelupredux-demomedia-delete" class="button"
				       value="Delete Media" data-nonce="<?php echo $nonce; ?>">
				</div>
			</div>

			<?php
			echo '</div>';
			echo '</fieldset>';
			?>

			<p class="levelup_import_guide" style="display: none;">
				<?php echo wp_kses( '<b>All media data included</b> – import of all the layouts and media files in such view as you see them on the demo site in Internet.', array( 'b' => array() ) ); ?>
				<br>
				<br>
				<?php echo wp_kses( '<b>Placeholders</b> – import of all the layouts, but main part of “heavy file size” images is replaced by stub images, that is why this very version differs from that one you see on the demo site in Internet. The loading speed is becoming higher.', array( 'b' => array() ) ); ?>
				<br>
				<br>
				<span style="font-size: 12px">* Variants of downloading are available only for Main Demo.</span>
			</p>

			<hr>

			<?php

			if ( $media_ids_js ) {
				$media_ids_data = ' data-media_ids="' . $media_ids_js . '"';
			}


			$post_array      = array();
			$page_array      = array();
			$portfolio_array = array();
			$product_array   = array();

			if ( isset( $main_pages_array ) ) {
				if ( isset( $main_pages_array['post'] ) ) {
					$post_array = $main_pages_array['post'];
				}

				if ( isset( $main_pages_array['page'] ) ) {
					$page_array = $main_pages_array['page'];
				}

				if ( isset( $main_pages_array['portfolio'] ) ) {
					$portfolio_array = $main_pages_array['portfolio'];
				}

				if ( isset( $main_pages_array['product'] ) ) {
					$product_array = $main_pages_array['product'];
				}

			}

			$is_woocommerce = class_exists( 'WooCommerce' );
			?>

			<div class="levelup_import_single_demo">
				<h3><?php esc_html_e( 'Selective Import of Main Demo', 'LEVELUP' ); ?></h3>
				<p class="levelup_import_single_desc"><?php esc_html_e( 'Selective import panel enables to import only those layout pages from Main Demo, which you need, not the entire rather sizeable Main Demo fully.', 'LEVELUP' ); ?></p>

				<div class="levelup-import-import-form import-singles" data-demo-id="<?php echo $main_demo_id; ?>"
				     data-parts="media,data" data-demo_main="1"
				     data-nonce="<?php echo $nonce; ?>"<?php echo $media_ids_data; ?>>
					<div class="levelup-import-single-col"
					     style="width:<?php echo ( $is_woocommerce ) ? '25' : '33.3333' ?>%;">
						<h4><?php esc_html_e( 'Posts', 'LEVELUP' ); ?></h4>
						<select class="noUpdate" name="post[]" multiple>
							<?php
							ksort( $post_array );
							foreach ( $post_array as $key => $value ) {
								echo '<option value="' . esc_attr( implode( ',', $value['ids'] ) ) . '">' . $key . '</option>';
							}
							?>
						</select>
					</div>
					<div class="levelup-import-single-col"
					     style="width:<?php echo ( $is_woocommerce ) ? '25' : '33.3333' ?>%;">
						<h4><?php esc_html_e( 'Pages', 'LEVELUP' ); ?></h4>
						<select class="noUpdate" name="page[]" multiple>
							<?php
							ksort( $page_array );
							foreach ( $page_array as $key => $value ) {
								echo '<option value="' . esc_attr( implode( ',', $value['ids'] ) ) . '">' . $key . '</option>';
							}
							?>
						</select>
					</div>
					<div class="levelup-import-single-col"
					     style="width:<?php echo ( $is_woocommerce ) ? '25' : '33.3333' ?>%;">
						<h4><?php esc_html_e( 'Portfolio Page', 'LEVELUP' ); ?></h4>
						<select class="noUpdate" name="rdy_portfolio[]" multiple>
							<?php
							ksort( $portfolio_array );
							foreach ( $portfolio_array as $key => $value ) {
								echo '<option value="' . esc_attr( implode( ',', $value['ids'] ) ) . '">' . $key . '</option>';
							}
							?>
						</select>
					</div>
					<?php if ( $is_woocommerce ) { ?>
						<div class="levelup-import-single-col"
						     style="width:<?php echo ( $is_woocommerce ) ? '25' : '33.3333' ?>%;">
							<h4><?php esc_html_e( 'WooCommerce Products', 'LEVELUP' ); ?></h4>
							<select class="noUpdate" name="product[]" multiple>
								<?php
								ksort( $product_array );
								foreach ( $product_array as $key => $value ) {
									echo '<option value="' . esc_attr( implode( ',', $value['ids'] ) ) . '">' . $key . '</option>';
								}
								?>
							</select>
						</div>
					<?php } ?>
					<div class="clear"></div>
					<p><?php esc_html_e( 'You can select multiple pages. Press and hold CTRL while you select the objects.', 'LEVELUP' ); ?></p>

					<div class="single_import_save">
						<span class="spinner"><?php esc_attr_e( 'Please Wait...', 'LEVELUP' ); ?></span><input
							class="panel-save button-primary" type="submit"
							value="<?php esc_html_e( 'Selective import', 'LEVELUP' ); ?>"/>
					</div>
				</div>

			</div>


			<script type="text/javascript">

				jQuery(document).ready(function ($) {

					$('.help_tip').tipTip({attribute: 'data-tip'});
					$('a.help_tip').click(function () {
						return false;
					});

				});

			</script>
			<?php


			echo '<h3>' . esc_html__('Pre-built Demo', 'LEVELUP') . '</h3>';
			echo '<fieldset class="levelupredux-field wbc_importer">';

			// No errors please
			$defaults    = array(
				'id'         => '',
				'url'        => '',
				'width'      => '',
				'height'     => '',
				'thumbnail'  => '',
				'full_width' => true,
				'overflow'   => 'inherit',
			);
			$this->value = wp_parse_args( $this->value, $defaults );

			$imported = false;

			echo '<div class="theme-browser"><div class="themes">';

			if ( ! empty( $this->field['wbc_demo_imports'] ) ) {

				foreach ( $this->field['wbc_demo_imports'] as $section => $imports ) {

					if ( empty( $imports ) || $imports['directory'] == 'Main' ) {
						continue;
					}

//                    if ( !array_key_exists( 'imported', $imports ) ) {
					$extra_class    = 'not-imported';
					$imported       = false;
					$import_message = esc_html__( 'Import Demo', 'LEVELUP' );
					/*} else {
						$imported = true;
						$extra_class = 'active imported';
						$import_message = esc_html__( 'Demo Imported', 'LEVELUP' );
					}*/

					$parts          = '';
					$parts_array    = array();
					$media_ids_data = '';
					if ( isset( $imports['content_media_file'] ) ) {
						$parts_array[] = 'media';
					}
					if ( isset( $imports['content_file'] ) ) {
						$parts_array[] = 'data';
					}

					if ( ! empty( $parts_array ) ) {
						$parts = implode( ',', $parts_array );
					}


					if ( isset( $imports['content_media_file'] ) ) {
						$media_ids_js = apply_filters( "levelupredux/{$this->parent->args['opt_name']}/field/wbc_importer_media_ids_js", $imports['directory'] );
						if ( $media_ids_js ) {
							$media_ids_data = ' data-media_ids="' . $media_ids_js . '"';
						}
					}


					echo '<div class="wrap-importer theme ' . $extra_class . '"  data-demo-id="' . esc_attr( $section ) . '" data-demo_main="' . ( $imports['directory'] == 'Main' ? 1 : 0 ) . '"  data-nonce="' . $nonce . '" data-parts="' . esc_attr( $parts ) . '" id="' . $this->field['id'] . '-custom_imports"' . $media_ids_data . '>';

					echo '<div class="theme-screenshot">';
					if ( isset( $imports['image'] ) ) {
						echo '<img class="wbc_image" src="' . esc_attr( esc_url( $this->demo_data_url . $imports['directory'] . '/' . $imports['image'] ) ) . '"/>';

					}
					echo '<span class="more-details">' . $import_message . '</span>';
					echo '</div>';


					echo '<h3 class="theme-name">' . esc_html( apply_filters( 'wbc_importer_directory_title', $imports['title'] ) ) . '</h3>';

					echo '<div class="theme-actions">';
//                    if ( false == $imported ) {
					echo '<div class="wbc-importer-buttons"><span class="spinner">' . esc_html__( 'Please Wait...', 'LEVELUP' ) . '</span>';

					if ( isset( $imports['preview'] ) && $imports['preview'] ) {
						echo '<a href="' . esc_url( $imports['preview'] ) . '" target="_blank" class="button-primary preview-button">' . esc_html__( 'Preview', 'LEVELUP' ) . '</a>';
					}
					
					echo '<span class="button-primary importer-button import-demo-data">' . esc_html__( 'Import', 'LEVELUP' ) . '</span></div>';
//                    } else {
//                        echo '<div class="wbc-importer-buttons button-secondary importer-button">'.esc_html__( 'Imported', 'LEVELUP' ).'</div>';
//                        echo '<span class="spinner">'.esc_html__( 'Please Wait...', 'LEVELUP' ).'</span>';
//                        echo '<div id="wbc-importer-reimport" class="wbc-importer-buttons button-primary import-demo-data importer-button">'.esc_html__( 'Re-Import', 'LEVELUP' ).'</div>';
//                    }

					echo '</div>';
					echo '</div>';

				}

			} else {
				echo "<h5>" . esc_html__( 'No Demo Data Provided', 'LEVELUP' ) . "</h5>";
			}

			echo '</div></div>';
			echo '</fieldset>';
			?>

			<?php
			echo '<fieldset class="levelupredux-field wbc_importer">';
			echo '<h3>' . esc_html__('Pre-built Pages', 'LEVELUP') . '</h3>';
			?>
			<script>
				jQuery(function () {
					jQuery("#tabs").tabs();
				});
			</script>
			<div id="tabs">
				<ul>
					<?php
					$page_group = array();
					foreach ( $main_pages as $id => $page ) {
						if ( ! in_array( $page['group'], $page_group ) ) {
							$page_group[] = $page['group'];
						}
					}

					$i = 0;
					foreach ( $page_group as $group ) {
						$i ++;
						echo '<li><a href="#tabs-' . $i . '">' . $group . '</a></li>';
					}
					?>

				</ul>

				<?php
				$i = 0;
				foreach ( $page_group as $group ) {
					$i ++;
					?>
					<div id="tabs-<?php echo $i; ?>">
						<?php
						echo '<div class="theme-browser"><div class="themes">';

						foreach ( $main_pages as $id => $page ) {
							if ( $group != $page['group'] ) {
								continue;
							}

							$main_page_id = $id;

							$media_ids_data = '';

							if ( isset( $page['images'] ) && is_array( $page['images'] ) ) {
								$images = $page['images'];

								if ( isset( $page['slides'] ) && $page['slides'] ) {
									$images = array_merge( $images, $main_pages_data['slider_images'] );
								}

								if ( isset( $page['portfolio'] ) && $page['portfolio'] && isset( $main_pages_data['portfolio']['images'] ) ) {
									$images = array_merge( $images, $main_pages_data['portfolio']['images'] );
								}

								if ( isset( $page['testimonials'] ) && $page['testimonials'] && isset( $main_pages_data['testimonials']['images'] ) ) {
									$images = array_merge( $images, $main_pages_data['testimonials']['images'] );
								}

								if ( isset( $page['team'] ) && $page['team'] && isset( $main_pages_data['team']['images'] ) ) {
									$images = array_merge( $images, $main_pages_data['team']['images'] );
								}

								if ( isset( $page['client_list'] ) && $page['client_list'] && isset( $main_pages_data['client_list']['dark'] ) ) {
									$images = array_merge( $images, $main_pages_data['client_list']['dark'] );
								}
								if ( isset( $page['client_list_light'] ) && $page['client_list_light'] && isset( $main_pages_data['client_list']['light'] ) ) {
									$images = array_merge( $images, $main_pages_data['client_list']['light'] );
								}

								if ( isset( $page['blog'] ) && $page['blog'] && isset( $main_pages_data['blog']['images'] ) ) {
									$images = array_merge( $images, $main_pages_data['blog']['images'] );
								}

								$media_ids_data = ' data-media_ids=""';
								$media_ids_chunks = @array_chunk( $images, 2 );
								if ( count( $media_ids_chunks ) ) {
									$media_ids_data = ' data-media_ids="' . json_encode( $media_ids_chunks ) . '"';
								}

//							$media_ids_data = ' data-media_ids="[[' . implode(',', $images) . ']]"';

							}

							echo '<div class="wrap-importer theme ' . $extra_class . '" data-demo-id="' . $main_demo_id . '" data-page-id="' . $main_page_id . '" data-demo_main="' . ( $imports['directory'] == 'Main' ? 1 : 0 ) . '"  data-nonce="' . $nonce . '" data-parts="' . esc_attr( $parts ) . '" id="' . $this->field['id'] . '-custom_imports" ' . $media_ids_data . '>';
							echo '<div class="theme-screenshot">';
							if ( isset( $page['preview'] ) ) {
								echo '<img class="wbc_image" src="' . LEVELUP_THEME_TEMPLATE_URL . '/inc/demo-data/Main/pages/' . esc_attr( $page['preview'] ) . '"/>';
							}
							echo '<span class="more-details">' . esc_html__( 'Import Page', 'LEVELUP' ) . '</span>';
							echo '</div>';


							echo '<h3 class="theme-name">' . esc_html( $page['title'] ) . '</h3>';

							echo '<div class="theme-actions">';
							echo '<div class="wbc-importer-buttons"><span class="spinner">' . esc_html__( 'Please Wait...', 'LEVELUP' ) . '</span>';

							if ( isset( $page['preview_url'] ) && $page['preview_url'] ) {
								echo '<a href="' . esc_url( $page['preview_url'] ) . '" target="_blank" class="button-primary preview-button">' . esc_html__( 'Preview', 'LEVELUP' ) . '</a>';
							}

							echo '<span class="button-primary importer-button import-demo-data">' . esc_html__( 'Import', 'LEVELUP' ) . '</span></div>';
							echo '</div>';
							echo '</div>';

						}
						echo '<div style="clear:both"></div></div></div>';

						?>
					</div>
					<?php
				}
				?>
			</div>

			<?php
			echo '</fieldset>';
		}

		/**
		 * Enqueue Function.
		 *
		 * @since       1.0.0
		 * @access      public
		 * @return      void
		 */
		public function enqueue() {

//            $min = Redux_Functions::isMin();

			wp_enqueue_script(
				'levelupredux-field-wbc-importer-js',
				$this->extension_url . 'field_wbc_importer.js',
				array( 'jquery' ),
				time(),
				true
			);

			wp_enqueue_style(
				'levelupredux-field-wbc-importer-css',
				$this->extension_url . 'field_wbc_importer.css',
				array(),
				time(),
				'all'
			);

			wp_enqueue_script( 'jquery-ui-tabs' );
			wp_enqueue_style( 'jquery-ui-tabs' );
			wp_enqueue_style( 'jquery-ui-dialog' );
			wp_enqueue_style( 'wp-jquery-ui-dialog' );

		}
	}
}


function levelup_size_to_num( $size ) {
	$l   = substr( $size, - 1 );
	$ret = substr( $size, 0, - 1 );
	switch ( strtoupper( $l ) ) {
		case 'P':
			$ret *= 1024;
		case 'T':
			$ret *= 1024;
		case 'G':
			$ret *= 1024;
		case 'M':
			$ret *= 1024;
		case 'K':
			$ret *= 1024;
	}

	return $ret;
}