/*
 Field Border (border)
 */

/*global levelupredux_change, wp, redux*/

(function( $ ) {
    "use strict";

    levelupredux.field_objects = levelupredux.field_objects || {};
    levelupredux.field_objects.border = levelupredux.field_objects.border || {};

    levelupredux.field_objects.border.init = function(selector ) {
        if ( !selector ) {
            selector = $( document ).find( ".levelupredux-group-tab:visible" ).find( '.levelupredux-container-border:visible' );
        }

        $( selector ).each(
            function() {
                var el = $( this );
                var parent = el;

                if ( !el.hasClass( 'levelupredux-field-container' ) ) {
                    parent = el.parents( '.levelupredux-field-container:first' );
                }
                if ( parent.is( ":hidden" ) ) { // Skip hidden fields
                    return;
                }
                if ( parent.hasClass( 'levelupredux-field-init' ) ) {
                    parent.removeClass( 'levelupredux-field-init' );
                } else {
                    return;
                }
                el.find( ".levelupredux-border-top, .levelupredux-border-right, .levelupredux-border-bottom, .levelupredux-border-left, .levelupredux-border-all" ).numeric(
                    {
                        allowMinus: false
                    }
                );

                var default_params = {
                    triggerChange: true,
                    allowClear: true
                };

                var select2_handle = el.find( '.levelupredux-container-border' ).find( '.select2_params' );

                if ( select2_handle.size() > 0 ) {
                    var select2_params = select2_handle.val();

                    select2_params = JSON.parse( select2_params );
                    default_params = $.extend( {}, default_params, select2_params );
                }

                el.find( ".levelupredux-border-style" ).select2( default_params );

                el.find( '.levelupredux-border-input' ).on(
                    'change', function() {
                        var units = $( this ).parents( '.levelupredux-field:first' ).find( '.field-units' ).val();
                        if ( $( this ).parents( '.levelupredux-field:first' ).find( '.levelupredux-border-units' ).length !== 0 ) {
                            units = $( this ).parents( '.levelupredux-field:first' ).find( '.levelupredux-border-units option:selected' ).val();
                        }
                        var value = $( this ).val();
                        if ( typeof units !== 'undefined' && value ) {
                            value += units;
                        }
                        if ( $( this ).hasClass( 'levelupredux-border-all' ) ) {
                            $( this ).parents( '.levelupredux-field:first' ).find( '.levelupredux-border-value' ).each(
                                function() {
                                    $( this ).val( value );
                                }
                            );
                        } else {
                            $( '#' + $( this ).attr( 'rel' ) ).val( value );
                        }
                    }
                );

                el.find( '.levelupredux-border-units' ).on(
                    'change', function() {
                        $( this ).parents( '.levelupredux-field:first' ).find( '.levelupredux-border-input' ).change();
                    }
                );

                var data = {
                    change: function( e, ui ) {
                        $( this ).val( ui.color.toString() );
                        levelupredux_change( $( this ) );
                        el.find( '#' + e.target.getAttribute( 'data-id' ) + '-transparency' ).removeAttr( 'checked' );
                    },

                    clear: function( e, ui ) {
                        $( this ).val( ui.color.toString() );
                        levelupredux_change( $( this ).parent().find( '.levelupredux-color-init' ) );
                    }
                }

                if (typeof RDY != 'undefined') {
                    data.palettes = RDY.iris.palettes;
                }

                el.find( '.levelupredux-color-init' ).wpColorPicker(
                    data
                );

                el.find( '.levelupredux-color' ).on(
                    'keyup', function() {
                        var color = colorValidate( this );

                        if ( color && color !== $( this ).val() ) {
                            $( this ).val( color );
                        }
                    }
                );

                // Replace and validate field on blur
                el.find( '.levelupredux-color' ).on(
                    'blur', function() {
                        var value = $( this ).val();

                        if ( colorValidate( this ) === value ) {
                            if ( value.indexOf( "#" ) !== 0 ) {
                                $( this ).val( $( this ).data( 'oldcolor' ) );
                            }
                        }
                    }
                );

                // Store the old valid color on keydown
                el.find( '.levelupredux-color' ).on(
                    'keydown', function() {
                        $( this ).data( 'oldkeypress', $( this ).val() );
                    }
                );
            }
        );
    };
})( jQuery );