<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * @property mixed data
 */
class Levelup_CSS_Margin {
	/**
	 * @var array
	 */
	protected $settings = array();
	/**
	 * @var string
	 */
	protected $value = '';
	/**
	 * @var array
	 */
	protected $size_types = array(
		'lg' => 'Large',
		'md' => 'Medium',
		'sm' => 'Small',
		'xs' => 'Extra small',
	);
	/**
	 * @var array
	 */
	protected $column_width_list = array();

	/**
	 * @param $settings
	 * @param $value
	 */
	public function __construct( $settings, $value ) {

		$this->settings = $settings;
		$this->value = $value;

	}

	/**
	 * @return string
	 */
	public function render() {
		ob_start();
		/*vc_include_template( 'params/column_offset/template.tpl.php', array(
			'settings' => $this->settings,
			'value' => $this->value,
			'data' => $this->valueData(),
			'sizes' => $this->size_types,
			'param' => $this,
		) );*/

		$this->data = $this->valueData();
		?>
		<div class="vc_column-offset" data-margin-param="true">
			<?php if ( '1' === vc_settings()->get( 'not_responsive_css' ) ) :  ?>
				<div class="wpb_alert wpb_content_element vc_alert_rounded wpb_alert-warning">
					<div class="messagebox_text">
						<p><?php printf( __( 'Responsive design settings are currently disabled. You can enable them in Visual Composer <a href="%s">settings page</a> by unchecking "Disable responsive content elements".', 'js_composer' ), admin_url( 'admin.php?page=vc-general' ) ) ?></p>
					</div>
				</div>
			<?php endif ?>
			<input name="<?php echo esc_attr( $this->settings['param_name'] ) ?>"
			       class="wpb_vc_param_value <?php echo esc_attr( $this->settings['param_name'] ) ?>
			<?php echo esc_attr( $this->settings['type'] ) ?> '_field" type="hidden" value="<?php echo esc_attr( $this->value ) ?>"/>
			<table class="vc_table vc_levelup-css-table">
				<tr>
					<th>
						<?php _e( 'Device', 'LEVELUP' ) ?>
					</th>
					<th>
						<?php _e( 'Top', 'LEVELUP' ) ?>
					</th>
					<th>
						<?php _e( 'Right', 'LEVELUP' ) ?>
					</th>
					<th>
						<?php _e( 'Bottom', 'LEVELUP' ) ?>
					</th>
					<th>
						<?php _e( 'Left', 'LEVELUP' ) ?>
					</th>
					<th>
						<?php _e( 'Zero value', 'LEVELUP' ) ?>
					</th>
				</tr>
				<?php foreach ( $this->size_types as $key => $size ) : ?>
					<tr class="vc_size-<?php echo $key ?>">
						<td class="vc_screen-size vc_screen-size-<?php echo $key ?>">
							<span title="<?php echo $size ?>"><i class="vc-composer-icon vc-c-icon-layout-<?php echo $key ?>"></i></span>
						</td>
						<td>
							<?php echo $this->spaceControl( $key, 'top' ) ?>
						</td>
						<td>
							<?php echo $this->spaceControl( $key, 'right' ) ?>
						</td>
						<td>
							<?php echo $this->spaceControl( $key, 'bottom' ) ?>
						</td>
						<td>
							<?php echo $this->spaceControl( $key, 'left' ) ?>
						</td>
						<td>
							<a href="javascript:void(0)" class="breakpoint"><?php _e( 'Set', 'LEVELUP' ) ?></a>
							<a href="javascript:void(0)" class="reset"><?php _e( 'Clean', 'LEVELUP' ) ?></a>
						</td>
					</tr>
				<?php endforeach ?>
			</table>
		</div>
		<?php

		return ob_get_clean();
	}

	/**
	 * @return array|mixed
	 */
	public function valueData() {
		$this->data = @explode( ':', $this->value );

		return $this->data;
	}

	/**
	 * @param $size
	 *
	 * @return string
	 */
	public function spaceControl( $size, $direction ) {
		$prefix = 'vc_col-' . $size . '-margin-';

		if ( $size == 'lg' ) {
			if ( $direction == 'top' ) {
				$index = 0;
			} elseif ( $direction == 'right' ) {
				$index = 1;
			} elseif ( $direction == 'bottom' ) {
				$index = 2;
			} elseif ( $direction == 'left' ) {
				$index = 3;
			}
		}
		elseif ( $size == 'md' ) {
			if ( $direction == 'top' ) {
				$index = 4;
			} elseif ( $direction == 'right' ) {
				$index = 5;
			} elseif ( $direction == 'bottom' ) {
				$index = 6;
			} elseif ( $direction == 'left' ) {
				$index = 7;
			}
		}
		elseif ( $size == 'sm' ) {
			if ( $direction == 'top' ) {
				$index = 8;
			} elseif ( $direction == 'right' ) {
				$index = 9;
			} elseif ( $direction == 'bottom' ) {
				$index = 10;
			} elseif ( $direction == 'left' ) {
				$index = 11;
			}
		}
		elseif ( $size == 'xs' ) {
			if ( $direction == 'top' ) {
				$index = 12;
			} elseif ( $direction == 'right' ) {
				$index = 13;
			} elseif ( $direction == 'bottom' ) {
				$index = 14;
			} elseif ( $direction == 'left' ) {
				$index = 15;
			}
		}

		$value = isset( $this->data[ $index ] ) ? $this->data[ $index ] : '';

		$output = '<input name="vc_' . $size . '_margin_param" class="vc_levelup_css_margin_field vc_' . $direction . '"  data-type="margin-' . $size . '" value="' . esc_attr( $value ) . '" placeholder="-">';

		return $output;
	}
}

/**
 * @param $settings
 * @param $value
 *
 * @return string
 */
function levelup_css_margin_form_field( $settings, $value ) {
	$column_offset = new Levelup_CSS_Margin( $settings, $value );

	return $column_offset->render();
}

/**
 * @param $column_offset
 * @param $width
 *
 * @return mixed|string
 */
function levelup_css_margin_class_merge( $column_offset, $width ) {
	// Remove offset settings if
	if ( '1' === vc_settings()->get( 'not_css_margin_css' ) ) {
		$column_offset = preg_replace( '/vc_col\-(lg|md|xs)[^\s]*/', '', $column_offset );
	}
	if ( preg_match( '/vc_col\-sm\-\d+/', $column_offset ) ) {
		return $column_offset;
	}

	return $width . ( empty( $column_offset ) ? '' : ' ' . $column_offset );
}

/**
 *
 */
function levelup_load_css_margin_param() {
	vc_add_shortcode_param( 'levelup_css_margin', 'levelup_css_margin_form_field', LEVELUP_THEME_TEMPLATE_URL . '/admin/assets/js/vc_extend/rdy_css_margin.js' );
}

add_action( 'vc_load_default_params', 'levelup_load_css_margin_param' );



if ( ! class_exists( 'LevelupCSSTabs' ) ) {

	class LevelupCSSTabs {

		function __construct() {
			if ( function_exists( 'vc_add_shortcode_param' ) ) {
				vc_add_shortcode_param( 'levelup_css_tabs', array( &$this, 'rdy_param_callback' ), LEVELUP_THEME_TEMPLATE_URL . '/admin/assets/js/vc_extend/rdy_css_margin.js' );
			}
		}

		function rdy_param_callback( $settings, $value ) {
			$data .= '<div class="vc_levelup_css_tabs"><ul>';

			$categories = array(
				'margin' => 'Margin',
				'padding' => 'Padding',
				'offset' => 'Offset',
			);

			$first = true;
			foreach ( $categories as $key => $val ) {
				$data .= '<li data-val="' . $key . '"' . ( $first ? ' class="active"' : '' ) . '>' . esc_html( $val ) . '</li>';
				$first = false;
			}

			$data .= '</ul></div>';

			return $data;
		}
	}

}

if ( class_exists( 'LevelupCSSTabs' ) ) {
	new LevelupCSSTabs();
}
