<?php

if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}


class BR_Shortcode {

    protected $post_backup = null;
    protected $config_backup = null;

    public function get_posts_by_terms( $instance = array() ) {
        if ( empty($this->post_type) || empty($this->taxonomy) ) {
            return false;
        }

        $args = array(
            'no_found_rows'         => isset( $instance['no_found_rows'] ) ? $instance['no_found_rows'] : 1,
            'ignore_sticky_posts'   => 1,
            'posts_per_page'        => isset( $instance['number'] ) ? $instance['number'] : -1,
            'post_type'             => $this->post_type,
            'post_status'           => 'publish',
            'paged'                 => levelup_get_paged_var(),
            'orderby'               => isset( $instance['orderby'] ) ? $instance['orderby'] : 'date',
            'order'                 => isset( $instance['order'] ) ? $instance['order'] : 'DESC',
            'tax_query'             => array( array(
                'taxonomy'          => $this->taxonomy,
                'field'             => 'slug',
                'terms'             => $instance['category']
            ) ),
        );

        if (isset($instance) && array_key_exists('select_ids', $instance) && is_array($instance['select_ids'])) {
            $args['post__in'] = $instance['select_ids'];
        } elseif (isset($instance) && array_key_exists('exclude_ids', $instance) && is_array($instance['exclude_ids'])) {
            $args['post__not_in'] = $instance['exclude_ids'];
        }

        switch ($instance['select']) {
            case 'only':
                $args['tax_query'][0]['operator'] = 'IN';
                break;
            case 'except':
                $args['tax_query'][0]['operator'] = 'NOT IN';
                break;
            default:
                unset($args['tax_query']);
        }

        return new WP_Query( $args );
    }

    protected function vc_inline_dummy( $args = array() ) {
        $defaults = array(
            'title' => '',
            'title_tag' => 'h5',
            'fields' => array(),
            'class' => array(),
            'style' => array( 'height' => '250px' )
        );

        $args = wp_parse_args( $args, $defaults );

        extract( $args );

        $fields = (array) $fields;
        $class = (array) $class;
        $style = (array) $style;

        $class[] = 'rdy_vc-shortcode_dummy';

        $style_attr = '';
        if ( count( $style ) ) {

            foreach( $style as $rule=>$value ) {
                $style_attr .= "{$rule}: {$value};";
            }

            $style_attr = ' style="' . esc_attr( $style_attr ) . '"';
        }

        $fields_html = '';
        if ( count( $fields ) ) {

            foreach( $fields as $field_title=>$field_value ) {
                $fields_html .= sprintf( '<p class="text-small"><strong>%s:</strong> %s</p>', $field_title, $field_value );
            }

        }

        $output = sprintf(
            '<div class="%1$s"%2$s><%3$s>%4$s</%3$s>%5$s</div>',
            esc_attr( join( ' ', $class ) ),
            $style_attr,
            $title_tag,
            $title,
            $fields_html
        );

        return $output;
    }

    protected function backup_post_object() {
        global $post;
        $this->post_backup = $post;
    }

    protected function restore_post_object() {
        global $post;
        $post = $this->post_backup;
        setup_postdata( $post );
        unset( $this->post_backup );
    }

    protected function backup_theme_config() {
        $this->config_backup = levelup_config()->get();
    }

    protected function restore_theme_config() {
	    levelup_config()->reset( $this->config_backup );
        unset( $this->config_backup );
    }

    protected function set_compatible_att_value( &$atts, $new_att, $old_att ) {
        if ( ! isset( $atts[ $new_att ] ) && isset( $atts[ $old_att ] ) ) {
            $atts[ $new_att ] = $atts[ $old_att ];
            return $atts[ $new_att ];
        }

        return false;
    }

}

