<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * Contact form7 vendor
 * =======
 * Plugin Contact form 7 vendor
 * To fix issues when shortcode doesn't exists in frontend editor. #1053, #1054 etc.
 * @since 4.3
 */
class RdyVc_Vendor_ContactForm7 implements Vc_Vendor_Interface {

	/**
	 * Add action when contact form 7 is initialized to add shortcode.
	 * @since 4.3
	 */
	public function load() {

		vc_lean_map( 'contact-form-7',
			array(
				$this,
				'addShortcodeSettings',
			) );
	}

	/**
	 * Mapping settings for lean method.
	 *
	 * @since 4.9
	 *
	 * @param $tag
	 *
	 * @return array
	 */
	public function addShortcodeSettings( $tag ) {
		/**
		 * Add Shortcode To Visual Composer
		 */
		$cf7 = get_posts( 'post_type="wpcf7_contact_form"&numberposts=-1' );

		$contact_forms = array();
		if ( $cf7 ) {
			foreach ( $cf7 as $cform ) {
				$contact_forms[ $cform->post_title ] = $cform->ID;
			}
		} else {
			$contact_forms[ __( 'No contact forms found', 'LEVELUP' ) ] = 0;
		}

		return array(
			'base' => $tag,
			'name' => __( 'Contact Form 7', 'LEVELUP' ),
			'icon' => 'icon-wpb-contactform7',
			'category' => __( 'Content', 'LEVELUP' ),
			'description' => __( 'Place Contact Form7', 'LEVELUP' ),
			'params' => array(
				array(
					'type' => 'dropdown',
					'heading' => __( 'Select Contact Form', 'LEVELUP' ),
					'param_name' => 'id',
					'value' => $contact_forms,
					'save_always' => true,
					'description' => __( 'Choose previously created contact form from the drop down list.', 'LEVELUP' ),
				),

				array(
					'type' => 'dropdown',
					'heading' => __( 'Contact Form Style', 'LEVELUP' ),
					'param_name' => 'html_class',
					'value' => array(
							'Default' => '',
							'Style One' => 'style-1',
							'Style Two' => 'style-2',
							'Style Three' => 'style-3',
							'Style Four' => 'style-3 linecenter',
					),
					'admin_label' => true,
					'description' => __( 'Select display style.', 'LEVELUP' ),
				),

				array(
					'type' => 'rdy_param_heading',
					'param_name' => 'btn1_icon_setting',
					'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
				),

					array(
					'type' => 'textfield',
					'heading' => __( 'Search title', 'LEVELUP' ),
					'param_name' => 'title',
					'admin_label' => true,
					'description' => __( 'Enter optional title to search if no ID selected or cannot find by ID.', 'LEVELUP' ),
				),

			),
		);
	}
}
