<?php
if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}

class WPBakeryShortCode_Rdy_List extends WPBakeryShortCodeWithFont {

    protected function content( $atts, $content = null ) {

        $google_fonts = $font_container = $el_class = $css = $google_fonts_data = $font_container_data = '';
        $list_item_classes = $google_font_styles = $font_size = $line_height_size = "";

        $atts = vc_map_get_attributes( $this->getShortcode(), $atts );
        extract( $atts );
        extract( $this->getAttributes( $atts ) );
        extract( $this->getStyles( $el_class, $css, $google_fonts_data, $font_container_data, $atts ) );

        $style                       = esc_attr( $style );
        $number_type                 = esc_attr( $number_type );
        $item_text_hover             = esc_attr( $item_text_hover );
        $number_color_custom         = esc_attr( $number_color_custom );
        $icon_background_color       = esc_attr( $icon_background_color );
        $separator_color             = esc_attr( $separator_color );
        $item_margin_bottom          = esc_attr( $item_margin_bottom );
        $padding_left                = esc_attr( $padding_left );
        $item_hover_background_color = esc_attr( $item_hover_background_color );

        if($use_custom_font){
            $settings = get_option( 'wpb_js_google_fonts_subsets' );
            $subsets = '';
            if (is_array($settings) && !empty($settings)) {
                $subsets = '&subset=' . implode(',', $settings);
            }

            if (is_array($google_fonts_data) && !empty($google_fonts_data)) {
                wp_enqueue_style( 'vc_google_fonts_' . vc_build_safe_css_class( $google_fonts_data['values']['font_family'] ), '//fonts.googleapis.com/css?family=' . $google_fonts_data['values']['font_family'] . $subsets );
                $google_font_styles = implode( ';', $styles );
            }

            foreach ($styles as $key => $value) {
                if (strpos($value, 'font-size') !== false) {
                    $font_size = preg_replace('/\D/', '', $value);
                }
                if (strpos($value, 'line-height') !== false) {
                    $line_height_size = preg_replace('/\D/', '', $value);
                }
            }
        }

        if ($font_title_responsive && $use_custom_font) {
            foreach ($styles as $key => $value) {
                if (strpos($value, 'font-size') !== false) {
                    preg_match_all('!\d+!', $value, $font_size);
                    if ($font_size)
                        $font_size = intval($font_size[0][0]);
                    break;
                }
            }
            if ($font_size) {
                $list_item_classes .= levelup_calculate_responsive_font_class($font_size);
            }
        }


        vc_icon_element_fonts_enqueue( $type_font );
        $icon_class = esc_attr( ${"icon_" . $type_font} );

        $style_id = Levelup_Styles::shortcode_id();
        $separator = apply_filters('levelup_sanitize_flag', $separator);
        $list_anim = apply_filters('levelup_sanitize_flag', $list_anim);

        if ($style != "") {
            $list_item_classes .= " {$style}";
        } else {
            $list_item_classes .= " none";
        }

        if ($el_class != "") {
            $list_item_classes .= " {$el_class}";
        }

        if (('number' == $style || 'icon' == $style) && $number_type != "") {
            $list_item_classes .= " {$number_type}";
        }

        if ($number_zero) {
            $list_item_classes .= " number_zero";
        }

        if ($separator) {
            $list_item_classes .= " separator";
        }

        if ( ! empty( $item_hover_background_color ) && ! empty( $item_text_hover ) ) {
            $list_item_classes .= " hover-text-".$item_text_hover;
        }


        $html = '<div class="b_list b_list-' . $style_id . ' ' . $list_item_classes . '"';
        if ($google_font_styles) {
            $html .= ' style="' . $google_font_styles . '"';
        }

        if ($list_anim) {
            $html .= ' data-animation="true"';
        }

        if ($list_anim_repeat) {
            $html .= ' data-animation-repeat="true"';
        }

        if ($style == 'bullet') {
            $html .= ' data-list-icon="rdy_icon gi gi-dots"';
        } elseif ($style == 'dash') {
            $html .= ' data-list-icon="rdy_icon gi gi-dash"';
        }

        if ($style == 'icon' && $icon_class) {
            $html .= ' data-list-icon="rdy_icon ' . $icon_class . '"';
        }

        $html .= ">";
        $html .= levelup_remove_wpautop($content, true);
        $html .= "</div>";

        $stylesheet = '';

        $icon_color = levelup_get_accent_color($number_color, $number_color_custom);
        if ($icon_color) {
            if ('number' == $style)
                $stylesheet .= '.b_list-' . $style_id . '.number ul>li:before {
                    color: ' . $icon_color . ' !important;
                }';
            if ('icon' == $style)
                $stylesheet .= '.b_list-' . $style_id . ' ul>li .rdy_icon {
                    color: ' . $icon_color . ' !important;
                }';
        }

        if ($number_type == 'bg_color' && $icon_background_color) {
            $stylesheet .= '
            .b_list-' . $style_id . '.bg_color ul>li:before,
            .b_list-' . $style_id . '.bg_color ul>li .rdy_icon {
                background-color: ' . $icon_background_color . ';
            }';
        }

        if ($style == 'bullet' || $style == 'dash' || $style == 'icon') {
            $stylesheet .= '
            .b_list-' . $style_id . ' ul>li .fa {
               color: ' . $icon_color . ';
            }';
        }

        if (('number' == $style || 'icon' == $style) && $number_type == 'outline') {
            $stylesheet .= '
            .b_list-' . $style_id . '.outline ul>li .rdy_icon {
                border: 1px solid ' . $icon_color . ';
            }';
        }

        if ($separator && $separator_color) {
            $stylesheet .= '
             .b_list-' . $style_id . '.b_list.separator ul>li:after {
                border-color: ' . $separator_color . ' !important;
             }';
        }

        if ($font_size) {
            if ('number' == $style && $number_zero) {
                $stylesheet .= '
                    .b_list-' . $style_id . ' ul>li {
                        padding-left: ' . ($font_size + 25) . 'px!important;
                    }';
            } elseif ($style == 'bullet' || $style == 'dash' || $style == 'icon' || $style == 'number') {
                $stylesheet .= '
                    .b_list-' . $style_id . ' ul>li {
                        padding-left: ' . ($font_size + 10) . 'px!important;
                     }';
            }

            $stylesheet .= '
             .b_list-' . $style_id . ' ul>li .rdy_icon,
             .b_list-' . $style_id . '.number ul>li:before {
                height: ' . $font_size . 'px;
                width: ' . $font_size . 'px;
                line-height: ' . ($line_height_size ? $line_height_size : $font_size) . 'px !important;
             }
             .b_list-' . $style_id . '.icon ul>li,
             .b_list-' . $style_id . '.number ul>li {
                line-height: ' . $font_size . 'px !important;
             }';
        }

        if ($use_custom_font && $item_margin_bottom) {
            $stylesheet .= '
                 .b_list-' . $style_id . ' ul>li {
                    margin: 0;
                    padding-top: ' . ($item_margin_bottom) . 'px!important;
                    padding-bottom: ' . ($item_margin_bottom) . 'px!important;
                 }';
        }

        if ($style == '' && $padding_left) {
            $stylesheet .= '
                 .b_list-' . $style_id . ' ul>li {
                    padding-left: ' . ($padding_left) . 'px !important;
                 }';

            if ($reset_padding)
                $stylesheet .= '
                    @media (max-width: 767px) {
                    .b_list-' . $style_id . ' ul>li {
                         padding-left: 0 !important;
                     }
                     }';
        }

        if ( $item_hover_background_color ) {
            $stylesheet .= '
                 .b_list-' . $style_id . ' ul>li:hover {
                    background: ' . ($item_hover_background_color) . '!important;
                 }';
        }

        Levelup_Styles::addCSS($stylesheet, $style_id);

        return $html;
    }
}


//***********************************************************************
// List
//***********************************************************************

vc_map( array(
    "name" => esc_html__("List", 'LEVELUP'),
    "base" => "rdy_list",
    "icon" => LEVELUP_THEME_TEMPLATE_URL . "/admin/assets/images/vc/list.png",
    "category" => 'by '.'LEVELUP',
    "allowed_container_element" => 'vc_row',
    "params" => array(
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Type List", 'LEVELUP'),
            "param_name" => "style",
            "value" => array(
                esc_html__("None", 'LEVELUP') => "",
                esc_html__("Bullet", 'LEVELUP') => "bullet",
                esc_html__("Dash", 'LEVELUP') => "dash",
                esc_html__("Font Icon", 'LEVELUP') => "icon",
                esc_html__("Numbered list", 'LEVELUP') => "number",
            ),
			'description' => esc_html__('Select list type', 'LEVELUP'),
        ),

        array(
            "type" => "textarea_html",
            "class" => "",
            "heading" => esc_html__("List", 'LEVELUP'),
            "param_name" => "content",
            "value" => wp_kses( __("<ul><li>Lorem Ipsum</li><li>Lorem Ipsum</li><li>Lorem Ipsum</li></ul>", 'LEVELUP'), array( 'ul' => array(), 'li' => array(), ) ),
            'description' => '',
        ),

        array(
            'type' => 'dropdown',
            'heading' => esc_html__( 'Icon library', 'LEVELUP' ),
            'value' => array(
                esc_html__( 'Font Awesome', 'LEVELUP' ) => 'fontawesome',
                esc_html__( 'Open Iconic', 'LEVELUP' ) => 'openiconic',
                esc_html__( 'Typicons', 'LEVELUP' ) => 'typicons',
                esc_html__( 'Entypo', 'LEVELUP' ) => 'entypo',
                esc_html__( 'Linecons', 'LEVELUP' ) => 'linecons',
                esc_html__( 'Etline', 'LEVELUP' ) => 'etline',
            ),
            'admin_label' => true,
            'param_name' => 'type_font',
            'description' => esc_html__( 'Select icon library.', 'LEVELUP' ),
            "dependency" => Array('element' => "style", 'value' => array('icon')),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_fontawesome',
            'value' => 'fa fa-adjust', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false,
                // default true, display an "EMPTY" icon?
                'iconsPerPage' => 4000,
                // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'fontawesome',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_openiconic',
            'value' => 'vc-oi vc-oi-dial', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'openiconic',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'openiconic',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_typicons',
            'value' => 'typcn typcn-adjust-brightness', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'typicons',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'typicons',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_entypo',
            'value' => 'entypo-icon entypo-icon-note', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'entypo',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'entypo',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_linecons',
            'value' => 'vc_li vc_li-heart', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'linecons',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'linecons',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_etline',
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'etline',
                'iconsPerPage' => 200, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'etline',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Icon Color", 'LEVELUP'),
            "param_name" => "number_color",
            "value" => $extra_colors,
            'description' => esc_html__('Select Icon Color.', 'LEVELUP'),
            "dependency" => array('element' => "style", 'value' => array('icon')),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__("Icon Custom Color", 'LEVELUP'),
            "param_name" => "number_color_custom",
            "value" => "",
            'description' => esc_html__('Select Icon Color.', 'LEVELUP'),
            "dependency" => array('element' => "number_color", 'value' => array('custom')),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Use Custom Font & Size?", 'LEVELUP'),
            "value" => array(esc_html__("Yes.", 'LEVELUP') => "yes" ),
            "param_name" => "use_custom_font",
            'description' => esc_html__('If checked, you Use Custom Font & Size.', 'LEVELUP'),
            'group' => esc_html__('Custom Font & Size', 'LEVELUP'),
        ),

        array(
            'type' => 'google_fonts',
            'param_name' => 'google_fonts',
            'value' => '',
            'settings' => array(
                'fields'=>array(
                    'font_family'=>'Open Sans:regular',
                    'font_style'=>'400 regular:400:normal',
                    'font_family_description' => esc_html__('Select font family.','LEVELUP'),
                    'font_style_description' => esc_html__('Select font styling.','LEVELUP')
                )
            ),
            "dependency" => Array('element' => "use_custom_font", 'not_empty' => true),
            'group' => esc_html__('Custom Font & Size', 'LEVELUP'),
        ),

        array(
            'type' => 'font_container',
            'param_name' => 'font_container',
            'value'=>'',
            'settings'=>array(
                'fields'=>array(
                    'font_size',
                    'color',
                    'tag_description' => esc_html__('Select element tag.','LEVELUP'),
                    'text_align_description' => esc_html__('Select text alignment.','LEVELUP'),
                    'font_size_description' => esc_html__('Enter font size in pixels. Eg. 35','LEVELUP'),
                    'line_height_description' => esc_html__('Enter line height.','LEVELUP'),
                    'color_description' => esc_html__('Select text color.','LEVELUP'),
                ),
            ),
            "dependency" => Array('element' => "use_custom_font", 'not_empty' => true),
            'group' => esc_html__('Custom Font & Size', 'LEVELUP'),
        ),

        array(
            'type' => 'checkbox',
            'heading' => esc_html__( 'Responsive Font Size?', 'LEVELUP' ),
            'param_name' => 'font_title_responsive',
            'value' => array(
                esc_html__( 'Enable?', 'LEVELUP' ) => 'true',
            ),
            'description' => esc_html__('If checked, the Font Size will be Responsive.', 'LEVELUP'),
            "dependency" => Array('element' => "use_custom_font", 'not_empty' => true),
            'group' => esc_html__('Custom Font & Size', 'LEVELUP'),
        ),

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__("Item Line Height", 'LEVELUP'),
            "param_name" => "item_margin_bottom",
            "value" => 10,
            "description" => esc_html__("Enter a value for Line Height in pixels. Default 10 pixels.", 'LEVELUP'),
            "dependency" => Array('element' => "use_custom_font", 'not_empty' => true),
            'group' => esc_html__('Custom Font & Size', 'LEVELUP'),
        ),

        array(
            'type' => 'textfield',
            'heading' => esc_html__( 'List Item Left Padding', 'LEVELUP' ),
            'param_name' => 'padding_left',
            "dependency" => Array('element' => "style", 'value' => array('')),
            "description" => esc_html__("You can use left padding to push the list items to the right. Enter a value in pixels. E.g. 10", 'LEVELUP'),

        ),

        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Reset Padding?", 'LEVELUP'),
            "value" => array(esc_html__("Yes.", 'LEVELUP') => "yes" ),
            "param_name" => "reset_padding",
            "description" => esc_html__('If checked, padding will be reset when viewed on the phone.', 'LEVELUP'),
            "dependency" => array('element' => "padding_left", 'not_empty' => true),
        ),

        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Add zero in front of number?", 'LEVELUP'),
            "value" => array(esc_html__("Yes.", 'LEVELUP') => "yes" ),
            "param_name" => "number_zero",
            "description" => esc_html__('Example: 01 02 03', 'LEVELUP'),
            "dependency" => array('element' => "style", 'value' => array('number'))
        ),

        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Icon or Number Style", 'LEVELUP'),
            "param_name" => "number_type",
            "value" => array(
                esc_html__("Normal", 'LEVELUP') => "normal_number",
                esc_html__("Outlined", 'LEVELUP') => "outline",
                esc_html__("Background Color", 'LEVELUP') => "bg_color",
            ),
            'description' => esc_html__('Select Icon or Number Style.', 'LEVELUP'),
            "dependency" => array('element' => "style", 'value' => array('number', 'icon'))
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__("Icon Background Color", 'LEVELUP'),
            "param_name" => "icon_background_color",
            "value" => "#cccccc",
            "description" => esc_html__("Select Icon Background Color", 'LEVELUP'),
            "dependency" => Array('element' => "number_type", 'value' => array('bg_color'))
        ),
		
        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Enable Animation?", 'LEVELUP'),
            "value" => array(esc_html__("Yes.", 'LEVELUP') => "yes" ),
            "param_name" => "list_anim",
            'description' => esc_html__('If checked items will be are animation one after the other.', 'LEVELUP'),
            'group' => esc_html__('Animation', 'LEVELUP'),
        ),

        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Restart CSS Animation", 'LEVELUP'),
            'value' => array(esc_html__('Yes.', 'LEVELUP') => 'show_video'),
            "param_name" => "list_anim_repeat",
            'description' => esc_html__('If checked, the animation for the element will be restart whenever when it "enters" the browsers viewport (Note: works only in modern browsers).', 'LEVELUP'),
            'group' => esc_html__('Animation', 'LEVELUP'),
        ),

        array(
            'type' => 'rdy_param_heading',
            'param_name' => 'btn1_icon_setting',
            'text' => '',
            'description' => '',
            'value' => '',
            'class' => '',
            'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
        ),

        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Separator?", 'LEVELUP'),
            "value" => array(esc_html__("Yes.", 'LEVELUP') => "yes" ),
            "param_name" => "separator",
            'description' => esc_html__('If checked separators will be displayed between items.', 'LEVELUP'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__("Separator line Color", 'LEVELUP'),
            "param_name" => "separator_color",
            "value" => "#cccccc",
            'description' => esc_html__('Select Separator line Color. Default #cccccc.', 'LEVELUP'),
            "dependency" => array('element' => "separator", 'not_empty' => true),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),

        array(
            'type' => 'rdy_param_heading',
            'param_name' => 'btn1_icon_setting',
            'text' => '',
            'description' => '',
            'value' => '',
            'class' => '',
            'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__("Highlight Item on hover", 'LEVELUP'),
            "param_name" => "item_hover_background_color",
            "description" => esc_html__("Select Highlight Color", 'LEVELUP'),
        ),

        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__("Item Text Color on Hover", 'LEVELUP'),
            "param_name" => "item_text_hover",
            "value" => array(
                esc_html__("Default", 'LEVELUP') => "",
                esc_html__("Light", 'LEVELUP') => "light",
                esc_html__("Dark", 'LEVELUP') => "dark",
            ),
            "description" => esc_html__("Select Item Text Color.", 'LEVELUP'),
            "dependency" => array('element' => "item_hover_background_color", 'not_empty' => true),
        ),

        array(
            'type' => 'rdy_param_heading',
            'param_name' => 'btn1_icon_setting',
            'text' => '',
            'description' => '',
            'value' => '',
            'class' => '',
            'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
        ),

        array(
            'type' => 'textfield',
            'heading' => esc_html__( 'Extra class name', 'LEVELUP' ),
            'param_name' => 'el_class',
            'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'LEVELUP' )
        )
    )
) );
