<?php
if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}

class WPBakeryShortCode_Rdy_Message extends WPBakeryShortCode {

    protected function content( $atts, $content = null ) {

	    $el_class = '';

        $atts = vc_map_get_attributes( $this->getShortcode(), $atts );
        extract( $atts );

        $style_id = Levelup_Styles::shortcode_id();

        vc_icon_element_fonts_enqueue( $type_font );
        $icon_class = esc_attr( ${"icon_" . $type_font} );

        $uppercase = apply_filters('levelup_sanitize_flag', $uppercase);

        $html                   = "";
        $icon_html              = "";
        $message_classes        = "b_message-".$style_id;
        $message_styles         = "";
        $icon_styles            = "";
        $close_button_styles    = "";
        $icon_background_color  = "";

        $background_color      = esc_attr( $background_color );
        $border_width          = esc_attr( $border_width );
        $border_color          = esc_attr( $border_color );
        $text_color            = esc_attr( $text_color );
        $icon_size             = esc_attr( $icon_size );
        $icon_color            = esc_attr( $icon_color );
        $icon_background_color = esc_attr( $icon_background_color );
        $close_button_color    = esc_attr( $close_button_color );
        $css_animation         = esc_attr( $css_animation );
        $animation_delay       = esc_attr( $animation_delay );


        if ($type == "with_icon" || $type == "with_custom_icon") {
            $message_classes .= " with_icon";
        }

        if ($background_color != "") {
            $message_styles .= "background-color: " . $background_color . ";";
        }

        if ($border) {
            $message_styles .= "border-style:solid;";
            if ($border_width != "") {
                $message_styles .= "border-width: " . $border_width . "px;";
            }
            if ($border_color != "") {
                $message_styles .= "border-color: " . $border_color . ";";
            }
        }

        if ($icon_color != "") {
            $icon_styles .= "color: " . $icon_color . ';';
        }

        if ($icon_background_color != "") {
            $icon_styles .= " background-color: " . $icon_background_color;
        }

        if ($close_button_color != "") {
            $close_button_styles .= "color: " . $close_button_color . ";";
        }
        if ($uppercase) {
            $message_classes .= ' uppercase';
        }

        $class_css_animation = "";
        if ($css_animation != "") {
            $class_css_animation = $css_animation;
        }

        if ($css_animation) {
            $message_classes .= ' ' . ($class_css_animation ? ' animate-element' : '');
        }

        if ($animation_delay != "") {
            $message_styles .= " transition-delay:" . $animation_delay . "ms; -webkit-animation-delay:" . $animation_delay . "ms; animation-delay:" . $animation_delay . "ms;";
        }

        if ($text_color) {
            $stylesheet = '
                .b_message-' . $style_id . ' .message_text_inner * {
                    color: ' . $text_color . ' !important;
                }';
        }

	    if ( $el_class ) {
		    $message_classes .= ' ' . esc_attr( $el_class );
	    }

        Levelup_Styles::addCSS($stylesheet, $style_id);

        $html .= "<div class='b_message " . $message_classes . "' style='" . $message_styles . "'" . ($class_css_animation ? ' data-animation-class="' . $class_css_animation . '"' : '') . ">";
        $html .= "<div class='b_message_inner col-table clearfix'>";

        $html .= "<a href='#' class='close'>";
        $html .= "<i class='fa fa-times' style='" . $close_button_styles . "'></i>";
        $html .= "</a>";

        if ($type == "with_icon" || ($type == "with_custom_icon" && $custom_icon != "")) {
            $icon_html .= '<div class="b_message_icon_holder col-td"><div class="q_message_icon"><div class="q_message_icon_inner">';
            if ($custom_icon != "" && $type == "with_custom_icon") {
                if (is_numeric($custom_icon)) {
                    $custom_icon_src = wp_get_attachment_url($custom_icon);
                } else {
                    $custom_icon_src = $custom_icon;
                }

                $custom_icon_styles = '';
                if ($icon_size) {
                    $custom_icon_styles = ' style="max-width:' . ($icon_size ? $icon_size : 20) . 'px;"';
                }

                $icon_html .= '<img src="' . esc_url( $custom_icon_src ) . '" alt=""' . $custom_icon_styles . '>';

            } else if ($type == "with_icon") {
                if ($icon_size) {
                    $icon_styles .= 'font-size:' . ($icon_size ? $icon_size : 20) . 'px;';
                }
                $icon_html .= "<i class='" . $icon_class . "' style='" . $icon_styles . "'></i>";
            }
            $icon_html .= '</div></div></div>';
        }

        $html .= $icon_html;

        $html .= "<div class='message_text_holder col-td'><div class='message_text'><div class='message_text_inner'><p>" . do_shortcode(esc_html($content)) . "</p></div></div></div>";

        $html .= "</div></div>";
        
        return $html;
    }
}


//***********************************************************************
// Message
//***********************************************************************

vc_map( array(
    "name" => esc_html__( "Message", 'LEVELUP' ),
    "base" => "rdy_message",
    "category" => 'by '.'LEVELUP',
    "icon" => LEVELUP_THEME_TEMPLATE_URL . "/admin/assets/images/vc/message.png",
    "allowed_container_element" => 'vc_row',
    "params" => array(
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__( "Type", 'LEVELUP' ),
            "param_name" => "type",
            "value" => array(
                esc_html__( "Normal", 'LEVELUP' ) => "normal",
                esc_html__( "With Icon library", 'LEVELUP' ) => "with_icon",
                esc_html__( "With Custom Icon", 'LEVELUP' ) => "with_custom_icon"
            ),
            "description" => esc_html__( "Select message type.", 'LEVELUP' )
        ),

        array(
            'type' => 'dropdown',
            'heading' => esc_html__( 'Icon library', 'LEVELUP' ),
            'value' => array(
                esc_html__( 'Font Awesome', 'LEVELUP' ) => 'fontawesome',
                esc_html__( 'Open Iconic', 'LEVELUP' ) => 'openiconic',
                esc_html__( 'Typicons', 'LEVELUP' ) => 'typicons',
                esc_html__( 'Entypo', 'LEVELUP' ) => 'entypo',
                esc_html__( 'Linecons', 'LEVELUP' ) => 'linecons',
                esc_html__( 'Etline', 'LEVELUP' ) => 'etline',
            ),
            'admin_label' => true,
            'param_name' => 'type_font',
            'description' => esc_html__( 'Select icon library.', 'LEVELUP' ),
            "dependency" => Array('element' => "type", 'value' => array('with_icon')),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_fontawesome',
            'value' => 'fa fa-adjust', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false,
                // default true, display an "EMPTY" icon?
                'iconsPerPage' => 4000,
                // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'fontawesome',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_openiconic',
            'value' => 'vc-oi vc-oi-dial', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'openiconic',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'openiconic',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_typicons',
            'value' => 'typcn typcn-adjust-brightness', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'typicons',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'typicons',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_entypo',
            'value' => 'entypo-icon entypo-icon-note', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'entypo',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'entypo',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_linecons',
            'value' => 'vc_li vc_li-heart', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'linecons',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'linecons',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_etline',
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'etline',
                'iconsPerPage' => 200, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'etline',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),

        array(
            "type" => "attach_image",
            "class" => "",
            "heading" => esc_html__( "Custom Icon", 'LEVELUP' ),
            "param_name" => "custom_icon",
            "dependency" => Array('element' => "type", 'value' => array('with_custom_icon')),
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Icon Size", 'LEVELUP' ),
            "param_name" => "icon_size",
            "value" => "",
            "description" => esc_html__( "Enter icon size in px.", 'LEVELUP' ),
            "dependency" => Array('element' => "type", 'value' => array('with_icon', 'with_custom_icon')),
			'edit_field_class' => 'vc_col-sm-7 vc_column',
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Icon Color", 'LEVELUP' ),
            "param_name" => "icon_color",
            'description' => esc_html__('Select Color Icon.', 'LEVELUP'),
            "dependency" => Array('element' => "type", 'value' => array('with_icon')),
			'edit_field_class' => 'vc_col-sm-5 vc_column',
            'group' => esc_html__('Icon', 'LEVELUP'),
        ),
		
		 array(
            "type" => "textarea_html",
            "class" => "",
            "heading" => esc_html__( "Message text", 'LEVELUP' ),
            "param_name" => "content",
            "value" => wp_kses( __( "<p>I am test text for Message shortcode.</p>", 'LEVELUP' ), array( 'p' => array() ) ),
            'description' => '',
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Text Color", 'LEVELUP' ),
            "param_name" => "text_color",
            'description' => esc_html__('Select Text Color.', 'LEVELUP'),
			'edit_field_class' => 'vc_col-sm-4 vc_column',
            "value" => "#333333",
        ),
		
		array(
            "type" => "checkbox",
            "heading" => esc_html__("Uppercase Text?", 'LEVELUP'),
            "param_name" => "uppercase",
            "value" => array(
                esc_html__( "Yes.", 'LEVELUP' ) => "true",
            ),
			'description' => esc_html__('If checked, text in the block is all uppercase.', 'LEVELUP'),
			'edit_field_class' => 'vc_col-sm-8 vc_column',
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Background Color", 'LEVELUP' ),
            "param_name" => "background_color",
            'description' => esc_html__('Select Background Color.', 'LEVELUP'),
            'edit_field_class' => 'vc_col-sm-4 vc_column',
            "value" => "#999999",
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Close Button Color", 'LEVELUP' ),
            "param_name" => "close_button_color",
            'description' => esc_html__('Select Close Button Color.', 'LEVELUP'),
            'edit_field_class' => 'vc_col-sm-8 vc_column',
            "value" => "##dd3333",
        ),
		
		array(
            "type" => "checkbox",
            "heading" => esc_html__("Box Border", 'LEVELUP'),
            "param_name" => "border",
            "value" => array(
                esc_html__( "Yes.", 'LEVELUP' ) => "true",
            ),
			'description' => esc_html__('If checked, displays border.', 'LEVELUP'),
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Border Width", 'LEVELUP' ),
            "param_name" => "border_width",
            "dependency" => Array('element' => "border", 'value' => array('true')),
			'description' => '',
			'edit_field_class' => 'vc_col-sm-6 vc_column', 
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Border Color", 'LEVELUP' ),
            "param_name" => "border_color",
            "dependency" => Array('element' => "border", 'value' => array('true')),
			'description' => '',
			'edit_field_class' => 'vc_col-sm-6 vc_column', 
        ),
		
        array(
            "type" => "dropdown",
            "heading" => esc_html__( "CSS Animation", 'LEVELUP' ),
            "param_name" => "css_animation",
            "admin_label" => true,
            "value" => levelup_get_vc_animation_options(),
            'description' => esc_html__('Select type of animation for element to be animated when it "enters" the browsers viewport or you can specify delay (Note: works only in modern browsers).', 'LEVELUP'),
            'group' => esc_html__('Animation', 'LEVELUP'),
        ),

        array(
            "type" => "textfield",
            "heading" => esc_html__( "Animation delay", 'LEVELUP' ),
            "param_name" => "animation_delay",
            "admin_label" => true,
            "value" => "",
            'description' => esc_html__('Specify the delay in milliseconds when animation start.', 'LEVELUP'),
            'group' => esc_html__('Animation', 'LEVELUP'),
        ),

        array(
            'type' => 'rdy_param_heading',
            'param_name' => 'btn1_icon_setting',
            'text' => '',
            'description' => '',
            'value' => '',
            'class' => '',
            'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
        ),

        array(
            'type' => 'textfield',
            'heading' => esc_html__( 'Extra class name', 'LEVELUP' ),
            'param_name' => 'el_class',
            'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'LEVELUP' )
        )
    )
) );
