<?php
if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}

class WPBakeryShortCode_Rdy_Pie_Chart extends WPBakeryShortCode {

    protected function content( $atts, $content = null ) {

	    $el_class = '';
	    $classes = '';

        $atts = vc_map_get_attributes( $this->getShortcode(), $atts );
        extract( $atts );

        vc_icon_element_fonts_enqueue( $type_font );
        $icon_class = esc_attr( ${"icon_" . $type_font} );

        $headings_array = array('h2', 'h3', 'h4', 'h5', 'h6');

        $title_tag = (in_array($title_tag, $headings_array)) ? $title_tag : 'h2';

        $color1 = levelup_get_accent_color($accent_color, $active_color);
        if ($accent_color == 'custom') {
            $color2 = $noactive_color;
        } else {
            $color2 = '#e0e0e0';
        }

        $width               = esc_attr( $width );
        $icon_size           = esc_attr( $icon_size );
        $icon_color          = esc_attr( $icon_color );
        $percentage_color    = esc_attr( $percentage_color );
        $percent_font_size   = esc_attr( $percent_font_size );
        $percent_font_weight = esc_attr( $percent_font_weight );
        $title_inside        = esc_html( $title_inside );
        $units               = esc_attr( $units );
        $units_font_size     = esc_attr( $units_font_size );
        $margin_title_top    = esc_attr( $margin_title_top );
        $margin_title_bottom = esc_attr( $margin_title_bottom );
        $title_color         = esc_attr( $title_color );
        $title               = esc_html( $title );

	    if ( $el_class ) {
		    $classes .= ' ' . esc_attr( $el_class );
	    }


	    $html = '';
        $html .= '<div class="b_pie_chart_holder' . ( $classes ? $classes : '' ) . '"><div class="b_percentage"  data-round="' . ($round ? 1 : 0) . '" data-width="' . $width . '" data-percent="' . $percent . '" data-linewidth="' . $line_width . '" data-active="' . $color1 . '" data-noactive="' . $color2 . '" data-animation-speed="' . ($animation_speed ? $animation_speed : 0) . '"';

        if ($type == "icon") {
            $html .= '>';
            $html .= '<i class="' . $icon_class . '" style="font-size:' . $icon_size . 'px;';
            if ($icon_color != "") {
                $html .= 'color: ' . $icon_color . ';';
            }
            $html .= '"></i>';

        } else {
            if ($percentage_color != "" || $percent_font_size != "" || $percent_font_weight != "") {
                $html .= ' style="';

                if ($percentage_color != "") {
                    $html .= 'color:' . $percentage_color . ';';
                }
                if ($percent_font_size != "") {
                    $html .= 'font-size:' . $percent_font_size . 'px;';
                }
                if ($percent_font_weight != "") {
                    $html .= 'font-weight:' . $percent_font_weight . ';';
                }
                $html .= '"';
            }
            $html .= '>';

            if ($type == "text" && $title_inside) {
                $html .= '<span>' . $title_inside . '</span>';
            } else {
                $html .= '<span class="tocounter">' . $percent . '</span><span class="units" style="font-size:' . ($units_font_size ? $units_font_size : 14) . 'px">' . $units . '</span>';
            }
        }

        $html .= '</div>';

        if ($title) {
            $html .= '<div class="pie_chart_text">';
            if ($title != "") {
                $title_style = "";
                if ($margin_title_top) {
                    $title_style .= 'margin-top: ' . $margin_title_top . 'px;';
                }
                if ($margin_title_bottom) {
                    $title_style .= 'margin-bottom: ' . $margin_title_bottom . 'px;';
                }

                if ($title_color != "") {
                    $title_style .= 'color: ' . $title_color . ';';
                }

                $html .= '<' . $title_tag . ' class="pie_title"' . ($title_style ? ' style="' . $title_style . '"' : '') . '>' . $title . '</' . $title_tag . '>';
            }

            if ($text != "") {
                $html .= '<p';
                if ($text_color != "") {
                    $html .= ' style="color: ' . $text_color . ';"';
                }
                $html .= '>' . $text . '</p>';
            }
            $html .= "</div>";
        }

        $html .= "</div>";
        
        return $html;
    }
}


//***********************************************************************
// Pie
//***********************************************************************

vc_map( array(
    "name" => esc_html__( "Round Chart", 'LEVELUP' ),
    "base" => "rdy_pie_chart",
    "icon" => LEVELUP_THEME_TEMPLATE_URL . "/admin/assets/images/vc/round-chart.png",
    "category" => 'by '.'LEVELUP',
    "allowed_container_element" => 'vc_row',
    "params" => array(
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__( "Type", 'LEVELUP' ),
            "param_name" => "type",
            "value" => array(
                esc_html__( "Pie Value Inside", 'LEVELUP' ) => "pievalue",
                esc_html__( "Text inside", 'LEVELUP' ) => "text",
                esc_html__( "Icon inside", 'LEVELUP' ) => "icon",
            ),
            'description' => esc_html__('Select Pie Chart Type.', 'LEVELUP'),
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Pie Chart Size", 'LEVELUP' ),
            "param_name" => "width",
            "description" => esc_html__( "Enter the size in width in pixels. Default 175.", 'LEVELUP' ),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Pie value", 'LEVELUP' ),
            "param_name" => "percent",
            "description" => esc_html__( "Input graph value here. Choose range between 0 and 100.", 'LEVELUP' ),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Text Inside", 'LEVELUP' ),
            "param_name" => "title_inside",
            "description" => esc_html__( "Enter Text Here.", 'LEVELUP' ),
            "dependency" => array('element' => 'type', 'value' => 'text')
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Pie Value/Text Color", 'LEVELUP' ),
            "param_name" => "percentage_color",
            "value" => "#333333",
            'description' => esc_html__('Select Pie value Color.', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => array('text', 'pievalue'))
        ),

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Pie Label Value Font Size", 'LEVELUP' ),
            "param_name" => "percent_font_size",
            'description' => esc_html__('Enter Pie label value Font Size.', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => array('text', 'pievalue')),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),
		
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__( "Pie Label Value Font weight", 'LEVELUP' ),
            "param_name" => "percent_font_weight",
            "value" => $font_weight_array,
            'description' => esc_html__('Select Pie label value Font weight.', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => array('text', 'pievalue')),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Units", 'LEVELUP' ),
            "param_name" => "units",
            "value" => "%",
            'description' => esc_html__('Enter Units.', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => 'pievalue'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Units Size", 'LEVELUP' ),
            "param_name" => "units_font_size",
            'description' => esc_html__('Enter Units Size in pixels. E.g. 20', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => 'pievalue'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),

        array(
            'type' => 'dropdown',
            'heading' => esc_html__( 'Icon library', 'LEVELUP' ),
            'value' => array(
                esc_html__( 'Font Awesome', 'LEVELUP' ) => 'fontawesome',
                esc_html__( 'Open Iconic', 'LEVELUP' ) => 'openiconic',
                esc_html__( 'Typicons', 'LEVELUP' ) => 'typicons',
                esc_html__( 'Entypo', 'LEVELUP' ) => 'entypo',
                esc_html__( 'Linecons', 'LEVELUP' ) => 'linecons',
                esc_html__( 'Etline', 'LEVELUP' ) => 'etline',
            ),
            'admin_label' => true,
            'param_name' => 'type_font',
            'description' => esc_html__( 'Select icon library.', 'LEVELUP' ),
            "dependency" => array('element' => "type", 'value' => array('icon'))
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_fontawesome',
            'value' => 'fa fa-adjust', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false,
                // default true, display an "EMPTY" icon?
                'iconsPerPage' => 4000,
                // default 100, how many icons per/page to display, we use (big number) to display all icons in single page
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'fontawesome',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_openiconic',
            'value' => 'vc-oi vc-oi-dial', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'openiconic',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'openiconic',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_typicons',
            'value' => 'typcn typcn-adjust-brightness', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'typicons',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'typicons',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_entypo',
            'value' => 'entypo-icon entypo-icon-note', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'entypo',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'entypo',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
        ),
		
        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_linecons',
            'value' => 'vc_li vc_li-heart', // default value to backend editor admin_label
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'linecons',
                'iconsPerPage' => 4000, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'linecons',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
        ),

        array(
            'type' => 'iconpicker',
            'heading' => esc_html__( 'Icon', 'LEVELUP' ),
            'param_name' => 'icon_etline',
            'settings' => array(
                'emptyIcon' => false, // default true, display an "EMPTY" icon?
                'type' => 'etline',
                'iconsPerPage' => 200, // default 100, how many icons per/page to display
            ),
            'dependency' => array(
                'element' => 'type_font',
                'value' => 'etline',
            ),
            'description' => esc_html__( 'Select icon from library.', 'LEVELUP' ),
        ),

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Icon Size", 'LEVELUP' ),
            "param_name" => "icon_size",
            "value" => "30",
            'description' => esc_html__('Enter Icon Size in pixels. E.g. 20', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => 'icon'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Icon Color", 'LEVELUP' ),
            "param_name" => "icon_color",
            "value" => "#333333",
            'description' => esc_html__('Select Icon Color.', 'LEVELUP'),
            "dependency" => array('element' => 'type', 'value' => 'icon'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),
		
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__( "Bar color", 'LEVELUP' ),
            "param_name" => "accent_color",
            "value" => $extra_colors,
			'description' => esc_html__('Select Bar colors.', 'LEVELUP'),
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Bar Active Color", 'LEVELUP' ),
            "param_name" => "active_color",
            'description' => esc_html__('Select Bar Active Color.', 'LEVELUP'),
            "dependency" => array('element' => 'accent_color', 'value' => 'custom'),
			'edit_field_class' => 'vc_col-sm-4 vc_column', 
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Bar Noactive Color", 'LEVELUP' ),
            "param_name" => "noactive_color",
            'description' => esc_html__('Select Bar Noactive Color.', 'LEVELUP'),
            "dependency" => array('element' => 'accent_color', 'value' => 'custom'),
			'edit_field_class' => 'vc_col-sm-4 vc_column', 
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Pie Chart Line Width", 'LEVELUP' ),
            "param_name" => "line_width",
            'description' => esc_html__('Enter Pie Chart Line Width.', 'LEVELUP'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',
        ),
		
        array(
            "type" => "checkbox",
            "class" => "",
            "heading" => esc_html__("Round corner?", 'LEVELUP'),
            "param_name" => "round",
            "value" => array(
                esc_html__( "Yes", 'LEVELUP' ) => "true"
            ),
			'description' => esc_html__('If checked, corners are rounded.', 'LEVELUP'),
            'edit_field_class' => 'vc_col-sm-6 vc_column',

        ),
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Animation Duration", 'LEVELUP' ),
            "param_name" => "animation_speed",
            "description" => esc_html__( "Enter Animation Duration in milliseconds. E.g. 2500", 'LEVELUP' ),
        ),

        /*
        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__( "Additional Text", 'LEVELUP' ),
            "param_name" => "addtext",
            "value" => array(
                esc_html__( "No", 'LEVELUP' ) => "",
                esc_html__( "Yes", 'LEVELUP' ) => "yes"
            ),
            "description" => esc_html__( "If you need additional text, select 'Yes'", 'LEVELUP' ),
            'group' => esc_html__('Text', 'LEVELUP'),
        ),
        */

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Title", 'LEVELUP' ),
            "param_name" => "title",
            'description' => esc_html__('Enter Title Here.', 'LEVELUP'),
            //"dependency" => array('element' => 'addtext', 'value' => 'yes'),
            'group' => esc_html__('Text', 'LEVELUP'),
        ),

        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Title Color", 'LEVELUP' ),
            "param_name" => "title_color",
            "value" => "#333333",
            'description' => esc_html__('Select Tiltle Color.', 'LEVELUP'),
            //"dependency" => array('element' => 'addtext', 'value' => 'yes'),
            'group' => esc_html__('Text', 'LEVELUP'),
        ),

        array(
            "type" => "dropdown",
            "class" => "",
            "heading" => esc_html__( "Title Tag", 'LEVELUP' ),
            "param_name" => "title_tag",
            "value" => array(
                ""   => "",
                "h2" => "h2",
                "h3" => "h3",
                "h4" => "h4",
                "h5" => "h5",
                "h6" => "h6",
            ),
            'description' => esc_html__('Use the tag to apply for the Title display style.', 'LEVELUP'),
            //"dependency" => array('element' => 'addtext', 'value' => 'yes'),
            'group' => esc_html__('Text', 'LEVELUP'),
        ),

        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Title Top Margin", 'LEVELUP' ),
            "param_name" => "margin_title_top",
            "description" => esc_html__( "Enter the value of the margin from the top. E.g. 20", 'LEVELUP' ),
            "dependency" => array('element' => 'addtext', 'value' => 'yes'),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
            'group' => esc_html__('Text', 'LEVELUP'),
        ),
		
        array(
            "type" => "textfield",
            "class" => "",
            "heading" => esc_html__( "Title Bottom Margin", 'LEVELUP' ),
            "param_name" => "margin_title_bottom",
            "description" => esc_html__( "Enter the value of the margin from the bottom. E.g. 20", 'LEVELUP' ),
            "dependency" => array('element' => 'addtext', 'value' => 'yes'),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
            'group' => esc_html__('Text', 'LEVELUP'),
        ),
		
        array(
            "type" => "textarea",
            "class" => "",
            "heading" => esc_html__( "Text", 'LEVELUP' ),
            "param_name" => "text",
            'description' => esc_html__('Enter Text.', 'LEVELUP'),
            "dependency" => array('element' => 'addtext', 'value' => 'yes'),
            'group' => esc_html__('Text', 'LEVELUP'),
        ),
		
        array(
            "type" => "colorpicker",
            "class" => "",
            "heading" => esc_html__( "Text Color", 'LEVELUP' ),
            "param_name" => "text_color",
            "value" => "#333333",
            'description' => esc_html__('Select Text Color.', 'LEVELUP'),
            "dependency" => array('element' => 'addtext', 'value' => 'yes'),
            'group' => esc_html__('Text', 'LEVELUP'),
        ),

        array(
            'type' => 'rdy_param_heading',
            'param_name' => 'btn1_icon_setting',
            'text' => '',
            'description' => '',
            'value' => '',
            'class' => '',
            'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
        ),

        array(
            'type' => 'textfield',
            'heading' => esc_html__( 'Extra class name', 'LEVELUP' ),
            'param_name' => 'el_class',
            'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'LEVELUP' )
        )
    )
) );