<?php
if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

class WPBakeryShortCode_Rdy_Products extends WPBakeryShortCode {

	protected function content( $atts, $content = null ) {

		$el_class = '';

		$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
		extract( $atts );

		$html = '';
		$numbers = absint($numbers);
		$columns = absint($columns);
		$autoslide = absint($autoslide);
		$show_navigation_dots = apply_filters('levelup_sanitize_flag', $show_navigation_dots);
		$show_navigation_arrows = apply_filters('levelup_sanitize_flag', $show_navigation_arrows);

		$operator = 'IN';

		$query_args = array(
			'post_type'           => 'product',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
//			'orderby'             => $orderby,
//			'order'               => $order,
			'posts_per_page'      => ($numbers > 0) ? $numbers : 4,
			'meta_query'          => WC()->query->get_meta_query()
		);

		$loop_name = 'products';

		if ( empty( $products_type ) || $products_type == 'products') {

			$query_args['orderby'] = $orderby ? $orderby : 'title';
			$query_args['order'] = $order ? $order : 'asc';

			if ( ! empty( $ids ) ) {
				$query_args['post__in'] = array_map( 'trim', explode( ',', $ids ) );

				$query_args['meta_query'] = array_merge( $query_args['meta_query'], WC()->query->stock_status_meta_query() );
			}

		} else if ( $products_type == 'top_rated' ) {
			$loop_name = 'top_rated_products';

		} else if ( $products_type == 'best_selling' ) {
			$loop_name = 'best_selling_products';

			$query_args['meta_key'] = 'total_sales';
			$query_args['orderby'] = 'meta_value_num';

		} else if ( $products_type == 'sale' ) {
			$loop_name = 'sale_products';

			$query_args['orderby'] = $orderby ? $orderby : 'title';
			$query_args['order'] = $order ? $order : 'asc';

			$query_args['meta_key'] = 'total_sales';
			$query_args['post__in'] = array_merge( array( 0 ), wc_get_product_ids_on_sale() );

		} else if ( $products_type == 'featured' ) {
			$loop_name = 'featured_products';

			$query_args['orderby'] = $orderby ? $orderby : 'date';
			$query_args['order'] = $order ? $order : 'desc';

			$meta_query   = WC()->query->get_meta_query();
			$meta_query[] = array(
				'key'   => '_featured',
				'value' => 'yes'
			);

			$query_args['meta_query'] = $meta_query;

		} else if ( $products_type == 'recent' ) {
			$loop_name = 'recent_products';

			$query_args['orderby'] = $orderby ? $orderby : 'date';
			$query_args['order'] = $order ? $order : 'desc';

		}


		if ( $products_type == 'top_rated' ) {
			add_filter( 'posts_clauses', array( __CLASS__, 'order_by_rating_post_clauses' ) );
		}

		global $woocommerce_loop;

		$products                    = new WP_Query( apply_filters( 'woocommerce_shortcode_products_query', $query_args, $atts, 'products' ) );
		$columns                     = absint( $atts['columns'] );
		$woocommerce_loop['columns'] = $columns;
		$woocommerce_loop['name']    = $loop_name;

		ob_start();

		if ( $products->have_posts() ) {
			while ( $products->have_posts() ) : $products->the_post();

				wc_get_template_part( 'content', 'product' );

			endwhile;
		}

		woocommerce_reset_loop();
		wp_reset_postdata();

		if ( $products_type == 'top_rated' ) {
			remove_filter( 'posts_clauses', array( __CLASS__, 'order_by_rating_post_clauses' ) );
		}

		$slider_data_attr = array();

		if ( $show_navigation_arrows ) {
			$slider_data_attr[] = 'data-slider-nav="1"';
		}
		if ( $show_navigation_dots ) {
			$slider_data_attr[] = 'data-slider-dots="1"';
		}
		if ( $show_navigation_dots ) {
			$slider_data_attr[] = 'data-autoslide="' . $autoslide . '"';
		}

		$slider_data_attr[] = 'data-columns="' . ($columns ? $columns : 3) . '"';

		$slider_data_attr = ' ' . implode(' ', $slider_data_attr);

		$html = '<div class="woocommerce"><ul class="products rdy_products_carousel owl-carousel' . ($el_class ? ' ' . esc_attr( $el_class ) : '') . '' . ($color_scheme == 'light' ? ' color-light' : '') . '"' . $slider_data_attr . '>' . ob_get_clean() . '</ul></div>';

		return $html;
	}

	public static function order_by_rating_post_clauses( $args ) {
		global $wpdb;

		$args['where']   .= " AND $wpdb->commentmeta.meta_key = 'rating' ";
		$args['join']    .= "LEFT JOIN $wpdb->comments ON($wpdb->posts.ID               = $wpdb->comments.comment_post_ID) LEFT JOIN $wpdb->commentmeta ON($wpdb->comments.comment_ID = $wpdb->commentmeta.comment_id)";
		$args['orderby'] = "$wpdb->commentmeta.meta_value DESC";
		$args['groupby'] = "$wpdb->posts.ID";

		return $args;
	}

}


function getCategoryChildsFull( $parent_id, $pos, $array, $level, &$dropdown ) {

	for ( $i = $pos; $i < count( $array ); $i ++ ) {
		if ( $array[ $i ]->category_parent == $parent_id ) {
			$name = str_repeat( '- ', $level ) . $array[ $i ]->name;
			$value = $array[ $i ]->slug;
			$dropdown[] = array(
				'label' => $name,
				'value' => $value,
			);
			getCategoryChildsFull( $array[ $i ]->term_id, $i, $array, $level + 1, $dropdown );
		}
	}
}


//***********************************************************************
// Products
//***********************************************************************

vc_map( array(
	"name"                      => __( 'Products Carousel', 'LEVELUP' ),
	"base"                      => "rdy_products",
	"icon"                      => "icon-wpb-woocommerce",
	"category"                  => 'by ' . 'LEVELUP',
	'description'               => __( 'Woo Products Carousel all in one', 'LEVELUP' ),
	"allowed_container_element" => 'vc_row',
	"params"                    => array(

		array(
			'type'        => 'dropdown',
			'heading'     => __( 'Products Type', 'LEVELUP' ),
			'param_name'  => 'products_type',
			'value'       => array(
				__( 'Products', 'LEVELUP' )     => 'products',
				__( 'Top Rated', 'LEVELUP' )    => 'top_rated',
				__( 'Best Selling', 'LEVELUP' ) => 'best_selling',
				__( 'Sale', 'LEVELUP' )         => 'sale',
				__( 'Featured', 'LEVELUP' )     => 'featured',
				__( 'Recent', 'LEVELUP' )       => 'recent',
			),
			'std'         => 'products',
			'description' => esc_html__( 'Select products type.', 'LEVELUP' ),
		),

		array(
			'type'        => 'textfield',
			'heading'     => __( 'Number of Products to Show', 'LEVELUP' ),
			'value'       => 4,
			'param_name'  => 'numbers',
			'save_always' => true,
			'description' => esc_html__( 'The `number` field is used to display the number of products.', 'LEVELUP' ),
		),

		array(
			'type'        => 'dropdown',
			'heading'     => __( 'Number of Products in Row', 'LEVELUP' ),
			'value'       => array(
				'3' => '3',
				'4' => '4',
				'5' => '5',
				'6' => '6',
			),
			'param_name'  => 'columns',
			'save_always' => true,
			'description' => esc_html__( 'Select number of products per row.', 'LEVELUP' ),
		),

		array(
			'type'        => 'autocomplete',
			'heading'     => __( 'Products', 'LEVELUP' ),
			'param_name'  => 'ids',
			'settings'    => array(
				'multiple'      => true,
				'sortable'      => true,
				'unique_values' => true,
				// In UI show results except selected. NB! You should manually check values in backend
			),
			'save_always' => true,
			'description' => __( 'Enter List of Products', 'LEVELUP' ),
			'dependency'  => array(
				'element' => 'products_type',
				'value'   => 'products',
			),
		),

		array(
			'type'             => 'dropdown',
			'heading'          => __( 'Order by', 'LEVELUP' ),
			'param_name'       => 'orderby',
			'value'            => array(
				'',
				__( 'Date', 'LEVELUP' )          => 'date',
				__( 'ID', 'LEVELUP' )            => 'ID',
				__( 'Author', 'LEVELUP' )        => 'author',
				__( 'Title', 'LEVELUP' )         => 'title',
				__( 'Modified', 'LEVELUP' )      => 'modified',
				__( 'Random', 'LEVELUP' )        => 'rand',
				__( 'Comment count', 'LEVELUP' ) => 'comment_count',
				__( 'Menu order', 'LEVELUP' )    => 'menu_order',
			),
			'std'              => 'title',
			'save_always'      => true,
			'description'      => sprintf( __( 'Select how to sort retrieved products. More at %s. Default by Title', 'LEVELUP' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
			'dependency'       => array(
				'element' => 'products_type',
				'value'   => array( 'products', 'recent', 'featured', 'sale' ),
			),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
		),

		array(
			'type'             => 'dropdown',
			'heading'          => __( 'Sort order', 'LEVELUP' ),
			'param_name'       => 'order',
			'value'            => array(
				'',
				__( 'Descending', 'LEVELUP' ) => 'DESC',
				__( 'Ascending', 'LEVELUP' )  => 'ASC',
			),
			'save_always'      => true,
			'description'      => sprintf( __( 'Designates the ascending or descending order. More at %s. Default by ASC', 'LEVELUP' ), '<a href="http://codex.wordpress.org/Class_Reference/WP_Query#Order_.26_Orderby_Parameters" target="_blank">WordPress codex page</a>' ),
			'dependency'       => array(
				'element' => 'products_type',
				'value'   => array( 'products', 'recent', 'featured', 'sale' ),
			),
			'edit_field_class' => 'vc_col-sm-6 vc_column',
		),

		array(
			'type'             => 'rdy_param_heading',
			'param_name'       => 'btn1_icon_setting',
			'text'             => '',
			'description'      => '',
			'value'            => '',
			'class'            => '',
			'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
		),

		array(
			'type'        => 'dropdown',
			'heading'     => __( 'Color Scheme Elements', 'LEVELUP' ),
			'param_name'  => 'color_scheme',
			'value'       => array(
				__( 'Dark', 'LEVELUP' )  => 'dark',
				__( 'Light', 'LEVELUP' ) => 'light',
			),
			'std'         => 'dark',
			'description' => esc_html__( 'Select a color scheme for the nav elements.', 'LEVELUP' )
		),

		array(
			"type"             => "checkbox",
			"class"            => "",
			"heading"          => esc_html__( "Show Navigation Arrows?", 'LEVELUP' ),
			"value"            => array( esc_html__( "Yes.", 'LEVELUP' ) => "yes" ),
			"param_name"       => "show_navigation_arrows",
			'edit_field_class' => 'vc_col-sm-6 vc_column',
		),

		array(
			"type"             => "checkbox",
			"class"            => "",
			"heading"          => esc_html__( "Show Dots Navigation?", 'LEVELUP' ),
			"value"            => array( esc_html__( "Yes.", 'LEVELUP' ) => "yes" ),
			"param_name"       => "show_navigation_dots",
			'edit_field_class' => 'vc_col-sm-6 vc_column',
		),

		array(
			'type'             => 'rdy_param_heading',
			'param_name'       => 'btn1_icon_setting',
			'text'             => '',
			'description'      => '',
			'value'            => '',
			'class'            => '',
			'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
		),


		array(
			'type'        => 'dropdown',
			'heading'     => __( 'Autoslide', 'LEVELUP' ),
			'param_name'  => 'autoslide',
			'value'       => array(
				__( 'Disable', 'LEVELUP' ) => '',
				__( '3 sec', 'LEVELUP' )   => '3000',
				__( '4 sec', 'LEVELUP' )   => '4000',
				__( '5 sec', 'LEVELUP' )   => '5000',
				__( '6 sec', 'LEVELUP' )   => '6000',
				__( '7 sec', 'LEVELUP' )   => '7000',
				__( '8 sec', 'LEVELUP' )   => '8000',
				__( '9 sec', 'LEVELUP' )   => '9000',
				__( '10 sec', 'LEVELUP' )  => '10000',
			),
			'description' => esc_html__( 'Select a value for the autoslide.', 'LEVELUP' ),
		),

		array(
			'type'       => 'hidden',
			'param_name' => 'skus',
		),

		array(
			'type'             => 'rdy_param_heading',
			'param_name'       => 'btn1_icon_setting',
			'text'             => '',
			'description'      => '',
			'value'            => '',
			'class'            => '',
			'edit_field_class' => 'rdy-param-heading-wrapper rdy_space_border vc_column vc_col-sm-12',
		),

		array(
			'type'        => 'textfield',
			'heading'     => esc_html__( 'Extra class name', 'LEVELUP' ),
			'param_name'  => 'el_class',
			'description' => esc_html__( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'LEVELUP' )
		)
	)
) );




function productIdAutocompleteSuggester( $query ) {
	global $wpdb;
	$product_id = (int) $query;
	$post_meta_infos = $wpdb->get_results( $wpdb->prepare( "SELECT a.ID AS id, a.post_title AS title, b.meta_value AS sku
					FROM {$wpdb->posts} AS a
					LEFT JOIN ( SELECT meta_value, post_id  FROM {$wpdb->postmeta} WHERE `meta_key` = '_sku' ) AS b ON b.post_id = a.ID
					WHERE a.post_type = 'product' AND ( a.ID = '%d' OR b.meta_value LIKE '%%%s%%' OR a.post_title LIKE '%%%s%%' )", $product_id > 0 ? $product_id : - 1, stripslashes( $query ), stripslashes( $query ) ), ARRAY_A );

	$results = array();
	if ( is_array( $post_meta_infos ) && ! empty( $post_meta_infos ) ) {
		foreach ( $post_meta_infos as $value ) {
			$data = array();
			$data['value'] = $value['id'];
			$data['label'] = __( 'Id', 'LEVELUP' ) . ': ' . $value['id'] . ( ( strlen( $value['title'] ) > 0 ) ? ' - ' . __( 'Title', 'LEVELUP' ) . ': ' . $value['title'] : '' ) . ( ( strlen( $value['sku'] ) > 0 ) ? ' - ' . __( 'Sku', 'LEVELUP' ) . ': ' . $value['sku'] : '' );
			$results[] = $data;
		}
	}

	return $results;
}


function productIdDefaultValueFromSkuToId( $query ) {
	$result = productIdAutocompleteSuggesterExactSku( $query );

	return isset( $result['value'] ) ? $result['value'] : false;
}


function productIdAutocompleteSuggesterExactSku( $query ) {
	global $wpdb;
	$query = trim( $query );
	$product_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM {$wpdb->postmeta} WHERE meta_key='_sku' AND meta_value='%s' LIMIT 1", stripslashes( $query ) ) );
	$product_data = get_post( $product_id );
	if ( 'product' !== $product_data->post_type ) {
		return '';
	}

	$product_object = wc_get_product( $product_data );
	if ( is_object( $product_object ) ) {

		$product_sku = $product_object->get_sku();
		$product_title = $product_object->get_title();
		$product_id = $product_object->id;

		$product_sku_display = '';
		if ( ! empty( $product_sku ) ) {
			$product_sku_display = ' - ' . __( 'Sku', 'LEVELUP' ) . ': ' . $product_sku;
		}

		$product_title_display = '';
		if ( ! empty( $product_title ) ) {
			$product_title_display = ' - ' . __( 'Title', 'LEVELUP' ) . ': ' . $product_title;
		}

		$product_id_display = __( 'Id', 'LEVELUP' ) . ': ' . $product_id;

		$data = array();
		$data['value'] = $product_id;
		$data['label'] = $product_id_display . $product_title_display . $product_sku_display;

		return ! empty( $data ) ? $data : false;
	}

	return false;
}


function productsIdsDefaultValue( $current_value, $param_settings, $map_settings, $atts ) {
	$value = trim( $current_value );
	if ( strlen( trim( $value ) ) === 0 && isset( $atts['skus'] ) && strlen( $atts['skus'] ) > 0 ) {
		$data = array();
		$skus = $atts['skus'];
		$skus_array = explode( ',', $skus );
		foreach ( $skus_array as $sku ) {
			$id = productIdDefaultValueFromSkuToId( trim( $sku ) );
			if ( is_numeric( $id ) ) {
				$data[] = $id;
			}
		}
		if ( ! empty( $data ) ) {
			$values = explode( ',', $value );
			$values = array_merge( $values, $data );
			$value = implode( ',', $values );
		}
	}

	return $value;
}


function productIdAutocompleteRender( $query ) {
	$query = trim( $query['value'] ); // get value from requested
	if ( ! empty( $query ) ) {
		// get product
		$product_object = wc_get_product( (int) $query );
		if ( is_object( $product_object ) ) {
			$product_sku = $product_object->get_sku();
			$product_title = $product_object->get_title();
			$product_id = $product_object->id;

			$product_sku_display = '';
			if ( ! empty( $product_sku ) ) {
				$product_sku_display = ' - ' . __( 'Sku', 'LEVELUP' ) . ': ' . $product_sku;
			}

			$product_title_display = '';
			if ( ! empty( $product_title ) ) {
				$product_title_display = ' - ' . __( 'Title', 'LEVELUP' ) . ': ' . $product_title;
			}

			$product_id_display = __( 'Id', 'LEVELUP' ) . ': ' . $product_id;

			$data = array();
			$data['value'] = $product_id;
			$data['label'] = $product_id_display . $product_title_display . $product_sku_display;

			return ! empty( $data ) ? $data : false;
		}

		return false;
	}

	return false;
}


//Filters For autocomplete param:
//For suggestion: vc_autocomplete_[shortcode_name]_[param_name]_callback
add_filter( 'vc_autocomplete_rdy_products_ids_callback', 'productIdAutocompleteSuggester', 10, 1 ); // Get suggestion(find). Must return an array
add_filter( 'vc_autocomplete_rdy_products_ids_render', 'productIdAutocompleteRender', 10, 1 ); // Render exact product. Must return an array (label,value)
//For param: ID default value filter
add_filter( 'vc_form_fields_render_field_rdy_products_ids_param_value',	'productsIdsDefaultValue', 10, 4 ); // Defines default value for param if not provided. Takes from other param value.
