<?php
if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}


class Vc_Vendor_Royalslider implements Vc_Vendor_Interface {
    protected static $instanceIndex = 1;

    public function load() {
        $this->buildShortcode();
    }

    public function buildShortcode() {
        if ( class_exists( 'NewRoyalSliderMain' ) ) {
            global $wpdb;
            $table = NewRoyalSliderMain::get_sliders_table_name();
            $qstr = "SELECT * FROM $table WHERE active=1 AND type = 'custom' ORDER by id";
            $res = $wpdb->get_results( $qstr , ARRAY_A );

            if ( $res ) {
                foreach ( $res as $slider ) {
                    $name = $slider['name'] ? $slider['name'] : 'Untitled slider #'. $slider['id'];
                    $revsliders[ $name ] = $slider['id'];
                }
            } else {
                $revsliders[ esc_html__( 'No sliders found', 'LEVELUP' ) ] = 0;
            }
            // add shortcode to visual composer
            $this->mapShortcode( $revsliders );

            // Add fixes for frontend editor to regenerate id
            if ( vc_is_frontend_ajax() || vc_is_frontend_editor() ) {
                add_filter( 'vc_royalslider_shortcode', array( &$this, 'setId' ) );
            }
        }
    }

    public function mapShortcode( $revsliders = array() ) {
        vc_map( array(
            'base' => 'rdy_royal_slider_vc',
            'name' => esc_html__( 'Royal Slider', 'LEVELUP' ),
            'icon' => LEVELUP_THEME_TEMPLATE_URL . "/admin/assets/images/vc/royal-slider.png",
            'category' => esc_html__( 'Content', 'LEVELUP' ),
            'description' => esc_html__( 'Place Royal slider', 'LEVELUP' ),
            "params" => array(

                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__( 'Royal Slider', 'LEVELUP' ),
                    'param_name' => 'alias',
                    'admin_label' => true,
                    'value' => $revsliders,
                    'description' => esc_html__( 'Select your Royal Slider.', 'LEVELUP' )
                ),

            )
        ));
    }

    public function setId( $output ) {
        return preg_replace( '/rev_slider_(\d+)_(\d+)/', 'rev_slider_$1_$2' . time() . '_' . self::$instanceIndex ++, $output );
    }

}


function levelup_royalslider_load() {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' ); // Require plugin.php to use is_plugin_active() below
	if ( is_plugin_active( 'new-royalslider/newroyalslider.php' ) ) {
		if ( class_exists( 'NewRoyalSliderMain' ) ) {
			$vendor = new Vc_Vendor_Royalslider();
			$vendor->load();
		}
	}
}
add_action( 'init', 'levelup_royalslider_load', 20 );


class WPBakeryShortCode_Rdy_Royal_Slider_Vc extends WPBakeryShortCode {

    protected function content( $atts, $content = null ) {
        $output = $title = $alias = $el_class = '';
        $args = array(
            'title' => '',
            'alias' => '',
            'el_class' => ''
        );
        extract(shortcode_atts($args, $atts));

        $el_class = $this->getExtraClass($el_class);
        $css_class = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, 'wpb_royalslider_element wpb_content_element' . $el_class, $this->settings['base'], $atts );

        $output .= '<div class="' . $css_class . '">';
        $output .= wpb_widget_title(array('title' => $title, 'extraclass' => 'wpb_royalslider_heading'));


	    if ( class_exists('NewRoyalSliderMain') ) {
		    if ( ! $alias ) {
			    global $wpdb;
			    $table = NewRoyalSliderMain::get_sliders_table_name();
			    $qstr  = "SELECT * FROM $table WHERE active=1 AND type = 'custom' ORDER by id LIMIT 1";
			    $res   = $wpdb->get_row( $qstr, ARRAY_A );
			    if ( $res ) {
				    $alias = $res['id'];
			    }
		    }

		    global $new_royalSlider;

		    register_new_royalslider_files( $alias );
		    $output .= apply_filters( 'vc_royalslider_shortcode', do_shortcode( '[new_royalslider id="' . $alias . '"]' ) );
		    $new_royalSlider->frontend_styles();
	    }

        $output .= '</div>' . "\n";

        return $output;
    }
}
