<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


class BR_Shortcode_Portfolio extends BR_Shortcode {

    static protected $instance;

    protected $shortcode_name = 'rdy_portfolio';
    protected $post_type = 'rdy_portfolio';
    protected $taxonomy = 'rdy_portfolio_category';
    protected $atts;

    public static function get_instance() {
        if ( !self::$instance ) {
            self::$instance = new BR_Shortcode_Portfolio();
        }
        return self::$instance;
    }

    protected function __construct() {

        add_shortcode( $this->shortcode_name, array($this, 'shortcode') );

    }

    public function shortcode( $atts, $content = null ) {
        if ( ! function_exists( 'vc_map_get_attributes' ) ) {
            return;
        }

        $attributes = vc_map_get_attributes( $this->shortcode_name, $atts );

        if ( $attributes['category']) {
            $attributes['category'] = explode(',', $attributes['category']);
            $attributes['category'] = array_map('trim', $attributes['category']);
            $attributes['select'] = 'only';
        } else {
            $attributes['select'] = 'all';
        }

        $attributes['type'] = in_array($attributes['type'], array('masonry', 'grid', 'grid_adv', 'height', 'animation1') ) ? $attributes['type'] : 'masonry';
        $attributes['item_height'] = absint($attributes['item_height']);
        $attributes['item_dynamic_height'] = absint($attributes['item_dynamic_height']);
        $attributes['adv_pattern'] = intval($attributes['adv_pattern']);

        if (in_array($attributes['type'], array('animation1'))) {
            $attributes['columns'] = 3;
        } else {
            $attributes['columns'] = in_array($attributes['columns'], array('2', '3', '4', '6')) ? absint($attributes['columns']) : 2;
        }

        $attributes['filter'] = in_array($attributes['filter'], array('light', 'dark') ) ? $attributes['filter'] : '';
        $attributes['filter_animation'] = in_array($attributes['filter_animation'], array('anim-1', 'anim-2') ) ? $attributes['filter_animation'] : '';
        $attributes['filter_align'] = in_array($attributes['filter_align'], array('left', 'center', 'right') ) ? $attributes['filter_align'] : 'left';
        $attributes['filter_margin_top'] = absint($attributes['filter_margin_top']);
        $attributes['filter_margin_bottom'] = absint($attributes['filter_margin_bottom']);
        $attributes['number'] = apply_filters('rdy_sanitize_posts_per_page', $attributes['number']);

        $attributes['gallery'] = apply_filters('levelup_sanitize_flag', $attributes['gallery']);
        $attributes['square_image'] = apply_filters('levelup_sanitize_flag', $attributes['square_image']);
        $attributes['hide_title'] = apply_filters('levelup_sanitize_flag', $attributes['hide_title']);
        $attributes['hide_subtitle'] = apply_filters('levelup_sanitize_flag', $attributes['hide_subtitle']);
        $attributes['use_custom_font'] = apply_filters('levelup_sanitize_flag', $attributes['use_custom_font']);
        $attributes['large_image'] = apply_filters('levelup_sanitize_flag', $attributes['large_image']);

        $attributes['text_shadow'] = in_array($attributes['text_shadow'], array('shadow1', 'shadow2', 'shadow3',)) ? $attributes['text_shadow'] : '';
        $attributes['hover_type'] = in_array($attributes['hover_type'], array('', '1', '2', '3', '4', '5', '6', '10', '11')) ? $attributes['hover_type'] : '1';
        $attributes['height_hover_type'] = in_array($attributes['height_hover_type'], array('zoom_in', 'zoom_out', 'zoom_in_title', 'zoom_out_title', 'fade_in', 'fade_out')) ? $attributes['height_hover_type'] : '';
        $attributes['height_hover_speed'] = in_array($attributes['height_hover_speed'], array('fast', 'slow')) ? $attributes['height_hover_speed'] : '';
        $attributes['caption_valign'] = in_array($attributes['caption_valign'], array('middle', 'bottom')) ? $attributes['caption_valign'] : '';

        if(in_array($attributes['type'], array('height') )) {
            $attributes['content_align'] = in_array($attributes['height_content_align'], array('left', 'center', 'right') ) ? $attributes['height_content_align'] : 'left';
        } else {
            $attributes['content_align'] = in_array($attributes['content_align'], array('left', 'center', 'right') ) ? $attributes['content_align'] : 'left';
        }

        $attributes['hover_opacity'] = intval($attributes['hover_opacity']) >= 0 ? intval($attributes['hover_opacity']) : 0;
        $attributes['hover_opacity_from'] = intval($attributes['hover_opacity_from']) >= 0 ? intval($attributes['hover_opacity_from']) : 100;

        if (in_array($attributes['type'], array('animation1'))) {
            $attributes['gutter'] = 40;
        } else {
            $attributes['gutter'] = intval($attributes['gutter']);
        }

        if($attributes['select_items'] == 'select') {
            $attributes['select_ids'] = array_map('intval', explode(',', $attributes['ids']));
        }
        elseif($attributes['select_items'] == 'exclude'){
            $attributes['exclude_ids'] = array_map('intval', explode(',', $attributes['ids']));
        }

        $this->atts = $attributes;

        $output = $this->portfolio_grid( $attributes );

        return $output;
    }


    public function portfolio_grid( $attributes = array() ) {
        global $post;

        $output = $html = $category = $infinite_class = '';

        $post_backup = $post;
        $post_per_page = absint($attributes['number']);

        $style_id = Levelup_Styles::shortcode_id();
        if (!($post_per_page > 0 && $post_per_page < 100)){
            $post_per_page = 20;
        }

        if($attributes['pagination'] != 'no'){
            $attributes['no_found_rows'] = 0;
            $attributes['number'] = $post_per_page;
        }

        $wp_query = $this->get_posts_by_terms( $attributes );

        if ( $wp_query->have_posts() ) {

            $config = Levelup_Config::get_instance();

            wp_enqueue_script( 'isotope' );

            $config_backup = $config->get();

            $config->set('style_id', $style_id);
            $config->set('type', $attributes['type']);
            $config->set('layout', $attributes['type']);
            $config->set('large_image', $attributes['large_image']);
            $config->set('height', $attributes['item_height'] ? $attributes['item_height'] : 300);
            $config->set('dynamic_height', $attributes['item_dynamic_height'] ? $attributes['item_dynamic_height'] : 40);
            $config->set('columns', $attributes['columns']);

            $config->set('hover_type', $attributes['hover_type']);
            $config->set('adv_pattern', $attributes['adv_pattern']);

            if(in_array($attributes['hover_type'], array('1', '2', '3', '4', '5'))){
                $config->set('hide_title', $attributes['hide_title']);
            }
            $config->set('hide_subtitle', $attributes['hide_subtitle']);
            $config->set('pagination', $attributes['pagination']);

            $config->set('hover_color', $attributes['hover_color']);
            $config->set('hover_opacity', $attributes['hover_opacity']);
            $config->set('hover_opacity_from', $attributes['hover_opacity_from']);
            $config->set('content_align', $attributes['content_align']);

            $config->set('title_fontsize', absint($attributes['title_fontsize']));
            $config->set('title_font_color', $attributes['title_font_color']);
            $config->set('subtitle_fontsize', absint($attributes['subtitle_fontsize']));
            $config->set('subtitle_font_color', $attributes['subtitle_font_color']);

            $config->set('gallery', $attributes['gallery']);
            $config->set('square_image', $attributes['square_image']);
            $config->set('use_custom_font', $attributes['use_custom_font']);

            $config->set('items_animation', $attributes['items_animation']);


            if ($attributes['filter'] && ( $attributes['type'] == 'masonry' || $attributes['type'] == 'grid' )) {
                $html .= "<div class='filter_portfolio list_categories " . ( $attributes['filter_animation'] ? ' ' . esc_attr( $attributes['filter_animation'] ) : 'no-anim' ) . ( $attributes['filter'] == 'light' ? ' light' : ' dark' ) . "' style='margin-top: " . esc_attr( $attributes['filter_margin_top'] ) . "px; margin-bottom: " . esc_attr( $attributes['filter_margin_bottom'] ) . "px;'>";
                $html .= "<div class='filter_outer col-table'>";
                $html .= "<ul class='filter_holder col-td " . esc_attr( $attributes['filter_align'] ) . "'>";

                $html .= "<li><a href='#' class='filter current' data-filter='*'><span>" . esc_html__('All', 'LEVELUP') . "</span></a></li>";

                if ($category == "") {
                    $args = array(
                        'parent' => 0,
                        'slug' => $attributes['category'],
                    );
                    $portfolio_categories = get_terms('rdy_portfolio_category', $args);
                } else {
                    $top_category = get_term_by('slug', $category, 'rdy_portfolio_category');
                    $term_id = '';

                    if (isset($top_category->term_id))
                        $term_id = $top_category->term_id;

                    $args = array(
                        'parent' => $term_id,
                        'slug' => $attributes['category'],
                    );
                    $portfolio_categories = get_terms('portfolio_category', $args);
                }
                foreach ($portfolio_categories as $portfolio_category) {
                    $html .= "<li><a href='#' class='filter' data-filter='category-$portfolio_category->term_id'><span>$portfolio_category->name</span>";
                    $args = array(
                        'child_of' => $portfolio_category->term_id
                    );
                    $html .= '</a></li>';
                }
                $html .= "</ul>";
                $html .= "</div>";
                $html .= "</div>";
            }


            $item_count = 0;
            while ( $wp_query->have_posts() ) {
                $wp_query->the_post();
                ob_start();

                set_query_var('item_count', $item_count);
                levelup_get_template_part( 'portfolio-loop' );

                $output .= ob_get_contents();
                ob_end_clean();
                $item_count++;

                if ($config->get('type') == 'grid_adv') {
                    if ($config->get('adv_pattern') == 1) {
                        if ($item_count >= 10) $item_count = 0;
                    } elseif ($config->get('adv_pattern') == 2) {
                        if ($item_count >= 12) $item_count = 0;
                    } elseif ($config->get('adv_pattern') == 4) {
                        if ($item_count >= 15) $item_count = 0;
                    }  elseif ($config->get('adv_pattern') == 5) {

                    } else {
                        if ($item_count >= 10) $item_count = 0;
                    }
                }
            }


            if( empty( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ] ) ||
                strtolower( $_SERVER[ 'HTTP_X_REQUESTED_WITH' ]) != 'xmlhttprequest' ) {

                if ( $config->get( 'type' ) == 'grid_adv' ) {
                    $output .= '<div class="grid-item grid-sizer"></div>';
                } else {
                    $output .= '<div class="' . levelup_calc_columns_class( $attributes['columns'] ) . ' grid-sizer"></div>';
                }
            }

            $post = $post_backup;
            setup_postdata( $post );

            $config->reset( $config_backup );

            $masonry_container_classes[] = 'rdy_portfolio-' . $style_id ;
            $masonry_container_classes[] = 'rdy-portfolio-container';

            $masonry_container_classes[] = 'iso-container';

            if($attributes['el_class']){
                $masonry_container_classes[] = $attributes['el_class'];
            }

            if(!$attributes['gutter']){
                $masonry_container_classes[] = 'no-gutter';
            }

            if($attributes['active_border']){
                $masonry_container_classes[] = 'active-border';

                if($attributes['active_border'] == 'animation'){
                    $masonry_container_classes[] = 'active-border-animation';
                }

                if($attributes['active_border'] == 'fade'){
                    $masonry_container_classes[] = 'active-border-fade';
                }
            }

            if($attributes['text_shadow']){
                $masonry_container_classes[] = 'title-' . esc_attr( $attributes['text_shadow'] );
            }

            if (in_array($attributes['type'], array('height'))) {
                $masonry_container_classes[] = 'type-height';

                if ($attributes['height_hover_type']) {
                    if (in_array($attributes['height_hover_type'], array('zoom_in', 'zoom_out', 'fade_in', 'fade_out'))) {
                        $masonry_container_classes[] = 'hover-' . esc_attr( $attributes['height_hover_type'] );
                    }
                    elseif($attributes['height_hover_type'] == 'zoom_in_title'){
                        $masonry_container_classes[] = 'hover-zoom_in';
                        $masonry_container_classes[] = 'hover-title-zoom_in';
                    }
                    elseif($attributes['height_hover_type'] == 'zoom_out_title'){
                        $masonry_container_classes[] = 'hover-zoom_out';
                        $masonry_container_classes[] = 'hover-title-zoom_out';
                    }
                }
                if ($attributes['height_hover_speed']) {
                    if ($attributes['height_hover_speed'] == 'slow') {
                        $masonry_container_classes[] = 'hover-speed-slow';
                    }
                }
                if ($attributes['caption_valign']) {
                    $masonry_container_classes[] = 'caption-valign-' . esc_attr( $attributes['caption_valign'] );
                }
            }

            if ($attributes['hover_type'] && !(in_array($attributes['type'], array('height')))) {
                $masonry_container_classes[] = 'hover-' . esc_attr( $attributes['hover_type'] );
            }


            if ( $attributes['type'] == 'grid_adv' ) {
                $masonry_container_classes[] = 'rdy-masonry';
                $masonry_container_classes[] = 'rdy-masonry-adv';
            } elseif ( $attributes['type'] == 'grid' ) {
                $masonry_container_classes[] = 'rdy-grid';
            } elseif ( $attributes['type'] == 'height' ) {
            } else {
                $masonry_container_classes[] = 'rdy-masonry';
            }

            if ($attributes['pagination'] == 'more') {
                $masonry_container_classes[] = 'load-button-style';
            } elseif ($attributes['pagination'] == 'infinite') {
                $masonry_container_classes[] = 'infinite-style';
            }

            if (in_array($attributes['hover_type'], array(10, 11)) || in_array($attributes['type'], array('height'))) {
                $masonry_container_classes[] = 'content-' . esc_attr($attributes['content_align']);
            }

            $masonry_container_classes = implode(' ', $masonry_container_classes);

            $item_id = (!empty($item_id)) ? $item_id : 1409305847;

            $masonry_container_data_attr = array(
                'data-gutter="' . ($attributes['gutter'] ? $attributes['gutter'] : 0) . '"',
                'data-uniqid="' . $item_id . '"',
            );

            if ($attributes['type'] == 'grid_adv' && ($attributes['adv_pattern'] == 3 || $attributes['adv_pattern'] == 4 || $attributes['adv_pattern'] == 5)) {
                $masonry_container_data_attr[] = 'data-col="' . 4 . '"';
            }

            if ($attributes['items_animation']) {
                $masonry_container_data_attr[] = 'data-items-animation="' . esc_attr($attributes['items_animation']) . '"';


                if ($attributes['items_animation_queue']) {
                    $masonry_container_data_attr[] = 'data-items-animation-queue="1"';
                }
            }

            $masonry_container_data_attr = ' ' . implode(' ', $masonry_container_data_attr);


            if ($attributes['pagination'] == 'more' || $attributes['pagination'] == 'infinite') {
                //$output_template = '%s<div class="infinite-scroll0"><div class="%s"%s>%s</div>';
                $infinite_class = ' infinite-scroll';
            } else {
                //$output_template = '%s<div class="%s"%s>%s</div>';
            }

            $output_template = '%s<div class="%s"%s>%s</div>';

            $output = sprintf( $output_template,
                $html,
                esc_attr($masonry_container_classes),
                $masonry_container_data_attr,
                $output
            );

            if ($attributes['pagination'] == 'more' || $attributes['pagination'] == 'infinite') {
                $output .= '<div class="infinite-loading"></div>';
            }

            if ($attributes['pagination'] != 'no') {
                $paginate = levelup_paginator($wp_query, array('type' => $attributes['pagination']));
                $output = sprintf( '%s<div>%s</div>',
                    $output,
                    $paginate
                );
            }

            if ($attributes['pagination'] == 'more') {
                $output .= do_shortcode('[rdy_button el_class="rdy-load-more" text="load more" font_weight="700" uppercase="true" size="large" style="outline" outline_skin="custom" outline_active_color="' . esc_attr( $attributes['pagination_button_color'] ) . '" outline_hover_color="#ffffff" border_size="1" border_radius="2" margin_top="0" margin_bottom="0"]');
            }

            if ($attributes['pagination'] == 'more' || $attributes['pagination'] == 'infinite') {
                $output .= '</div>';
            }


        }

        $output = '<div class="container-fluid0 rdy_portfolio_container"><div class="rdy_portfolio_wrap row0' . $infinite_class . '">' . $output . '</div></div>';

        $stylesheet = '';

        if ($attributes['gutter']) {
            $gutter = esc_attr( $attributes['gutter'] );

            if ($gutter == 1) {
                $stylesheet .= '
                .rdy_portfolio-'.$style_id.':not(.rdy-masonry-adv) .grid-item {
                    padding-left: 0;
                    padding-right: 1px;
                    margin-bottom: 1px;
                }
                ';
            } else {
                if ( in_array( $attributes['type'], array( 'height' ) ) ) {
                    $gutter_rl   = 0;
                    $gutter_rl_m = 0;
                    $gutter_b    = $gutter * 2;
                } else {
                    $gutter_rl   = $gutter;
                    $gutter_rl_m = 10;
                    if ( $attributes['type'] == 'animation1' ) {
                        $gutter_b = $gutter * 7;
                    } else {
                        $gutter_b = $gutter * 2;
                    }

                }
                $stylesheet .= '
                @media (min-width: 992px) {
                    .rdy_portfolio-' . $style_id . ':not(.rdy-masonry-adv) .grid-item {
                        padding-left: ' . $gutter_rl . 'px;
                        padding-right: ' . $gutter_rl . 'px;
                        margin-bottom: ' . $gutter_b . 'px;
                    }
                    .rdy_portfolio-' . $style_id . ':not(.rdy-masonry-adv) {
                        margin-left: -' . $gutter_rl . 'px;
                        margin-right: -' . $gutter_rl . 'px;
                    }
                }
                @media (max-width: 992px) {
                    .rdy_portfolio-' . $style_id . ':not(.rdy-masonry-adv) .grid-item {
                        padding-left: ' . $gutter_rl_m . 'px;
                        padding-right: ' . $gutter_rl_m . 'px;
                        margin-bottom: 30px;
                    }
                    .rdy_portfolio-' . $style_id . ':not(.rdy-masonry-adv) {
                        margin-left: -' . $gutter_rl_m . 'px;
                        margin-right: -' . $gutter_rl_m . 'px;
                    }
                }

                ';
            }
        }


        $opacity = levelup_convert_opacity($attributes['hover_opacity'], false);
        $opacity_from = levelup_convert_opacity($attributes['hover_opacity_from'], false);

        if ($opacity >= 0 && (in_array($attributes['hover_type'], array(1, 2, 3, 4, 5, 10, 11)) || in_array($attributes['type'], array('height')))) {

            $stylesheet .= '
                .rdy_portfolio-' . $style_id . ' .grid-item figure .picture .overlay {
                    opacity: ' . esc_attr( $opacity_from ) . '
                }
                .rdy_portfolio-' . $style_id . ' .grid-item figure:hover .picture .overlay {
                    opacity: ' . esc_attr( $opacity ) . ' !important
                }
            ';

        }


        if ($attributes['active_border']) {
            if ($attributes['active_border'] == 'animation') {
                $stylesheet .= '
                .rdy_portfolio-' . $style_id . '.active-border .grid-item .rdy_portfolio figure .picture:before {
                    border-color: ' . esc_attr( $attributes['active_border_color'] ) . '
                }
                .rdy_portfolio-' . $style_id . '.active-border .grid-item .rdy_portfolio figure:hover .picture:before {
                    border-width: ' . esc_attr( $attributes['active_border_width'] ) . 'px
                }
                ';
            } else {
                $stylesheet .= '
                .rdy_portfolio-' . $style_id . '.active-border .grid-item .rdy_portfolio figure .picture:before {
                    border-color: ' . esc_attr( $attributes['active_border_color'] ) . ';
                    border-width: ' . esc_attr( $attributes['active_border_width'] ) . 'px;
                }
                ';
            }
        }

        if (isset($_GET["portfolio_1"])) {
            $stylesheet .= '
            .rdy-portfolio-container .figcaption h2,
            .rdy-portfolio-container .figcaption .description,
            .rdy-portfolio-container.hover-10 figure:hover .figcaption h2,
            .rdy-portfolio-container.hover-11 figure:hover .figcaption h2,
            .rdy-portfolio-container.hover-10 figure:hover .figcaption .description,
            .rdy-portfolio-container.hover-11 figure:hover .figcaption .description {
                color: #222222;
            }
            .rdy-portfolio-container .figcaption h2 {
                font-size: 35px;
                font-weight: 600;
            }
            ';
        }

        Levelup_Styles::addCSS($stylesheet, $style_id);

        return $output;
    }

}


BR_Shortcode_Portfolio::get_instance();