<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


class BR_Shortcode_Portfolio_List extends BR_Shortcode {

	static protected $instance;

	protected $shortcode_name = 'rdy_portfolio_list';
	protected $post_type = 'rdy_portfolio';
	protected $taxonomy = 'rdy_portfolio_category';
	protected $atts;

	public static function get_instance() {
		if ( !self::$instance ) {
			self::$instance = new BR_Shortcode_Portfolio_List();
		}
		return self::$instance;
	}

	protected function __construct() {

		add_shortcode( $this->shortcode_name, array($this, 'shortcode') );

	}

	public function shortcode( $atts, $content = null ) {
		if ( ! function_exists( 'vc_map_get_attributes' ) ) {
			return;
		}

		$attributes = vc_map_get_attributes( $this->shortcode_name, $atts );

		if ( $attributes['category']) {
			$attributes['category'] = explode(',', $attributes['category']);
			$attributes['category'] = array_map('trim', $attributes['category']);
			$attributes['select'] = 'only';
		} else {
			$attributes['select'] = 'all';
		}

		if($attributes['select_items'] == 'select'){
			$attributes['select_ids'] = array_map('intval', explode(',', $attributes['ids']));
		}
		elseif($attributes['select_items'] == 'exclude'){
			$attributes['exclude_ids'] = array_map('intval', explode(',', $attributes['ids']));
		}

		$this->atts = $attributes;

		$output = $this->portfolio_list( $attributes );

		return $output;
	}


	public function portfolio_list( $attributes = array() ) {
		global $post;

		$output = $html = $category = '';

		$post_backup = $post;

		$style_id = Levelup_Styles::shortcode_id();
		$post_per_page = 100;


		$wp_query = $this->get_posts_by_terms( $attributes );

		if ( $wp_query->have_posts() ) {

			$config = Levelup_Config::get_instance();

			wp_enqueue_script( 'isotope' );

			$config_backup = $config->get();

			$config->set('style_id', $style_id);

			$config->set('list_divider_color', $attributes['list_divider_color']);
			$config->set('list_divider_size', $attributes['list_divider_size']);
			$config->set('list_hover_color', $attributes['list_hover_color']);
			$config->set('list_hover_bgcolor', $attributes['list_hover_bgcolor']);


			while ( $wp_query->have_posts() ) {
				$wp_query->the_post();
				ob_start();

				levelup_get_template_part('portfolio-list-loop');

				$output .= ob_get_contents();
				ob_end_clean();

			}


			$post = $post_backup;
			setup_postdata( $post );

			$config->reset( $config_backup );

			$masonry_container_data_attr = array();
			$masonry_container_classes = array();
			$masonry_container_classes[] = 'rdy_portfolio-' . $style_id ;
			$masonry_container_classes[] = 'rdy-portfolio-container';
			$masonry_container_classes[] = 'type-list';

			if ( ! empty( $attributes['items_animation'] ) ) {
				$masonry_container_classes[] = 'list-animation';
			}

			if ( ! empty( $attributes['items_animation'] ) ) {
				$masonry_container_data_attr[] = 'data-animation="' . esc_attr( $attributes['items_animation'] ) . '"';
			}

			if ( !empty($attributes['align']) ) {
				$masonry_container_classes[] = 'align-' . esc_attr( $attributes['align'] );
			}

			if ( !empty($attributes['divider']) ) {
				$masonry_container_classes[] = 'type-list-divider';
			}

			if($attributes['el_class']){
				$masonry_container_classes[] = $attributes['el_class'];
			}

			$masonry_container_classes = implode(' ', $masonry_container_classes);
			$masonry_container_data_attr = ' ' . implode(' ', $masonry_container_data_attr);

			$output_template = '%s<div class="%s"%s>%s</div>';

			$output = sprintf( $output_template,
				$html,
				esc_attr( $masonry_container_classes ),
				$masonry_container_data_attr,
				$output
			);

		}

		$output = '<div class="container-fluid rdy_portfolio_container rdy_portfolio_list"><div class="rdy_portfolio_wrap row">' . $output . '</div></div>';

		$stylesheet = '';


		if ( $attributes['list_padding_left'] && $attributes['align'] == "" ) {
			$stylesheet .= '
                .rdy_portfolio-' . $style_id . '.type-list article a {
                    padding-left: ' . esc_attr( $attributes['list_padding_left'] ) . 'px !important;
                }
                ';
		}

		if ( $attributes['list_padding'] ) {
			$stylesheet .= '
                .rdy_portfolio-' . $style_id . '.type-list article a {
                    padding-top: ' . esc_attr( $attributes['list_padding'] ) . 'px !important;
                    padding-bottom: ' . esc_attr( $attributes['list_padding'] ) . 'px !important;
                }
                ';
		}

		if ( $attributes['divider'] && $attributes['list_divider_color'] && $attributes['list_divider_size'] ) {
			$stylesheet .= '
                .rdy_portfolio-' . $style_id . '.type-list.type-list-divider article:after {
                    border-color: ' . esc_attr( $attributes['list_divider_color'] ) . ';
                    border-width: ' . esc_attr( $attributes['list_divider_size'] ) . 'px;
                }
                ';
		}

		if ( $attributes['list_hover_color'] ) {
			$stylesheet .= '
                .rdy_portfolio-' . $style_id . '.type-list article:hover h2,
                .rdy_portfolio-' . $style_id . '.type-list article:hover p {
                    color: ' . esc_attr( $attributes['list_hover_color'] ) . ' !important;
                }
                ';
		}

		if ( $attributes['list_hover_bgcolor'] ) {
			$stylesheet .= '
                .rdy_portfolio-' . $style_id . '.type-list article:hover {
                    background-color: ' . esc_attr( $attributes['list_hover_bgcolor'] ) . ';
                }
                ';
		}


		Levelup_Styles::addCSS($stylesheet, $style_id);

		return $output;
	}

}


BR_Shortcode_Portfolio_List::get_instance();