<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


class BR_Shortcode_Team extends BR_Shortcode {

    static protected $instance;

    protected $shortcode_name = 'rdy_team';
    protected $post_type = 'rdy_team';
    protected $taxonomy = 'rdy_team_category';

    public static function get_instance() {
        if ( !self::$instance ) {
            self::$instance = new BR_Shortcode_Team();
        }
        return self::$instance;
    }

    protected function __construct() {
        add_shortcode( $this->shortcode_name, array( $this, 'shortcode' ) );
    }

    public function shortcode( $atts, $content = null ) {

        $attributes = $this->sanitize_attributes( $atts );

        $output = '';
        $rdy_query = $this->get_posts_by_terms( $attributes );
        if ( $rdy_query->have_posts() ) {

            $this->backup_post_object();
            $this->backup_theme_config();

            $this->setup_config( $attributes );
            $config = Levelup_Config::get_instance();

            ob_start();

            if (array_key_exists('full_width', $attributes) && $attributes['full_width']) {
                echo '<div class="full-width-wrap">';
            }

            $class_column = 'small-block-grid-1 medium-block-grid-2 large-block-grid-3 xlarge-block-grid-4 xxlarge-block-grid-4';

            if ( $attributes['columns'] == '6' ) {
                $class_column = 'small-block-grid-1 medium-block-grid-3 large-block-grid-4 xlarge-block-grid-5 xxlarge-block-grid-6';
            } elseif ( $attributes['columns'] == '5' ) {
                $class_column = 'small-block-grid-1 medium-block-grid-2 large-block-grid-3 xlarge-block-grid-4 xxlarge-block-grid-5';
            } elseif ( $attributes['columns'] == '3' ) {
                $class_column = 'small-block-grid-1 medium-block-grid-2 large-block-grid-3 xlarge-block-grid-3 xxlarge-block-grid-3';
            } else if ( $attributes['columns'] == '2' ) {
                $class_column = 'small-block-grid-1 medium-block-grid-2 large-block-grid-2 xlarge-block-grid-2 xxlarge-block-grid-2';
            } else if ( $attributes['columns'] == '1' ) {
                $class_column = 'small-block-grid-1 medium-block-grid-1 large-block-grid-1 xlarge-block-grid-1 xxlarge-block-grid-1';
            }

            $classes = '';
            if ( $attributes['animation_border'] && $attributes['hover'] == '' && ! $attributes['animation_icon'] ) {
                $classes = " animation-border animation-border-size-" . esc_attr( $attributes['animation_border'] );
            }

	        if ( $attributes['el_class'] ) {
		        $classes .= ' ' . esc_attr( $attributes['el_class'] );
            }

            $style_id = Levelup_Styles::shortcode_id();

            $stylesheet_rules = '';
            if ( ( ! $attributes['hover'] || $attributes['hover'] == 'style1' ) && $attributes['text_color'] ) {
                if ($attributes['text_color'] == 'light') {
                    $text_color = '#fff';
                }

                if ( $attributes['text_color'] == 'dark' ) {
                    $text_color = '#000';
                }

                if ( $text_color ) {
                    $config->set( 'separator_color', $text_color );
                    $stylesheet_rules .= '
                    .rdy_team-' . $style_id . ' .team-author,
                    .rdy_team-' . $style_id . ' .team-author a,
                    .rdy_team-' . $style_id . ' .team-desc .soc-ico a,
                    .rdy_team-' . $style_id . ' .team-content p {
                        color: ' . esc_attr( $text_color ) . ' !important;
                    }
                    ';
                }
            }

            if ( $attributes['overlay_color'] && $attributes['overlay_color2'] ) {
                $stylesheet_rules .= '
                    .rdy_team-' . $style_id . ' .team-container.hover1 .team-desc:before {
                        opacity: ' . levelup_convert_opacity( $attributes['overlay_opacity'] ) . ' !important;
                        ' . levelup_gradient_style( $attributes['overlay_color'], $attributes['overlay_color2'], 'tb' ) . '
                    }
                    ';
            } elseif ( $attributes['overlay_color'] ) {
                $stylesheet_rules .= '
                    .rdy_team-' . $style_id . ' .team-container.hover1 .team-desc:before {
                        opacity: ' . levelup_convert_opacity( $attributes['overlay_opacity'] ) . ' !important;
                        background-color: ' . $attributes['overlay_color'] . ' !important
                    }
                    ';
            }

	        if ( $attributes['type'] == 'carousel' ) {
		        $classes .=' owl-posts-slider owl-carousel';

		        $config->set( 'team.type', $attributes['type'], '' );
		        $config->set( 'team.carousel_appear', $attributes['carousel_appear'], '' );
	        }

	        echo '<ul class="rdy_team rdy_team-' . $style_id . ' ' . $class_column . $classes . '" data-lg="' . ( !empty($attributes['columns']) ? esc_attr($attributes['columns']) : 4 ) . '"' . ( $attributes['carousel_dots'] ? ' data-dots="1"' : '' ) . '' . ($attributes['autoplay'] ? ' data-autoplay="true" data-loop="true"' : '') . '' . ( $attributes['autoplay'] && isset( $attributes['autoplay_timeout'] ) && $attributes['autoplay_timeout'] ? ' data-timeout="' . esc_attr( $attributes['autoplay_timeout'] ) . '"' : '') . ( $attributes['autoplay'] && isset( $attributes['animation_speed'] ) && $attributes['animation_speed'] ? ' data-navspeed="' . esc_attr( $attributes['animation_speed'] ) . '"' : '') . ' data-hoverpause="true">';

            while ( $rdy_query->have_posts() ) { $rdy_query->the_post();

	            levelup_populate_team_config();
	            levelup_get_template_part( 'team/team-post' );

            }

            echo '</ul>';


            $stylesheet_rules .= '
                .rdy_team-' . $style_id . ' .team-author a:hover {
                    color: ' . esc_attr( levelup_get_options('accent-color') ) . ' !important;
                }
                ';

            if ($attributes['padding']) {
                $stylesheet_rules .= '
                    .rdy_team-' . $style_id . ' {
                      margin-left: -' . esc_attr( $attributes['padding'] ) . 'px !important;
                      margin-right: -' . esc_attr( $attributes['padding'] ) . 'px !important;
                    }
                ';
            }
            if ($attributes['animation_border']) {
                if ($attributes['border_color'] == 'accent') {
                    $stylesheet_rules .= '
                        .rdy_team-' . $style_id . '.animation-border .img:hover:before {
                          border-color: ' . esc_attr( levelup_get_options('accent-color') ) . ';
                        }
                    ';
                } else if($attributes['custom_border_color']) {
                    $stylesheet_rules .= '
                        .rdy_team-' . $style_id . '.animation-border .img:hover:before {
                          border-color: ' . esc_attr( $attributes['custom_border_color'] ) . ';
                        }
                    ';
                }
            }

            Levelup_Styles::addCSS($stylesheet_rules, $style_id);

            if (array_key_exists('full_width', $attributes) && $attributes['full_width']) {
                echo '</div>';
            }

            $output .= ob_get_contents();
            ob_end_clean();

            $this->restore_theme_config();
            $this->restore_post_object();

        }

        return $output;
    }

    protected function sanitize_attributes( $atts ) {
        $atts = $this->compatibility_filter( $atts );

        if ( ! function_exists( 'vc_map_get_attributes' ) ) {
            return;
        }

        $attributes = vc_map_get_attributes( $this->shortcode_name, $atts );

        $attributes['order'] = apply_filters('levelup_sanitize_order', $attributes['order']);
        $attributes['orderby'] = apply_filters('levelup_sanitize_orderby', $attributes['orderby']);
        $attributes['number'] = apply_filters('levelup_sanitize_posts_per_page', $attributes['number']);

        $attributes['show_excerpts'] = apply_filters('levelup_sanitize_flag', $attributes['show_excerpts']);
        $attributes['socials'] = apply_filters('levelup_sanitize_flag', $attributes['socials']);
        $attributes['link_icon'] = apply_filters('levelup_sanitize_flag', $attributes['link_icon']);

        $attributes['images_sizing'] = in_array( $attributes['images_sizing'], array( 'original', 'square', 'round' ) ) ? $attributes['images_sizing'] : 'original';

        $attributes['padding'] = (int)$attributes['padding'];
        $attributes['separator_thickness'] = (int)$attributes['separator_thickness'];
        $attributes['separator_width'] = (int)$attributes['separator_width'];
        $attributes['title_fontsize'] = absint($attributes['title_fontsize']);
        $attributes['subtitle_fontsize'] = absint($attributes['subtitle_fontsize']);

        if ( $attributes['category']) {
            $attributes['category'] = explode(',', $attributes['category']);
            $attributes['category'] = array_map('trim', $attributes['category']);
            $attributes['select'] = 'only';
        } else {
            $attributes['select'] = 'all';
        }

        return $attributes;
    }

    protected function setup_config( &$attributes ) {
        $config = Levelup_Config::get_instance();

        $config->set( 'hover', $attributes['hover'] );
        $config->set( 'align', $attributes['align'] );
        $config->set( 'content_valign', $attributes['content_valign'] );
        $config->set( 'separator', $attributes['separator'] );
        $config->set( 'separator_thickness', $attributes['separator_thickness'] );
        $config->set( 'separator_width', $attributes['separator_width'] );
        $config->set( 'title_fontsize', $attributes['title_fontsize'] );
        $config->set( 'subtitle_fontsize', $attributes['subtitle_fontsize'] );
        $config->set( 'team.text_color', $attributes['text_color'] );
        $config->set( 'image_layout', $attributes['images_sizing'] );
        $config->set( 'show_excerpts', $attributes['show_excerpts'] );
        $config->set( 'animation_border', $attributes['animation_border'] );
        $config->set( 'animation_icon', $attributes['animation_icon'] );

        $config->set( 'overlay_color', $attributes['overlay_color'] );
        $config->set( 'overlay_color2', $attributes['overlay_color2'] );

        $config->set( 'load_style', 'default' );

        $config->set( 'item_padding', $attributes['padding'] );
        $config->set( 'item_socials', $attributes['socials'] );
        $config->set( 'team.link_icon', $attributes['link_icon'] );
    }

    protected function compatibility_filter( &$atts ) {

        if ( ! isset( $atts['columns'] ) && isset( $atts['column_width'] ) ) {

            $abs_column_width = absint( $atts['column_width'] );
            if ( $abs_column_width ) {
                $atts['columns'] = intval( round( 1200 / $abs_column_width ) );
            }

            $atts['show_excerpts'] = 'true';
        }

        return $atts;
    }

}


BR_Shortcode_Team::get_instance();

