<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


class BR_Shortcode_Testimonials extends BR_Shortcode {

    static protected $instance;

    protected $shortcode_name = 'rdy_testimonials';
    protected $post_type = 'rdy_testimonials';
    protected $taxonomy = 'rdy_testimonials_category';

    public static function get_instance() {
        if ( !self::$instance ) {
            self::$instance = new BR_Shortcode_Testimonials();
        }
        return self::$instance;
    }

    protected function __construct() {
        add_shortcode( $this->shortcode_name, array( $this, 'shortcode' ) );
    }

    public function shortcode( $atts, $content = null ) {

        $attributes = $this->sanitize_attributes( $atts );

        $output = $this->testimonials_slider( $attributes );

        return $output;
    }

    protected function testimonials_slider( $attributes = array() ) {

        $output = '';
        $show_nav_arrows = esc_attr( $attributes['show_nav_arrows'] );
        $show_nav_dots = esc_attr( $attributes['show_nav_dots'] );
        $color = esc_attr( $attributes['color'] );
        $align = esc_attr( $attributes['align'] );
        $animation = esc_attr( $attributes['animation'] );

        $this->setup_config( $attributes );

        $rdy_query = $this->get_posts_by_terms( $attributes );
        if ( $rdy_query->have_posts() ) {
	        $classes = array();

	        if ( $attributes['el_class'] ) {
		        $classes[] = esc_attr( $attributes['el_class'] );
	        }

	        if ( ! $show_nav_arrows ) {
		        $classes[] = 'owl-hide-arrows';
	        }

	        if ( ! $show_nav_dots ) {
		        $classes[] = 'owl-hide-dots';
	        }

	        if ( $align ) {
		        $classes[] = $align;
	        }

	        if ( $color ) {
		        $classes[] = $color;
	        }

	        $classes = implode(' ', $classes);

            $autoslide = $attributes['autoslide'];
            $output .= '<ul class="owl-testimonials owl-carousel '. ( $classes ? $classes : '' ) . ' testimonials slider-content rsCont"' . ($autoslide ? ' data-autoslide="' . $autoslide . '"' : '') . ($animation ? ' data-animation="' . $animation . '"' : '') . '>' . "\n";

            $this->backup_post_object();

            while ( $rdy_query->have_posts() ) { $rdy_query->the_post();

                $output .= '<li class="item">' . Levelup_Inc_Testimonials_Post_Type::render_testimonial() . '</li>';

            }

            $this->restore_post_object();

            $output .= '</ul>' . "\n";

            $output = '<section class="testimonial-item testimonial-item-slider">' . $output . '</section>';

        }

        return $output;
    }

    protected function sanitize_attributes( $atts ) {
        if ( ! function_exists( 'vc_map_get_attributes' ) ) {
            return;
        }

        $attributes = vc_map_get_attributes( $this->shortcode_name, $atts );

        // sanitize attributes
        $attributes['order'] = apply_filters('levelup_sanitize_order', $attributes['order']);
        $attributes['orderby'] = apply_filters('levelup_sanitize_orderby', $attributes['orderby']);
        $attributes['number'] = apply_filters('levelup_sanitize_posts_per_page', $attributes['number']);
        $attributes['show_nav_arrows'] = apply_filters('levelup_sanitize_flag', $attributes['show_nav_arrows']);
        $attributes['show_nav_dots'] = apply_filters('levelup_sanitize_flag', $attributes['show_nav_dots']);
        $attributes['show_picture'] = apply_filters('levelup_sanitize_flag', $attributes['show_picture']);
        $attributes['quote_icon'] = apply_filters('levelup_sanitize_flag', $attributes['quote_icon']);
        $attributes['is_link'] = apply_filters('levelup_sanitize_flag', $attributes['is_link']);
        $attributes['img_position'] = in_array($attributes['img_position'], array('img_top', 'img_left') ) ? $attributes['img_position'] : 'img_top';

        $attributes['align'] = in_array($attributes['align'], array('left', 'center', 'right') ) ? $attributes['align'] : 'left';

        $attributes['autoslide'] = absint($attributes['autoslide']);
        $attributes['img_size'] = absint($attributes['img_size']);
        $attributes['img_type'] = in_array($attributes['img_type'], array('square', 'circle',) ) ? $attributes['img_type'] : 'square';

        if ( $attributes['category'] ) {
            $attributes['category'] = levelup_sanitize_explode_string( $attributes['category'] );
            $attributes['select'] = 'only';
        } else {
            $attributes['select'] = 'all';
        }

        return $attributes;
    }

    protected function setup_config( &$attributes ) {
        $config = levelup_config();
        $config->set( 'template', 'testimonials' );
        $config->set( 'layout', 'masonry' );
        $config->set( 'template.layout.type', 'masonry' );

        $config->set( 'show_picture', $attributes['show_picture'] );
        $config->set( 'quote_icon', $attributes['quote_icon'] );
        $config->set( 'img_position', $attributes['img_position'] );
        $config->set( 'img_size', $attributes['img_size'] );
        $config->set( 'img_type', $attributes['img_type'] );
        $config->set( 'is_link', $attributes['is_link'] );

        $config->set( 'load_style', 'default' );
    }

}


BR_Shortcode_Testimonials::get_instance();