<?php
if ( ! defined( 'ABSPATH' ) ) {
    die( '-1' );
}

/**
 * Shortcode attributes
 * @var $atts
 * @var $el_class
 * @var $css
 * @var $el_id
 * @var $equal_height
 * @var $content_placement
 * @var $content - shortcode content
 * Shortcode class
 * @var $this WPBakeryShortCode_VC_Row_Inner
 */
$el_class = $equal_height = $content_placement = $css = $el_id = $css_zindex = '';
$output = $after_output = '';
$shadow = $text_align = $row_hide_lg = $row_hide_md = $row_hide_sm = $row_hide_xs = '';
$css_margin = $css_padding = $css_offset = '';
$atts = vc_map_get_attributes( $this->getShortcode(), $atts );
extract( $atts );

$column_style = '';

$text_align = esc_attr( $text_align );
$css_zindex = absint($css_zindex);

$el_class = $this->getExtraClass( $el_class );
$css_classes = array(
    'vc_row',
    'wpb_row', //deprecated
    'vc_inner',
    'vc_row-fluid',
    $el_class,
    vc_shortcode_custom_css_class( $css ),
);

if (vc_shortcode_custom_css_has_property( $css, array('border', 'background') )) {
    $css_classes[]='vc_row-has-fill';
}

if (!empty($atts['gap'])) {
    $css_classes[] = 'vc_column-gap-' . esc_attr( $atts['gap'] );
}

if ( ! empty( $equal_height ) ) {
    $flex_row = true;
    $css_classes[] = ' vc_row-o-equal-height';
}

if ( ! empty( $content_placement ) ) {
    $flex_row = true;
    $css_classes[] = ' vc_row-o-content-' . $content_placement;
}

if ( ! empty( $flex_row ) ) {
    $css_classes[] = ' rdy_vc_row-flex';
}

if(!empty($shadow) && $shadow != ''){
	if($shadow){
		$css_classes[] = esc_attr( $shadow );
	}
}

$wrapper_attributes = array();
// build attributes for wrapper
if ( ! empty( $el_id ) ) {
    $wrapper_attributes[] = 'id="' . esc_attr( $el_id ) . '"';
}

$style_id = levelup_get_uniqid();
$css_classes[] = 'vc_row-' . $style_id;


if ( $row_hide_lg || $row_hide_sm || $row_hide_xs || $row_hide_md ) {

	if ( !$row_hide_xs ) {
		$css_classes[] = ' visible-xs-block';
	}

	if ( !$row_hide_sm ) {
		$css_classes[] = ' visible-sm-block';
	}

	if ( !$row_hide_md ) {
		$css_classes[] = ' visible-md-block';
	}

	if ( !$row_hide_lg ) {
		$css_classes[] = ' visible-lg-block';
	}

	if ( $row_hide_xs && $row_hide_sm && $row_hide_md && $row_hide_lg ) {
		$css_classes[] = ' hidden-lg hidden-md hidden-sm hidden-xs';
	}

}

$css_class = preg_replace( '/\s+/', ' ', apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, implode( ' ', array_filter( $css_classes ) ), $this->settings['base'], $atts ) );
$wrapper_attributes[] = 'class="' . esc_attr( trim( $css_class ) ) . '"';


$style_content = '';

if ($clean_margin || $clean_padding) {
    if ($clean_margin == 'xs' || $clean_padding == 'xs') {
        $style_content .= '
        @media (max-width: 767px) {
          .wpb_row.vc_row-' . $style_id . ' {';

        if ($clean_margin == 'xs') {
            $style_content .= '
             margin-left: 0 !important;
             margin-right: 0 !important;
             margin-top: 0 !important;
             margin-bottom: 0 !important;
        ';
        }
        if ($clean_padding == 'xs') {
            $style_content .= '
             padding-left: 0 !important;
             padding-right: 0 !important;
             padding-top: 0 !important;
             padding-bottom: 0 !important;
        ';
        }

        $style_content .= '
          }
        }
        ';
    }

    if ($clean_margin == 'sm' || $clean_padding == 'sm') {
        $style_content .= '
        @media (max-width: 991px) {
          .wpb_row.vc_row-' . $style_id . ' {';

        if ($clean_margin == 'sm') {
            $style_content .= '
             margin-left: 0 !important;
             margin-right: 0 !important;
             margin-top: 0 !important;
             margin-bottom: 0 !important;
        ';
        }
        if ($clean_padding == 'sm') {
            $style_content .= '
             padding-left: 0 !important;
             padding-right: 0 !important;
             padding-top: 0 !important;
             padding-bottom: 0 !important;
        ';
        }

        $style_content .= '
          }
        }
        ';
    }

    if ($clean_margin == 'md' || $clean_padding == 'md') {
        $style_content .= '
        @media (max-width: 1199px) {
          .wpb_row.vc_row-' . $style_id . ' {';

        if ($clean_margin == 'md') {
            $style_content .= '
             margin-left: 0 !important;
             margin-right: 0 !important;
             margin-top: 0px !important;
             margin-bottom: 0px !important;
        ';
        }
        if ($clean_padding == 'md') {
            $style_content .= '
             padding-left: 0 !important;
             padding-right: 0 !important;
             padding-top: 0 !important;
             padding-bottom: 0 !important;
        ';
        }

        $style_content .= '

          }
        }
        ';
    }
}


if ( $text_align ) {
	$column_style .= "text-align:" . $text_align . ";";
}

if ( $css_zindex != "" ) {
	$column_style .= ' z-index:' . $css_zindex . ';';
}

Levelup_Styles::addCSS($style_content, $style_id);

$output .= '<div ' . implode( ' ', $wrapper_attributes ) . '' . ( $column_style ? ' style="' . $column_style . '"' : '' ) . '>';
$output .= wpb_js_remove_wpautop( $content );
$output .= '</div>';
$output .= $after_output;

$css_r_el = '.wpb_row.vc_row-' . $style_id;
LevelupCSSResponsive( $css_margin, $style_id, $css_r_el, 'margin' );
LevelupCSSResponsive( $css_padding, $style_id, $css_r_el, 'padding' );
LevelupCSSResponsive( $css_offset, $style_id, $css_r_el, 'offset' );

echo $output;
