<?php


class Levelup_Walker_Nav_Menu_Edit extends Walker_Nav_Menu  {

    public function start_lvl( &$output, $depth = 0, $args = array() ) {
    }


    public function end_lvl( &$output, $depth = 0, $args = array() ) {
    }


    public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {

        global $_wp_nav_menu_max_depth;

        $_wp_nav_menu_max_depth = $depth > $_wp_nav_menu_max_depth ? $depth : $_wp_nav_menu_max_depth;

        $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

        ob_start();
        $item_id = esc_attr( $item->ID );
        $removed_args = array(
            'action',
            'customlink-tab',
            'edit-menu-item',
            'menu-item',
            'page-tab',
            '_wpnonce',
        );

        $original_title = '';
        if ( 'taxonomy' == $item->type ) {
            $original_title = get_term_field( 'name', $item->object_id, $item->object, 'raw' );
            if ( is_wp_error( $original_title ) )
                $original_title = false;
        } elseif ( 'post_type' == $item->type ) {
            $original_object = get_post( $item->object_id );
            $original_title = $original_object->post_title;
        }

        $classes = array(
            'menu-item menu-item-depth-' . $depth,
            'menu-item-' . esc_attr( $item->object ),
            'menu-item-edit-' . ( ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? 'active' : 'inactive'),
        );

        $title = $item->title;

        if ( ! empty( $item->_invalid ) ) {
            $classes[] = 'menu-item-invalid';
            /* translators: %s: title of menu item which is invalid */
            $title = sprintf( esc_html__( '%s (Invalid)', 'LEVELUP' ), $item->title );
        } elseif ( isset( $item->post_status ) && 'draft' == $item->post_status ) {
            $classes[] = 'pending';
            /* translators: %s: title of menu item in draft status */
            $title = sprintf( esc_html__('%s (Pending)', 'LEVELUP'), $item->title );
        }

        $title = empty( $item->label ) ? $title : $item->label;

        ?>
    <li id="menu-item-<?php echo esc_attr( $item_id ); ?>" class="<?php echo esc_attr( implode( ' ', $classes ) ); ?>">
        <dl class="menu-item-bar">
            <dt class="menu-item-handle">
                <span class="item-title"><?php echo esc_html( $title ); ?></span>
	                <span class="item-controls">
	                    <span class="item-type"><?php echo esc_html( $item->type_label ); ?></span>
	                    <span class="item-order hide-if-js">
	                        <a href="<?php
                            echo wp_nonce_url(
                                add_query_arg(
                                    array(
                                        'action' => 'move-up-menu-item',
                                        'menu-item' => $item_id,
                                    ),
                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
                                ),
                                'move-menu_item'
                            );
                            ?>" class="item-move-up"><abbr title="<?php esc_attr_e('Move up', 'LEVELUP'); ?>">&#8593;</abbr></a>
	                        |
	                        <a href="<?php
                            echo wp_nonce_url(
                                add_query_arg(
                                    array(
                                        'action' => 'move-down-menu-item',
                                        'menu-item' => $item_id,
                                    ),
                                    remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
                                ),
                                'move-menu_item'
                            );
                            ?>" class="item-move-down"><abbr title="<?php esc_attr_e('Move down', 'LEVELUP'); ?>">&#8595;</abbr></a>
	                    </span>
	                    <a class="item-edit" id="edit-<?php echo esc_attr( $item_id ); ?>" title="<?php esc_attr_e('Edit Menu Item', 'LEVELUP'); ?>" href="<?php
                        echo ( isset( $_GET['edit-menu-item'] ) && $item_id == $_GET['edit-menu-item'] ) ? admin_url( 'nav-menus.php' ) : add_query_arg( 'edit-menu-item', $item_id, remove_query_arg( $removed_args, admin_url( 'nav-menus.php#menu-item-settings-' . $item_id ) ) );
                        ?>"><?php esc_html_e( 'Edit Menu Item', 'LEVELUP' ); ?></a>
	                </span>
            </dt>
        </dl>

        <div class="menu-item-settings" id="menu-item-settings-<?php echo esc_attr( $item_id ); ?>">
            <?php if( 'custom' == $item->type ) : ?>
                <p class="field-url description description-wide">
                    <label for="edit-menu-item-url-<?php echo esc_attr( $item_id ); ?>">
                        <?php esc_html_e( 'URL', 'LEVELUP' ); ?><br />
                        <input type="text" id="edit-menu-item-url-<?php echo esc_attr( $item_id ); ?>" class="widefat code edit-menu-item-url" name="menu-item-url[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->url ); ?>" />
                    </label>
                </p>
            <?php endif; ?>
            <p class="description description-thin">
                <label for="edit-menu-item-title-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e( 'Navigation Label', 'LEVELUP' ); ?><br />
                    <input type="text" id="edit-menu-item-title-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-title" name="menu-item-title[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->title ); ?>" />
                </label>
            </p>
            <p class="description description-thin">
                <label for="edit-menu-item-attr-title-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e( 'Title Attribute', 'LEVELUP' ); ?><br />
                    <input type="text" id="edit-menu-item-attr-title-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-attr-title" name="menu-item-attr-title[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->post_excerpt ); ?>" />
                </label>
            </p>
            <p class="field-link-target description">
                <label for="edit-menu-item-target-<?php echo esc_attr( $item_id ); ?>">
                    <input type="checkbox" id="edit-menu-item-target-<?php echo esc_attr( $item_id ); ?>" value="_blank" name="menu-item-target[<?php echo esc_attr( $item_id ); ?>]"<?php checked( $item->target, '_blank' ); ?> />
                    <?php esc_html_e( 'Open link in a new window/tab', 'LEVELUP' ); ?>
                </label>
            </p>
            <p class="field-css-classes description description-thin">
                <label for="edit-menu-item-classes-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e( 'CSS Classes (optional)', 'LEVELUP' ); ?><br />
                    <input type="text" id="edit-menu-item-classes-<?php echo esc_attr( $item_id ); ?>" class="widefat code edit-menu-item-classes" name="menu-item-classes[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( implode(' ', $item->classes ) ); ?>" />
                </label>
            </p>
            <p class="field-xfn description description-thin">
                <label for="edit-menu-item-xfn-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e( 'Link Relationship (XFN)', 'LEVELUP' ); ?><br />
                    <input type="text" id="edit-menu-item-xfn-<?php echo esc_attr( $item_id ); ?>" class="widefat code edit-menu-item-xfn" name="menu-item-xfn[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->xfn ); ?>" />
                </label>
            </p>
            <p class="field-description description description-wide">
                <label for="edit-menu-item-description-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e( 'Description', 'LEVELUP' ); ?><br />
                    <textarea id="edit-menu-item-description-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-description" rows="3" cols="20" name="menu-item-description[<?php echo esc_attr( $item_id ); ?>]"><?php echo esc_html( $item->description ); ?></textarea>
                    <span class="description"><?php esc_html_e('The description will be displayed in the menu if the current theme supports it.', 'LEVELUP'); ?></span>
                </label>
            </p>

            <?php
            /* New fields insertion starts here */
            ?>

            <div class="clear menu_edit_sep"></div>

                <p class="field-onlytitle description description-thin">
                    <label for="edit-menu-item-onlytitle-<?php echo esc_attr( $item_id ); ?>">
                        <input type="checkbox" id="edit-menu-item-onlytitle-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-onlytitle" name="menu-item-onlytitle[<?php echo esc_attr( $item_id ); ?>]" value="1" <?php checked( $item->onlytitle, '1' ); ?> />
                        <?php esc_html_e( 'Heading (w/o link)', 'LEVELUP' ); ?>
                    </label>
                </p>

                <p class="field-icon description description-wide">
                    <label for="edit-menu-item-icon-<?php echo esc_attr( $item_id ); ?>">
                        <?php esc_html_e( 'Icon', 'LEVELUP' ); echo esc_attr($item->icon); ?><br />
                        <select id="edit-menu-item-icon<?php echo esc_attr( $item_id ); ?>" name="menu-item-icon[<?php echo esc_attr( $item_id ); ?>]">
                            <option value="" <?php if(esc_attr($item->icon) == ""){echo 'selected="selected"';} ?>></option>
                            <?php
                            $fa_icons = levelup_getFontAwesomeIconArray();
                            foreach ($fa_icons as $key => $value) {
                                ?>
                                <option value="<?php echo esc_attr( $key ); ?>" <?php if(esc_attr($item->icon) == $key){echo 'selected="selected"';} ?>><?php echo esc_attr( $key ); ?></option>
                            <?php
                            }
                            ?>
                        </select>
                    </label>
                </p>

                <div class="clear">
                    <p class="linkcolor linkcolor-thin description description-thin">
                        <label for="edit-menu-item-linkcolor-<?php echo esc_attr( $item_id ); ?>">
                            <?php esc_html_e( 'Custom Link Color', 'LEVELUP' ); ?><br />
                            <input type="text" id="edit-menu-item-linkcolor-<?php echo esc_attr( $item_id ); ?>" class="widefat edit-menu-item-linkcolor" name="menu-item-linkcolor[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->linkcolor ); ?>" />
                        </label>
                    </p>
                </div>

                <p class="field-icon description description-wide">
                    <label for="edit-menu-item-blank-<?php echo esc_attr( $item_id ); ?>">
                        <input id="edit-menu-item-blank-<?php echo esc_attr( $item_id ); ?>" type="checkbox" class="edit-menu-item-blank" name="menu-item-blank[<?php echo esc_attr( $item_id ); ?>]" <?php checked( $item->blank ); ?>/>
                        <?php _ex( 'Open Link in a new tab', 'edit menu walker', 'LEVELUP' ); ?>
                    </label>
                </p>

                <div class="clear menu_edit_sep"></div>

            <?php
            /* New fields insertion ends here */

            do_action( 'wp_nav_menu_item_custom_fields', $item_id, $item, $depth, $args );
            ?>
            <p class="field-custom custom-widget description-wide clear">
                <label for="edit-menu-item-sidebar-<?php echo esc_attr( $item_id ); ?>">
                    <?php esc_html_e( 'Custom widget area', 'LEVELUP' ); ?><br />
                    <select id="edit-menu-item-sidebar<?php echo esc_attr( $item_id ); ?>" name="menu-item-sidebar[<?php echo esc_attr( $item_id ); ?>]">
                        <option value="" <?php if ( esc_attr($item->sidebar) == "" ) { echo 'selected="selected"'; } ?>></option>
                        <?php
                        foreach ( $GLOBALS['wp_registered_sidebars'] as $sidebar ) {
                            if ( levelup_is_user_made_sidebar( ucwords( $sidebar['name'] ) ) ) {
                                ?>

                                <option value="<?php echo ucwords( $sidebar['id'] ); ?>" <?php if (esc_attr($item->sidebar) == ucwords( $sidebar['id'] ) ) { ?> selected="selected" <?php } ?>>
                                    <?php echo ucwords( $sidebar['name'] ); ?>
                                </option>

                            <?php	}
                        }
                        ?>
                    </select>
                </label>
            </p>


            <div class="menu-item-actions description-wide submitbox">
                <?php if( 'custom' != $item->type && $original_title !== false ) : ?>
                    <p class="link-to-original">
                        <?php printf( esc_html__('Original: %s', 'LEVELUP'), '<a href="' . esc_attr( $item->url ) . '">' . esc_html( $original_title ) . '</a>' ); ?>
                    </p>
                <?php endif; ?>
                <a class="item-delete submitdelete deletion" id="delete-<?php echo esc_attr( $item_id ); ?>" href="<?php
                echo wp_nonce_url(
                    add_query_arg(
                        array(
                            'action' => 'delete-menu-item',
                            'menu-item' => $item_id,
                        ),
                        remove_query_arg($removed_args, admin_url( 'nav-menus.php' ) )
                    ),
                    'delete-menu_item_' . $item_id
                ); ?>"><?php esc_html_e('Remove', 'LEVELUP'); ?></a> <span class="meta-sep"> | </span> <a class="item-cancel submitcancel" id="cancel-<?php echo esc_attr( $item_id ); ?>" href="<?php echo esc_url( add_query_arg( array('edit-menu-item' => $item_id, 'cancel' => time()), remove_query_arg( $removed_args, admin_url( 'nav-menus.php' ) ) ) );
                ?>#menu-item-settings-<?php echo esc_attr( $item_id ); ?>"><?php esc_html_e('Cancel', 'LEVELUP'); ?></a>
            </div>

            <div class="clear menu_edit_sep"></div>
            <input class="menu-item-data-db-id" type="hidden" name="menu-item-db-id[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item_id ); ?>" />
            <input class="menu-item-data-object-id" type="hidden" name="menu-item-object-id[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->object_id ); ?>" />
            <input class="menu-item-data-object" type="hidden" name="menu-item-object[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->object ); ?>" />
            <input class="menu-item-data-parent-id" type="hidden" name="menu-item-parent-id[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->menu_item_parent ); ?>" />
            <input class="menu-item-data-position" type="hidden" name="menu-item-position[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->menu_order ); ?>" />
            <input class="menu-item-data-type" type="hidden" name="menu-item-type[<?php echo esc_attr( $item_id ); ?>]" value="<?php echo esc_attr( $item->type ); ?>" />
        </div><!-- .menu-item-settings-->
        <ul class="menu-item-transport"></ul>

        <?php

        $output .= ob_get_clean();

    }
}
