<?php

// File Security Check
if ( ! defined( 'ABSPATH' ) ) { exit; }


if ( ! function_exists( 'levelup_posted_on' ) ) {
    
    function levelup_posted_on() {
	    global $levelup_options;

	    if ( empty( $levelup_options['blog-list-meta-info'] ) ) {
		    return;
	    }

	    $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
	    if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
		    $time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
	    }

	    $time_string = sprintf( $time_string,
		    esc_attr( get_the_date( 'c' ) ),
		    esc_html( get_the_date() ),
		    esc_attr( get_the_modified_date( 'c' ) ),
		    esc_html( get_the_modified_date() )
	    );


	    if ( is_search() ) {
		    $posted_on = sprintf('<a href="%1$s" rel="bookmark">%2$s</a>', esc_url( get_permalink() ), $time_string );
	    } else {
		    $posted_on = $time_string;
	    }

	    $byline = sprintf(
		    _x( 'by %s', 'post author', 'LEVELUP' ),
		    '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
	    );


	    $categories = '';
	    $categories_list = get_the_category_list( esc_html__( ', ', 'LEVELUP' ) );

	    if ( $categories_list ) {
		    $categories .= ' <span class="cat-links">';
		    $categories .= sprintf( esc_html__( 'in %1$s', 'LEVELUP' ), $categories_list );
		    $categories .= '</span>';
	    }

	    if ( in_array( $levelup_options['blog-list-meta-info'], array( 1, 2, 3, 4 ) ) ) {
		    echo '<span class="byline"> ' . $byline . '</span>';
	    }

	    if ( in_array( $levelup_options['blog-list-meta-info'], array( 1, 3 ) ) ) {
		    echo ' ' . $categories;
	    }

	    if ( in_array( $levelup_options['blog-list-meta-info'], array( 1, 2, ) ) ) {
		    echo ' ' . ( $levelup_options['blog-list-meta-info'] == 1 ? '<br>' : '' ) . '<span class="posted-on">' . $posted_on . '</span>';
	    }

    }

}


if ( ! function_exists( 'levelup_posted_on_full' ) ) {
    
    function levelup_posted_on_full($print=true) {
	    global $levelup_options;

        $out = '';
        $config = Levelup_Config::get_instance();

        if ('fancy' == $config->get('header_title')) {
            $title_style = 'color: ' . esc_attr( $config->get('fancy_header.title.color') ) . ';';
        } else {
            $title_style = 'color: ' . esc_attr( $levelup_options['page_title_font']['color'] ) . ';';
        }


        $time_string = '<time class="entry-date published" datetime="%1$s">%2$s</time>';
        if ( get_the_time( 'U' ) !== get_the_modified_time( 'U' ) ) {
            $time_string .= '<time class="updated" datetime="%3$s">%4$s</time>';
        }
    
        $time_string = sprintf( $time_string,
            esc_attr( get_the_date( 'c' ) ),
            esc_html( get_the_date() ),
            esc_attr( get_the_modified_date( 'c' ) ),
            esc_html( get_the_modified_date() )
        );

        $posted_on = $time_string;
    
        $byline = sprintf(
            _x( 'by %s', 'post author', 'LEVELUP' ),
            '<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
        );


        $out .= '<span class="posted-on">' . $posted_on . '</span><span class="sp">|</span>';

        $categories_list = get_the_category_list( esc_html__( ', ', 'LEVELUP' ) );

        if ( $categories_list ) :
            $out .= ' <span class="cat-links">';
            $out .=  sprintf( esc_html__( 'in %1$s', 'LEVELUP' ), $categories_list );
            $out .= '</span>';
        endif;
    

        $out .= '<span class="sp">|</span><span class="byline"> ' . $byline . '</span>';

	    if ( class_exists( 'Levelup_Styles' ) ) {
		    $style_id = Levelup_Styles::shortcode_id();
		    Levelup_Styles::addCSS( '.fancy-header .meta-info, .page-title  .meta-info, .fancy-header .meta-info a, .page-title .meta-info a {' . $title_style . '}', $style_id );
	    }

	    if ($print) {
            echo $out;
        } else {
            return $out;
        }

        return true;
    }

}


if ( ! function_exists( 'levelup_categorized_blog' ) ) {

    function levelup_categorized_blog() {

        if ( false === ( $all_the_cool_cats = get_transient( 'levelup_categories' ) ) ) {
            $all_the_cool_cats = get_categories( array(
                'fields'     => 'ids',
                'hide_empty' => 1,
                'number'     => 2,
            ) );

            $all_the_cool_cats = count( $all_the_cool_cats );

            set_transient( 'levelup_categories', $all_the_cool_cats );
        }

        if ( $all_the_cool_cats > 1 ) {
            return true;
        } else {
            return false;
        }

    }

}


function levelup_category_transient_flusher() {
	delete_transient( 'levelup_categories' );
}
add_action( 'edit_category', 'levelup_category_transient_flusher' );
add_action( 'save_post',     'levelup_category_transient_flusher' );


if ( ! function_exists( 'levelup_after_post_masonry' ) ) {

    function levelup_after_post_masonry() {
        echo '</div>';
    }

}


if ( ! function_exists( 'levelup_fancy_header_controller' ) ) {

	function levelup_fancy_header_controller() {
		global $levelup_options;

		$config = Levelup_Config::get_instance();

		if ( ('fancy' != $config->get('header_title')) || (class_exists( 'Woocommerce' ) && is_cart() && WC()->cart->is_empty()) ) {
			return;
		}

        $container_classes = array( 'fancy-header' );

        $overlay = '';
        if ($config->get('fancy_header.overlay_animation') != '') {
            $container_classes[] = 'bg-overlay';
            $overlay = '<div class="overlay ' . esc_attr( $config->get('fancy_header.overlay_animation') ) . ($config->get('fancy_header.overlay_animation') == 'light' ? ' light' : '') . '" data-top="opacity:0"  data-top-bottom="opacity:1" ></div>';
        }

        if ($config->get('fancy_header.overlay') == 'dark') {
            $container_classes[] = 'ht-overlay dark-overlay';
        } elseif ($config->get('fancy_header.overlay') == 'light') {
            $container_classes[] = 'ht-overlay light-overlay';
        } elseif ($config->get('fancy_header.overlay') == 'custom') {
            $container_classes[] = 'ht-overlay';
        }


        //  title

		$title = '';
		if ( $config->get('fancy_header.title') ) {

            $title_class = "";
            $title_font_size = $config->get('fancy_header.title.font.size');
            $animation_data = '';

            if ($config->get('fancy_header.title.valign') == 'bottom') {
                $container_classes[] = 'fh-va-bottom';
            } else {
                $container_classes[] = 'fh-va-middle';
            }

            $title_style = '';
            $title_style .= 'color: ' . esc_attr( $config->get('fancy_header.title.color') ) . ';';

            if ($config->get('fancy_header.title.margin_bottom') && !$config->get('fancy_header.swap_titles')) {
                $title_style .= 'margin-bottom: ' . esc_attr( $config->get('fancy_header.title.margin_bottom') ) . 'px;';
            }

            $title_style_hilight = '';
            if (levelup_check_valid_color($config->get('fancy_header.highlight'))) {
                $title_class .= 'highlight';
                if ($levelup_options['page_title_font']['font-size']) {
                    $shadow_size = intval( levelup_sanitize_px($levelup_options['page_title_font']['font-size']) * 0.35);
                } else {
                    $shadow_size = 15;
                }

                $title_style_hilight = sprintf( ' style="box-shadow: %1$s %2$spx 0 0 0,%1$s -%2$spx 0 0 0; -webkit-box-shadow: %1$s %2$spx 0 0 0, %1$s -%2$spx 0 0 0; background:%1$s;"', esc_attr( $config->get('fancy_header.highlight') ), $shadow_size );

                if (!$config->get('fancy_header.swap_titles')) {
                    $title_class .= ' first';
                }
            }

			$ft_title_fontsize = levelup_sanitize_px($levelup_options['page_title_font']['font-size']);
            if ($ft_title_fontsize) {
                $title_class .= ' ' . levelup_calculate_responsive_font_class($ft_title_fontsize);
            }

			$title .= sprintf( '<h1 style="%s" class="fancy-title %s"', $title_style, $title_class );
            $filter_title = apply_filters( 'levelup_get_fancy_title', wp_kses_post( $config->get('fancy_header.title') ) );
			$title .= '><span class="hilight' . ($config->get('fancy_header.title.shadow') ? ' '.$config->get('fancy_header.title.shadow') : '') . '" ' . $title_style_hilight . '>' . $filter_title . '</span></h1>';

		}

        if ( $levelup_options['page-title-fancy-separator'] && ( $config->get('fancy_header.title') || $config->get('fancy_header.subtitle'))) {
            $title .= '<div class="h-separator" style="border-top-color: ' . esc_attr( $config->get('fancy_header.title.color') ) . ';"></div>';
        }

        //  subtitle

        $sub_title = '';
		if ( $config->get('fancy_header.subtitle') ) {
            $subtitle_class = $subtitle_style_hilight = '';
            $subtitle_style = '';
            $subtitle_style .= 'color: ' . esc_attr( $config->get('fancy_header.title.color') ) . ';';

            if (levelup_check_valid_colorhex($config->get('fancy_header.highlight'))) {
                $subtitle_class .= 'highlight';

                if (array_key_exists('font-size', $levelup_options['page_subtitle_font'])) {
                    $fontsize = intval($levelup_options['page_subtitle_font']['font-size']);
                    $shadow_size = intval($fontsize * 0.35);
                } else {
                    $shadow_size = 15;
                }

                $subtitle_style_hilight = sprintf( ' style="box-shadow: %1$s %2$spx 0 0 0,%1$s -%2$spx 0 0 0; -webkit-box-shadow: %1$s %2$spx 0 0 0, %1$s -%2$spx 0 0 0; background:%1$s;"', $config->get('fancy_header.highlight'), $shadow_size );


                if ($config->get('fancy_header.swap_titles')) {
                    $subtitle_class .= ' first';
                }
            }

            if ($config->get('fancy_header.title.margin_bottom') && $config->get('fancy_header.swap_titles')) {
                $subtitle_style .= 'margin-bottom: '.$config->get('fancy_header.title.margin_bottom').'px !important;';
            }

			$sub_title .= sprintf( '<h2 style="%s" class="fancy-subtitle %s"', $subtitle_style, $subtitle_class );

            $sub_title .= '><span'.$subtitle_style_hilight.'>' . wp_kses_post( $config->get('fancy_header.subtitle') ) . '</span></h2>';

		}

        if ($config->get('fancy_header.swap_titles')) {
            $title = $sub_title . $title;
        } else {
            $title = $title . $sub_title;
        }


		if ( $config->get('fancy_header.breadcrumbs') ) {
			$title .= '<div class="breadcrumbs-container">' . levelup_get_breadcrumbs() . '</div>';
		}



		$content = '';

		if ( $title ) {

            $content = '<div class="col-td hgroup"><div class="scroll-animation" ' .$animation_data . ' data-down="' . ( in_array($config->get('fancy_header.title.animation'), array('down', 'down_alpha') ) ? '1' : '0' ) . '" data-opacity="' . (in_array($config->get('fancy_header.title.animation'), array('alpha', 'down_alpha') ) ? '1' : '0' ) . '">';
            $content .= $title;
			if ( is_singular( 'post' ) && $levelup_options['blog-hide_page_title_meta'] ) {
                $content .= levelup_get_pagetitle_meta();
            }
            $content .= levelup_get_pagetitle_catalogs();
            $content .= '</div></div>';

		} else {
			$container_classes[] = 'titles-off';
		}


        //  container
		switch ( $config->get('fancy_header.title.aligment') ) {
			case 'center': $container_classes[] = 'fh-a-center'; break;
			case 'right':
				$container_classes[] = 'title-right';
				break;
			case 'all_left':
				$container_classes[] = 'fh-a-left';
				break;
			case 'all_right':
				$container_classes[] = 'fh-a-right';
				break;
			default: $container_classes[] = 'fh-a-left';
		}


        //  container style

		$container_style = array();
        $background_style = array();
		if ( $config->get('fancy_header.bg.color') && $config->get('fancy_header.bg.color') != '#' ) {
            $background_style[] = 'background-color: ' . $config->get('fancy_header.bg.color');
		}

        $background_image_src = '';
		if ( $config->get('fancy_header.bg.image') ) {

			$image_meta = wp_get_attachment_image_src( $config->get('fancy_header.bg.image'), 'full' );
			if ( $image_meta ) {

				if ( $config->get('fancy_header.bg.fullscreen') ) {
					$bg_size = 'cover';
					$repeat = 'no-repeat';
				} else {
					$bg_size = 'auto auto';
					$repeat = $config->get('fancy_header.bg.repeat');
				}

                $background_style[] = "background-size: {$bg_size}";
                $background_style[] = "background-repeat: {$repeat}";
                $background_image_src = esc_url( $image_meta[0] );

				if ( $config->get('fancy_header.bg.fixed') ) {
					$background_style[] = 'background-attachment: fixed';
				}


				$position_x = $config->get('fancy_header.bg.position.x');
				$position_y = $config->get('fancy_header.bg.position.y');
				if ( ! $config->get( 'fancy_header.parallax' ) ) {
					$background_style[] = "background-position: {$position_x} {$position_y}";
				}

			}

		}


        //  parallax

        $data_attr = array();
        $data_bg_attr = array();
        if ( $config->get('fancy_header.parallax') && $background_image_src) {
            $container_classes[] = 'fancy-parallax-bg';
            $data_bg_attr[] = 'data-vc-parallax-image="' . esc_url( $background_image_src ) . '"';
        }


        //  header height

		$min_h_height = ' style="min-height: ' . $config->get('fancy_header.height') . 'px;"';
		if ( $config->get('fancy_header.dynamic_height') ) {
			$wf_table_height = ' style="min-height: ' . esc_attr( $config->get('fancy_header.height') ) . 'px; height: ' . esc_attr( $config->get('fancy_header.dynamic_height') ) . 'vh;"';
		} else {
			$wf_table_height = ' style="height: ' . esc_attr( $config->get('fancy_header.height') ) . 'px;"';
		}

		$container_style[] = 'min-height: ' . esc_attr( $config->get('fancy_header.height') ) . 'px';

        $basic_animation = '';
        $down_button = '';
        if ($config->get('fancy_header.header_fullscreen')) {
            $container_classes[] = 'fullscreen-header';
            if ($config->get('fancy_header.down_button')) {
                $down_button = '<a href="#" class="section-down-arrow"><i class="icon-down-arrow icon-default-style' . ($config->get('fancy_header.down_button') == 'dark' ? ' icon-dark-style' : '') . '"> </i></a>';
            }
        }

        if ($config->get('header.logo_style')) {
            $data_attr[] = 'data-midnight="' . esc_attr( $config->get('header.logo_style') ) . '"';
        }

		if ( $config->get('fancy_header.bg.image_mobile') ) {

			if ( $config->get('fancy_header.bg.image_mobile') ) {

				$image_meta = wp_get_attachment_image_src( $config->get('fancy_header.bg.image_mobile'), 'full' );
				if ( $image_meta ) {

					$data_bg_attr[] = 'data-original-mobile="' . esc_url( $image_meta[0] ) . '"';

				}

			}

		}


        //  output

        $container_class = 'container';

        if ( levelup_is_blog() && levelup_get_options('blog_fullwidth')) {
            $container_class = 'container-fluid container-main';
        }

        $video_html = '';
        if ($config->get('fancy_header.video.mp4') || $config->get('fancy_header.video.webm') || $config->get('fancy_header.video.ogg')) {

            $video_html .= '<video preload="auto" loop autoplay muted>';
            if ($config->get('fancy_header.video.webm')) {
                $video_html .= '<source type="video/webm" src="' . esc_attr( $config->get('fancy_header.video.webm') ) . '">';
            }
            if ($config->get('fancy_header.video.mp4')) {
                $video_html .= '<source type="video/mp4" src="' . esc_attr( $config->get('fancy_header.video.mp4') ) . '">';
            }
            if ($config->get('fancy_header.video.ogg')) {
                $video_html .= '<source type="video/ogg" src="' . esc_attr( $config->get('fancy_header.video.ogg') ) . '">';
            }
            $video_html .= '</video>';

        }

		printf(
			'<header id="fancy-header" class="%1$s" style="%2$s" %3$s>
                ' . $overlay . '
				<div class="' . esc_attr( $container_class ) . '"' . $basic_animation . '>
					<div class="row">
					<div class="ft-wrap col-xs-12">
						<div class="col-table"%5$s>%4$s</div>
					</div>
					</div>
				</div>
				<div class="background-container' . ($config->get('fancy_header.overlay_fx') == 'glitch' ? ' glitch' : '') .  ($config->get('fancy_header.parallax') ? ' fancy_parallax' : '') . ($levelup_options['page-title-fancy-bg_animation'] && isset($background_image_src) && $background_image_src ? ' animate' : '') . '" data-original="%9$s" style="%8$s" ' . implode( ' ', $data_bg_attr ) . '' . ($levelup_options['page-title-fancy-bg_animation'] ? ' data-bg_animation="1"' : '') . '></div>
				' . $video_html . '
                %7$s
			</header>',
			esc_attr( implode( ' ', $container_classes ) ),
			esc_attr( implode( '; ', $container_style ) ),
			implode( ' ', $data_attr ),
			$content,
			$wf_table_height,
			$min_h_height,
            $down_button,
            esc_attr( implode( '; ', $background_style ) ),
            $background_image_src
		);

        $stylesheet = '';
        if ($config->get('fancy_header.overlay') == 'custom') {
            if ($config->get('fancy_header.overlay_color') && $config->get('fancy_header.overlay_color2')) {
                $overlay_style = levelup_gradient_style($config->get('fancy_header.overlay_color'), $config->get('fancy_header.overlay_color2'), $config->get('fancy_header.overlay_gradient_direction'));
            } else {
                $overlay_style = 'background: none repeat scroll 0 0 ' . esc_attr( $config->get('fancy_header.overlay_color') );
            }

            $stylesheet .= '
                .fancy-header.ht-overlay:after {
                    ' . $overlay_style . '
                }
            ';
        }

        if ($config->get('fancy_header.overlay') && $config->get('fancy_header.overlay_opacity') != 40) {
            $stylesheet .= '
                .fancy-header.ht-overlay:after {
                    opacity: ' . levelup_stylesheet_get_opacity($config->get('fancy_header.overlay_opacity')) . ';
                }
            ';
        }

		/*$text_gradient = levelup_get_css_text_gradient($config->get('fancy_header.title.gradient.color1'), $config->get('fancy_header.title.gradient.color2'), $config->get('fancy_header.title.gradient.color3'));

		if ( $title && $text_gradient ) {
			$stylesheet .= '
				.fancy-header .fancy-title {
					position: relative;
				}
				
	            .fancy-header .fancy-title span:not(.alt) {
					position: relative;
				    z-index: 11;
				    color: transparent
	            }
	            
	            .fancy-header .fancy-title span.alt {
	                background: ' . $text_gradient . ';
	            }
	        ';
		}*/

		if ( class_exists( 'Levelup_Styles' ) ) {
			$style_id = Levelup_Styles::shortcode_id();
			Levelup_Styles::addCSS( $stylesheet, $style_id );
		}

	}

}


if ( ! function_exists( 'levelup_page_title_controller' ) ) {

	function levelup_page_title_controller() {
        global $levelup_options, $post;

		$config = Levelup_Config::get_instance();

		$levelup_header_disable = levelup_is_header_enable();

		if ( ( $config->get( 'siteheader.layout' ) == 'fixed' || $config->get( 'siteheader.layout' ) == 'static' ) && ! $levelup_header_disable ) {
			echo '<div id="header_spacer"></div>';
		}

        if( 'fancy' == $config->get('header_title')
            || is_post_type_archive('rdy_project')
            || ( $levelup_options['blog-title_disable'] && is_home())
            || (class_exists( 'Woocommerce' ) && is_cart() && WC()->cart->is_empty())
        ){
            return;
        }

        if ('slideshow' == apply_filters('levelup_show_header_title', $config->get('header_title'))) {
	        $slider = '';
            $slider_id = apply_filters('levelup_demo_slider_id', $config->get('header.slider.id'));
            $slider_type = apply_filters('levelup_demo_slider', $config->get('header.slider.type'));

            if ($slider_type == 'revolution' && $config->get('header.slider.id')) {
                $slider = do_shortcode('[rev_slider alias="' . esc_attr( $slider_id ) . '"]');
            }

            if ($slider_type == 'royal' && $config->get('header.slider.id')) {
	            $slider = do_shortcode('[rdy_royal_slider_vc alias="' . esc_attr( $slider_id ) . '"]');
            }

	        if ( $slider ) {
		        echo '<div class="title-area-slider_holder">' . $slider . '</div>';
	        }

            return;
        }


		if ( isset( $post ) ) {
			$_post_format     = get_post_format();
			$video_post_style = get_post_meta( $post->ID, '_rdy_page_video_post_style', true );
			if ( is_singular( 'post' ) && $_post_format == 'video' && $video_post_style == 'header' ) {
				switch ( $_post_format ) {
					case "video":
						levelup_get_blog_video();
						break;
					case "audio":
						break;
				}

				return;
			}
		}

		$show_page_title = ( levelup_is_post_title_enabled() );

        if( class_exists( 'Woocommerce' ) && is_woocommerce() && (is_product_category() || is_product_tag()) ){
            if ($config->get('wc.header.category.disable')) {
                return;
            }

	        $wc_title_fontsize = levelup_sanitize_px($levelup_options['page_title_font']['font-size']);
            if ($wc_title_fontsize) {
                $responsive_class = levelup_calculate_responsive_font_class($wc_title_fontsize);
            }

	        $description_html = '';
            $description = wc_format_content( term_description() );
            if ( $description ) {
                $description_html = '<div class="container"><div class="term-description col-sm-10 col-sm-push-1">' . $description . '</div></div>';
            }
            ?>
            <div class="category_header <?php if ($config->get('wc.header.image.src') != "") : ?> with_featured_img<?php endif; ?>" style="<?php if($config->get('wc.header.bgcolor') != "") : ?>background-color: <?php echo esc_attr( $config->get('wc.header.bgcolor') );?>;<?php endif; ?><?php if ($config->get('wc.header.image.src') != "") : ?>background-position: center; background-repeat: no-repeat; background-image:url(<?php echo esc_attr( $config->get('wc.header.image.src') ); ?>);<?php endif; ?><?php if($config->get('wc.header.padding.top') > 0) : ?>padding-top: <?php echo esc_attr( $config->get('wc.header.padding.top') ); ?>px;<?php endif; ?><?php if($config->get('wc.header.padding.bottom') > 0) : ?>padding-bottom: <?php echo esc_attr( $config->get('wc.header.padding.bottom') ) ; ?>px;<?php endif; ?>">
                <div class="container">
                    <div class="row">
                        <div class="col-md-12<?php if($config->get('wc.header.text.color')) echo ' ' . esc_attr( $config->get('wc.header.text.color') );?>">

                            <h1 class="page-title<?php if($responsive_class) echo ' ' . esc_attr( $responsive_class ); ?>"><?php woocommerce_page_title(); ?></h1>

                            <?php if ($description_html) echo $description_html; ?>
                            <?php echo levelup_get_pagetitle_catalogs(); ?>

                        </div>
                    </div>
                </div>
            </div>
            <?php
            return;
        }

        if ( ! $show_page_title ) {
			return;
		}


		$page_title_wrap_attrs = '';
        $title_style = '';

        if ($config->get('header.logo_style')) {
            $page_title_wrap_attrs .= ' data-midnight="' . esc_attr( $config->get('header.logo_style') ) . '"';
        }

        if (isset($levelup_options['page_title_font']['font-size']) && empty($levelup_options['page_title_font']['line-height'])) {
            $title_style .= 'line-height: 120%;';
        }

		$background_image = '';
		$page_title_classes = array('page-title');
		$featured_image = false;

		if ( has_post_thumbnail() &&
		     (
		     	( isset( $levelup_options['page-title-background-featured'] ) && ! empty( $levelup_options['page-title-background-featured'] ) && $config->get( 'header.featured_image_bg' ) != 'disable' )
		        || $config->get( 'header.featured_image_bg' ) == 'enable'
		     )
		) {
			$featured_image = true;
			$page_title_classes[] = 'with_featured';
			$large_image_url = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
			if ( ! empty( $large_image_url[0] ) ) {
				$large_image_url_src = esc_url( $large_image_url[0] );
			}

			$background_image = 'background-image: url(' . $large_image_url_src . ');';

		} else if (isset($levelup_options['page-title-background-image']) && !empty($levelup_options['page-title-background-image']['background-image'])) {
			$page_title_classes[] = 'with_background';
		}


		$title_height = absint( $config->get( 'page_title.height' ) );
		$page_title_wrap_attrs .= ' style="min-height: ' . esc_attr( $title_height ) . 'px;' . $background_image . '"';
		$page_title_wrap_table_style = ' style="height: ' . esc_attr( $title_height ) . 'px;"';

		if ( levelup_get_options( 'page-title-breadcrumbs' ) ) {
			$page_title_classes[] = 'breadcrumbs-container';
		}

		if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'side' && ( $config->get( 'page_title.align' ) == 'all_left' || $config->get( 'page_title.align' ) == 'all_right' ) ) {
			$page_title_classes[] = 'breadcrumbs-side';
		}

		if ( $config->get( 'header.breadcrumbs.color' ) == 'light' ) {
			$page_title_classes[] = 'breadcrumbs-light';
		}

		?>

		<div <?php echo levelup_get_page_title_wrap_html_class( $page_title_classes ), $page_title_wrap_attrs; ?>>
			<div class="container<?php if(levelup_get_options( 'page-title-fullwidth' )) echo '-fluid'; ?>">
			<div class="row">
				<div class="title-container">
					<div class="col-table"<?php echo $page_title_wrap_table_style; ?>>

						<?php
						$breadcrumbs_html = '';
						if ( levelup_get_options( 'page-title-breadcrumbs' ) && levelup_get_options( 'page-title-breadcrumbs' ) != 'bottom' ) {
							$breadcrumbs = levelup_get_breadcrumbs();

							if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'side' && ( $config->get( 'page_title.align' ) == 'all_left' || $config->get( 'page_title.align' ) == 'all_right' ) ) {
								$breadcrumbs_html = '<div class="col-td col-breadcrumbs">' . $breadcrumbs . '</div>';
							} else if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'under' ) {
								$breadcrumbs_html = $breadcrumbs;
							}

							if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'side' && $config->get( 'page_title.align' ) == 'all_right' ) {
								echo $breadcrumbs_html;
							}

						}

                        $page_subtitle = '';
                        $title = '<h1 ' . levelup_get_page_title_html_class() . ($title_style ? ' style="' . esc_attr( $title_style ) . '"' : '') . '>' . levelup_get_page_title() . '</h1>';

                        if( $config->get('header.subtitle') != "" ) {
                            $page_subtitle = '<p class="subtitle">' . esc_html( $config->get('header.subtitle') ) . '</p>';
                        }

                        if ($config->get('header.swap_titles')) {
                            $title = $page_subtitle . $title;
                        } else {
                            $title = $title . $page_subtitle;
                        }

						if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'under' ) {
							$title = $title . $breadcrumbs_html;
						}

						$page_title = '<div class="col-td hgroup">' . $title . '</div>';
						$page_title = apply_filters( 'levelup_page_title', $page_title );
                        echo $page_title;

                        if ( is_singular('post') && $levelup_options['blog-hide_page_title_meta']) {
                            echo levelup_get_pagetitle_meta();
                        }

                        echo levelup_get_pagetitle_catalogs();

						if ( is_category() && levelup_get_options( 'page-title-category-description' ) ) {
							$description = category_description();
							if ( $description ) {
								echo '<div class="col-td pt-cat-description"><div class="inner">' . $description . '</div></div>';
							}
						}

						if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'side' && $config->get( 'page_title.align' ) == 'all_left' ) {
							echo $breadcrumbs_html;
						}

						?>
                    </div>
				</div>
			</div>
			</div>
			<?php if($featured_image && isset($levelup_options['page-title-background-overlay-color']) && isset($levelup_options['page-title-background-overlay-color']['rgba']) ) { ?>
				<div class="pagetitle-overlay" style="background: <?php echo esc_attr($levelup_options['page-title-background-overlay-color']['rgba']); ?>"></div>
			<?php } ?>
		</div>

		<?php if ( levelup_get_options( 'page-title-breadcrumbs' ) == 'bottom' ) {
			echo '<div class="container' . (levelup_get_options( 'page-title-fullwidth' ) ? '-fluid' : '') . ' breadcrumbs-container"><div class="row"><div class="col-md-12">' . levelup_get_breadcrumbs() . '</div></div></div>';
		} ?>

	<?php

	}

}
add_action('levelup_before_main_container', 'levelup_page_title_controller', 15);
add_action('levelup_before_main_container', 'levelup_fancy_header_controller', 16);


if ( ! function_exists( 'levelup_get_blog_readmore' ) ) :

    function levelup_get_blog_readmore(){
        global $levelup_options;

        if ( $levelup_options['blog_type'] != 'list-small-blog') {
            $class = ' more-button';
        }

        echo '<a class="more-link' . esc_attr( $class ) . '" href="' . esc_url( get_permalink() ) . '"><span class="continue-reading">' . esc_html__("Read More", 'LEVELUP') . '</span></a>';
    }

endif;


if (!function_exists('levelup_get_row_block')) {

	function levelup_get_row_block($content) {

		if ($content === '') return;

		return 	'
<div class="container row_section vc_row_p_30">
	<div class="vc_row wpb_row vc_row-fluid vc_column-gap-30">
		<div class="row-container container-fluid">
			<div class="row-inner">
				<div class="wpb_column vc_column_container vc_col-sm-12">
					<div class="vc_column-inner ">
						<div class="wpb_wrapper">
							' . $content . '
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>
</div>';
	}
}
