<?php
/**
 * The template for displaying product content within loops
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/content-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @author      WooThemes
 * @package     WooCommerce/Templates
 * @version 3.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

global $product, $woocommerce_loop, $levelup_options;

// Ensure visibility
if ( empty( $product ) || ! $product->is_visible() ) {
	return;
}

wp_enqueue_script( 'isotope' );


// Store loop count we're currently on
if ( empty( $woocommerce_loop['loop'] ) ) {
    $woocommerce_loop['loop'] = 0;
}

// Store column count for displaying the grid
if ( empty( $woocommerce_loop['columns'] ) ) {
    $woocommerce_loop['columns'] = apply_filters( 'loop_shop_columns', 4 );
}

// Increase loop count
$woocommerce_loop['loop']++;

// Extra post classes
$classes = array();

if ($woocommerce_loop['columns'] == 2){
    $classes[] = "col-lg-6 col-md-6 col-sm-6 col-xs-6";
}elseif ($woocommerce_loop['columns'] == 3){
    $classes[] = "col-lg-4 col-md-4 col-sm-6 col-xs-6";
}elseif ($woocommerce_loop['columns'] == 4){
    $classes[] = "col-lg-3 col-md-4 col-sm-6 col-xs-6";
}elseif ($woocommerce_loop['columns'] == 6){
    $classes[] = "col-lg-2 col-md-3 col-sm-4 col-xs-6";
}else{
    $classes[] = "col-lg-3 col-md-3 col-sm-6 col-xs-6";
}

$classes[] = 'product-item';

if ( 0 === ( $woocommerce_loop['loop'] - 1 ) % $woocommerce_loop['columns'] || 1 === $woocommerce_loop['columns'] ) {
	$classes[] = 'first';
}
if ( 0 === $woocommerce_loop['loop'] % $woocommerce_loop['columns'] ) {
	$classes[] = 'last';
}

remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 11 );

?>
<li <?php post_class( levelup_sanitize_classes( $classes ) ); ?>>
    <div>

    <div class="top-product-section">

		    <?php
		    /**
		     * woocommerce_before_shop_loop_item hook.
		     *
		     * @hooked woocommerce_template_loop_product_link_open - 10
		     */
		    do_action( 'woocommerce_before_shop_loop_item' );
		    ?>

            <?php
            $attachment_ids = $product->get_gallery_image_ids();
            if ( $attachment_ids ) {
                $loop = 0;
                foreach ( $attachment_ids as $attachment_id ) {
                    $image_link = wp_get_attachment_url( $attachment_id );
                    if (!$image_link) continue;
                    $loop++;
                    $product_thumbnail_second = wp_get_attachment_image_src($attachment_id, 'shop_catalog');
                    if ($loop == 1) break;
                }
            }

            $style = '';
            $class = '';

            if (isset($product_thumbnail_second[0])) {
                if ( (!isset($levelup_options['woo-enable-image-hover'])) || ( $levelup_options['woo-enable-image-hover'] == "1" ) ) {
                    $style = 'background-image:url(' . esc_url( $product_thumbnail_second[0] ) . '); background-size: contain; background-position: center left;';
                    $class = 'woo_product_image_hover';
                }
            }
            ?>

            <div class="product_thumbnail <?php echo esc_attr( $class );?>">
                <span class="product_thumbnail_background" style="<?php echo esc_attr( $style ); ?>"></span>
                <?php
                /**
                 * woocommerce_before_shop_loop_item_title hook.
                 *
                 * @hooked woocommerce_show_product_loop_sale_flash - 10
                 * @hooked woocommerce_template_loop_product_thumbnail - 10
                 */
                do_action( 'woocommerce_before_shop_loop_item_title' );
                ?>
            </div>
        <?php

        if ( $levelup_options['woo-enable-rating-catalog'] ) {
            woocommerce_template_loop_rating();
        }

        ?>

	    <?php
	    /**
	     * woocommerce_after_shop_loop_item hook.
	     *
	     * @hooked woocommerce_template_loop_product_link_close - 5
	     * @hooked woocommerce_template_loop_add_to_cart - 10
	     */
	    do_action( 'woocommerce_after_shop_loop_item' );
	    ?>

        <div class="product_button"><?php do_action( 'levelup_woocommerce_after_product_image' ); ?></div>

    </div>


    <?php if( $levelup_options["woo-enable-catalog-category"] == "1"):?>
        <p class="category">
        <?php echo wc_get_product_category_list( $product->get_id(), ', ' ); ?>
        </p>

    <?php endif;?>

    <a href="<?php the_permalink(); ?>">

        <h4><?php the_title(); ?></h4>

        <?php
        /**
         * woocommerce_after_shop_loop_item_title hook.
         *
         * @hooked woocommerce_template_loop_rating - 5
         * @hooked woocommerce_template_loop_price - 10
         */
        do_action( 'woocommerce_after_shop_loop_item_title' );
        ?>
    </a>

    </div>
</li>