<?php
/**
 * ReduxFramework Sample Config File
 * For full documentation, please visit: http://docs.reduxframework.com/
 */

if ( ! class_exists( 'LevelupRedux' ) ) {
    return;
}

// This is your option name where all the Redux data is stored.
$opt_name = "levelup_options";

// This line is only for altering the demo. Can be easily removed.
$opt_name = apply_filters( 'levelupredux_demo/opt_name', $opt_name );

/*
 *
 * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
 *
 */

$sampleHTML = '';
if ( file_exists( get_template_directory() . '/info-html.html' ) ) {
    LevelupRedux_Functions::initWpFilesystem();

    global $wp_filesystem;

    $sampleHTML = $wp_filesystem->get_contents( get_template_directory() . '/info-html.html' );
}

// Background Patterns Reader
$sample_patterns_path = LevelupReduxFramework::$_dir . '../sample/patterns/';
$sample_patterns_url  = LevelupReduxFramework::$_url . '../sample/patterns/';
$sample_patterns      = array();

if ( is_dir( $sample_patterns_path ) ) {

    if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
        $sample_patterns = array();

        while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

            if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                $name              = explode( '.', $sample_patterns_file );
                $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                $sample_patterns[] = array(
                    'alt' => $name,
                    'img' => $sample_patterns_url . $sample_patterns_file
                );
            }
        }
    }
}


/**
 * ---> SET ARGUMENTS
 * All the possible arguments for Redux.
 * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
 * */

$theme = wp_get_theme(); // For use with some settings. Not necessary.

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get( 'Name' ),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get( 'Version' ),
    // Version that appears at the top of your panel
    'menu_type'            => 'menu',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__( 'LEVELUP', 'LEVELUP' ),
    'page_title'           => esc_html__( 'LEVELUP Options', 'LEVELUP' ),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => true,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => false,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-portfolio',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => false,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

    // OPTIONAL -> Give you extra features
    'page_priority'        => 40,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => 'themes.php',
    // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => get_template_directory_uri() . '/admin/assets/images/menu/main_logo.png',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => '',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => true,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    'footer_credit'     => 'LEVELUP Options',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!

    'allow_tracking' => false,

    // HINTS
    'hints'                => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    )
);


LevelupRedux::setArgs( $opt_name, $args );

/*
 * ---> END ARGUMENTS
 */


/*
 * ---> START HELP TABS
 */

$tabs = array(
    array(
        'id'      => 'redux-help-tab-1',
        'title'   => esc_html__( 'Theme Information 1', 'LEVELUP' ),
        'content' => wp_kses( __( '<p>This is the tab content, HTML is allowed.</p>', 'LEVELUP' ), array( 'p' => array(), 'a' => array( 'href' => array() ) ) )
    ),
    array(
        'id'      => 'redux-help-tab-2',
        'title'   => esc_html__( 'Theme Information 2', 'LEVELUP' ),
        'content' => wp_kses( __( '<p>This is the tab content, HTML is allowed.</p>', 'LEVELUP' ), array( 'p' => array(), 'a' => array( 'href' => array() ) ) )
    )
);
LevelupRedux::setHelpTab( $opt_name, $tabs );

// Set the help sidebar
$content = wp_kses( __( '<p>This is the sidebar content, HTML is allowed.</p>', 'LEVELUP' ), array( 'p' => array(), 'a' => array( 'href' => array() ) ) );
LevelupRedux::setHelpSidebar( $opt_name, $content );


/*
 * <--- END HELP TABS
 */


/*
 *
 * ---> START SECTIONS
 *
 */

/*
    As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for
 */


LevelupRedux::setSection($opt_name, array(
    'id' => 'general',
    'icon' => 'general',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('General Settings', 'LEVELUP'),
    'fields' => array(
        array(
            'id' => 'front-page',
            'type' => 'button_set',
            'title' => esc_html__('Front Page', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Default', 'LEVELUP'),
                'project' => esc_html__('Slides', 'LEVELUP'),
            ),
            'default' => '',
			'subtitle' => esc_html__('Select how to start your website (either as the Page or the Slides).', 'LEVELUP')
        ),

	    array(
		    'id' => 'section-maintenance-start',
		    'type' => 'section',
		    'title' => esc_html__('Maintenance Mode', 'LEVELUP'),
		    'subtitle' => '',
		    'indent' => true,
	    ),

	    array(
		    'id' => 'maintenance_mode',
		    'type' => 'switch',
		    'title' => esc_html__('Maintenance Mode', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting if you want to switch your website to maintenance mode.', 'LEVELUP'),
		    'default' => '0',
	    ),

	    array(
		    'id'       => 'maintenance_page',
		    'type'     => 'select',
		    'title'    => esc_html__('Maintenance Page', 'LEVELUP'),
		    'subtitle' => esc_html__('Specify the page to which the unregistered visitor will be re-directed when your website is during the maintenance mode.', 'LEVELUP'),
		    'data'  => 'pages',
		    'default'  => '',
		    'required'  => array('maintenance_mode', '=', '1'),
	    ),

	    array(
		    'id' => 'section-maintenance-end',
		    'type' => 'section',
		    'indent' => false,
	    ),

        array(
            'id' => 'section-back-to-top-classic-version-start',
            'type' => 'section',
            'title' => esc_html__('Main Back To Top Button (Global)', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),


        array(
            'id' => 'back-to-top-main-icon',
            'type' => 'image_select',
            'title' => esc_html__('Back To Top Button / Classic Version', 'LEVELUP'),
            'subtitle' => esc_html__('Choose button type. When you press the "Back To Top" button, the page scrolls itself up to the very beginning. Classic Version makes the button "Back To Top" always displayed (apart from the first screen) at the bottom right corner.', 'LEVELUP'),
            'options' => array(
                '' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_none.png'
                ),
                'icon1' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_01.png'
                ),
                'icon2' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_02.png'
                ),
                'icon3' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_03.png'
                ),
            ),
            'default' => 'icon1'
        ),

        array(
            'id' => 'section-back-to-top-classic-version-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-row-padding-start',
            'type' => 'section',
            'title' => esc_html__('Row Padding (Global)', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'vc_row__padding',
            'type' => 'button_set',
            'title' => esc_html__('Visual Composer Row Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you may set the padding (on all sides) in pixels in the Row.', 'LEVELUP'),
            'options' => array(
                0 =>  esc_html__('0', 'LEVELUP'),
                15 => esc_html__('15', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
            ),
            'default' => 30,
        ),

        array(
            'id' => 'vc_row__padding_fix',
            'type' => 'button_set',
            'title' => esc_html__('Remove Row Bottom Spacing?', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you may remove row bottom spacing globally in every row on phone view.', 'LEVELUP'),
            'options' => array(
                '' =>  esc_html__('None', 'LEVELUP'),
                'xs' => esc_html__('Phone view', 'LEVELUP'),
            ),
            'default' => '',
        ),

        array(
            'id' => 'section-row-padding-end',
            'type' => 'section',
            'indent' => false,
        ),

        /*array(
            'id' => 'vc_column__spacing_xs',
            'type' => 'slider',
            'title' => esc_html__('Visual Composer Row Mobile Spacing', 'LEVELUP'),
            "default" => 0,
            "min" => 0,
            "step" => 1,
            "max" => 100,
        ),*/

		array(
            'id' => 'section-global-padding-start',
            'type' => 'section',
            'title' => esc_html__('Content Area Padding (Global)', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'page-title-margin-bottom',
            'type' => 'button_set',
            'title' => esc_html__('Content Area Top Padding (Global)', 'LEVELUP'),
            'subtitle' => wp_kses( __('Using this option, you may set a global top padding for the page content in pixels. This option applies globally to all of the pages. For more information, please check out the <a href="http://puzzlerbox.com/levelup/documentation/Theme_Options/General_Settings.html#global_spacing" target="_blank">online documentation.</a>', 'LEVELUP'), array( 'a' => array( 'href' => array() ) ) ),
            'desc' => '',
            'options' => array(
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => 60,
        ),

        array(
            'id' => 'footer-margin_top',
            'type' => 'button_set',
            'title' => esc_html__('Content Area Bottom Padding (Global)', 'LEVELUP'),
            'subtitle' => wp_kses( __('Using this option, you may set a global bottom padding for the page content in pixels. This option applies globally to all of the pages. For more information, please check out the <a href="http://puzzlerbox.com/levelup/documentation/Theme_Options/General_Settings.html#global_spacing" target="_blank">online documentation.</a>', 'LEVELUP'), array( 'a' => array( 'href' => array() ) ) ),
            'desc' => '',
            'options' => array(
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => 60,
        ),

        array(
            'id' => 'section-global-search-start',
            'type' => 'section',
            'title' => esc_html__('Search', 'LEVELUP'),
            'indent' => true,
        ),

        array(
            'id' => 'header-search-button-by',
            'type' => 'button_set',
            'title' => esc_html__('Search by...', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the search section to work with.', 'LEVELUP'),
            'options' => array(
                'wordpress' =>  esc_html__('WordPress', 'LEVELUP'),
                'woocommerce' => esc_html__('WooCommerce', 'LEVELUP'),
            ),
            'default' => 'wordpress',
        ),

        array(
            'id' => 'header-search-color-style',
            'type' => 'button_set',
            'title' => esc_html__('Search Panel Color Scheme', 'LEVELUP'),
            'subtitle' => esc_html__('Using this setting for choosing dark or light search panel.', 'LEVELUP'),
            'options' => array(
                '' =>  esc_html__('Light', 'LEVELUP'),
                'dark' => esc_html__('Dark', 'LEVELUP'),
            ),
            'default' => '',
        ),

        array(
            'id' => 'header-style-search-overlay',
            'type' => 'switch',
            'title' => esc_html__('Content Overlapping', 'LEVELUP'),
			'subtitle' => esc_html__('Using this setting you can enable / disable page content overlapping while the search bar panel is opened. Enabled by default.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'section-global-search-end',
            'type' => 'section',
            'indent' => false,
        ),


	    array(
		    'id' => 'section-page-transition-start',
		    'type' => 'section',
		    'title' => esc_html__('Page Transition', 'LEVELUP'),
		    'subtitle' => '',
		    'indent' => true,
	    ),

	    array(
		    'id'        => 'transition-layout',
		    'type'      => 'switch',
		    'title'     => esc_html__('Enable Transition?', 'LEVELUP'),
		    'subtitle'  => esc_html__('Using this setting you can enable / disable custom page transition.', 'LEVELUP'),
		    'default'   => 1
	    ),
	    array(
		    'id'        => 'transition-in-duration',
		    'type'      => 'spinner',
		    'title'     => esc_html__('In Duration', 'LEVELUP'),
		    'subtitle'  => '',
		    'required'  => array('transition-layout', '=', '1'),
		    'min'      => '20',
		    'step'     => '50',
		    'max'      => '3000',
		    'default'   => '1500'
	    ),

	    array(
		    'id'        => 'transition-out-duration',
		    'type'      => 'spinner',
		    'title'     => esc_html__('Out Duration', 'LEVELUP'),
		    'subtitle'  => '',
		    'required'  => array('transition-layout', '=', '1'),
		    'min'      => '20',
		    'step'     => '50',
		    'max'      => '3000',
		    'default'   => '800'
	    ),

	    array(
		    'id'        => 'transition-page-in',
		    'type'      => 'select',
		    'title'     => esc_html__('Transition Page In?', 'LEVELUP'),
		    'subtitle'  => '',
		    'required'  => array('transition-layout', '=', '1'),
		    'options'   =>  array(
			    'fade-in' => esc_html__('Fade In', 'LEVELUP'),
			    'fade-in-up' => esc_html__('Fade In Up', 'LEVELUP'),
			    'fade-in-down' => esc_html__('Fade In Down', 'LEVELUP'),
			    'fade-in-left' => esc_html__('Fade In Left', 'LEVELUP'),
			    'fade-in-right' => esc_html__('Fade In Right', 'LEVELUP'),
			    'rotate-in' => esc_html__('Rotate In', 'LEVELUP'),
			    'flip-in-x' => esc_html__('Flip In X', 'LEVELUP'),
			    'flip-in-y' => esc_html__('Flip In Y', 'LEVELUP'),
			    'zoom-in' => esc_html__('Zoom In', 'LEVELUP'),
		    ),
		    'default'      => 'fade-in'
	    ),

	    array(
		    'id'        => 'transition-page-out',
		    'type'      => 'select',
		    'title'     => esc_html__('Transition Page Out?', 'LEVELUP'),
		    'subtitle'  => '',
		    'required'  => array('transition-layout', '=', '1'),
		    'options'   =>  array(
			    'fade-out' => esc_html__('Fade Out', 'LEVELUP'),
			    'fade-out-up' => esc_html__('Fade Out Up', 'LEVELUP'),
			    'fade-out-down' => esc_html__('Fade Out Down', 'LEVELUP'),
			    'fade-out-left' => esc_html__('Fade Out Left', 'LEVELUP'),
			    'fade-out-right' => esc_html__('Fade Out Right', 'LEVELUP'),
			    'rotate-out' => esc_html__('Rotate Out', 'LEVELUP'),
			    'flip-out-x' => esc_html__('Flip Out X', 'LEVELUP'),
			    'flip-out-y' => esc_html__('Flip Out Y', 'LEVELUP'),
			    'zoom-out' => esc_html__('Zoom Out', 'LEVELUP'),
		    ),
		    'default'   => 'fade-out'
	    ),

	    array(
		    'id'        => 'transition-layout-loading',
		    'type'      => 'switch',
		    'title'     => esc_html__('Custom Loading Image', 'LEVELUP'),
		    'subtitle'  => esc_html__('Use this setting to upload image (.jpg .png .gif) that will be used on your site as the loading image. Disabled by default.', 'LEVELUP'),
		    'required'  => array('transition-layout', '=', '1'),
		    'default'   => 0
	    ),

	    array(
		    'id' => 'transition-image',
		    'type' => 'media',
		    'required'  => array('transition-layout-loading', '=', '1'),
		    'title' => esc_html__('Upload Your Custom Image', 'LEVELUP'),
		    'subtitle' => esc_html__('Upload a .jpg, .png or .gif image.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'transition-exclude-extend',
		    'type' => 'text',
		    'required'  => array('transition-layout', '=', '1'),
		    'title' => esc_html__('Page Transitions Rules (exceptions)', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option you can add a rule precluding the Page Transitions function.', 'LEVELUP'),
		    'default' => ''
	    ),

	    array(
		    'id' => 'section-page-transition-end',
		    'type' => 'section',
		    'indent' => false,
	    ),

        array(
            'id' => 'section-global-comments-start',
            'type' => 'section',
            'title' => esc_html__('Comments', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'comments-page-enable',
            'type' => 'switch',
            'title' => esc_html__('Comments (Pages / Portfolio / SLIDES)', 'LEVELUP'),
			'subtitle' => esc_html__('Using this setting you can enable / disable the comment sections at all of the Single Pages, in Portfolio and in the Slides.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'section-global-comments-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-slugs-start',
            'type' => 'section',
            'title' => esc_html__('Post Slugs', 'LEVELUP'),
            'subtitle' => 'It is important. After you have changed the slag you need to wait a little (around 5 seconds) till the changes will be applied.',
            'indent' => true,
        ),

	    array(
		    'id' => 'general-post_type_project_slug',
		    'type' => 'text',
		    'title' => esc_html__('SLIDES Slug', 'LEVELUP'),
			'subtitle' => esc_html__('Using this setting, you may rewrite slug for the SLIDES.', 'LEVELUP'),
		    'default' => 'slides'
	    ),
	    array(
		    'id' => 'general-post_type_portfolio_slug',
		    'type' => 'text',
		    'title' => esc_html__('Portfolio Slug', 'LEVELUP'),
			'subtitle' => esc_html__('Using this setting, you may rewrite slug for the Portfolio.', 'LEVELUP'),
		    'default' => 'portfolio'
	    ),

	    array(
		    'id' => 'general-post_type_team_slug',
		    'type' => 'text',
		    'title' => esc_html__('Team Slug', 'LEVELUP'),
			'subtitle' => esc_html__('Using this setting, you may rewrite slug for the Team.', 'LEVELUP'),
		    'default' => 'rdy_team'
	    ),

	    array(
		    'id' => 'general-post_type_testimonials_slug',
		    'type' => 'text',
		    'title' => esc_html__('Testimonials Slug', 'LEVELUP'),
			'subtitle' => esc_html__('Using this setting, you may rewrite slug for the Testimonials.', 'LEVELUP'),
		    'default' => 'rdy_testimonials'
	    ),

		array(
			'id' => 'section-slugs-end',
			'type' => 'section',
			'indent' => false,
		),

		array(
			'id' => 'section-global-etc-start',
			'type' => 'section',
			'title' => esc_html__('Other Settings', 'LEVELUP'),
			'subtitle' => '',
			'indent' => true,
		),

        array(
            'id' => 'google-maps-apikey',
            'type' => 'text',
            'title' => esc_html__('Google Maps Api', 'LEVELUP'),
            'subtitle' => wp_kses( __('Google imposed restrictions, you need generate api key for your web site. <a target="_blank" href="https://developers.google.com/maps/documentation/javascript/get-api-key" target="_blank">API Key Guide</a>', 'LEVELUP'), array( 'a' => array( 'href' => array() ) ) ),
            'default' => ''
        ),

        array(
            'id' => 'general-custom-css2',
            'type' => 'ace_editor',
            'title' => esc_html__('Custom CSS Code', 'LEVELUP'),
            'subtitle' => esc_html__('If you have any custom CSS you would like to be added to the site, please enter it here.', 'LEVELUP'),
            'mode' => 'css',
            'theme' => 'monokai',
            'default' => ''
        ),

		array(
            'id' => 'section-global-etc-end',
            'type' => 'section',
            'indent' => false,
        ),
    )
));

LevelupRedux::setSection($opt_name, array(
    'id' => 'logo',
    'icon' => 'logo',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Logo', 'LEVELUP'),
    'subtitle' => '',
    'fields' => array(

        array(
            'id' => 'use-logo',
            'type' => 'button_set',
            'title' => esc_html__('Logo Visualization Options', 'LEVELUP'),
            'subtitle' => esc_html__('Select the way of how the logo is displayed. The logo can also be turned off.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'image' => esc_html__('Image', 'LEVELUP'),
                'title' => esc_html__('Text', 'LEVELUP'),
            ),
            'default' => 'title',
        ),

        array(
            'id' => 'logo-title',
            'type' => 'text',
            'required' => array('use-logo', '=', 'title'),
            'title' => esc_html__('Text Logo', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the text for the logo. It will be displayed at the page.', 'LEVELUP'),
            'default' => 'LEVELUP'
        ),

        array(
            'id' => 'logo-title-font',
            'type' => 'typography',
            'google' => true,
            'text-align' => false,
            'line-height' => false,
            'letter-spacing' => false,
            'color' => true,
            'text-transform' => true,
            'title' => esc_html__('Logo Custom Font', 'LEVELUP'),
            'subtitle' => esc_html__('Set the font, size and color for the logo.', 'LEVELUP'),
            'default' => array(
                'color' => '#333333',
                'font-weight' => '700',
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '24px',
                'letter-spacing' => '0px'
            ),
            'required' => array('use-logo', '=', 'title'),
        ),

        array(
            'id' => 'logo',
            'type' => 'media',
            'required' => array('use-logo', '=', 'image'),
            'title' => esc_html__('Upload Your Logo', 'LEVELUP'),
            'subtitle' => esc_html__('Upload your logo image.', 'LEVELUP'),
            'default' => '',
        ),

        array(
            'id' => 'retina-logo',
            'type' => 'media',
            'required' => array('use-logo', '=', 'image'),
            'title' => esc_html__('Upload Your Retina Logo', 'LEVELUP'),
            'subtitle' => esc_html__('Upload a higher-resolution image to be used for retina display devices.', 'LEVELUP'),
            'default' => '',
        ),
        array(
            'id' => 'logo-light',
            'type' => 'media',
            'required' => array('use-logo', '=', 'image'),
            'title' => esc_html__('Upload Your Logo (Light Version)', 'LEVELUP'),
            'subtitle' => esc_html__('Upload a logo image to display for "Light" header skin', 'LEVELUP'),
            'default' => '',
        ),
        array(
            'id' => 'retina-logo-light',
            'type' => 'media',
            'required' => array('use-logo', '=', 'image'),
            'title' => esc_html__('Upload Your Retina Logo (Light Version)', 'LEVELUP'),
            'subtitle' => esc_html__('Upload a higher-resolution image to be used for retina display devices.', 'LEVELUP'),
            'default' => '',
        ),

	    array(
		    'id' => 'logo-custom-url',
		    'type' => 'text',
		    'required' => array('use-logo', '!=', ''),
		    'title' => esc_html__('Logo Custom URL', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this setting you may enter custom URL, which is applied on the logotype.', 'LEVELUP'),
		    'default' => '',
		    'validate' => 'url'
	    ),

        array(
            'id' => 'logo-top-stick',
            'type' => 'switch',
            'title' => esc_html__('Make the logo to stick/flush to the top?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable to make the logo stick/flush to the top? Disabled by default.', 'LEVELUP'),
            'required' => array('use-logo', '=', 'image'),
            'default' => 0
        ),

    )
));

LevelupRedux::setSection($opt_name, array(
    'id' => 'topbar',
    'icon' => 'topbar',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('TopBar', 'LEVELUP'),
    'heading' => esc_html__('TopBar', 'LEVELUP'),
    'desc' => esc_html__('Important! TopBar does not work with Sliding Top and Fullscreen Headers.', 'LEVELUP'),
    'fields' => array(

	    array(
		    'id' => 'header-topbar-enable',
		    'type' => 'button_set',
		    'title' => esc_html__('TopBar Width', 'LEVELUP'),
		    'subtitle' => esc_html__('Enable / Disable the TopBar or choose the TopBar Width.', 'LEVELUP'),
		    'options' => array(
			    '' => esc_html__('Disable', 'LEVELUP'),
			    'boxed' => esc_html__('Content width', 'LEVELUP'),
			    'fullwidth' => esc_html__('Full Width', 'LEVELUP'),
		    ),
		    'default' => '',
		    'required' => array('header-layout', '=', array('fixed', 'static')),
	    ),


        array(
            'id' => 'section-header-topbar-start',
            'type' => 'section',
            'title' => esc_html__('TopBar Settings', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
            'required' => array('header-topbar-enable', '=', array('boxed', 'fullwidth')),
        ),

	    array(
		    'id' => 'header-topbar-show_mobile',
		    'type' => 'switch',
		    'title' => esc_html__('Show TopBar on Mobile Devices?', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to show or hide the TopBar on Mobile Devices.', 'LEVELUP'),
		    'default' => 0,
		    'required' => array('header-topbar-enable', '!=', array('')),
	    ),

	    array(
		    'id' => 'header-topbar-position',
		    'type' => 'button_set',
		    'title' => esc_html__('TopBar Position', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option, to set the top bar fixed up at the top when scrolled.', 'LEVELUP'),
		    'options' => array(
				    '' => esc_html__('Default', 'LEVELUP'),
				    'sticky' => esc_html__('Fixed top', 'LEVELUP'),
		    ),
		    'default' => '',
		    'required' => array('header-layout', '=', array('fixed',)),
	    ),

        array(
            'id' => 'header-topbar-height',
            'type' => 'slider',
            'title' => esc_html__('TopBar Height', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the TopBar Height.', 'LEVELUP'),
            "default" => 30,
            "min" => 20,
            "step" => 1,
            "max" => 60,
            'display_value' => 'text',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-background_color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('TopBar Background Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a background color for TopBar area.', 'LEVELUP'),
            'default' => '#000000',
            'required' => array('header-topbar-enable', '!=', ''),
        ),


        array(
            'id' => 'header-topbar-font_size',
            'type' => 'slider',
            'title' => esc_html__('TopBar Font Size', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the TopBar Font Size.', 'LEVELUP'),
            "default" => 14,
            "min" => 10,
            "step" => 1,
            "max" => 30,
            'display_value' => 'text',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-font_color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('TopBar Font Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for TopBar Font.', 'LEVELUP'),
            'default' => '#FFFFFF',
            'required' => array('header-topbar-enable', '!=', ''),
        ),


        array(
            'id' => 'header-topbar-elem-text',
            'type' => 'text',
            'title' => esc_html__('TopBar Text', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the TopBar text.', 'LEVELUP'),
            'default' => '',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-elem-email',
            'type' => 'text',
            'title' => esc_html__('TopBar Email', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the email.', 'LEVELUP'),
            'default' => '',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-elem-email_icon',
            'type' => 'switch',
            'title' => esc_html__('TopBar Email Icon', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to show or hide the Email Icon in TopBar area. Hidden by default.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-elem-phone',
            'type' => 'text',
            'title' => esc_html__('TopBar Phone Number', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the phone number.', 'LEVELUP'),
            'default' => '',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-elem-phone_icon',
            'type' => 'switch',
            'title' => esc_html__('TopBar Phone Icon', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to show or hide the Email Icon in TopBar area. Hidden by default.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),
        array(
            'id' => 'header-topbar-elem-phone_link',
            'type' => 'switch',
            'title' => esc_html__('Clickable Phone Number (href:tel).', 'LEVELUP'),
		        'subtitle' => esc_html__('Use this setting to adding a clickable phone number.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-elem-skype',
            'type' => 'text',
            'title' => esc_html__('TopBar Skype', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the skype.', 'LEVELUP'),
            'default' => '',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-elem-skype_icon',
            'type' => 'switch',
            'title' => esc_html__('TopBar Skype Icon', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to show or hide the Email Icon in TopBar area. Hidden by default.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id'      => 'header-topbar-blocks',
            'type'    => 'sorter',
            'title'   => esc_html__('TopBar Blocks', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting you can specify the position of elements on the TopBar panel.', 'LEVELUP'),
            'desc'    => '',
            'options' => array(
                'Elements' => array(
                    'text'   => esc_html__('Text', 'LEVELUP'),
                    'email'  => esc_html__('Email', 'LEVELUP'),
                    'phone'  => esc_html__('Phone', 'LEVELUP'),
                    'skype'  => esc_html__('Skype', 'LEVELUP'),
                    'login'  => esc_html__('Login', 'LEVELUP'),
                    'search' => esc_html__('Search', 'LEVELUP'),
                    'cart'   => esc_html__('Cart', 'LEVELUP'),
                    'social' => esc_html__('Social', 'LEVELUP'),
                    'menu'   => esc_html__('Menu', 'LEVELUP'),
                ),
                'Left'     => array(),
                'Center'   => array(),
                'Right'    => array(),
            ),
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social_padding',
            'type' => 'slider',
            'title' => esc_html__('Social Icons Spacing', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the Social Icons Spacing.', 'LEVELUP'),
            'desc' => esc_html__('Default 20px', 'LEVELUP'),
            'required' => array('header-topbar-enable', '!=', ''),
            'default' => 4,
            'min' => 2,
            'step' => 1,
            'max' => 20,
        ),

        array(
            'id' => 'header-topbar-social_hover_color',
            'type' => 'color',
            'title' => esc_html__('TopBar Social Icons Hover Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the hover color for TopBar Social Icons.', 'LEVELUP'),
            'default' => '#cccccc',
            'transparent' => false,
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-facebook',
            'type' => 'checkbox',
            'title' => esc_html__('Facebook', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-twitter',
            'type' => 'checkbox',
            'title' => esc_html__('Twitter', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-google-plus',
            'type' => 'checkbox',
            'title' => esc_html__('Google+', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-vimeo',
            'type' => 'checkbox',
            'title' => esc_html__('Vimeo', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-pinterest',
            'type' => 'checkbox',
            'title' => esc_html__('Pinterest', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-youtube',
            'type' => 'checkbox',
            'title' => esc_html__('Youtube', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-tumblr',
            'type' => 'checkbox',
            'title' => esc_html__('Tumblr', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-linkedin',
            'type' => 'checkbox',
            'title' => esc_html__('LinkedIn', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-rss',
            'type' => 'checkbox',
            'title' => esc_html__('RSS', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-behance',
            'type' => 'checkbox',
            'title' => esc_html__('Behance', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-instagram',
            'type' => 'checkbox',
            'title' => esc_html__('Instagram', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-github',
            'type' => 'checkbox',
            'title' => esc_html__('GitHub', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-soundcloud',
            'type' => 'checkbox',
            'title' => esc_html__('SoundCloud', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-xing',
            'type' => 'checkbox',
            'title' => esc_html__('Xing', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-vk',
            'type' => 'checkbox',
            'title' => esc_html__('VK', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-wechat',
            'type' => 'checkbox',
            'title' => esc_html__('WeChat', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-snapchat',
            'type' => 'checkbox',
            'title' => esc_html__('Snapchat', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),

        array(
            'id' => 'header-topbar-social-flickr',
            'type' => 'checkbox',
            'title' => esc_html__('Flickr', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-topbar-enable', '!=', ''),
        ),


        array(
            'id' => 'section-header-topbar-end',
            'type' => 'section',
            'indent' => false,
        ),

    )
));

LevelupRedux::setSection($opt_name, array(
    'id' => 'header',
    'icon' => 'header',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Header', 'LEVELUP'),
    'heading' => esc_html__('Header', 'LEVELUP'),
    'desc' => '',
    'fields' => array(

        array(
            'id' => 'menu-disable',
            'type' => 'switch',
            'title' => esc_html__('Disable Header Area?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Header Area.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'header-layout',
            'type' => 'image_select',
            'title' => esc_html__('Header Layout', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the header layout & behavior.', 'LEVELUP'),
            'options' => array(

                'fixed' => array(
                    'title' => esc_html__('Sticky', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout_02.gif'
                ),

                'static' => array(
                    'title' => esc_html__('Classic', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout_03.gif'
                ),

                'gamburg' => array(
                    'title' => esc_html__('Sliding Top', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout_01.gif'
                ),

                'gamburg_full' => array(
                    'title' => esc_html__('Fullscreen', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/menu_03.gif'
                ),

            ),
            'default' => 'fixed',
        ),

        array(
            'id' => 'header-fullwidth',
            'type' => 'switch',
            'title' => esc_html__('Full Width Header', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting if you want to expand the header to full width of the page.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-layout', '=', array('fixed', 'static', 'gamburg', 'gamburg_full')),
        ),


        array(
            'id' => 'section-header-logo-start',
            'type' => 'section',
            'title' => esc_html__('Logo Settings', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
            'required' => array('use-logo', '=', array('image',)),
        ),

        array(
            'id' => 'logo-height',
            'type' => 'text',
            'title' => esc_html__('Logo Height', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the height of the logo. Default 20', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '20',
            'required' => array('use-logo', '=', array('image',)),
        ),

        array(
            'id' => 'menu-style',
            'type' => 'button_set',
            'title' => esc_html__('Logo Style', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to choose the dark or light version of the logo that will be displayed in the Header Area.', 'LEVELUP'),
            'options' => array(
                'dark' => esc_html__('Dark', 'LEVELUP'),
                'light' => esc_html__('Light', 'LEVELUP'),
            ),
            'default' => 'dark',
            'required' => array('use-logo', '=', array('image')),
        ),

        array(
            'id' => 'menu-style-opened',
            'type' => 'button_set',
            'title' => esc_html__('Logo Style (when Header Area is opened)', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to choose dark or light version of the logo that will be displayed in the opened Header Area.', 'LEVELUP'),
            'options' => array(
                'dark' => esc_html__('Dark', 'LEVELUP'),
                'light' => esc_html__('Light', 'LEVELUP'),
            ),
            'default' => 'dark',
            'required' => array('header-layout', '=', array('gamburg', 'gamburg_full')),
        ),

        array(
            'id' => 'section-header-logo-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-header-area-settings-start',
            'type' => 'section',
            'title' => esc_html__('Header Area Settings', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'header-height',
            'type' => 'text',
            'title' => esc_html__('Header Height', 'LEVELUP'),
            'subtitle' => esc_html__('Enter header height in pixels. Does not work in fullscreen mode.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. Default 80', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '80',
            'required' => array('header-layout', '!=', 'gamburg_full'),
        ),

        array(
            'id' => 'header-style-menu-columns',
            'type' => 'switch',
            'title' => esc_html__('Enable column view of menu items?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable column view of menu items. You can place up to 4 adjacent columns in the header area.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-layout', '=', array('static', 'gamburg',)),
        ),

        array(
            'id' => 'header-align',
            'type' => 'button_set',
            'title' => esc_html__('Menu Items Position', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a menu items position (left, center or right alignment). Does not work when column view of menu items.', 'LEVELUP'),
            'options' => array(
                'left' => esc_html__('Left', 'LEVELUP'),
                'center' => esc_html__('Center', 'LEVELUP'),
                'right' => esc_html__('Right', 'LEVELUP'),
            ),
            'default' => 'left',
            'required' => array('header-layout', '=', array('fixed', 'static', 'gamburg', 'gamburg_full')),
        ),

	    array(
		    'id' => 'header-background',
		    'type' => 'switch',
		    'title' => esc_html__('Header Background', 'LEVELUP'),
		    'default' => '1',
		    'required' => array('header-layout', '=', array('fixed', 'static')),
		    'subtitle' => esc_html__('Use this setting to enable / disable the background in a header area.', 'LEVELUP'),
        ),

        array(
            'id' => 'header-background-color',
            'type' => 'color',
            'title' => esc_html__('Header Background Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a background color for header area.', 'LEVELUP'),
            'default' => '#ffffff',
        ),

        array(
            'id' => 'header-bottom_line',
            'type' => 'button_set',
            'title' => esc_html__('Header Bottom Border', 'LEVELUP'),
            'subtitle' => esc_html__('Select the way how Header Bottom Border is displayed.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'line' => esc_html__('Line', 'LEVELUP'),
                'shadow' => esc_html__('Shadow', 'LEVELUP'),
            ),
            'default' => 'line',
            'required' => array('header-layout', '!=', 'gamburg_full'),
        ),

        array(
            'id' => 'header-lines-color',
            'type' => 'color',
            'title' => esc_html__('Header Bottom Border Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Header Bottom Border.', 'LEVELUP'),
            'desc' => esc_html__('Default #cccccc', 'LEVELUP'),
            'default' => '#cccccc',
            'transparent' => false,
            'required' => array('header-bottom_line', '=', array('line')),
        ),

        array(
            'id' => 'header-background-appear-enable',
            'type' => 'switch',
            'title' => esc_html__('Transparent Header appear (global)', 'LEVELUP'),
            'subtitle' => esc_html__('Transparent Header Area background will appear after scrolling the page. Works with Sticky Header.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-layout', '=', array('fixed')),
        ),

        array(
            'id' => 'header-background-appear',
            'type' => 'text',
            'title' => esc_html__('Header Background Appear After (N-px)', 'LEVELUP'),
            'subtitle' => esc_html__('Enter pixel value resulting a header area background color during scrolling. Works with sticky header while scrolling process.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 350', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '200',
            'required' => array('header-background-appear-enable', '=', array('1')),
        ),

        array(
            'id' => 'header-background-appear-line',
            'type' => 'switch',
            'title' => esc_html__('Hide Header Bottom Border (Line/Shadow)?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to hide a shadow or a line in the Header Area until the Header Area background will appear after scrolling the page.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-background-appear-enable', '=', array('1')),
        ),

        array(
            'id' => 'header-style-down-content',
            'type' => 'switch',
            'title' => esc_html__('Lower a little down the contents?', 'LEVELUP'),
            'subtitle' => esc_html__('Lower a little down the contents, when header menu panel is opened.', 'LEVELUP'),
            'default' => '1',
            'required' => array('header-layout', '=', array('gamburg',)),
        ),

        array(
            'id' => 'header-style-menu-overlay',
            'type' => 'switch',
            'title' => esc_html__('Enable Content overlapping?', 'LEVELUP'),
            'subtitle' => esc_html__('Using this setting you can enable / disable page content overlapping while the header area is opened.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-layout', '=', array('gamburg')),
        ),

        array(
            'id' => 'header-style-menu-inline',
            'type' => 'switch',
            'title' => esc_html__('Enable Menu Items Inline?', 'LEVELUP'),
            'default' => '0',
            'subtitle' => esc_html__('Use this setting you can place the menu items one by one in a line.', 'LEVELUP'),
            'required' => array('header-layout', '=', array('gamburg_full',)),
        ),

        array(
            'id' => 'header-style-menu-widget',
            'type' => 'switch',
            'title' => esc_html__('Menu Widget', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the widget on the right side of the header area.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-layout', '=', array('gamburg', 'gamburg_full', 'static', 'fixed')),
        ),

        array(
            'id' => 'header-widget-color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Header Widget Text Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a text color for Widget in the Header area.', 'LEVELUP'),
            'desc' => esc_html__('Default #333333', 'LEVELUP'),
            'default' => '#333333',
            'required' => array('header-style-menu-widget', '=', '1'),
        ),

        array(
            'id' => 'header-dividers-enable',
            'type' => 'switch',
            'title' => esc_html__('Widget Divider', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the separating line near Header Widget. Disabled by default.', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-style-menu-widget', '=', '1'),
        ),

        array(
            'id' => 'header-dividers-lines-color',
            'type' => 'color',
            'title' => esc_html__('Widget Divider Line Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Header Divider Line.', 'LEVELUP'),
            'desc' => esc_html__('Default #cccccc', 'LEVELUP'),
            'default' => '#cccccc',
            'transparent' => false,
            'required' => array('header-dividers-enable', '=', array('1')),
        ),

        array(
            'id' => 'menu-widget-position',
            'type' => 'button_set',
            'title' => esc_html__('Fullscreen Menu / Widget Position', 'LEVELUP'),
            'subtitle' => esc_html__('Select the widget position in fullscreen layout only.', 'LEVELUP'),
            'options' => array(
                'right' => esc_html__('Right', 'LEVELUP'),
                'bottom' => esc_html__('Bottom', 'LEVELUP'),
            ),
            'default' => 'right',
            'required' => array('header-style-menu-widget', '=', array('1')),
        ),

        array(
            'id' => 'section-header-area-settings-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-header-elements-start',
            'type' => 'section',
            'title' => esc_html__('Header Elements', 'LEVELUP'),
            'subtitle' => esc_html__('Header Elements Settings (search, hamburger icon).', 'LEVELUP'),
            'indent' => true,

        ),

        array(
            'id' => 'menu-buttons-style',
            'type' => 'button_set',
            'title' => esc_html__('Header Icons Style', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to choose dark or light version of Header Icons in the Header Area.', 'LEVELUP'),
            'options' => array(
                'dark' => esc_html__('Dark', 'LEVELUP'),
                'light' => esc_html__('Light', 'LEVELUP'),
            ),
            'default' => 'dark',
        ),

        array(
            'id' => 'header-hamburger-text-enable',
            'type' => 'image_select',
            'title' => esc_html__('Hamburger Icon Type', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the Hamburger Icon with the word MENU or without it.', 'LEVELUP'),
            'options' => array(
                '0' => array(
                    'alt' => '0',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/menu/humburger.png'
                ),
                '1' => array(
                    'alt' => '1',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/menu/humburger_with_title.png'
                ),
            ),
            'default' => '0',
            'required' => array('header-layout', '=', array('gamburg', 'gamburg_full')),
        ),

        array(
            'id' => 'header-icons-hover',
            'type' => 'button_set',
            'title' => esc_html__('Header Icons Hover Color', 'LEVELUP'),
            'subtitle' => esc_html__('Set the color for the Header Icons (Hamburger, Shopping Cart, Search).', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('None', 'LEVELUP'),
                '1' => esc_html__('Accent', 'LEVELUP'),
                '2' => esc_html__('Gray', 'LEVELUP'),
            ),
            'default' => ''
        ),

        array(
            'id' => 'header-search-enable',
            'type' => 'switch',
            'title' => esc_html__('Header Search Icon', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Search Icon in the Header Area. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'header-side_icons-bg-enable',
            'type' => 'switch',
            'title' => esc_html__('Enable Bottom Layer under the Header Icon?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the bottom layer under the Header Icon in Header Area. Disabled by default.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'header-side_icons-bg_color',
            'type' => 'color',
            'title' => esc_html__('Header Icon Background Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Header Icon Background.', 'LEVELUP'),
            'desc' => esc_html__('Default #cccccc', 'LEVELUP'),
            'default' => '#cccccc',
            'transparent' => false,
            'required' => array('header-side_icons-bg-enable', '=', '1'),
        ),

	    array(
		    'id' => 'header-side_icons-rounded',
		    'type' => 'slider',
		    'title' => esc_html__('Header Icon Background Rounded', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting in order to round the corners in bottom layer.', 'LEVELUP'),
		    "default" => 0,
		    "min" => 0,
		    "step" => 1,
		    "max" => 30,
		    'display_value' => 'text',
		    'required' => array('header-side_icons-bg-enable', '=', '1'),
	    ),

        array(
            'id' => 'header-side_icons-opacity',
            'type' => 'slider',
            'title' => esc_html__('Header Icon Background Opacity', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the measure of transparency of Header Icon Background.', 'LEVELUP'),
            "default" => 100,
            "min" => 0,
            "step" => 1,
            "max" => 100,
            'display_value' => 'text',
            'required' => array('header-side_icons-bg-enable', '=', '1'),
        ),

        array(
            'id' => 'section-header-elements-end',
            'type' => 'section',
            'indent' => false,
        ),

	    array(
		    'id' => 'section-header-CTAB-start',
		    'type' => 'section',
		    'title' => esc_html__('Call to Action Button', 'LEVELUP'),
		    'indent' => true,
		    'required' => array('header-layout', '=', array('fixed', 'static',)),
	    ),

	    array(
		    'id' => 'header-cta-position',
		    'type' => 'button_set',
		    'title' => esc_html__('Button Position', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this option to define the position for call-to-action button.', 'LEVELUP'),
		    'default' => '',
		    'required' => array('header-layout', '=', array('fixed', 'static',)),
		    'options' => array(
			    '' => esc_html__('Disable', 'LEVELUP'),
			    'menu_right' => esc_html__('Menu Inline - Right', 'LEVELUP'),
			    'right' => esc_html__('Right Side', 'LEVELUP'),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-1-type',
		    'type' => 'image_select',
		    'title' => esc_html__('Button Type', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the call-to-action button type.', 'LEVELUP'),
		    'default' => 'flat',
		    'required' => array('header-cta-position', '!=', ''),
		    'options' => array(
			    'flat' => array(
				    'title' => esc_html__('Flat', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_flat_rd.png'
			    ),
			    'outline' => array(
				    'title' => esc_html__('Outline', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_outln_rd.png'
			    ),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-1-size',
		    'type' => 'button_set',
		    'title' => esc_html__('Button Size', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the call-to-action button size.', 'LEVELUP'),
		    'default' => 'medium',
		    'required' => array('header-cta-position', '!=', ''),
		    'options' => array(
			    'small' => esc_html__('Small', 'LEVELUP'),
			    'medium' => esc_html__('Medium', 'LEVELUP'),
			    'big' => esc_html__('Big', 'LEVELUP'),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-1-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color for the call-to-action button.', 'LEVELUP'),
		    'default' => '#000000',
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-1-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose text color for the call-to-action button.', 'LEVELUP'),
		    'default' => '#ffffff',
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-1-action-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Hover Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color on hover for the call-to-action button.', 'LEVELUP'),
		    'default' => '#dddddd',
		    'required' => array('header-cta-1-type', '=', 'flat'),
	    ),

	    array(
		    'id' => 'header-cta-1-action-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Hover Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose text color on hover for the call-to-action button.', 'LEVELUP'),
		    'default' => '#ffffff',
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-1-border',
		    'type' => 'slider',
		    'title' => esc_html__('Button Border Thickness', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to specify the call-to-action button border thickness.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
		    "default"   => 2,
		    "min"       => 1,
		    "step"      => 1,
		    "max"       => 8,
		    'required' => array('header-cta-1-type', '=', 'outline'),
	    ),

	    array(
		    'id' => 'header-cta-1-border_radius',
		    'type' => 'slider',
		    'title' => esc_html__('Button Border Radius', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to specify the call-to-action button border radius.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
		    "default"   => 0,
		    "min"       => 0,
		    "step"      => 1,
		    "max"       => 30,
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-1-text',
		    'type' => 'text',
		    'required' => array('header-cta-position', '!=', ''),
		    'title' => esc_html__('Call to Action Text', 'LEVELUP'),
		    'subtitle' => esc_html__('Text on the call-to-action button.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-1-url',
		    'type' => 'text',
		    'required' => array('header-cta-position', '!=', ''),
		    'title' => esc_html__('Button URL (Link)', 'LEVELUP'),
		    'subtitle' => esc_html__('Call-to-action button Link.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-1-padding',
		    'type' => 'text',
		    'required' => array('header-cta-position', '!=', ''),
		    'title' => esc_html__('Custom Padding Left/Right', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to set the call-to-action button width in pixels.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-1-appear',
		    'type' => 'text',
		    'title' => esc_html__('Activate Action Button After (N-px)', 'LEVELUP'),
		    'subtitle' => esc_html__('Indicate the value in pixels and after that the call-to-action button will turn into active color.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 350', 'LEVELUP'),
		    'validate' => 'numeric',
		    'default' => '',
		    'required' => array('header-cta-position', '!=', ''),
        ),

	    array(
		    'id' => 'header-cta-1-mobile',
		    'type' => 'switch',
		    'title' => esc_html__('Display CTA Button on Mobile Menu?', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to display the Call-to-Action Button on mobile devices.', 'LEVELUP'),
		    'default' => '1',
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-mobile-position',
		    'type' => 'button_set',
		    'title' => esc_html__('CTA Button Position on Mobile Menu', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to set position the call-to-action button.', 'LEVELUP'),
		    'default' => 'top',
		    'required' => array('header-cta-1-mobile', '=', '1'),
		    'options' => array(
				    'top' => esc_html__('Above Menu Items', 'LEVELUP'),
				    'bottom' => esc_html__('Under Menu Items', 'LEVELUP'),
		    ),
	    ),


	    array(
		    'id' => 'section-header-CTAB-end',
		    'type' => 'section',
		    'indent' => false,
	    ),

	    array(
		    'id' => 'section-header-SCTAB-start',
		    'type' => 'section',
		    'title' => esc_html__('Second Call to Action Button', 'LEVELUP'),
		    'indent' => true,
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-2-enable',
		    'type' => 'switch',
		    'title' => esc_html__('Enable Button', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable the second call-to-action button.', 'LEVELUP'),
		    'default' => '0',
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-2-type',
		    'type' => 'image_select',
		    'title' => esc_html__('Button Type', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the call-to-action button type.', 'LEVELUP'),
		    'default' => 'flat',
		    'required' => array('header-cta-2-enable', '=', '1'),
		    'options' => array(
			    'flat' => array(
				    'title' => esc_html__('Flat', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_flat_rd.png'
			    ),
			    'outline' => array(
				    'title' => esc_html__('Outline', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_outln_rd.png'
			    ),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-2-size',
		    'type' => 'button_set',
		    'title' => esc_html__('Button Size', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the call-to-action button size.', 'LEVELUP'),
		    'default' => 'medium',
		    'required' => array('header-cta-2-enable', '=', '1'),
		    'options' => array(
			    'small' => esc_html__('Small', 'LEVELUP'),
			    'medium' => esc_html__('Medium', 'LEVELUP'),
			    'big' => esc_html__('Big', 'LEVELUP'),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-2-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color for the call-to-action button.', 'LEVELUP'),
		    'default' => '#000000',
		    'required' => array('header-cta-2-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-2-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose text color for the call-to-action button.', 'LEVELUP'),
		    'default' => '#ffffff',
		    'required' => array('header-cta-2-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-2-action-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Hover Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color on hover for the call-to-action button.', 'LEVELUP'),
		    'default' => '#dddddd',
		    'required' => array('header-cta-2-type', '=', 'flat'),
	    ),

	    array(
		    'id' => 'header-cta-2-action-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Hover Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose text color on hover for the call-to-action button.', 'LEVELUP'),
		    'default' => '#ffffff',
		    'required' => array('header-cta-2-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-2-border',
		    'type' => 'slider',
		    'title' => esc_html__('Button Border Thickness', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to specify the call-to-action button border thickness.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
		    "default"   => 2,
		    "min"       => 1,
		    "step"      => 1,
		    "max"       => 8,
		    'required' => array('header-cta-2-enable', '=', 'outline'),
	    ),

	    array(
		    'id' => 'header-cta-2-border_radius',
		    'type' => 'slider',
		    'title' => esc_html__('Button Border Radius', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to specify the call-to-action button border radius.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
		    "default"   => 0,
		    "min"       => 0,
		    "step"      => 1,
		    "max"       => 30,
		    'required' => array('header-cta-2-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-2-text',
		    'type' => 'text',
		    'required' => array('header-cta-2-enable', '=', '1'),
		    'title' => esc_html__('Call to Action Text', 'LEVELUP'),
		    'subtitle' => esc_html__('Text on the call-to-action button.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-2-url',
		    'type' => 'text',
		    'required' => array('header-cta-2-enable', '=', '1'),
		    'title' => esc_html__('Button URL (Link)', 'LEVELUP'),
		    'subtitle' => esc_html__('Call-to-action button Link.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-2-padding',
		    'type' => 'text',
		    'required' => array('header-cta-2-enable', '=', '1'),
		    'title' => esc_html__('Custom Padding Left/Right', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to set the call-to-action button width in pixels.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-2-appear',
		    'type' => 'text',
		    'title' => esc_html__('Activate Action Button After (N-px)', 'LEVELUP'),
		    'subtitle' => esc_html__('Indicate the value in pixels and after that the call-to-action button will turn into active color.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 350', 'LEVELUP'),
		    'validate' => 'numeric',
		    'default' => '',
		    'required' => array('header-cta-2-enable', '=', '1'),
	    ),


	    array(
		    'id' => 'header-cta-2-mobile',
		    'type' => 'switch',
		    'title' => esc_html__('Display CTA Button on Mobile Menu?', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to display the Call-to-Action Button on mobile devices.', 'LEVELUP'),
		    'default' => '1',
		    'required' => array('header-cta-2-enable', '=', '1'),
	    ),

	    array(
			    'id' => 'section-header-SCTAB-end',
			    'type' => 'section',
			    'indent' => false,
	    ),

	    array(
		    'id' => 'section-header-TCTAB-start',
		    'type' => 'section',
		    'title' => esc_html__('Third Call to Action Button', 'LEVELUP'),
		    'indent' => true,
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-3-enable',
		    'type' => 'switch',
		    'title' => esc_html__('Enable Button', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable the third call-to-action button.', 'LEVELUP'),
		    'default' => '0',
		    'required' => array('header-cta-position', '!=', ''),
	    ),

	    array(
		    'id' => 'header-cta-3-type',
		    'type' => 'image_select',
		    'title' => esc_html__('Button Type', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the call-to-action button type.', 'LEVELUP'),
		    'default' => 'flat',
		    'required' => array('header-cta-3-enable', '=', '1'),
		    'options' => array(
			    'flat' => array(
				    'title' => esc_html__('Flat', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_flat_rd.png'
			    ),
			    'outline' => array(
				    'title' => esc_html__('Outline', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_outln_rd.png'
			    ),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-3-size',
		    'type' => 'button_set',
		    'title' => esc_html__('Button Size', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the call-to-action button size.', 'LEVELUP'),
		    'default' => 'medium',
		    'required' => array('header-cta-3-enable', '=', '1'),
		    'options' => array(
			    'small' => esc_html__('Small', 'LEVELUP'),
			    'medium' => esc_html__('Medium', 'LEVELUP'),
			    'big' => esc_html__('Big', 'LEVELUP'),
		    ),
	    ),

	    array(
		    'id' => 'header-cta-3-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color for the call-to-action button.', 'LEVELUP'),
		    'default' => '#000000',
		    'required' => array('header-cta-3-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-3-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose text color for the call-to-action button.', 'LEVELUP'),
		    'default' => '#ffffff',
		    'required' => array('header-cta-3-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-3-action-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Hover Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color on hover for the call-to-action button.', 'LEVELUP'),
		    'default' => '#dddddd',
		    'required' => array('header-cta-3-type', '=', 'flat'),
	    ),

	    array(
		    'id' => 'header-cta-3-action-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Button Hover Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose text color on hover for the call-to-action button.', 'LEVELUP'),
		    'default' => '#ffffff',
		    'required' => array('header-cta-3-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-3-border',
		    'type' => 'slider',
		    'title' => esc_html__('Button Border Thickness', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to specify the call-to-action button border thickness.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
		    "default"   => 2,
		    "min"       => 1,
		    "step"      => 1,
		    "max"       => 8,
		    'required' => array('header-cta-3-enable', '=', 'outline'),
	    ),

	    array(
		    'id' => 'header-cta-3-border_radius',
		    'type' => 'slider',
		    'title' => esc_html__('Button Border Radius', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to specify the call-to-action button border radius.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
		    "default"   => 0,
		    "min"       => 0,
		    "step"      => 1,
		    "max"       => 30,
		    'required' => array('header-cta-3-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'header-cta-3-text',
		    'type' => 'text',
		    'required' => array('header-cta-3-enable', '=', '1'),
		    'title' => esc_html__('Call to Action Text', 'LEVELUP'),
		    'subtitle' => esc_html__('Text on the call-to-action button.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-3-url',
		    'type' => 'text',
		    'required' => array('header-cta-3-enable', '=', '1'),
		    'title' => esc_html__('Button URL (Link)', 'LEVELUP'),
		    'subtitle' => esc_html__('Call-to-action button Link.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-3-padding',
		    'type' => 'text',
		    'required' => array('header-cta-3-enable', '=', '1'),
		    'title' => esc_html__('Custom Padding Left/Right', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to set the call-to-action button width in pixels.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
		    'id' => 'header-cta-3-appear',
		    'type' => 'text',
		    'title' => esc_html__('Activate Action Button After (N-px)', 'LEVELUP'),
		    'subtitle' => esc_html__('Indicate the value in pixels and after that the call-to-action button will turn into active color.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 350', 'LEVELUP'),
		    'validate' => 'numeric',
		    'default' => '',
		    'required' => array('header-cta-3-enable', '=', '1'),
	    ),

		    array(
				    'id' => 'header-cta-3-mobile',
				    'type' => 'switch',
				    'title' => esc_html__('Display CTA Button on Mobile Menu?', 'LEVELUP'),
				    'subtitle' => esc_html__('Use this setting to display the Call-to-Action Button on mobile devices.', 'LEVELUP'),
				    'default' => '1',
				    'required' => array('header-cta-3-enable', '=', '1'),
		    ),

	    array(
		    'id' => 'section-header-TCTAB-end',
		    'type' => 'section',
		    'indent' => false,
	    ),

        array(
            'id' => 'section-socila-network-start',
            'type' => 'section',
            'title' => esc_html__('Header Social Networks', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        /*array(
            'id' => 'header-social-show',
            'type' => 'switch',
            'title' => esc_html__('Header Widget / Social Icons', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Header Widget Social Icons. Disabled by default.', 'LEVELUP'),
            'default' => '0',
        ),*/

        array(
            'id' => 'header-social-position',
            'type' => 'button_set',
            'title' => esc_html__('Social Icons Position', 'LEVELUP'),
            'subtitle' => esc_html__('Use this option to define the position for social icons.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'inline' => esc_html__('Menu - inline', 'LEVELUP'),
                'right' => esc_html__('Menu - Right Side', 'LEVELUP'),
                'widget' => esc_html__('Widget', 'LEVELUP'),
            ),
            'default' => '',
        ),

        array(
            'id' => 'header-social-height',
            'type' => 'slider',
            'title' => esc_html__('Social Icons Height', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the Social Icons Height.', 'LEVELUP'),
            'required' => array('header-social-position', '!=', ''),
            'default' => '18',
            'min' => '10',
            'step' => '1',
            'max' => '100',
        ),

        array(
            'id' => 'header-social-padding',
            'type' => 'slider',
            'title' => esc_html__('Social Icons Spacing', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the Social Icons Spacing.', 'LEVELUP'),
            'required' => array('header-social-position', '!=', ''),
            'default' => '20',
            'min' => '10',
            'step' => '1',
            'max' => '100',
        ),

        array(
            'id' => 'header-social-color',
            'type' => 'color',
            'title' => esc_html__('Header Social Icons Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Header Social Icons.', 'LEVELUP'),
            'default' => '#cccccc',
            'transparent' => false,
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-facebook',
            'type' => 'checkbox',
            'title' => esc_html__('Facebook', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-twitter',
            'type' => 'checkbox',
            'title' => esc_html__('Twitter', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-google-plus',
            'type' => 'checkbox',
            'title' => esc_html__('Google+', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-vimeo',
            'type' => 'checkbox',
            'title' => esc_html__('Vimeo', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-pinterest',
            'type' => 'checkbox',
            'title' => esc_html__('Pinterest', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-youtube',
            'type' => 'checkbox',
            'title' => esc_html__('Youtube', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-tumblr',
            'type' => 'checkbox',
            'title' => esc_html__('Tumblr', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-linkedin',
            'type' => 'checkbox',
            'title' => esc_html__('LinkedIn', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-rss',
            'type' => 'checkbox',
            'title' => esc_html__('RSS', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-behance',
            'type' => 'checkbox',
            'title' => esc_html__('Behance', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-instagram',
            'type' => 'checkbox',
            'title' => esc_html__('Instagram', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-github',
            'type' => 'checkbox',
            'title' => esc_html__('GitHub', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-soundcloud',
            'type' => 'checkbox',
            'title' => esc_html__('SoundCloud', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-xing',
            'type' => 'checkbox',
            'title' => esc_html__('Xing', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-vk',
            'type' => 'checkbox',
            'title' => esc_html__('VK', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-wechat',
            'type' => 'checkbox',
            'title' => esc_html__('WeChat', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-snapchat',
            'type' => 'checkbox',
            'title' => esc_html__('Snapchat', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'header-social-flickr',
            'type' => 'checkbox',
            'title' => esc_html__('Flickr', 'LEVELUP'),
            'default' => '0',
            'required' => array('header-social-position', '!=', ''),
        ),

        array(
            'id' => 'section-socila-network-end',
            'type' => 'section',
            'indent' => false,
        ),

    )
));

LevelupRedux::setSection( $opt_name, array(
    'id'    => 'header_menu',
    'icon'  => 'menu',
    'icon_class' => 'rdy-icon',
    'title'     => esc_html__('Menus', 'LEVELUP'),
    'fields'    => array(

        array(
            'id' => 'menu_font',
            'type' => 'typography',
            'title' => esc_html__('Main Menu Items', 'LEVELUP'),
			'subtitle' => esc_html__('Set up the font and size of menu items. ', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '14px',
                'font-weight' => '700',
            ),
        ),
		
        array(
            'id' => 'header-menu-color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Main Menu Items Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Main Menu Items.', 'LEVELUP'),
			'desc' => '',
            'default' => '#333333',
        ),

        array(
            'id'       => 'menu-hover',
            'type'     => 'button_set',
            'title'    => esc_html__('Main Menu Items Color on Hover', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Default', 'LEVELUP'),
                1 => esc_html__('Accent', 'LEVELUP'),
                2 => esc_html__('Custom', 'LEVELUP'),
                3 => esc_html__('None', 'LEVELUP'),
            ),
            'subtitle' => esc_html__('Choose the hover color for Main Menu, Drop-down and MegaMenu Items.', 'LEVELUP'),
            'default' => ''
        ),

        array(
            'id' => 'header-menu-hover-color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Custom Color on Hover', 'LEVELUP'),
            'default' => '#333333',
            'subtitle' => esc_html__('Choose the custom  hover color for Main Menu, Drop-down and MegaMenu Items.', 'LEVELUP'),
            'required'  => array('menu-hover', '=', '2'),
        ),

        array(
            'id' => 'menu-hover-underline',
            'type' => 'switch',
            'title' => esc_html__('Enable Underline on Hover?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Underline on Hover at Main Menu Items.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'header-active-item-enable',
            'type' => 'switch',
            'title' => esc_html__('Active Main Menu Item Highlight?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the highlight of menu items (Menu Hover Items Color).  The menu item will be highlighted on the page you are located at.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'header-menu-padding',
            'type' => 'slider',
            'title' => esc_html__('Main Menu Items Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set up the distance between the Main Menu Items.', 'LEVELUP'),
            "default" => 10,
            "min" => 5,
            "step" => 1,
            "max" => 100,
            'display_value' => 'label',
            'required'  => array('header-layout', '!=', 'gamburg_full'),
        ),

        array(
            'id' => 'menu-angle-down-enable',
            'type' => 'switch',
            'title' => esc_html__('Enable Dropdown Arrows (next level) on Main Menu?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Arrows at Drop-Down Main Menu.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'header-menu-title-items-margin-bottom',
            'type' => 'slider',
            'title' => esc_html__('Spacing between Heading and Menu Items', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the distance between the heading and menu items. This setting is applicable to column view type of menus,  as well as for the Drop-Down menu and Mega menu.', 'LEVELUP'),
            "default" => 0,
            "min" => 0,
            "step" => 1,
            "max" => 100,
            'display_value' => 'text',
            'required' => array('header-layout', '!=', 'gamburg_full'),
        ),

        array(
            'id' => 'header-menu-icon-padding',
            'type' => 'slider',
            'title' => esc_html__('Distance between Icons and Menu Items', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to adjust the distance between the icon and the menu item. This option works if you select the icon for the menu item. The setting is applicable to Main Menu and Drop-Down menu.', 'LEVELUP'),
            "default" => 6,
            "min" => 1,
            "step" => 1,
            "max" => 30,
            'display_value' => 'label',
        ),

	    array(
		    'id' => 'section-one-page-start',
		    'type' => 'section',
		    'title' => esc_html__('One Page Navigation', 'LEVELUP'),
		    'subtitle' => esc_html__('Smooth page scroll to an anchors.', 'LEVELUP'),
		    'indent' => true,
	    ),

	    array(
		    'id' => 'menu-animated-anchors',
		    'type' => 'switch',
		    'title' => esc_html__('One Page Scroll Support', 'LEVELUP'),
		    'subtitle' => esc_html__('One page scroll support (animated active menu items) you should be able to smooth scroll to any target (Section ID) on the page.', 'LEVELUP'),
		    'default' => '1'
	    ),

	    array(
			    'id' => 'section-one-page-end',
			    'type' => 'section',
			    'indent' => false,
	    ),

        array(
            'id' => 'section-menu-positions-settings-start',
            'type' => 'section',
            'title' => esc_html__('Menu Items Position', 'LEVELUP'),
            'subtitle' => esc_html__('Settings of Main Menu items position', 'LEVELUP'),
            'indent' => true,
        ),

        array(
            'id' => 'header-menu-padding-top',
            'type' => 'text',
            'title' => esc_html__('Main Menu Top Padding', 'LEVELUP'),
            'subtitle' => esc_html__('If necessary, you can specify custom padding for top Main Menu.', 'LEVELUP'),
            'desc' => '',
            'validate' => 'numeric',
            'default' => '0',
            'desc' => esc_html__('Enter a value in pixels. E.g. 25', 'LEVELUP'),
        ),

        array(
            'id' => 'header-menu-padding-left',
            'type' => 'text',
            'title' => esc_html__('Main Menu Left Padding', 'LEVELUP'),
            'subtitle' => esc_html__('If necessary, you can specify custom padding on the left of the Main Menu.', 'LEVELUP'),
            'desc' => '',
            'validate' => 'numeric',
            'default' => '0',
            'desc' => esc_html__('Enter a value in pixels. E.g. 25', 'LEVELUP'),
        ),

        array(
            'id' => 'header-menu-padding-right',
            'type' => 'text',
            'title' => esc_html__('Main Menu Right Padding', 'LEVELUP'),
            'subtitle' => esc_html__('If necessary, you can specify custom padding on the right of the Main Menu.', 'LEVELUP'),
            'desc' => '',
            'validate' => 'numeric',
            'default' => '0',
            'desc' => esc_html__('Enter a value in pixels. E.g. 25', 'LEVELUP'),
        ),

        array(
            'id' => 'section-menu-positions-settings-end',
            'type' => 'section',
            'indent' => false,
        ),
		
		array(
            'id'       => 'section-dropdawn-menu-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Drop-Down Menu', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),
		
		array(
            'id' => 'menu_font_dropdown',
            'type' => 'typography',
            'title' => esc_html__('Drop-Down Menu Items', 'LEVELUP'),
			'subtitle' => esc_html__('Set the font and size of the Drop-Down Menu Items.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '14px',
                'line-height' => '20px',
                'font-weight' => '400',
            ),
        ),


		
		array(
            'id' => 'header-menu-drop-color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Drop-Down Menu Items Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Drop-Down Menu Items.', 'LEVELUP'),
			'desc' => '',
            'default' => '#e5e5e5',
        ),

        array(
            'id' => 'header-menu-drop-hover',
            'type' => 'button_set',
            'title' => esc_html__('Drop-Down Menu Items Color on Hover', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Drop-Down Menu Items on hover.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Inherit Main Menu Settings', 'LEVELUP'),
                'custom' => esc_html__('Custom', 'LEVELUP'),
            ),
            'default' => 'custom',
        ),

        array(
            'id' => 'header-menu-drop-hover-color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Custom Hover Color', 'LEVELUP'),
            'desc' => '',
            'subtitle' => esc_html__('Choose a color.', 'LEVELUP'),
            'default' => '#e5e5e5',
            'required'  => array('header-menu-drop-hover', '=', 'custom'),
        ),

        array(
            'id' => 'menu-drop-hover-underline',
            'type' => 'switch',
            'title' => esc_html__('Enable Underline on Hover?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Underline on Hover at the Drop-Down Menu Items.', 'LEVELUP'),
            'default' => '0'
        ),
		
		array(
            'id' => 'header-menu-dropdown-bgcolor',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Drop-Down Menu Background Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for the Drop-Down menu background.', 'LEVELUP'),
			'desc' => '',
            'default' => '#333333',
        ),

		array(
            'id' => 'menu-dropdown-hover',
            'type' => 'switch',
            'title' => esc_html__('Highlight the current Drop-Down Menu Item?', 'LEVELUP'),
			'subtitle' => esc_html__('Use this setting to enable / disable the highlighting of Drop-Down Menu Items on Hover.', 'LEVELUP'),
            'default' => '1'
        ),
		
        array(
            'id' => 'header-menu-dropdown-hover-bgcolor',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Highlight Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Highlight the Drop-Down Menu Item on Hover.', 'LEVELUP'),
            'default' => '#444444',
            'required'  => array('menu-dropdown-hover', '=', '1'),
        ),

        array(
            'id' => 'menu-dropdown-separator',
            'type' => 'switch',
            'title' => esc_html__('Drop-Down Menu Items Horizontal Separators', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable horizontal separators between items drop-down menu. Disabled by default.', 'LEVELUP'),
            'default'  => 0,
        ),

        array(
            'id' => 'menu-dropdown-separator-color',
            'type' => 'color',
            'title' => esc_html__('Horizontal Separators Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Horizontal Separators between items drop-down menu.', 'LEVELUP'),
            'transparent' => false,
            'default'  => '#000000',
            'required'  => array('menu-dropdown-separator', '=', '1'),
        ),

        array(
            'id' => 'header-menu-drop-line-color',
            'type' => 'color',
            'transparent' => false,
            'title' => esc_html__('Mega Menu and Drop-Down Divider Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the color of the vertical divider line in the mega menu and of the upper horizontal line above the drop-down menu.', 'LEVELUP'),
            'desc' => '',
            'default' => '#515151',
            'transparent' => true
        ),
		
		array(
            'id'     => 'section-dropdawn-menu-end',
            'type'   => 'section',
            'indent' => false,
        ),
	)
));

LevelupRedux::setSection( $opt_name, array(
    'id' => 'typography',
    'icon'  => 'typography',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Typography ', 'LEVELUP'),
    'fields'    => array(

        array(
            'id' => 'body_font',
            'type' => 'typography',
            'title' => esc_html__('Body', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for body text.', 'LEVELUP'),
            'google'   => true,
	        'custom_fonts' => true,
            'text-align'   => false,
            'line-height'  => false,
            'letter-spacing'  => false,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '400',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '14px',
            ),
        ),

        array(
            'id'        => 'paragraph-line_height',
            'type'      => 'slider',
            'title'     => esc_html__('Paragraph Line Height (%)', 'LEVELUP'),
            'subtitle' => esc_html__('The line-height property specifies the line height. Default 180%', 'LEVELUP'),
            "default"   => 180,
            "min"       => 90,
            "step"      => 1,
            "max"       => 200,
        ),

        array(
            'id'        => 'paragraph-margin_bottom',
            'type'      => 'slider',
            'title'     => esc_html__('Paragraph Bottom Margin (px)', 'LEVELUP'),
            'subtitle' => esc_html__('Changes margin-bottom between paragraphs of content. Default 30', 'LEVELUP'),
            "default"   => 30,
            "min"       => 0,
            "step"      => 1,
            "max"       => 100,
        ),

        array(
            'id' => 'h1_font',
            'type' => 'typography',
            'title' => esc_html__('Heading 1', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for H1 heading.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '600',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '35px',
                'line-height'  => '40px',
            ),
        ),

        array(
            'id' => 'h1_font_margin',
            'type' => 'text',
            'title' => esc_html__('Heading 1 Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'default' => '0',
            'validate' => 'numeric',
        ),

        array(
            'id' => 'h2_font',
            'type' => 'typography',
            'title' => esc_html__('Heading 2', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for H2 heading', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '600',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '28px',
                'line-height'  => '40px',
            ),
        ),

        array(
            'id' => 'h2_font_margin',
            'type' => 'text',
            'title' => esc_html__('Heading 2 Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'default' => '0',
            'validate' => 'numeric',
        ),

        array(
            'id' => 'h3_font',
            'type' => 'typography',
            'title' => esc_html__('Heading 3', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for H3 heading', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '600',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '24px',
                'line-height'  => '35px',
            ),
        ),

        array(
            'id' => 'h3_font_margin',
            'type' => 'text',
            'title' => esc_html__('Heading 3 Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'default' => '0',
            'validate' => 'numeric',
        ),

        array(
            'id' => 'h4_font',
            'type' => 'typography',
            'title' => esc_html__('Heading 4', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for H4 heading', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'font-weight' => '600',
                'google'      => true,
                'font-size'   => '20px',
                'line-height'  => '30px',
            ),
        ),

        array(
            'id' => 'h4_font_margin',
            'type' => 'text',
            'title' => esc_html__('Heading 4 Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'default' => '0',
            'validate' => 'numeric',
        ),

        array(
            'id' => 'h5_font',
            'type' => 'typography',
            'title' => esc_html__('Heading 5', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for H5 heading', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'font-weight' => '600',
                'google'      => true,
                'font-size'   => '18px',
                'line-height'  => '30px',
            ),
        ),
        array(
            'id' => 'h5_font_margin',
            'type' => 'text',
            'title' => esc_html__('Heading 5 Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'default' => '0',
            'validate' => 'numeric',
        ),

        array(
            'id' => 'h6_font',
            'type' => 'typography',
            'title' => esc_html__('Heading 6', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for H6 heading', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'font-weight' => '600',
                'google'      => true,
                'font-size'   => '15px',
                'line-height'  => '25px',
            ),
        ),

        array(
            'id' => 'h6_font_margin',
            'type' => 'text',
            'title' => esc_html__('Heading 6 Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
            'default' => '0',
            'validate' => 'numeric',
        ),

        array(
            'id'       => 'section-typography-blockquote-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Blockquote', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'blockquote_font',
            'type' => 'typography',
            'title' => esc_html__('Blockquote', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for blockquote text.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => false,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '300',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '25px',
                'line-height'  => '35px',
            ),
        ),

        array(
            'id' => 'blockquote-color',
            'type' => 'color',
            'title' => esc_html__('Blockquote Line Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Blockquote Line Color. By default used Accent Color.', 'LEVELUP'),
            'default' => '#cccccc',
            'transparent' => true
        ),

        array(
            'id'     => 'section-typography-blockquote-end',
            'type'   => 'section',
            'indent' => false,
        ),

        array(
            'id'       => 'section-widgets-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Widgets', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'menu_widget_title_font',
            'type' => 'typography',
            'title' => esc_html__('Widget Title on a Menu', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Widget Title on the Main Menu or FullScreen Menu.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => false,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '400',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '15px',
            ),
        ),

        array(
            'id' => 'menu_widget_text_font',
            'type' => 'typography',
            'title' => esc_html__('Widget Content on a Menu', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Widget Content on the Main Menu or FullScreen Menu.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => false,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-style'  => '400',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '15px',
            ),
        ),

        array(
            'id'     => 'section-widgets-end',
            'type'   => 'section',
            'indent' => false,
        ),

        array(
            'id'       => 'section-typography-shortcodes-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Typography Shortcodes', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'accordion_title_font',
            'type' => 'typography',
            'title' => esc_html__('Accordion Title', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Accordion Title.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => false,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '30px',
                'font-weight' => '400',
            ),
        ),

        array(
            'id' => 'tabs_title_font',
            'type' => 'typography',
            'title' => esc_html__('Tabs Title', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Tabs Title.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => false,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '16px',
                'font-weight' => '700',
            ),
        ),

        array(
            'id'     => 'section-typography-shortcodes-end',
            'type'   => 'section',
            'indent' => false,
        ),

        array(
            'id'       => 'section-dropcaps-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Dropcaps', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'dropcaps_font',
            'type' => 'typography',
            'title' => esc_html__('Dropcaps', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Dropcaps.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '30px',
                'font-weight' => '400',
            ),
        ),

        array(
            'id'             => 'dropcaps_margin',
            'type'           => 'spacing',
            'output'         => array('.wpb_text_column .dropcap'),
            'mode'           => 'padding',
            'units'          => array('em', 'px'),
            'units_extended' => 'false',
            'title'          => esc_html__('Dropcaps Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Set a position for Dropcaps.', 'LEVELUP'),
            'default'            => array(
                'padding-top'     => '0px',
                'padding-right'   => '0px',
                'padding-bottom'  => '0px',
                'padding-left'    => '0px',
                'units'          => 'px',
            )
        ),

        array(
            'id' => 'dropcaps2_font',
            'type' => 'typography',
            'title' => esc_html__('Dropcaps "Shadow"', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Dropcaps "Shadow".', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => false,
            'color'        => true,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '30px',
                'color'   => '#000000',
                'font-weight' => '400',
            ),
        ),

        array(
            'id' => 'dropcaps2_left',
            'type' => 'text',
            'title' => esc_html__('Dropcaps "Shadow" Left (px)', 'LEVELUP'),
            'subtitle' => esc_html__('Set the left padding for a Dropcaps Shadow.', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '0',
        ),

        array(
            'id' => 'dropcaps2_top',
            'type' => 'text',
            'title' => esc_html__('Dropcaps "Shadow" Top (px)', 'LEVELUP'),
            'subtitle' => esc_html__('Set the top padding for a Dropcaps Shadow.', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '0',
        ),

        array(
            'id'     => 'section-dropcaps-end',
            'type'   => 'section',
            'indent' => false,
        ),

    )
));

LevelupRedux::setSection( $opt_name, array(
    'id' => 'typography_custom',
    'icon'  => 'typography',
    'icon_class' => 'rdy-icon',
	'subsection' => true,
    'title' => esc_html__('Custom Fonts ', 'LEVELUP'),
    'fields'    => array(

	    array(
		    'title'       => esc_html__( 'Custom Fonts', 'LEVELUP' ),
		    'subtitle' => wp_kses( __( 'Using this setting you may add custom font for using on the site. All formats of the font are not required, but are recommended for full support of the browser. <br><br><b>It is important! Refresh the page after adding new Fonts. Only after page refreshing all new fonts will appear in drop-down settings of Typography.</b> <br><br> In order to add several custom font press the <b>button "Add"</b>.<br><br> <b>Additional parameters 100 - 800</b> are defined from thin to thick characters. 400 is the same as normal, and 700 is the same as bold. This values will be displayed in Font Weight & Style dropdown.', 'LEVELUP' ), array( 'b' => array(), 'br' => array(), ) ),
		    'id'          => 'custom_fonts',
		    'default'     => array(),
		    'group_values' => true,
		    'type'        => 'repeater',
		    'bind_title'  => 'name',
		    'fields'      => array(
			    'name' => array(
				    'title'       => esc_html__( 'Font Name (this will be used in the font-family dropdown)', 'LEVELUP' ),
				    'description' => '',
				    'id'          => 'name',
				    'default'     => '',
				    'type'        => 'text',
				    'class'		  => 'LEVELUP-custom-font-name',
			    ),
			    'woff' => array(
				    'title'       => 'WOFF',
				    'description' => esc_html__( 'Upload the .woff font file.', 'LEVELUP' ),
				    'id'          => 'woff',
				    'default'     => '',
				    'type'        => 'media',
				    'mode'        => false,
			    ),
			    'woff2' => array(
				    'title'       => 'WOFF2',
				    'description' => esc_html__( 'Upload the .woff2 font file.', 'LEVELUP' ),
				    'id'          => 'woff2',
				    'default'     => '',
				    'type'        => 'media',
				    'mode'        => false,
			    ),
			    'ttf' => array(
				    'title'       => 'TTF',
				    'description' => esc_html__( 'Upload the .ttf font file.', 'LEVELUP' ),
				    'id'          => 'ttf',
				    'default'     => '',
				    'type'        => 'media',
				    'mode'        => false,
			    ),
			    'svg' => array(
				    'title'       => 'SVG',
				    'description' => esc_html__( 'Upload the .svg font file.', 'LEVELUP' ),
				    'id'          => 'svg',
				    'default'     => '',
				    'type'        => 'media',
				    'mode'        => false,
			    ),
			    'eot' => array(
				    'title'       => 'EOT',
				    'description' => esc_html__( 'Upload the .eot font file.', 'LEVELUP' ),
				    'id'          => 'eot',
				    'default'     => '',
				    'type'        => 'media',
				    'mode'        => false,
			    ),


			    '100' => array(
				    'id' => '100',
				    'type' => 'checkbox',
				    'description' => esc_html__('100', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '200' => array(
				    'id' => '200',
				    'type' => 'checkbox',
				    'description' => esc_html__('200', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '300' => array(
				    'id' => '300',
				    'type' => 'checkbox',
				    'description' => esc_html__('300', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '400' => array(
				    'id' => '400',
				    'type' => 'checkbox',
				    'description' => esc_html__('400', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '500' => array(
				    'id' => '500',
				    'type' => 'checkbox',
				    'description' => esc_html__('500', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '600' => array(
				    'id' => '600',
				    'type' => 'checkbox',
				    'description' => esc_html__('600', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '700' => array(
				    'id' => '700',
				    'type' => 'checkbox',
				    'description' => esc_html__('700', 'LEVELUP'),
				    'default' => '0',
			    ),
			    '800' => array(
				    'id' => '800',
				    'type' => 'checkbox',
				    'description' => esc_html__('800', 'LEVELUP'),
				    'default' => '0',
			    ),
			    'italic' => array(
				    'id' => 'italic',
				    'type' => 'checkbox',
				    'description' => esc_html__('italic', 'LEVELUP'),
				    'default' => '0',
			    ),

		    ),
	    ),

    )
));

LevelupRedux::setSection( $opt_name, array(
    'id' => 'color',
    'icon'  => 'color',
    'icon_class' => 'rdy-icon',
    'title'         => esc_html__('Colors & Background', 'LEVELUP'),
    'fields'        => array(
        array(
            'id' => 'body-color',
            'type' => 'color',
            'title' => esc_html__('Body Text Color', 'LEVELUP'),
            'subtitle' => esc_html__('Body Texts Color of the site.', 'LEVELUP'),
            'default' => '#333333',
            'transparent' => false
        ),

        array(
            'id' => 'accent-color',
            'type' => 'color',
            'title' => esc_html__('Accent Color', 'LEVELUP'),
            'subtitle' => esc_html__('Define the accent color for your theme. Several elements (design elements, icons, titles, buttons, and so on) on the theme will automatically inherit the styling properties defined here.', 'LEVELUP'),
            'desc' => '',
            'default' => '#ff7200',
            'transparent' => false
        ),

        array(
            'id' => 'extra-color1',
            'type' => 'color',
            'title' => esc_html__('Extra Color 1', 'LEVELUP'),
            'subtitle' => esc_html__('Add color to the palette. The color will be available in the colorpicker. Important note! After you choose the color and save the settings, please refresh the page, for the changes were applied in the colorpicker.', 'LEVELUP'),
            'desc' => '',
            'default' => '#ff4c4c',
            'transparent' => false
        ),

        array(
            'id' => 'extra-color2',
            'type' => 'color',
            'title' => esc_html__('Extra Color 2', 'LEVELUP'),
            'subtitle' => esc_html__('Add color to the palette. The color will be available in the colorpicker. Important note! After you choose the color and save the settings, please refresh the page, for the changes were applied in the colorpicker.', 'LEVELUP'),
            'desc' => '',
            'default' => '#0099e5',
            'transparent' => false
        ),

        array(
            'id' => 'extra-color3',
            'type' => 'color',
            'title' => esc_html__('Extra Color 3', 'LEVELUP'),
            'subtitle' => esc_html__('Add color to the palette. The color will be available in the colorpicker. Important note! After you choose the color and save the settings, please refresh the page, for the changes were applied in the colorpicker.', 'LEVELUP'),
            'desc' => '',
            'default' => '#34bf49',
            'transparent' => false
        ),

        array(
            'id' => 'extra-color4',
            'type' => 'color',
            'title' => esc_html__('Extra Color 4', 'LEVELUP'),
            'subtitle' => esc_html__('Add color to the palette. The color will be available in the colorpicker. Important note! After you choose the color and save the settings, please refresh the page, for the changes were applied in the colorpicker.', 'LEVELUP'),
            'desc' => '',
            'default' => '#4d4f53',
            'transparent' => false
        ),

        array(
            'id' => 'extra-color5',
            'type' => 'color',
            'title' => esc_html__('Extra Color 5', 'LEVELUP'),
            'subtitle' => esc_html__('Add color to the palette. The color will be available in the colorpicker. Important note! After you choose the color and save the settings, please refresh the page, for the changes were applied in the colorpicker.', 'LEVELUP'),
            'desc' => '',
            'default' => '#00a0af',
            'transparent' => false
        ),

        array(
            'id' => 'extra-color6',
            'type' => 'color',
            'title' => esc_html__('Extra Color 6', 'LEVELUP'),
            'subtitle' => esc_html__('Add color to the palette. The color will be available in the colorpicker. Important note! After you choose the color and save the settings, please refresh the page, for the changes were applied in the colorpicker.', 'LEVELUP'),
            'desc' => '',
            'default' => '#f47721',
            'transparent' => false
        ),

        array(
            'id' => 'heading-color',
            'type' => 'color',
            'title' => esc_html__('Heading Color', 'LEVELUP'),
            'subtitle' => esc_html__('Headings Color (H1-H6) of the site. It is applied if color of the heading we do not specify separately.', 'LEVELUP'),
            'default' => '#222222',
            'transparent' => false
        ),

        array(
            'id' => 'selection-color',
            'type' => 'color',
            'title' => esc_html__('Text Selection Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color users see when selecting text.', 'LEVELUP'),
            'default' => '#ff7200',
            'transparent' => false
        ),

        array(
            'id' => 'lines-color',
            'type' => 'color',
            'title' => esc_html__('Lines Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for lines of the site.', 'LEVELUP'),
            'desc' => esc_html__('Default #cccccc', 'LEVELUP'),
            'default' => '#ccc',
            'transparent' => false
        ),

        array(
            'id' => 'links-color',
            'type' => 'color',
            'title' => esc_html__('Links', 'LEVELUP'),
            'subtitle' => esc_html__('Default a color for links of the site.', 'LEVELUP'),
            'desc' => '',
            'default' => '#333333',
            'transparent' => false
        ),

        array(
            'id' => 'links-color-hover',
            'type' => 'color',
            'title' => esc_html__('Links Color on Hover', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a hover color for links.', 'LEVELUP'),
            'desc' => '',
            'default' => '#ff7200',
            'transparent' => false
        ),

        array(
            'id'       => 'layout-background',
            'type'     => 'background',
            'title'    => esc_html__('Background Color & Background Image', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the page background (body) color and choose an image to be displayed in background.', 'LEVELUP'),
            'default'  => array(
                'background-color' => '#ffffff',
            )
        ),

    )
));

LevelupRedux::setSection( $opt_name, array(
    'id' => 'page_title',
    'icon'  => 'page_title',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Page Titles', 'LEVELUP'),
    'desc' => '',
    'fields' => array(

        array(
            'id'       => 'page-title-layout',
            'type'     => 'image_select',
            'title'    => esc_html__('Title Area Layout', 'LEVELUP'),
            'subtitle' => esc_html__('Please select your Title Page format here.', 'LEVELUP'),

            'options'  => array(
                'all_left'      => array(
                    'alt'   => esc_html__('Left', 'LEVELUP'),
                    'title' => esc_html__('Left-aligned', 'LEVELUP'),
                    'img'  => get_template_directory_uri().'/inc/admin/assets/images/title/l-l.png'
                ),
                'all_right'      => array(
                    'alt'   => esc_html__('Right', 'LEVELUP'),
                    'title' => esc_html__('Right-aligned', 'LEVELUP'),
                    'img'  => get_template_directory_uri().'/inc/admin/assets/images/title/r-r.png'
                ),
                'center'      => array(
                    'alt'   => esc_html__('Center', 'LEVELUP'),
                    'title' => esc_html__('Centered', 'LEVELUP'),
                    'img'  => get_template_directory_uri().'/inc/admin/assets/images/title/centre.png'
                ),
            ),
            'default' => 'center'
        ),

	    array(
		    'id' => 'page-title-fullwidth',
		    'type' => 'switch',
		    'title' => esc_html__('Page Title Full Width', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting if you want to expand the Page Title to full width of the page.', 'LEVELUP'),
		    'default' => '0',
	    ),

        array(
            'id'       => 'page-title-height',
            'type'     => 'text',
            'title'    => esc_html__('Title Area Height (px)', 'LEVELUP'),
            'subtitle' => esc_html__('Set a height for Title Area in pixels. Default 350.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 425', 'LEVELUP'),
            'validate' => 'numeric',
            'default'  => '350',
        ),

        array(
            'id'       => 'page-title-background-color',
            'type'     => 'color',
            'title'    => esc_html__('Background Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a background color for Title Area.', 'LEVELUP'),
            'default'  => '#f2f2f2',
        ),

        array(
            'id'       => 'page-title-background-image',
            'type'     => 'background',
            'title'    => esc_html__('Background Image', 'LEVELUP'),
            'subtitle' => esc_html__('Choose an image to be displayed as a background in the Title Area.', 'LEVELUP'),
            'background-color' => false,
            'default'  => array()
        ),

	    array(
		    'id'       => 'page-title-breadcrumbs',
		    'type'     => 'button_set',
		    'title'    => esc_html__( 'Breadcrumbs', 'LEVELUP' ),
		    'subtitle' => esc_html__( 'Use this setting in order to set way of displaying breadcrumbs.', 'LEVELUP' ),
		    'options'  => array(
			    ''       => esc_html__( 'Disable', 'LEVELUP' ),
			    'under' => esc_html__( 'Under the Page Title', 'LEVELUP' ),
			    'side'   => esc_html__( 'To Mirror into One Line', 'LEVELUP' ),
//				    'right' => esc_html__('Right', 'LEVELUP'),
			    'bottom' => esc_html__( 'Under Title Area', 'LEVELUP' ),
		    ),
		    'default'  => '',
	    ),

	    array(
		    'id'       => 'page-title-breadcrumbs-color-style',
		    'type'     => 'button_set',
		    'title'    => esc_html__( 'Breadcrumbs Color Style', 'LEVELUP' ),
		    'subtitle' => esc_html__( 'Use this setting you can set a breadcrumbs style.', 'LEVELUP' ),
		    'options'  => array(
			    ''      => esc_html__( 'Dark', 'LEVELUP' ),
			    'light' => esc_html__( 'Light', 'LEVELUP' ),
		    ),
		    'default'  => '',
		    'required' => array('page-title-breadcrumbs', '!=', ''),
	    ),

	    array(
		    'id'       => 'page-title-breadcrumbs-fontsize',
		    'type'     => 'slider',
		    'title'    => esc_html__('Breadcrumbs Font Size', 'LEVELUP'),
		    'subtitle' => esc_html__('Drag the slider to set the breadcrumbs font size.', 'LEVELUP'),
		    "default"   => 13,
		    "min"       => 9,
		    "step"      => 1,
		    "max"       => 20,
		    'required' => array('page-title-breadcrumbs', '!=', ''),
	    ),

	    array(
		    'id' => 'page-title-background-featured',
		    'type' => 'switch',
		    'title' => esc_html__('Featured Background Image', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable Featured Images as Background Image.', 'LEVELUP'),
		    'default' => '0',
	    ),

	    array(
		    'id'        => 'page-title-background-overlay-color',
		    'type'      => 'color_rgba',
		    'title'     => esc_html__( 'Featured Background Image Overlay Color', 'LEVELUP' ),
		    'subtitle' => esc_html__('Choose a overlay color for Featured Background Image.', 'LEVELUP'),
		    'default'   => array(
			    'color'     => '#000000',
			    'alpha'     => .5
		    ),
		    'options'       => array(
			    'show_input'                => true,
			    'show_initial'              => true,
			    'show_alpha'                => true,
			    'show_palette'              => true,
			    'show_palette_only'         => false,
			    'show_selection_palette'    => true,
			    'max_palette_size'          => 10,
			    'allow_empty'               => true,
			    'clickout_fires_change'     => false,
			    'choose_text'               => 'Choose',
			    'cancel_text'               => 'Cancel',
			    'show_buttons'              => true,
			    'use_extended_classes'      => true,
			    'palette'                   => null,  // show default
			    'input_text'                => 'Select Color'
		    ),
		    'required' => array('page-title-background-featured', '=', '1'),
	    ),

        array(
            'id' => 'page-title-bottom-line-enable',
            'type' => 'switch',
            'title' => esc_html__('Title Area Bottom Border?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Title Area Bottom Border.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id'       => 'page-title-bottom-line-color',
            'type'     => 'color',
            'title'    => esc_html__('Title Area Bottom Border Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a Bottom Border Color for Title Area.', 'LEVELUP'),
            'default'  => '#000000',
            'required' => array('page-title-bottom-line-enable', '=', '1'),
        ),

        array(
            'id' => 'page-title-bottom-line-height',
            'type' => 'slider',
            'title' => esc_html__('Title Area Bottom Border Thickness', 'LEVELUP'),
            'subtitle' => esc_html__('This option will set the Title Area bottom border thickness.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 5', 'LEVELUP'),
            "default"   => 1,
            "min"       => 0,
            "step"      => 1,
            "max"       => 15,
            'required' => array('page-title-bottom-line-enable', '=', '1'),
        ),

        array(
            'id'       => 'page-title-list-style',
            'type'     => 'image_select',
            'title'    => esc_html__('Category Filter Animation', 'LEVELUP'),
            'subtitle' => esc_html__('Use this option to choose the style of the animation when you hover on the Category Filter in Title Area.', 'LEVELUP'),

            'options'  => array(
                'anim-1'      => array(
                    'alt'   => '1',
                    'img'  => get_template_directory_uri().'/inc/admin/assets/images/anim_01.gif'
                ),
                'anim-2'      => array(
                    'alt'   => '2',
                    'img'  => get_template_directory_uri().'/inc/admin/assets/images/anim_02.gif'
                ),
                ''      => array(
                    'alt'   => '1',
                    'img'  => get_template_directory_uri().'/inc/admin/assets/images/wout_anim.png'
                ),
            ),
            'default' => 'anim-2'
        ),

        array(
            'id'       => 'page-title-list-style-color',
            'type'     => 'button_set',
            'title'    => esc_html__('Category Filter Style', 'LEVELUP'),
            'subtitle' => esc_html__('Select style the Category Filter.', 'LEVELUP'),
            'options' => array(
                'dark' => esc_html__('Dark', 'LEVELUP'),
                'light' => esc_html__('Light', 'LEVELUP'),
            ),
            'default' => 'dark'
        ),

	    array(
		    'id' => 'page-title-category-description',
		    'type' => 'switch',
		    'title' => esc_html__('Display Category Description?', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable Category description below Page Title.', 'LEVELUP'),
		    'default' => '0',
	    ),

	    array(
		    'id'       => 'page-title-category-description_width',
		    'type'     => 'text',
		    'title'    => esc_html__('Category Description Max Width', 'LEVELUP'),
		    'subtitle' => esc_html__('The max-width is used to set the maximum width of Category description.', 'LEVELUP'),
		    'validate' => 'numeric',
		    'desc' => esc_html__('Enter a value in pixels. E.g. 600', 'LEVELUP'),
		    'default'  => '700',
		    'required' => array('page-title-category-description', '=', '1'),
	    ),

        array(
            'id'       => 'section-typography-page-title-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Typography & Color', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'page_title_font',
            'type' => 'typography',
            'title' => esc_html__('Page Title Font', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Page Title. This setting applies to Regular Title and Fancy Title.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'font-size'   => true,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => true,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'color'       => '#333333',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '60px',
                'line-height' => '75px',
                'font-weight' => '700',
            ),
        ),

        array(
            'id'       => 'page_title_margin_bottom',
            'type'     => 'text',
            'title'    => esc_html__('Page Title Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'validate' => 'numeric',
            'desc' => esc_html__('Enter a value in pixels. E.g. 30', 'LEVELUP'),
            'default'  => '20',
        ),

        array(
            'id' => 'page_subtitle_font',
            'type' => 'typography',
            'title' => esc_html__('Subtitle', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Page Subtitle. This setting applies to Regular Subtitle and Fancy Subtitle.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => true,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'color'       => '#333333',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '16px',
                'line-height' => '20px',
                'font-weight' => '400',
            ),
        ),

        array(
            'id'       => 'page_subtitle_margin_bottom',
            'type'     => 'text',
            'title'    => esc_html__('Subtitle Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px. This setting applies to Regular Subtitle and Fancy Subtitle.', 'LEVELUP'),
            'validate' => 'numeric',
            'desc' => esc_html__('Enter a value in pixels. E.g. 30', 'LEVELUP'),
            'default'  => '0',
        ),

        array(
            'id'     => 'section-typography-page-title-end',
            'type'   => 'section',
            'indent' => false,
        ),

        array(
            'id'       => 'page-title-fancy-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Fancy Title Settings', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'page-title-fancy-separator',
            'type' => 'switch',
            'title' => esc_html__('Fancy Title Separator', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Separator in Fancy Title. Disabled by default.', 'LEVELUP'),
            'default' => '0'
        ),
        
        array(
            'id'        => 'page-title-fancy-separator-margin',
            'type'      => 'slider',
            'title'     => esc_html__('Fancy Title Separator Spacing', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the separator top and bottom padding size.', 'LEVELUP'),
            "default"   => 45,
            "min"       => 10,
            "step"      => 1,
            "max"       => 100,
            'required'  => array('page-title-fancy-separator', '=', '1'),
        ),
        
        array(
            'id' => 'page-title-fancy-bg_animation',
            'type' => 'switch',
            'title' => esc_html__('Fade In Background Image After Load', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Fade In Background Image after page load. Disabled by default.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id'     => 'page-title-fancy-end',
            'type'   => 'section',
            'indent' => false,
        ),

    )
));

LevelupRedux::setSection( $opt_name, array(
		'id'    => 'transition',
		'icon'  => 'transition',
		'icon_class' => 'rdy-icon',
		'title'     => esc_html__('Pages', 'LEVELUP'),
		'fields'    => array(

		array(
			'id' => 'page_sidebar',
			'type' => 'image_select',
			'title' => esc_html__('Pages Sidebar', 'LEVELUP'),
			'subtitle' => esc_html__('Choose a sidebar layout or w/o sidebar layout for all Pages.', 'LEVELUP'),

			'options' => array(
				'' => array(
						'title' => esc_html__('No Sidebar', 'LEVELUP'),
						'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/no_sidebar.png'
				),
				'left' => array(
						'title' => esc_html__('Left Sidebar', 'LEVELUP'),
						'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/side_bar_left.png'
				),
				'right' => array(
						'title' => esc_html__('Right Sidebar', 'LEVELUP'),
						'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/side_bar_right.png'
				),
			),
			'default' => '',
		),

		array(
			'id'    => 'page_sidebar-area',
			'type'  => 'select',
			'title' => __( 'Select Widget Area', 'LEVELUP' ),
			'subtitle' => 'Choose the widget which will be displayed in the sidebar globally.',
			'data'  => 'sidebars',
			'required'  => array('page_sidebar', '!=', ''),
		),

		array(
			'id'        => 'page-fullscreen',
			'type'      => 'switch',
			'title'     => esc_html__('Content Area Full-width?', 'LEVELUP'),
			'subtitle'  => esc_html__('Use this setting if you want to expand the Page Content Area to full width of the page.', 'LEVELUP'),
			'default'   => 1,
			'required'  => array('page_sidebar', '!=', ''),
		),

		)
));

LevelupRedux::setSection($opt_name, array(
    'id' => 'footer',
    'icon' => 'footer',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Footer', 'LEVELUP'),
    'fields' => array(

	    /*array(
		    'id' => 'rdy_preset1',
		    'type' => 'rdy_preset',
		    'title' => esc_html__('Preset', 'LEVELUP'),
		    'subtitle' => esc_html__('???.', 'LEVELUP'),
		    'default' => '',
		    'options' => array(
			    'p1' => array(
					    'title' => 'Title',
					    'img' => get_template_directory_uri() . '/inc/admin/assets/images/presets/001.png',
					    'params' => array(
							    'maintenance_mode' => '1',
							    'back-to-top-main-icon' => 'icon3',
					    )

			    ),
			    'p2' => array(
					    'title' => 'Title 2',
					    'img' => get_template_directory_uri() . '/inc/admin/assets/images/presets/002.png',
					    'params' => array(
							    'maintenance_mode' => '1',
							    'back-to-top-main-icon' => 'icon2',
					    )

			    ),
			    'p3' => array(
					    'title' => 'Title 3',
					    'img' => get_template_directory_uri() . '/inc/admin/assets/images/presets/003.png',
					    'params' => array(
							    'maintenance_mode' => '0',
							    'back-to-top-main-icon' => 'icon1',
					    )

			    ),
			    'p4' => array(
					    'title' => 'Title 4',
					    'img' => get_template_directory_uri() . '/inc/admin/assets/images/presets/004.png',
					    'params' => array(
							    'maintenance_mode' => '0',
							    'back-to-top-main-icon' => 'icon1',
					    )

			    ),
		    ),
	    ),*/

        array(
            'id' => 'section-back-to-top-start',
            'type' => 'section',
            'title' => esc_html__('Back to Top Button', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'back-to-top-icon',
            'type' => 'image_select',
            'title' => esc_html__('Back To Top Button', 'LEVELUP'),
            'subtitle' => esc_html__('Choose an icon image to be displayed. Enabling this option will display a Back to Top button on every page.', 'LEVELUP'),
            'options' => array(
                '' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_none.png'
                ),
                'icon1' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_01.png'
                ),
                'icon2' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_02.png'
                ),
                'icon3' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_03.png'
                ),
            ),
            'default' => ''
        ),

        array(
            'id' => 'back-to-top-align',
            'type' => 'button_set',
            'title' => esc_html__('Back To Top Button Alignment', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the alignment Back to Top Button on a page.', 'LEVELUP'),
            'options' => array(
                'center' => esc_html__('Center', 'LEVELUP'),
                'right' => esc_html__('Right', 'LEVELUP'),
            ),
            'default' => 'center',
        ),
        
        array(
            'id' => 'back-to-top',
            'type' => 'switch',
            'title' => esc_html__('Show Caption "Back To Top"?', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the "Back to Top" caption under the icon.', 'LEVELUP'),
            'switch' => false,
            'default' => false,
        ),

	    array(
		    'id' => 'section-back-to-top-end',
		    'type' => 'section',
		    'indent' => false,
	    ),

	    array(
		    'id' => 'section-footer-features-start',
		    'type' => 'section',
		    'title' => esc_html__('Footer Features', 'LEVELUP'),
		    'subtitle' => '',
		    'indent' => true,
	    ),

	    array(
		    'id' => 'footer-effects',
		    'type' => 'button_set',
		    'title' => esc_html__('Footer Effects', 'LEVELUP'),
			    'subtitle' => wp_kses( __( 'In the given setting you may choose which effect to apply for the footer. <br><br> <b>Uncovering</b><br>Using this option, you may enable footer uncovering effect (content revealing footer on scroll event).', 'LEVELUP' ), array( 'b' => array(), 'br' => array(), ) ),
		    'options' => array(
			    '' => esc_html__('None', 'LEVELUP'),
			    'uncovering' => esc_html__('Uncovering', 'LEVELUP'),
		    ),
		    'default' => '',
	    ),

	    array(
		    'id' => 'footer-shadow',
		    'type' => 'button_set',
		    'title' => esc_html__('Uncovering Shadow Style', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the shadow you would like for your Uncovering footer.', 'LEVELUP'),
		    'options' => array(
			    '' => esc_html__('None', 'LEVELUP'),
			    'shadow1' => esc_html__('Shadow 01', 'LEVELUP'),
			    'shadow2' => esc_html__('Shadow 02', 'LEVELUP'),
			    'shadow3' => esc_html__('Shadow 03', 'LEVELUP'),
			    'shadow4' => esc_html__('Shadow 04', 'LEVELUP'),
			    'shadow5' => esc_html__('Shadow 05', 'LEVELUP'),
			    'shadow6' => esc_html__('Shadow 06', 'LEVELUP'),
		    ),
		    'default' => '',
		    'required' => array('footer-effects', '=', 'uncovering'),
	    ),

	    array(
		    'id'        => 'footer-shadow-color',
		    'type'      => 'color_rgba',
		    'title'     => esc_html__( 'Uncovering Shadow Style Color', 'LEVELUP' ),
		    'subtitle' => esc_html__('Choose a shadow color for uncovering shadow.', 'LEVELUP'),
		    'default'   => array(
			    'color'     => '#000000',
			    'alpha'     => .25
		    ),
		    'options'       => array(
			    'show_input'                => true,
			    'show_initial'              => true,
			    'show_alpha'                => true,
			    'show_palette'              => true,
			    'show_palette_only'         => false,
			    'show_selection_palette'    => true,
			    'max_palette_size'          => 10,
			    'allow_empty'               => true,
			    'clickout_fires_change'     => false,
			    'choose_text'               => 'Choose',
			    'cancel_text'               => 'Cancel',
			    'show_buttons'              => true,
			    'use_extended_classes'      => true,
			    'palette'                   => null,  // show default
			    'input_text'                => 'Select Color'
		    ),
		    'required' => array('footer-shadow', '!=', ''),
	    ),

        array(
            'id' => 'footer-pre-widget-area',
            'type' => 'switch',
            'title' => esc_html__('Bottom Widget in Footer Area?', 'LEVELUP'),
	        'subtitle' => esc_html__('Using this option, you may move and fix Bottom Widget in the footer area. If the settings is turned off, the Bottom Widget will be placed by default, after the content and before footer.', 'LEVELUP'),
            'switch' => false,
            'default' => false,
        ),

        array(
            'id' => 'section-footer-features-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-main-footer-area-start',
            'type' => 'section',
            'title' => esc_html__('Main Footer Area', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'use-footer-area',
            'type' => 'switch',
            'title' => esc_html__('Main Footer Area', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Main Footer Area. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'footer-area-separator',
            'type' => 'button_set',
            'title' => esc_html__('Separator  Width', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Separator or choose the Separator Width.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'grid' => esc_html__('Content width', 'LEVELUP'),
                'fullwidth' => esc_html__('Full Width', 'LEVELUP'),
            ),
            'default' => '',
            'required' => array('use-footer-area', '=', '1'),
        ),

        array(
            'id' => 'footer-area-grid',
            'type' => 'switch',
            'title' => esc_html__('Main Footer Full-width', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting if you want to expand the Main Footer to full width of the page.', 'LEVELUP'),
            'default' => '0',
            'required' => array('use-footer-area', '=', '1'),
        ),

        array(
            'id' => 'footer-layout',
            'type' => 'image_select',
            'title' => esc_html__('Main Footer Columns', 'LEVELUP'),
            'subtitle' => esc_html__('Select the number of columns you would like to have in your footer.', 'LEVELUP'),
            'options' => array(
                1 => array(
                    'alt' => esc_html__('1 Column', 'LEVELUP'),
                    'title' => esc_html__('1 Column', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/01.png'
                ),
                2 => array(
                    'alt' => esc_html__('2 Columns', 'LEVELUP'),
                    'title' => esc_html__('2 Columns', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/02.png'
                ),
                3 => array(
                    'alt' => esc_html__('3 Columns', 'LEVELUP'),
                    'title' => esc_html__('3 Columns', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/03.png'
                ),
                4 => array(
                    'alt' => esc_html__('4 Columns', 'LEVELUP'),
                    'title' => esc_html__('4 Columns', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/04.png'
                ),
                5 => array(
                    'alt' => esc_html__('5 Column', 'LEVELUP'),
                    'title' => esc_html__('5 Column', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/05.png'
                ),
                6 => array(
                    'alt' => esc_html__('6 Columns', 'LEVELUP'),
                    'title' => esc_html__('6 Columns', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/06.png'
                ),

                'half_sub_half' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/07.png'
                ),
                'half_sub_third' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/08.png'
                ),
                'third_sub_third' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/09.png'
                ),
                'third_sub_fourth' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/10.png'
                ),
                'sub_half_half' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/11.png'
                ),
                'sub_third_half' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/12.png'
                ),
                'sub_third_third' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/13.png'
                ),
                'sub_fourth_third' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/14.png'
                ),
            ),
            'default' => '4',
            'required' => array('use-footer-area', '=', '1'),
        ),

	    array(
		    'id' => 'footer-area-responsive-pad',
		    'type' => 'image_select',
		    'title' => esc_html__('Main Footer on Tablet View', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the option for footer displaying on tablet view.', 'LEVELUP'),
		    'options' => array(
			    1 => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/tablet_footer_01.png'
			    ),
			    2 => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/tablet_footer_02.png'
			    ),
			    3 => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/tablet_footer_03.png'
			    ),
			    4 => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/tablet_footer_04.png'
			    ),
		    ),
		    'default' => '1',
		    'required' => array('use-footer-area', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-area-responsive-phone',
		    'type' => 'image_select',
		    'title' => esc_html__('Main Footer on Phone View', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose the option for footer displaying on tablet view.', 'LEVELUP'),
		    'options' => array(
			    1 => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/phone_footer_01.png'
			    ),
			    2 => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/phone_footer_02.png'
			    ),
		    ),
		    'default' => '1',
		    'required' => array('use-footer-area', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-area-title-font',
		    'type' => 'typography',
		    'google' => true,
		    'text-align' => false,
		    'line-height' => true,
		    'letter-spacing' => false,
		    'color' => false,
		    'text-transform' => true,
		    'title' => esc_html__('Main Footer Area Heading Font', 'LEVELUP'),
		    'subtitle' => esc_html__('Define styles for Main Footer Area Heading.', 'LEVELUP'),
		    'default' => array(
			    'color' => '#333333',
			    'font-weight' => '700',
			    'font-family' => 'Open Sans',
			    'google' => true,
			    'font-size' => '14px',
			    'letter-spacing' => '0px'
		    ),
		    'required' => array('use-footer-area', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-area-header-color',
		    'type' => 'color',
		    'title' => esc_html__('Main Footer Area Heading Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a  color for Main Footer Area Header Color', 'LEVELUP'),
		    'desc' => '',
		    'default' => '#333333',
		    'required' => array('use-footer-area', '=', '1'),
		    'transparent' => false,
	    ),

	    array(
		    'id' => 'footer-area-title-padding_bottom',
		    'type' => 'text',
		    'title' => esc_html__('Main Footer Area Heading Margin Bottom', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px. Default 20px.', 'LEVELUP'),
		    'default' => '20',
		    'validate' => 'numeric',
		    'required' => array('use-footer-area', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-area-text-font',
		    'type' => 'typography',
		    'google' => true,
		    'text-align' => false,
		    'line-height' => true,
		    'letter-spacing' => false,
		    'color' => false,
		    'text-transform' => true,
		    'title' => esc_html__('Main Footer Area Text Font', 'LEVELUP'),
		    'subtitle' => esc_html__('Define styles for Main Footer Area Text Font.', 'LEVELUP'),
		    'default' => array(
			    'color' => '#333333',
			    'font-weight' => '400',
			    'font-family' => 'Open Sans',
			    'google' => true,
			    'font-size' => '14px',
			    'line-height'  => '24px',
			    'letter-spacing' => '0px'
		    ),
		    'required' => array('use-footer-area', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-area-text-color',
		    'type' => 'color',
		    'title' => esc_html__('Main Footer Area Text Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a color for Main Footer Area Text.', 'LEVELUP'),
		    'default' => '#969696',
		    'required' => array('use-footer-area', '=', '1'),
		    'transparent' => false,
	    ),

	    array(
		    'id' => 'footer-area-padding_top',
		    'type' => 'text',
		    'title' => esc_html__('Main Footer Area Padding Top', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option, you may set a top padding for the Main Footer Area in pixels.', 'LEVELUP'),
		    'default' => '60',
		    'validate' => 'numeric',
		    'required' => array('use-footer-area', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-area-padding_bottom',
		    'type' => 'text',
		    'title' => esc_html__('Footer Area Padding Bottom', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option, you may set a bottom padding for the Main Footer Area in pixels.', 'LEVELUP'),
		    'default' => '60',
		    'validate' => 'numeric',
		    'required' => array('use-footer-area', '=', '1'),
	    ),

        array(
            'id' => 'footer-area-align',
            'type' => 'button_set',
            'title' => esc_html__('Content Alignment', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the alignment for the Content.', 'LEVELUP'),
            'options' => array(
                'left' => esc_html__('Left', 'LEVELUP'),
                'center' => esc_html__('Center', 'LEVELUP'),
                'right' => esc_html__('Right', 'LEVELUP')
            ),
            'default' => 'left',
            'required' => array('use-footer-area', '=', '1'),
        ),

	    array(
		    'id' => 'footer-area-background',
		    'type' => 'color',
		    'title' => esc_html__('Main Footer Area Background Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Choose a background color for Main Footer Area.', 'LEVELUP'),
		    'default' => '#f6f6f6',
		    'required' => array('use-footer-area', '=', '1'),
		    'transparent' => true,
	    ),

        array(
            'id'       => 'footer-area-background-image',
            'type'     => 'background',
            'title'    => esc_html__('Main Footer Area Background Image', 'LEVELUP'),
            'subtitle' => esc_html__('Choose an image to be displayed as a background in the Main Footer Area.', 'LEVELUP'),
            'desc'     => '',
            'background-color' => false,
            'required' => array('use-footer-area', '=', '1'),
            'default' => '',
        ),

        array(
            'id' => 'footer-area-link-color',
            'type' => 'color',
            'title' => esc_html__('Main Footer Area | Link Color on Hover', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for Main Footer Area Link Hover.', 'LEVELUP'),
            'desc' => '',
            'default' => '#333333',
            'required' => array('use-footer-area', '=', '1'),
            'transparent' => false,
        ),

        array(
            'id' => 'footer-area-link-underline',
            'type' => 'switch',
            'title' => esc_html__('Main Footer Area | Link Underline on Hover', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Main Footer Area Link underline on hover. Enabled by default.', 'LEVELUP'),
            'default' => '1',
            'required' => array('use-footer-area', '=', '1'),
        ),
        array(
            'id' => 'footer-area-list-divider',
            'type' => 'switch',
            'title' => esc_html__('Main Footer Area List Lines', 'LEVELUP'),
	        'subtitle' => esc_html__('Using this option, you may enable / disable separator lines in the lists.', 'LEVELUP'),
            'default' => '0',
            'required' => array('use-footer-area', '=', '1'),
        ),
        array(
            'id' => 'footer-area-columns-divider',
            'type' => 'switch',
            'title' => esc_html__('Main Footer Area Columns Dividers', 'LEVELUP'),
	        'subtitle' => esc_html__('Using this option, you may enable / disable dividers between the columns.', 'LEVELUP'),
            'default' => '0',
            'required' => array('use-footer-area', '=', '1'),
        ),
        array(
            'id' => 'footer-area-columns-equal_height',
            'type' => 'switch',
            'title' => esc_html__('Main Footer Area Columns Equal Height', 'LEVELUP'),
	        'subtitle' => esc_html__('Using this option, you may make dividers between the columns of equal height.', 'LEVELUP'),
            'default' => '0',
            'required' => array('use-footer-area', '=', '1'),
        ),

        array(
            'id' => 'section-main-footer-area-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-footer-social-icons-start',
            'type' => 'section',
            'title' => esc_html__('Social Icons (Copyright Area)', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
            'required' => array('use-footer-sub', '=', '1'),
        ),

        array(
            'id' => 'footer-sub-social',
            'type' => 'switch',
            'title' => esc_html__('Centered Social Icons?', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you may Enable / Disable the Social Icons centered on the Copyright Footer Area.', 'LEVELUP'),
            'default' => '0',
            'required' => array('use-footer-sub', '=', '1'),
        ),

	    array(
		    'id' => 'footer-sub-social-padding_top',
		    'type' => 'text',
		    'title' => esc_html__('Centered Social Icons Padding Top', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option, you may set a top padding for the Centered Social Icons in pixels.', 'LEVELUP'),
		    'default' => '60',
		    'validate' => 'numeric',
		    'required' => array('footer-sub-social', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-social-padding_bottom',
		    'type' => 'text',
		    'title' => esc_html__('Centered Social Icons Padding Bottom', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option, you may set a bottom padding for the Centered Social Icons in pixels.', 'LEVELUP'),
		    'default' => '45',
		    'validate' => 'numeric',
		    'required' => array('footer-sub-social', '=', '1'),
	    ),


	    /*array(
			'id' => 'footer-sub-social-inline',
			'type' => 'switch',
			'title' => esc_html__('Social Icons inline with copyright text.', 'LEVELUP'),
			'subtitle' => esc_html__('Enable / Disable display of social icons in the Copyright Area on the same level as the copyright text. Disabled by default.', 'LEVELUP'),
			'default' => '0',
			'required' => array('use-footer-sub', '=', '1'),
		),*/

        array(
            'id' => 'footer-sub-social-height',
            'type' => 'slider',
            'title' => esc_html__('Social Icons Height', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the Social Icons Height.', 'LEVELUP'),
            'desc' => esc_html__('Default 18px', 'LEVELUP'),
            'default' => '18',
            'min' => '10',
            'step' => '1',
            'max' => '100',
            'required' => array('use-footer-sub', '=', '1'),
        ),

        array(
            'id' => 'footer-sub-social-padding',
            'type' => 'slider',
            'title' => esc_html__('Social Icons Spacing', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the Social Icons Spacing.', 'LEVELUP'),
            'desc' => esc_html__('Default 20px', 'LEVELUP'),
            'default' => '20',
            'min' => '10',
            'step' => '1',
            'max' => '100',
            'required' => array('use-footer-sub', '=', '1'),
        ),

        array(
            'id' => 'section-footer-social-icons-end',
            'type' => 'section',
            'indent' => false,
        ),


        /*****************************************************************
         *Sub Footer Area
         *****************************************************************/

        array(
            'id' => 'section-copyright-area-start',
            'type' => 'section',
            'title' => esc_html__('Copyright Area', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'use-footer-sub',
            'type' => 'switch',
            'title' => esc_html__('Footer Copyright Area', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Footer Copyright Area. Enabled by default.', 'LEVELUP'),
            'default' => '1',
        ),

	    array(
            'id' => 'footer-sub-separator',
            'type' => 'button_set',
            'title' => esc_html__('Separator Width', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Separator or choose the Separator Width.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'grid' => esc_html__('Content width', 'LEVELUP'),
                'fullwidth' => esc_html__('Full-width', 'LEVELUP'),
            ),
            'default' => '',
            'required' => array('use-footer-sub', '=', '1'),
        ),

        /*array(
            'id' => 'footer-sub-grid',
            'type' => 'button_set',
            'title' => esc_html__('Footer Copyright Area Full-width', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the width of the Footer Copyright Area.', 'LEVELUP'),
            'options' => array(
                'grid' => esc_html__('Boxed', 'LEVELUP'),
                'fullwidth' => esc_html__('Full Width', 'LEVELUP'),
            ),
            'default' => 'grid',
            'required' => array('use-footer-sub', '=', '1'),
        ),*/

        array(
            'id' => 'footer-sub-grid',
            'type' => 'switch',
            'title' => esc_html__('Footer Copyright Area Full-width', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting if you want to expand the Footer Copyright Area to full width of the page.', 'LEVELUP'),
            'default' => '0',
            'required' => array('use-footer-sub', '=', '1'),
        ),

	    array(
		    'id' => 'footer-sub-height',
		    'type' => 'text',
		    'title' => esc_html__('Footer Copyright Area Height', 'LEVELUP'),
		    'subtitle' => esc_html__('Enter a value to set the Footer Copyright Area Heigh.', 'LEVELUP'),
		    'desc' => esc_html__('Enter a value in pixels. E.g. 50', 'LEVELUP'),
		    'default' => '60',
		    'validate' => 'numeric',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-background',
		    'type' => 'color',
		    'title' => esc_html__('Background Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Specify the Footer Copyright Area background.', 'LEVELUP'),
		    'default' => '#333333',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-layout',
		    'type' => 'image_select',
		    'title' => esc_html__(' Columns', 'LEVELUP'),
		    'subtitle' => esc_html__('Select the number of columns you would like to have in the Copyright Area.', 'LEVELUP'),
		    'options' => array(
			    1 => array(
				    'alt' => esc_html__('1 Column', 'LEVELUP'),
				    'title' => esc_html__('1 Column', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/copyr_01.png'
			    ),
			    2 => array(
				    'alt' => esc_html__('2 Columns', 'LEVELUP'),
				    'title' => esc_html__('2 Columns', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/copyr_02.png'
			    ),
			    3 => array(
				    'alt' => esc_html__('3 Columns', 'LEVELUP'),
				    'title' => esc_html__('3 Columns', 'LEVELUP'),
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/copyr_03.png'
			    ),
		    ),
		    'default' => '1',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-align',
		    'type' => 'button_set',
		    'title' => esc_html__('Content Alignment', 'LEVELUP'),
		    'subtitle' => esc_html__('Set up the alignment for the Content.', 'LEVELUP'),
		    'options' => array(
			    'left' => esc_html__('Left', 'LEVELUP'),
			    'center' => esc_html__('Center', 'LEVELUP'),
			    'right' => esc_html__('Right', 'LEVELUP')
		    ),
		    'default' => 'left',
		    'required' => array('footer-sub-layout', '=', '1'),
	    ),

	    array(
		    'id'      => 'footer-sub-blocks',
		    'type'    => 'sorter',
		    'title'   => esc_html__('Footer Copyright Area Blocks', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting you can specify the position of elements on the Copyright Area.', 'LEVELUP'),
		    'desc'    => '',
		    'options' => array(
				    'Elements' => array(
						    'logo'   => esc_html__('Logo', 'LEVELUP'),
//				    'email'  => esc_html__('Email', 'LEVELUP'),
//				    'phone'  => esc_html__('Phone', 'LEVELUP'),
//				    'skype'  => esc_html__('Skype', 'LEVELUP'),
//				    'login'  => esc_html__('Login', 'LEVELUP'),
//				    'search' => esc_html__('Search', 'LEVELUP'),
//				    'cart'   => esc_html__('Cart', 'LEVELUP'),
						    'social' => esc_html__('Social', 'LEVELUP'),
						    'menu'   => esc_html__('Menu', 'LEVELUP'),
				    ),
				    'Column 1' => array(
					    'text'   => esc_html__('Text', 'LEVELUP'),
				    ),
				    'Column 2' => array(),
				    'Column 3' => array(),
		    ),
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-blocks-el-padding',
		    'type' => 'slider',
		    'title' => esc_html__('Elements Spacing / Column 1', 'LEVELUP'),
		    'subtitle' => esc_html__('Drag the slider to set the Social Icons Spacing.', 'LEVELUP'),
		    'desc' => esc_html__('Default 10px', 'LEVELUP'),
		    'default' => '10',
		    'min' => '4',
		    'step' => '2',
		    'max' => '50',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-blocks2-el-padding',
		    'type' => 'slider',
		    'title' => esc_html__('Elements Spacing / Column 2', 'LEVELUP'),
		    'subtitle' => esc_html__('Drag the slider to set the Social Icons Spacing.', 'LEVELUP'),
		    'desc' => esc_html__('Default 10px', 'LEVELUP'),
		    'default' => '10',
		    'min' => '4',
		    'step' => '2',
		    'max' => '50',
		    'required' => array('footer-sub-layout', '=', '2'),
	    ),

        array(
            'id' => 'footer-sub-column1-text',
            'type' => 'textarea',
            'title' => esc_html__('Footer Copyright Text', 'LEVELUP'),
            'subtitle' => esc_html__('Enter your copyright information or something else here.', 'LEVELUP'),
            'default' => wp_kses( __('LEVELUP 2016 WordPress Theme by Puzzlerbox', 'LEVELUP'), array( 'a' => array( 'href' => array() ) ) ),
            'required' => array('use-footer-sub', '=', '1'),
        ),

	    array(
		    'id' => 'footer-sub-text-font_size',
		    'type' => 'slider',
		    'title' => esc_html__('Copyright Text Font size', 'LEVELUP'),
		    'subtitle' => esc_html__('Drag the slider to set the Copyright Text Font Size.', 'LEVELUP'),
		    'default' => '12',
		    'min' => '10',
		    'step' => '1',
		    'max' => '20',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

        array(
            'id' => 'footer-sub-text-color',
            'type' => 'color',
            'title' => esc_html__('Footer Copyright Text Color', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the Footer Copyright Area Text Color.', 'LEVELUP'),
            'default' => '#cccccc',
            'required' => array('use-footer-sub', '=', '1'),
            'transparent' => false,

        ),

        array(
            'id' => 'footer-sub-link-style',
            'type' => 'color',
            'title' => esc_html__('Footer Copyright | Link Color on Hover', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the Footer Copyright Link Hover Color.', 'LEVELUP'),
            'default' => '#ffffff',
            'required' => array('use-footer-sub', '=', '1'),
            'transparent' => false,
        ),

        array(
            'id' => 'footer-sub-link-underline',
            'type' => 'switch',
            'title' => esc_html__('Footer Copyright Area | Link Underline on Hover', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Footer Copyright Link underline on hover. Enabled by default.', 'LEVELUP'),
            'default' => '1',
            'required' => array('use-footer-sub', '=', '1'),
        ),

	    array(
		    'id' => 'footer-sub-opacity-enable',
		    'type' => 'switch',
		    'title' => esc_html__('Copyright Area Appearance on Hover', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this setting you may set up the content transparency in Copyright Area, which will be displaying hovering the mouse over Copyright Area', 'LEVELUP'),
		    'default' => '0',
	    ),

	    array(
		    'id' => 'footer-sub-opacity',
		    'type' => 'slider',
		    'title' => esc_html__('Content Opacity', 'LEVELUP'),
		    'subtitle' => esc_html__('Drag the slider in order to set up the content transparency in Copyright Area.', 'LEVELUP'),
		    'default' => '30',
		    'min' => '0',
		    'step' => '1',
		    'max' => '100',
		    'required' => array('footer-sub-opacity-enable', '=', '1'),
	    ),

        array(
            'id' => 'footer-sub-logo',
            'type' => 'media',
            'title' => esc_html__('Logo in Footer Copyright Area?', 'LEVELUP'),
            'subtitle' => esc_html__('Upload (.jpg .png. gif) your logo image. The logo will be displayed before the Copyright Text.', 'LEVELUP'),
            'default' => '',
            'required' => array('use-footer-sub', '=', '1'),
        ),

	    array(
		    'id' => 'footer-sub-logo-height',
		    'type' => 'slider',
		    'title' => esc_html__('Logo Height', 'LEVELUP'),
		    'subtitle' => esc_html__('Drag the slider to set the logo height.', 'LEVELUP'),
		    'default' => '12',
		    'min' => '10',
		    'step' => '1',
		    'max' => '100',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-logo_link',
		    'type' => 'switch',
		    'title' => esc_html__('Make the Logo Clickable?', 'LEVELUP'),
		    'subtitle' => esc_html__('Using this option, you may set the link to the logotype on homepage.', 'LEVELUP'),
		    'default' => '0',
		    'required' => array('footer-sub-logo', '!=', ''),
	    ),



	    array(
			    'id' => 'section-copyright-area-end',
			    'type' => 'section',
			    'indent' => false,
	    ),

	    array(
			    'id' => 'section-copyright-area-mobile-start',
			    'type' => 'section',
			    'title' => esc_html__('Copyright Area on Mobile Devices', 'LEVELUP'),
			    'subtitle' => '',
			    'indent' => true,
	    ),

	    array(
		    'id' => 'footer-sub-mobile',
		    'type' => 'button_set',
		    'title' => esc_html__('Footer Copyright Area on Mobile Devices.', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting in order to display all the elements as a list in the Footer Copyright Area. Choose from which device (table or phone) the setting will be applied.', 'LEVELUP'),
		    'options' => array(
				    '' => esc_html__('Default', 'LEVELUP'),
				    'xs' => esc_html__('Phone', 'LEVELUP'),
				    'sm' => esc_html__('Tablet', 'LEVELUP'),
		    ),
		    'default' => 'xs',
		    'required' => array('use-footer-sub', '=', '1'),
	    ),

	    array(
		    'id' => 'footer-sub-mobile-align',
		    'type' => 'button_set',
		    'title' => esc_html__('Footer Copyright Area Mobile Content Alignment', 'LEVELUP'),
		    'subtitle' => esc_html__('Set up the alignment for the Content.', 'LEVELUP'),
		    'options' => array(
				    'left' => esc_html__('Left', 'LEVELUP'),
				    'center' => esc_html__('Center', 'LEVELUP'),
				    'right' => esc_html__('Right', 'LEVELUP'),
		    ),
		    'default' => 'left',
		    'required' => array('footer-sub-mobile', '!=', ''),
	    ),

        array(
            'id' => 'section-copyright-area-mobile-end',
            'type' => 'section',
            'indent' => false,
        ),
    )
));

LevelupRedux::setSection($opt_name, array(
    'id' => 'projects',
    'icon' => 'projects',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('SLIDES', 'LEVELUP'),
    'desc' => '',
    'fields' => array(

	    array(
		    'id' => 'project-list__html_title',
		    'type' => 'text',
		    'title' => esc_html__('Slides Homepage Title', 'LEVELUP'),
		    'subtitle' => esc_html__('Please enter the title for the homepage Slides, this setting is exclusively for HTML title.', 'LEVELUP'),
		    'default' => '',
	    ),
	    
        array(
            'id' => 'project-list__style',
            'type' => 'image_select',
            'title' => esc_html__('Slides Layout', 'LEVELUP'),
            'subtitle' => esc_html__('Select the layout of Slides to be displayed on your Front Page. You can choose one of the options: Split-screen or Full-screen mode.', 'LEVELUP'),
            'options' => array(
                '' => array(
                    'alt' => esc_html__('Split-screen', 'LEVELUP'),
                    'title' => esc_html__('Split-screen', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/signle_project/half.png'
                ),
                'full' => array(
                    'alt' => esc_html__('FullScreen', 'LEVELUP'),
                    'title' => esc_html__('FullScreen', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/signle_project/full.png'
                ),
            ),
            'default' => '',
        ),

        array(
            'id' => 'project-list__title_disable',
            'type' => 'switch',
            'title' => esc_html__('Disable Slides Title?', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Slides Titles.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'project-list__down_button',
            'type' => 'button_set',
            'title' => esc_html__('Enable Scroll-down Arrow Button?', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'dark' => esc_html__('Dark', 'LEVELUP'),
                'light' => esc_html__('Light', 'LEVELUP'),
            ),
            'default' => '',
            'subtitle' => esc_html__('Use this option to Enable / Disable the Scroll-down Arrow Button and choose the style.', 'LEVELUP')
        ),

        array(
            'id' => 'project-list__down_button_pos',
            'type' => 'button_set',
            'title' => esc_html__('Scroll-down Arrow Button Display', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('First Slide Only', 'LEVELUP'),
                'all' => esc_html__('On Each Slide', 'LEVELUP'),
            ),
            'default' => '',
            'required' => array('project-list__down_button', '=', array('dark','light')),
            'subtitle' => esc_html__('Use this option in order to indicate displaying Scroll-down Arrow Button only on the first slide or on all the slides.', 'LEVELUP')
        ),

        array(
            'id' => 'project-list__valign',
            'type' => 'image_select',
            'title' => esc_html__('Vertical Alignment', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the alignment the Vertical Alignment (Content Elements: Title, Subtitle, Text, Button).', 'LEVELUP'),
            'options' => array(
                'middle' => array(
                    'title' => esc_html__('Middle', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/valign/middle.png'
                ),
                'bottom' => array(
                    'title' => esc_html__('Bottom', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/valign/bottom.png'
                ),
            ),
            'default' => 'middle',
        ),

        array(
            'id' => 'project-list__align',
            'type' => 'image_select',
            'title' => esc_html__('Horizontal Alignment', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the alignment the Horizontal Alignment (Content Elements: Title, Subtitle, Text, Button).', 'LEVELUP'),
            'options' => array(
                'left' => array(
                    'title' => esc_html__('Left-aligned', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/align/left.png'
                ),
                'center' => array(
                    'title' => esc_html__('Centered', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/align/center.png'
                ),
                'right' => array(
                    'title' => esc_html__('Right-aligned', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/align/right.png'
                ),
            ),
            'default' => 'left',
        ),

        array(
            'id' => 'project-list__text_color',
            'type' => 'color',
            'title' => esc_html__('Text Color', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the Title, SubTitle and Text Color.', 'LEVELUP'),
            'default' => '#000000',
            'transparent' => false,
        ),

        array(
            'id' => 'project-list__text_hover_color',
            'type' => 'color',
            'title' => esc_html__('Title Hover Color', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the Title Hover Color.', 'LEVELUP'),
            'default' => '#000000',
            'transparent' => false,
        ),

        array(
            'id' => 'project-list__button',
            'type' => 'button_set',
            'title' => esc_html__('Button or Link', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the Button or Link for your Slides.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Disable', 'LEVELUP'),
                'button' => esc_html__('Button', 'LEVELUP'),
                'link' => esc_html__('Link', 'LEVELUP'),
            ),
            'default' => '',
        ),

        array(
            'id' => 'project-list__button_mobile',
            'type' => 'button_set',
            'title' => esc_html__('Button in Mobile View', 'LEVELUP'),
            'subtitle' => esc_html__('Please indicate the button behavior in Mobile View, to hide or to show?', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Hide', 'LEVELUP'),
                'show' => esc_html__('Show', 'LEVELUP'),
            ),
            'default' => '',
            'required' => array('project-list__button', '=', array('button')),
        ),

        array(
            'id' => 'project-list__button_type',
            'type' => 'image_select',
            'title' => esc_html__('Button Type', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the Button Type.', 'LEVELUP'),
            'options' => array(
                'flat' => array(
                    'title' => esc_html__('Flat', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_flat.png'
                ),
                'flat_rounded' => array(
                    'title' => esc_html__('Flat Rounded', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_flat_rd.png'
                ),
                'outline' => array(
                    'title' => esc_html__('Outline', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_outln.png'
                ),
                'outline_rounded' => array(
                    'title' => esc_html__('Outline Rounded', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/sl_outln_rd.png'
                ),
            ),
            'default' => 'flat',
            'required' => array('project-list__button', '=', array('button')),
        ),

        array(
            'id' => 'project-list__button_text',
            'type' => 'text',
            'title' => esc_html__('Text on the Button or Link', 'LEVELUP'),
            'subtitle' => esc_html__('Enter text on the Button or Link here.', 'LEVELUP'),
            'required' => array('project-list__button', '=', array('button', 'link')),
            'default' => '',
        ),

        array(
            'id' => 'project-list__button_style',
            'type' => 'button_set',
            'title' => esc_html__('Button/Link Color', 'LEVELUP'),
            'subtitle' => esc_html__('This option specifies the Button or Link Color Style.', 'LEVELUP'),
            'options' => array(
                'dark' => esc_html__('Dark', 'LEVELUP'),
                'light' => esc_html__('Light', 'LEVELUP'),
                'from_title' => esc_html__('Inherit Title Hover Color', 'LEVELUP'),
            ),
            'default' => 'dark',
            'required' => array('project-list__button', '=', array('button', 'link')),
        ),

	    array(
		    'id' => 'project-slide_link',
		    'type' => 'button_set',
		    'title' => esc_html__('Add a Link to the Entire Slide?', 'LEVELUP'),
		    'subtitle' => esc_html__('You can add a link to the entire slide by using the default link to the project page or Custom Link URL.', 'LEVELUP'),
		    'options' => array(
				    '' => esc_html__('Disable', 'LEVELUP'),
				    '1' => esc_html__('Enable', 'LEVELUP'),
		    ),
		    'default' => '',
	    ),

        array(
            'id' => 'project-list__show_hover',
            'type' => 'switch',
            'title' => esc_html__('Ken Burns / Pan Zoom', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Ken Burns / Pan Zoom Effect.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'project-list__pagination',
            'type' => 'image_select',
            'title' => esc_html__('Dots Navigation', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you are able to Enable / Disable the Dots Navigation or select display style.', 'LEVELUP'),
            'options' => array(
                '' => array(
                    'title' => 'Disable',
                    'img' => get_template_directory_uri() . '/admin/assets/images/vc/presets/hide.png'
                ),
                'enable' => array(
                    'title' => 'Dots only',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/dot_01.png'
                ),
                'title' => array(
                    'title' => 'w/ Title',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/dot_02.gif'
                ),
                'dash_title' => array(
                    'title' => 'w/ Title + Dash',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/dot_03.gif'
                ),
            ),
            'default' => '',
            'required' => array('header-layout', '=', array('fixed', 'static', 'gamburg', 'gamburg_full')),
        ),

		    array(
				    'id' => 'project-list__dots_style',
				    'type' => 'image_select',
				    'title' => esc_html__('Dots Navigation Style', 'LEVELUP'),
				    'subtitle' => esc_html__('Select the Dots Navigation style.', 'LEVELUP'),
				    'options' => array(
			    '' => array(
				    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/dot_style_01.png'
			    ),
			    'style2' => array(
			    'img' => get_template_directory_uri() . '/inc/admin/assets/images/slider/dot_style_02.png'
			    ),
	    ),
		    'default' => '',
		    'required' => array('project-list__pagination', '!=', ''),
		    ),

        array(
            'id' => 'project-list__dots_align',
            'type' => 'button_set',
            'title' => esc_html__('Dots Navigation Position', 'LEVELUP'),
            'subtitle' => esc_html__('Use this option to set the Dots Navigation position on the right/left side of the page.', 'LEVELUP'),
            'options' => array(
                'left' => esc_html__('Left', 'LEVELUP'),
                'right' => esc_html__('Right', 'LEVELUP'),
            ),
            'default' => 'left',
            'required' => array('project-list__pagination', '!=', ''),
        ),

        array(
            'id' => 'project-list__dots_valign',
            'type' => 'button_set',
            'title' => esc_html__('Dots Navigation Vertical Position', 'LEVELUP'),
            'subtitle' => esc_html__('Use this option to set the Dots Navigation vertical position on the right/left side of the page.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Bottom', 'LEVELUP'),
                'middle' => esc_html__('Middle', 'LEVELUP'),
            ),
            'default' => '',
            'required' => array('project-list__pagination', '!=', ''),
        ),

        array(
            'id' => 'section-typography-project-start',
            'type' => 'section',
            'title' => esc_html__('Typography Settings', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'project-title-font_size-responsive',
            'type' => 'button_set',
            'title' => esc_html__('Slides Title Font Size', 'LEVELUP'),
            'subtitle' => esc_html__('Use this option to set the static or dynamic (responsive) font size for Slides Title.', 'LEVELUP'),
            'options' => array(
                '' => esc_html__('Static', 'LEVELUP'),
                '1' => esc_html__('Dynamic', 'LEVELUP'),
            ),
            'default' => ''
        ),

        array(
            'id' => 'project-title-highlight',
            'type' => 'switch',
            'title' => esc_html__('Slides Title Highlight', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Title Highlight.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'project-title-highlight_color',
            'type' => 'color',
            'title' => esc_html__('Slides Title Highlight Color', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the Title Highlight Color.', 'LEVELUP'),
            'default' => '#ffffff',
            'transparent' => false,
            'required' => array('project-title-highlight', '=', array('1')),
        ),

        array(
            'id' => 'project_title_font',
            'type' => 'typography',
            'title' => esc_html__('Slides Title', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the Slides Title Font, Size, etc.', 'LEVELUP'),
            'google' => true,
            'text-align' => false,
            'line-height' => true,
            'letter-spacing' => true,
            'color' => false,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '60px',
                'font-weight' => '700',
            ),
        ),

        array(
            'id' => 'project_title_font-margin_bottom',
            'type' => 'text',
            'title' => esc_html__('Slides Title: Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'validate' => 'numeric',
            'desc' => esc_html__('Enter a value in pixels. E.g. 30', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'project_subtitle_font',
            'type' => 'typography',
            'title' => esc_html__('Slides Subtitle', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the Slides Subtitle Font, Size, etc.', 'LEVELUP'),
            'google' => true,
            'text-align' => false,
            'line-height' => true,
            'letter-spacing' => true,
            'color' => false,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '30px',
                'font-weight' => '600',
            ),
        ),

        array(
            'id' => 'project_subtitle_font-margin_bottom',
            'type' => 'text',
            'title' => esc_html__('Slides Subtitle: Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'validate' => 'numeric',
            'desc' => esc_html__('Enter a value in pixels. E.g. 30', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'section-typography-project-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-single-project-page-start',
            'type' => 'section',
            'title' => esc_html__('SLIDES / Project Page', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'single-navigation_bar',
            'type' => 'image_select',
            'title' => esc_html__('Navigation Bar', 'LEVELUP'),
            'subtitle' => esc_html__('Select the Navigation Bar type for the Slide Project Page.', 'LEVELUP'),
            'options' => array(
                '' => array(
                    'img' => get_template_directory_uri() . '/admin/assets/images/vc/presets/hide.png'
                ),
                '1' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_00.gif'
                ),
                '2' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_01.png'
                ),
            ),
            'default' => ''
        ),
        array(
            'id' => 'single-navigation_bar_v2',
            'type' => 'image_select',
            'title' => esc_html__('Navigation Bar Style', 'LEVELUP'),
            'subtitle' => esc_html__('Select the Navigation Bar Style.', 'LEVELUP'),
            'options' => array(
                'icons' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_01.png'
                ),
                'text' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_02.png'
                ),
            ),
            'default' => 'icons',
            'required' => array('single-navigation_bar', '=', array('2')),
        ),

        array(
            'id' => 'project-post_nav-enable',
            'type' => 'switch',
            'title' => esc_html__('Previous and Next Navigation', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Previous & Next Default Navigation Buttons on a Slide Project Page. Enabled by default.', 'LEVELUP'),
            'desc' => '',
            'default' => '1'
        ),

	    array(
		    'id' => 'project-post_nav-same_category',
		    'type' => 'switch',
		    'title' => esc_html__('Previous and Next Navigation on Same Category', 'LEVELUP'),
		    'subtitle' => esc_html__('With the help of this setting Next/Prev navigation will be only for chosen category.', 'LEVELUP'),
		    'desc' => '',
		    'default' => '',
		    'required' => array('project-post_nav-enable', '=', '1'),
	    ),

	    array(
		    'id' => 'project-post_nav-reverse',
		    'type' => 'switch',
		    'title' => esc_html__('Reverse Previous and Next Navigation', 'LEVELUP'),
		    'subtitle' => esc_html__(' Use this setting for reverse chronological order of Next/Prev navigation.', 'LEVELUP'),
		    'desc' => '',
		    'default' => '',
		    'required' => array('project-post_nav-enable', '=', '1'),
	    ),

        array(
            'id' => 'section-single-project-page-end',
            'type' => 'section',
            'indent' => false,
        ),

    )
));


LevelupRedux::setSection($opt_name, array(
    'id' => 'portfolio',
    'icon' => 'portfolio',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Portfolio & Gallery', 'LEVELUP'),
    'fields' => array(

        /*array(
            'id' => 'portfolio-post_nav-url',
            'type' => 'text',
            'title' => esc_html__('Portfolio Page URL', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the main page portfolio URL. Refers to the title page of the portfolio, to build up the proper navigation.', 'LEVELUP'),
            'validate' => 'url',
            'default' => '',
        ),*/

        array(
            'id'       => 'portfolio-post_nav-url',
            'type'     => 'select',
            'multi'    => false,
            'title'    => esc_html__('Main Portfolio Page URL', 'LEVELUP'),
            'subtitle' => esc_html__('Select the portfolio main page. Refers to the title page of the portfolio, to build up the proper navigation.', 'LEVELUP'),
            'data' => 'pages',
            'default' => '',
        ),

        array(
            'id' => 'section-portfolio-typography-start',
            'type' => 'section',
            'title' => esc_html__('Portfolio &#8212; Typography', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'portfolio_title_font',
            'type' => 'typography',
            'title' => esc_html__('Portfolio Grid Title', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the Porftolio Title Font, Size, Color, etc.', 'LEVELUP'),
            'google' => true,
            'text-align' => false,
            'line-height' => true,
            'letter-spacing' => true,
            'color' => true,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '40px',
                'color' => '#000000',
                'font-weight' => '700',
            ),
        ),

        array(
            'id' => 'portfolio_subtitle_font',
            'type' => 'typography',
            'title' => esc_html__('Portfolio Grid Subtitle', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the Porftolio Subtitle Font, Size, Color, etc.', 'LEVELUP'),
            'google' => true,
            'text-align' => false,
            'line-height' => true,
            'letter-spacing' => true,
            'color' => true,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '18px',
                'color' => '#000000',
                'font-weight' => '400',
            ),
        ),

        array(
            'id' => 'section-portfolio-typography-end',
            'type' => 'section',
            'indent' => false,
        ),


	    array(
            'id' => 'section-portfolio-singlepage-start',
            'type' => 'section',
            'title' => esc_html__('Portfolio &#8212; Project Page', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'single-portfolio-navigation_bar',
            'type' => 'image_select',
            'title' => esc_html__('Navigation Bar', 'LEVELUP'),
            'subtitle' => esc_html__('Select the Navigation Bar type for the Portfolio / Project Page.', 'LEVELUP'),
            'options' => array(
                '' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/footer/backtotop_none.png'
                ),
                '1' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_00.gif'
                ),
                '2' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_01.png'
                ),
            ),
            'default' => ''
        ),

        array(
            'id' => 'single-portfolio-navigation_bar_v2',
            'type' => 'image_select',
            'title' => esc_html__('Navigation Bar Style', 'LEVELUP'),
            'subtitle' => esc_html__('Select the Navigation Bar Style', 'LEVELUP'),
            'options' => array(
                'icons' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_01.png'
                ),
                'text' => array(
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/nav/nav_02.png'
                ),
            ),
            'default' => 'icons',
            'required' => array('single-portfolio-navigation_bar', '=', array('2')),
        ),

        array(
            'id' => 'portfolio-post_nav-enable',
            'type' => 'switch',
            'title' => esc_html__('Previous and Next Navigation', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Previous & Next Default Navigation Buttons on a Portfolio / Project Page. Enabled by default.', 'LEVELUP'),
            'desc' => '',
            'default' => '1'
        ),

        array(
            'id' => 'portfolio-post_nav-same_category',
            'type' => 'switch',
            'title' => esc_html__('Previous and Next Navigation on Same Category', 'LEVELUP'),
            'subtitle' => esc_html__('With the help of this setting Next/Prev navigation will be only for chosen category.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
            'required' => array('portfolio-post_nav-enable', '=', '1'),
        ),

        array(
            'id' => 'portfolio-post_nav-reverse',
            'type' => 'switch',
            'title' => esc_html__('Reverse Previous and Next Navigation', 'LEVELUP'),
            'subtitle' => esc_html__(' Use this setting for reverse chronological order of Next/Prev navigation.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
            'required' => array('portfolio-post_nav-enable', '=', '1'),
        ),

        array(
            'id' => 'section-portfolio-singlepage-start-end',
            'type' => 'section',
            'indent' => false,
        ),

	    array(
		    'id' => 'section-gallery-start',
		    'type' => 'section',
		    'title' => esc_html__('Gallery &#8212; Typography', 'LEVELUP'),
		    'subtitle' => '',
		    'indent' => true,
	    ),

	    array(
		    'id' => 'gallery_title_font',
		    'type' => 'typography',
		    'title' => esc_html__('Gallery Caption', 'LEVELUP'),
		    'subtitle' => esc_html__('Set up the Gallery Caption Font, Size, Color, etc.', 'LEVELUP'),
		    'google' => true,
		    'text-align' => false,
		    'line-height' => true,
		    'letter-spacing' => true,
		    'color' => true,
		    'text-transform' => true,
		    'all_styles' => true,
		    'default' => array(
				    'font-family' => 'Open Sans',
				    'google' => true,
				    'font-size' => '40px',
				    'color' => '#000000',
				    'font-weight' => '700',
		    ),
	    ),

	    array(
		    'id' => 'section-gallery-end',
		    'type' => 'section',
		    'indent' => false,
	    ),


    )
));

LevelupRedux::setSection($opt_name, array(
    'id' => 'blog',
    'icon' => 'blog',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Blog', 'LEVELUP'),
    'desc' => '',
    'fields' => array(

        array(
            'id' => 'blog_header_text_title',
            'type' => 'text',
            'title' => esc_html__('Blog Title', 'LEVELUP'),
            'subtitle' => esc_html__('Enter the title of the blog.', 'LEVELUP'),
            'default' => '',
        ),

        array(
            'id' => 'blog_type',
            'type' => 'image_select',
            'title' => esc_html__('Blog Layout', 'LEVELUP'),
            'subtitle' => esc_html__('Select your blog layout here. Grid or Masonry.', 'LEVELUP'),
            'options' => array(
                'grid-blog' => array(
                    'title' => esc_html__('Grid', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout/grid.png'
                ),
                'masonry-blog' => array(
                    'title' => esc_html__('Masonry', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout/masonry.png'
                ),
            ),
            'default' => 'masonry-blog',
        ),

        array(
            'id' => 'blog_fullwidth',
            'type' => 'switch',
            'title' => esc_html__('Full Width Layout', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the layout to full width.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'blog_columns',
            'type' => 'button_set',
            'title' => esc_html__('Blog Item Columns', 'LEVELUP'),
            'subtitle' => esc_html__('Select the number of columns you would like for your blog.', 'LEVELUP'),
            'options' => array(
                1 => '1',
                2 => '2',
                3 => '3',
                4 => '4',
                6 => '6',
            ),
            'default' => 2,
        ),

        array(
            'id' => 'blog-masonry_gap',
            'type' => 'button_set',
            'title' => esc_html__('Gap', 'LEVELUP'),
            'subtitle' => esc_html__('Specify the spacing between grid elements.', 'LEVELUP'),
            'options' => array(
                '15' => '30',
                '20' => '40',
                '25' => '50',
                '30' => '60',
            ),
            'default' => '20'
        ),

        array(
            'id' => 'blog_sidebar',
            'type' => 'image_select',
            'title' => esc_html__('Blog Sidebar', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a sidebar layout or w/o sidebar layout for Blog.', 'LEVELUP'),

            'options' => array(
                '' => array(
                    'title' => esc_html__('No Sidebar', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/no_sidebar.png'
                ),
                'right' => array(
                    'title' => esc_html__('Right Sidebar', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/side_bar_right.png'
                ),
            ),
            'default' => 'right',

        ),

        array(
            'id' => 'blog_title_font',
            'type' => 'typography',
            'title' => esc_html__('Blog List Title', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the Blog List Title Font, Size, etc.', 'LEVELUP'),
            'google' => true,
            'text-align' => false,
            'line-height' => true,
            'letter-spacing' => true,
            'color' => true,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '30px',
                'font-weight' => '800',
                'line-height' => '36px'
            ),
        ),

        array(
            'id' => 'blog_title_margin_bottom',
            'type' => 'text',
            'title' => esc_html__('Blog List Title: Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 20', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '15',
        ),

        array(
            'id' => 'blog-list-meta-info',
            'type' => 'image_select',
            'title' => esc_html__('Meta Data Display Style', 'LEVELUP'),
            'subtitle' => esc_html__('Choose any the post meta data display style or hide. This information usually includes the author of the post, when it was written (or posted), and how the author categorized that particular post.', 'LEVELUP'),

            'options' => array(
                '0' => array(
                    'title' => '',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/blog/bm_00.png'
                ),
                '1' => array(
                    'title' => '',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/blog/bm_01.png'
                ),
                '2' => array(
                    'title' => '',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/blog/bm_02.png'
                ),
                '3' => array(
                    'title' => '',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/blog/bm_03.png'
                ),
                '4' => array(
                    'title' => '',
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/blog/bm_04.png'
                ),
            ),
            'default' => '1',
        ),


        array(
            'id' => 'blog_subtitle_font',
            'type' => 'typography',
            'title' => esc_html__('Blog List Meta Data', 'LEVELUP'),
            'subtitle' => esc_html__('Set up the Blog Meta Data Font, Size, etc.', 'LEVELUP'),
            'google' => true,
            'text-align' => false,
            'line-height' => true,
            'letter-spacing' => true,
            'color' => true,
            'text-transform' => true,
            'all_styles' => true,
            'default' => array(
                'font-family' => 'Open Sans',
                'google' => true,
                'font-size' => '13px',
                'line-height' => '20px',
                'font-weight' => '400',
                'color'      => '#919191',
            ),
        ),

        array(
            'id' => 'blog_subtitle_margin_bottom',
            'type' => 'text',
            'title' => esc_html__('Blog List Meta Data: Bottom Margin', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the bottom margin of an element. Specify a fixed bottom margin in px.', 'LEVELUP'),
            'desc' => esc_html__('Enter a value in pixels. E.g. 20', 'LEVELUP'),
            'validate' => 'numeric',
            'default' => '25',
        ),

        array(
            'id' => 'blog-title_disable',
            'type' => 'switch',
            'title' => esc_html__('Blog Title Area Disable?', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Blog Title Area. Disabled by default.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'page-title-blog-category-enable',
            'type' => 'switch',
            'title' => esc_html__('Blog Category Filter', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Category Filter in the Blog. Disabled by default.', 'LEVELUP'),
            'required' => array('blog-title_disable', '!=', '1'),
            'default' => '0'
        ),

        array(
            'id' => 'blog-list-separator_disable',
            'type' => 'switch',
            'title' => esc_html__('Blog List. Separator Disable?', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the separator between Title Area and the page content. Disabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'page-title-bloglist-margin-bottom',
            'type' => 'button_set',
            'title' => esc_html__('Blog List. Content Area Top Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Override the Content Area Top Padding (Global).', 'LEVELUP'),
            'desc' => '',
            'options' => array(
                '' => esc_html__('Inherit', 'LEVELUP'),
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => '',
        ),

        array(
            'id' => 'page-title-bloglist-footer-spacing',
            'type' => 'button_set',
            'title' => esc_html__('Blog List. Content Area Bottom Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Override the Content Area Bottom Padding (Global).', 'LEVELUP'),
            'desc' => '',
            'options' => array(
                '' => esc_html__('Inherit', 'LEVELUP'),
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => '',
        ),

        array(
            'id' => 'blog_auto_excerpt',
            'type' => 'switch',
            'title' => esc_html__('Automatic Post Excerpts', 'LEVELUP'),
            'subtitle' => esc_html__('Using this  option, you may create automatic excerpts (e.g. ... ) for your posts, placing a "read more" button after each post.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'blog_excerpt_length',
            'type' => 'text',
            'required' => array('blog_auto_excerpt', '=', '1'),
            'title' => esc_html__('Excerpt Length', 'LEVELUP'),
            'subtitle' => esc_html__('How many words would you like to display for your post excerpts? The default is 30.', 'LEVELUP'),
            'default' => '30',
        ),

        array(
            'id' => 'section-blog-single-start',
            'type' => 'section',
            'title' => esc_html__('Single Post', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'blog-post__layout',
            'type' => 'switch',
            'title' => esc_html__('Single Post Full-width', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you may to expand the content area to full width.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'blog-post__sidebar',
            'type' => 'image_select',
            'title' => esc_html__('Single Post Sidebar', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a layout for Blog Single Post. W/ Sidebar or w/o Sidebar.', 'LEVELUP'),

            'options' => array(
                '' => array(
                    'title' => esc_html__('No Sidebar', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/no_sidebar.png'
                ),
                'right' => array(
                    'title' => esc_html__('Right Sidebar', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/sidebar/side_bar_right.png'
                ),
            ),
            'default' => '',
        ),

        array(
            'id' => 'page-title-blog-margin-bottom',
            'type' => 'button_set',
            'title' => esc_html__('Single Post. Content Area Top Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Override the Content Area Top Padding (Global). But if field is empty, global settings are applied.', 'LEVELUP'),
            'desc' => '',
            'options' => array(
                '' => esc_html__('Inherit', 'LEVELUP'),
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => 60,
        ),

        array(
            'id' => 'page-title-blog-footer-spacing',
            'type' => 'button_set',
            'title' => esc_html__('Single Post. Content Area Bottom Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Override the Content Area Bottom Padding (Global). But if field is empty, global settings are applied.', 'LEVELUP'),
            'desc' => '',
            'options' => array(
                '' => esc_html__('Inherit', 'LEVELUP'),
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => 60,
        ),

        array(
            'id' => 'comments-blog-enable',
            'type' => 'switch',
            'title' => esc_html__('Comments', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Comments Blog. Enabled by default.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'blog-hide_page_title_meta',
            'type' => 'switch',
            'title' => esc_html__('Meta Data in Title Area', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Meta data in Title Area. Enabled by default.', 'LEVELUP'),
            'desc' => '',
            'default' => '1'
        ),

        array(
            'id' => 'author_bio',
            'type' => 'switch',
            'title' => esc_html__('Author\'s Info', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Author\'s Information. Disabled by default.', 'LEVELUP'),
            'desc' => '',
            'default' => '0'
        ),

        array(
            'id' => 'blog_social',
            'type' => 'switch',
            'title' => esc_html__('Social Media Sharing Buttons', 'LEVELUP'),
            'subtitle' => esc_html__('Activate this to enable social sharing buttons on your blog posts. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'display-post_nav',
            'type' => 'switch',
            'title' => esc_html__('Previous & Next Post Buttons', 'LEVELUP'),
            'subtitle' => esc_html__('Enable / Disable the Previous & Next Default Navigation Buttons on a Blog Single Post. Enabled by default.', 'LEVELUP'),
            'desc' => '',
            'default' => '1'
        ),

	    array(
		    'id' => 'blog-post_nav-same_category',
		    'type' => 'switch',
		    'title' => esc_html__('Previous and Next Navigation on Same Category', 'LEVELUP'),
		    'subtitle' => esc_html__('With the help of this setting Next/Prev navigation will be only for chosen category.', 'LEVELUP'),
		    'desc' => '',
		    'default' => '',
		    'required' => array('display-post_nav', '=', '1'),
	    ),

	    array(
		    'id' => 'blog-post_nav-reverse',
		    'type' => 'switch',
		    'title' => esc_html__('Reverse Previous and Next Navigation', 'LEVELUP'),
		    'subtitle' => esc_html__(' Use this setting for reverse chronological order of Next/Prev navigation.', 'LEVELUP'),
		    'desc' => '',
		    'default' => '',
		    'required' => array('display-post_nav', '=', '1'),
	    ),

        array(
            'id' => 'section-blog-single-end',
            'type' => 'section',
            'indent' => false,
        ),
    )
));

LevelupRedux::setSection( $opt_name, array(
    'id' => 'social',
    'icon'  => 'social',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Social Media', 'LEVELUP'),
    'desc' => esc_html__('Enter in your social media locations here and then activate which ones you would like to display in your footer options etc.', 'LEVELUP'),
    'fields' => array(

        array(
            'id'       => 'header-social-hover',
            'type'     => 'button_set',
            'title'    => esc_html__('Social Icons Hover Color', 'LEVELUP'),
            'subtitle' => esc_html__('Choose the Social Icons Hover Color.', 'LEVELUP'),
            'options'  => array(
                0 => esc_html__('None', 'LEVELUP'),
                1 => esc_html__('Brand', 'LEVELUP'),
                2 => esc_html__('Accent', 'LEVELUP'),
                3 => esc_html__('Default', 'LEVELUP'),
            ),
            'default'  => 1,
        ),

		 array(
			'id'       => 'social-icons-animation',
		    'type'     => 'switch',
			'title'    => esc_html__('Social Icons Animation', 'LEVELUP'),
			'subtitle' => esc_html__('Enable / Disable the Social Icons Animation. Disabled by default.', 'LEVELUP'),
			'default'  => '0',
		    ),

	    array(
		    'id'       => 'social-media-order',
		    'type'     => 'sortable',
		    'title'    => __('Social Media Sortable', 'LEVELUP'),
		    'subtitle' => __('Define and reorder Social Media however you want.', 'LEVELUP'),
//		    'desc'     => __('This is the description field, again good for additional info.', 'LEVELUP'),
		    'mode'     => 'label',
		    'options' => array(
			    'facebook'    => 'Facebook',
			    'twitter'     => 'Twitter',
			    'google-plus' => 'Google Plus',
			    'vimeo'       => 'Vimeo',
			    'pinterest'   => 'Pinterest',
			    'youtube'     => 'Youtube',
			    'tumblr'      => 'Tumblr',
			    'dribbble'    => 'Dribbble',
			    'linkedin'    => 'Linkedin',
			    'xing'        => 'Xing',
			    'rss'         => 'RSS',
			    'behance'     => 'Behance',
			    'instagram'   => 'Instagram',
			    'github'      => 'Github',
			    'soundcloud'  => 'Soundcloud',
			    'vk'          => 'VK',
			    'wechat'      => 'WeChat',
			    'snapchat'    => 'SnapChat',
			    'flickr'      => 'Flickr',
		    ),
	    ),

        array(
            'id' => 'facebook-url',
            'type' => 'text',
            'title' => esc_html__('Facebook URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Facebook URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'twitter-url',
            'type' => 'text',
            'title' => esc_html__('Twitter URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Twitter URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'google-plus-url',
            'type' => 'text',
            'title' => esc_html__('Google+ URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Google+ URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'vimeo-url',
            'type' => 'text',
            'title' => esc_html__('Vimeo URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Vimeo URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'pinterest-url',
            'type' => 'text',
            'title' => esc_html__('Pinterest URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Pinterest URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'youtube-url',
            'type' => 'text',
            'title' => esc_html__('Youtube URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Youtube URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'tumblr-url',
            'type' => 'text',
            'title' => esc_html__('Tumblr URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Tumblr URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'dribbble-url',
            'type' => 'text',
            'title' => esc_html__('Dribbble URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Dribbble URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'linkedin-url',
            'type' => 'text',
            'title' => esc_html__('LinkedIn URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your LinkedIn URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'xing-url',
            'type' => 'text',
            'title' => esc_html__('Xing URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Xing URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'rss-url',
            'type' => 'text',
            'title' => esc_html__('RSS URL', 'LEVELUP'),
            'subtitle' => esc_html__('If you have an external RSS feed such as Feedburner, please enter it here. Will use built in Wordpress feed if left blank.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'behance-url',
            'type' => 'text',
            'title' => esc_html__('Behance URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Behance URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'instagram-url',
            'type' => 'text',
            'title' => esc_html__('Instagram URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Instagram URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'github-url',
            'type' => 'text',
            'title' => esc_html__('GitHub URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your GitHub URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'soundcloud-url',
            'type' => 'text',
            'title' => esc_html__('SoundCloud URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your SoundCloud URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'vk-url',
            'type' => 'text',
            'title' => esc_html__('VK URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your VK URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'wechat-url',
            'type' => 'text',
            'title' => esc_html__('WeChat URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your WeChat URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'snapchat-url',
            'type' => 'text',
            'title' => esc_html__('Snapchat URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Snapchat URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id' => 'flickr-url',
            'type' => 'text',
            'title' => esc_html__('Flickr URL', 'LEVELUP'),
            'subtitle' => esc_html__('Please enter in your Flickr URL.', 'LEVELUP'),
            'desc' => '',
            'default' => '',
        ),

        array(
            'id'       => 'section-sicial-media-share-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Share Settings', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'blog-facebook-sharing',
            'type' => 'checkbox',
            'title' => esc_html__('Facebook', 'LEVELUP'),
            'subtitle' => esc_html__('Share it.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'blog-twitter-sharing',
            'type' => 'checkbox',
            'title' => esc_html__('Twitter', 'LEVELUP'),
            'subtitle' => esc_html__('Tweet it.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'blog-google-plus-sharing',
            'type' => 'checkbox',
            'title' => esc_html__('Google+', 'LEVELUP'),
            'subtitle' => esc_html__('Share it.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'blog-pinterest-sharing',
            'type' => 'checkbox',
            'title' => esc_html__('Pinterest', 'LEVELUP'),
            'subtitle' => esc_html__('Pin it.', 'LEVELUP'),
            'default' => '1',
        ),

        array(
            'id' => 'blog-linkedin-sharing',
            'type' => 'checkbox',
            'title' => esc_html__('LinkedIn', 'LEVELUP'),
            'subtitle' => esc_html__('Share it.', 'LEVELUP'),
            'default' => '0',
            'desc' => '',
        ),

        array(
            'id'     => 'section-sicial-media-share-end',
            'type'   => 'section',
            'indent' => false,
        ),

    )
));


LevelupRedux::setSection($opt_name, array(
    'id' => 'woocommerce',
    'icon'  => 'woocommerce',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('WooCommerce', 'LEVELUP'),
    'desc' => '',
    'fields' => array(

        array(
            'id'       => 'woo_catalog_type',
            'type'     => 'image_select',
            'title'    => esc_html__('Shop Type', 'LEVELUP'),
            'subtitle' => esc_html__('Please select your Shop Type. Regular or Mosaic Style.', 'LEVELUP'),
            'options'  => array(
                1      => array(
                    'title' => esc_html__('Regular', 'LEVELUP'),
                    'img'   => get_template_directory_uri() . '/inc/admin/assets/images/woo_no_sidebar.png'
                ),
                2      => array(
                    'title' => esc_html__('Mosaic', 'LEVELUP'),
                    'img'   => get_template_directory_uri() . '/inc/admin/assets/images/woo_special_edition.png'
                )
            ),
            'default' => 1,
        ),

        array(
            'id' => 'section-woo-minicart-options-start',
            'type' => 'section',
            'title' => esc_html__('Mini Cart', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'header-cart-enable',
            'type' => 'switch',
            'title' => esc_html__('Header Shopping Cart', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Shopping Cart in Header Area. Disabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'header-cart-dropdown-enable',
            'type' => 'switch',
            'title' => esc_html__('Header Shopping Cart Drop-down', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the Shopping Cart drop-down. Enabled by default.', 'LEVELUP'),
            'required' => array('header-cart-enable', '=', '1'),
            'default' => '1'
        ),


        array(
            'id' => 'section-woo-minicart-options-end',
            'type' => 'section',
            'indent' => false,
        ),

        array(
            'id' => 'section-woo-catalog-options-start',
            'type' => 'section',
            'title' => esc_html__('Shop Options', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        /*array(
            'id'       => 'woo_catalog_fullwidth',
            'type'     => 'button_set',
            'title'    => esc_html__('Catalog Full-width', 'LEVELUP'),
            'subtitle' => esc_html__('Please select your Shop Catalog Layout.', 'LEVELUP'),
            'options'  => array(
                '' => esc_html__('Boxed', 'LEVELUP'),
                1 => esc_html__('Full Width', 'LEVELUP'),
            ),
            'default'  => '',
        ),*/

        array(
            'id' => 'woo-catalog-style',
            'type' => 'image_select',
            'title'    => esc_html__('Main Shop Layout', 'LEVELUP'),
            'subtitle' => esc_html__('Please select your Shop Page Layout here. Grid or Masonry.', 'LEVELUP'),
            'options' => array(
                'grid' => array(
                    'title' => esc_html__('Grid', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout/grid.png'
                ),
                'masonry' => array(
                    'title' => esc_html__('Masonry', 'LEVELUP'),
                    'img' => get_template_directory_uri() . '/inc/admin/assets/images/layout/masonry.png'
                ),
            ),
            'default' => 'grid',
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),


        array(
            'id' => 'woo_catalog_fullwidth',
            'type' => 'switch',
            'title'    => esc_html__('Shop Full-width', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to set the layout to full width.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id'       => 'woo-enable-catalog-sidebar',
            'type'     => 'image_select',
            'title'    => esc_html__('Shop Sidebar', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a sidebar layout or w/o sidebar layout for Shop Page.', 'LEVELUP'),
            'options'  => array(
                '0'      => array(
                    'title' => esc_html__('No Sidebar', 'LEVELUP'),
                    'img'   => get_template_directory_uri() . '/inc/admin/assets/images/woo_no_sidebar.png'
                ),
                '1'      => array(
                    'title' => esc_html__('Left Sidebar', 'LEVELUP'),
                    'img'   => get_template_directory_uri() . '/inc/admin/assets/images/woo_sidebar_left.png'
                ),
                '2'      => array(
                    'title' => esc_html__('Right Sidebar', 'LEVELUP'),
                    'img'  => get_template_directory_uri() . '/inc/admin/assets/images/woo_sidebar_right.png'
                )
            ),
            'default' => '0',
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),

	    array(
		    'id' => 'woo-enable-catalog-sidebar__hide-xs',
		    'type' => 'switch',
		    'title'    => esc_html__('Hide Shop Sidebar on Mobile View?', 'LEVELUP'),
			'subtitle' => esc_html__('Use this setting to enable / disable displaying of sidebar on mobile view.', 'LEVELUP'),
		    'required'  => array('woo-enable-catalog-sidebar', '!=', '0'),
		    'default' => '0',
	    ),

        array(
            'id' => 'wc-custom-spacing',
            'type' => 'switch',
            'title' => esc_html__('Custom Top/Bottom Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you can set a custom top and bottom padding on the shop page. Note! Does not work on the single product page.', 'LEVELUP'),
            'default' => '0',
        ),

        array(
            'id' => 'wc-page-title-margin-bottom',
            'type' => 'button_set',
            'title' => esc_html__('Shop Page Top Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you can set a custom top padding on the shop page. Note! Does not work on the single product page.', 'LEVELUP'),
            'desc' => '',
            'options' => array(
                '' => esc_html__('Inherit', 'LEVELUP'),
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => 75,
            'required'  => array('wc-custom-spacing', '=', '1'),
        ),

        array(
            'id' => 'wc-footer-margin_top',
            'type' => 'button_set',
            'title' => esc_html__('Shop Page Bottom Padding', 'LEVELUP'),
            'subtitle' => esc_html__('Using this option, you can set a custom bottom padding on the shop page. Note! Does not work on the single product page.', 'LEVELUP'),
            'desc' => '',
            'options' => array(
                '' => esc_html__('Inherit', 'LEVELUP'),
                0 =>  esc_html__('0', 'LEVELUP'),
                30 => esc_html__('30', 'LEVELUP'),
                45 => esc_html__('45', 'LEVELUP'),
                60 => esc_html__('60', 'LEVELUP'),
                75 => esc_html__('75', 'LEVELUP'),
                90 => esc_html__('90', 'LEVELUP'),
                120 => esc_html__('120', 'LEVELUP'),
            ),
            'default' => 90,
            'required'  => array('wc-custom-spacing', '=', '1'),
        ),

        array(
            'id'       => 'woo_columns',
            'type'     => 'button_set',
            'title'    => esc_html__('Number of Products per Row', 'LEVELUP'),
            'subtitle' => esc_html__('Select the number of products per row to be displayed on the Shop page.', 'LEVELUP'),
            'options'  => array(
                2 => '2',
                3 => '3',
                4 => '4',
                6 => '6',
            ),
            'default'  => 4,
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),

        array(
            'id'        => 'woo-catalog-count',
            'type'      => 'slider',
            'title'     => esc_html__('Number of Products per Page', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the number of displayed products on the Shop page. Range from 2 to 40.', 'LEVELUP'),
            "default"   => 20,
            "min"       => 2,
            "step"      => 1,
            "max"       => 40,
            'display_value' => 'label',
        ),

        array(
            'id'        => 'woo-catalog-list-padding',
            'type'      => 'slider',
            'title'     => esc_html__('Gap between items on Shop Page', 'LEVELUP'),
            'subtitle' => esc_html__('Drag the slider to set the distance between the blocks of the items on the Shop page. Range from 0 to 80.', 'LEVELUP'),
            "default"   => 15,
            "min"       => 0,
            "step"      => 1,
            "max"       => 80,
            'display_value' => 'text',
        ),

        array(
            'id' => 'woo-catalog-center-align',
            'type' => 'switch',
            'title' => esc_html__('Block Center Alignment?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable center alignment of categories of items, titles and prices in block. Disabled by default.', 'LEVELUP'),
            'default' => '1',
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),

        array(
            'id' => 'woo-enable-image-hover',
            'type' => 'switch',
            'title' => esc_html__('Shop Page Crossfade Image Effect', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Crossfade Image Effect on Shop page. Enabled by default.', 'LEVELUP'),
            'default' => '1',
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),

        array(
            'id' => 'woo-enable-rating-catalog',
            'type' => 'switch',
            'title' => esc_html__('Rating (stars) on Shop Page', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Rating (stars) on Shop page. Enabled by default.', 'LEVELUP'),
            'default' => '1',
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),

        array(
            'id' => 'woo-enable-catalog-category',
            'type' => 'switch',
            'title' => esc_html__('Product Category on Shop Page', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the display of categories of items on the Shop Page. Enabled by default.', 'LEVELUP'),
            'default' => '1',
            'required'  => array('woo_catalog_type', '!=', array('2')),
        ),

        array(
            'id' => 'woo-enable-breadchamps',
            'type' => 'switch',
            'title' => esc_html__('Breadcrumbs', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Breadcrumbs on Shop page. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'shop_catalog_pagetitle',
            'type' => 'typography',
            'title' => esc_html__('Shop Page Title', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for the Shop Page Title.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '75px',
                'font-weight' => '800',
                'line-height' => '90px',
            ),
        ),

        array(
            'id' => 'shop_catalog_title',
            'type' => 'typography',
            'title' => esc_html__('Product Title on Shop Page', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Product Title on the Shop page.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '14px',
                'font-weight' => '400',
                'line-height' => '20px',
            ),
        ),

        array(
            'id' => 'shop_catalog_category',
            'type' => 'typography',
            'title' => esc_html__('Title of the Product Category on Shop Page', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Title of the Product Category on the Shop page.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '14px',
                'font-weight' => '400',
            ),
        ),

        array(
            'id' => 'wc-catalog-price_font',
            'type' => 'typography',
            'title' => esc_html__('Product Price on Shop Page', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for Product Price on the Shop page.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => false,
            'letter-spacing'=> false,
            'color'        => false,
            'text-transform' => false,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '700',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '18px',
            ),
        ),

        array(
            'id'     => 'section-woo-catalog-options-end',
            'type'   => 'section',
            'indent' => false,
        ),

        array(
            'id'       => 'section-woo-product-page-start',
            'type'     => 'section',
            'title'    => esc_html__( 'Product Page', 'LEVELUP' ),
            'subtitle' => '',
            'indent'   => true,
        ),

        array(
            'id' => 'wc-bread-separator_disable',
            'type' => 'switch',
            'title' => esc_html__('Breadcrumbs: Separator Disable?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the separator under the breadcrumbs on a Product Page. Enabled by default.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'woo-product-content-align-center',
            'type' => 'switch',
            'title' => esc_html__('Product Content Alignment Center?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable center alignment of item\'s information (Title, Price, brief description, etc.). Left-aligned by default. ', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'woo-product-content-image-zoom',
            'type' => 'switch',
            'title' => esc_html__('Product Image Zoom?', 'LEVELUP'),
		    'subtitle' => esc_html__('Product Image Zoom helps your store visitors seamlessly zoom in to a single product image.', 'LEVELUP'),
		    'default' => '0'
        ),

        array(
            'id' => 'shop_product_title',
            'type' => 'typography',
            'title' => esc_html__('Product Title', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for product title.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => true,
            'letter-spacing'  => true,
            'color'        => false,
            'text-transform' => true,
            'all_styles' => true,
            'default'      => array(
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '40px',
                'line-height' => '45px',
                'font-weight' => '400',
            ),
        ),

        array(
            'id' => 'wc-product-price_font',
            'type' => 'typography',
            'title' => esc_html__('Product Price', 'LEVELUP'),
            'subtitle' => esc_html__('Define styles for product price.', 'LEVELUP'),
            'google'   => true,
            'text-align'   => false,
            'line-height'  => false,
            'letter-spacing'  => false,
            'color'        => false,
            'text-transform' => false,
            'all_styles' => true,
            'default'      => array(
                'font-weight' => '700',
                'font-family' => 'Open Sans',
                'google'      => true,
                'font-size'   => '35px',
            ),
        ),

        array(
            'id'       => 'buttons-color',
            'type'     => 'color',
            'title'    => esc_html__('Button Color (Add to Cart)', 'LEVELUP'),
            'subtitle' => esc_html__('Choose a color for "Add to Cart" Button.', 'LEVELUP'),
            'default'  => '#000000'
        ),

        array(
            'id' => 'woo-enable-product-tabs-center',
            'type' => 'switch',
            'title' => esc_html__('Tabs Alignment Center?', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable center alignment of Tabs Title (Description, Additional Information, Reviews). Disabled by default.', 'LEVELUP'),
            'default' => '0'
        ),

        array(
            'id' => 'woo-enable-product-social',
            'type' => 'switch',
            'title' => esc_html__('Social Icons', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Social Icons. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'woo-enable-product-description',
            'type' => 'switch',
            'title' => esc_html__('Description, Additional Information', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Description, Additional Information. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

        array(
            'id' => 'woo-enable-product-review',
            'type' => 'switch',
            'title' => esc_html__('Reviews', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable Reviews. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

	    array(
		    'id' => 'woo-upsales',
		    'type' => 'switch',
		    'title' => esc_html__('Up-sells Slider', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable the slider for scrolling the Up-sells Products in Row. Enabled by default.', 'LEVELUP'),
		    'default' => '',
	    ),

        array(
            'id' => 'woo-enable-product-related',
            'type' => 'switch',
            'title' => esc_html__('Related Products', 'LEVELUP'),
            'subtitle' => esc_html__('Use this setting to enable / disable the amount of Related Items on the Product Page. Enabled by default.', 'LEVELUP'),
            'default' => '1'
        ),

	    array(
		    'id' => 'woo-related',
		    'type' => 'switch',
		    'title' => esc_html__('Related Slider', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable the slider for scrolling the Related Products in Row. Enabled by default.', 'LEVELUP'),
		    'default' => '',
	    ),

        array(
            'id'       => 'wc_related_columns',
            'type'     => 'button_set',
            'title'    => esc_html__('Number of Related Items per Row', 'LEVELUP'),
            'subtitle' => esc_html__('Select the number of Related Items per row to be displayed on the Product Page.', 'LEVELUP'),
            'options'  => array(
                2 => '2',
                3 => '3',
                4 => '4',
                6 => '6',
            ),
            'default'  => 4,
            'required'  => array('woo-enable-product-related', '=', array('1')),
        ),

        array(
            'id'        => 'wc_related_count',
            'type'      => 'slider',
            'title'     => esc_html__('Number of Related Items on Page', 'LEVELUP'),
            "default"   => 4,
            "min"       => 2,
            "step"      => 1,
            "max"       => 20,
            'display_value' => 'label',
            'subtitle' => esc_html__('Drag the slider to set the number of displayed items on the Product Page. Range from 2 to 20.', 'LEVELUP'),
            'required'  => array('woo-enable-product-related', '=', array('1')),
        ),

        array(
            'id'     => 'section-woo-product-page-end',
            'type'   => 'section',
            'indent' => false,
        ),

	    array(
		    'id'       => 'section-woo-cart-page-start',
		    'type'     => 'section',
		    'title'    => esc_html__( 'Cart Page', 'LEVELUP' ),
		    'subtitle' => '',
		    'indent'   => true,
	    ),

	    array(
		    'id' => 'woo-cross-sales',
		    'type' => 'switch',
		    'title' => esc_html__('Cross-sells Slider', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting to enable / disable the slider for scrolling the Cross-sells Products in Row.', 'LEVELUP'),
		    'default' => '',
	    ),

	    array(
			    'id'     => 'section-woo-cart-page-end',
			    'type'   => 'section',
			    'indent' => false,
	    ),

    )
));

LevelupRedux::setSection( $opt_name, array(
	'id'         => 'mobile',
	'icon'       => 'mobile',
	'icon_class' => 'rdy-icon',
	'title'      => esc_html__( 'Mobile Devices', 'LEVELUP' ),
	'fields'     => array(

		array(
			'id'       => 'section-header-mobile-start',
			'type'     => 'section',
			'title'    => esc_html__( 'Header on Mobile Devices', 'LEVELUP' ),
			'subtitle' => '',
			'indent'   => true,
		),

		array(
			'id'       => 'header-mobile-bar',
			'title'    => esc_html__( 'Mobile Header Layout', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Choose the mobile header layout.', 'LEVELUP' ),
			'type'     => 'image_select',
			'options'  => array(
				''                         => array(
					'alt' => '0',
					'img' => get_template_directory_uri() . '/inc/admin/assets/images/mobile/header_mob_01.png'
				),
				'button_right_logo_center' => array(
					'alt' => '0',
					'img' => get_template_directory_uri() . '/inc/admin/assets/images/mobile/header_mob_02.png'
				),
				'button_left_logo_center'  => array(
					'alt' => '0',
					'img' => get_template_directory_uri() . '/inc/admin/assets/images/mobile/header_mob_03.png'
				),
			),
			'default'  => ''
		),

		array(
			'id'       => 'logo-mobile',
			'type'     => 'media',
			'required' => array( 'use-logo', '=', 'image' ),
			'title'    => esc_html__( 'Upload Your Mobile Logo', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Upload your mobile logo image.', 'LEVELUP' ),
			'default'  => '',
		),

		array(
			'id'       => 'logo-mobile-height',
			'type'     => 'text',
			'title'    => esc_html__( 'Logo Mobile Height', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Enter the height of the logo. Default 20', 'LEVELUP' ),
			'desc'     => esc_html__( 'Enter a value in pixels. E.g. 50', 'LEVELUP' ),
			'validate' => 'numeric',
			'default'  => '20',
			'required' => array( 'logo-mobile', '!=', array( '', ) ),
		),

		array(
			'id'          => 'mobile-header-background-color',
			'type'        => 'color',
			'transparent' => false,
			'title'       => esc_html__( 'Mobile Header Background Color', 'LEVELUP' ),
			'subtitle'    => esc_html__( 'Choose a background color for header area.', 'LEVELUP' ),
			'default'     => '#ffffff',
		),

		array(
			'id'          => 'mobile-header-icons-color',
			'type'        => 'color',
			'transparent' => false,
			'title'       => esc_html__( 'Mobile Header Icons Color', 'LEVELUP' ),
			'subtitle'    => esc_html__( 'Set the color for the Mobile Header Icons (Hamburger, Shopping Cart).', 'LEVELUP' ),
			'default'     => '#000',
		),

		array(
			'id'       => 'header-mobile-sticky',
			'type'     => 'switch',
			'title'    => esc_html__( 'Mobile Header Sticky?', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Use this setting to enable / disable the sticky header function on mobile devices.', 'LEVELUP' ),
			'default'  => '0',
		),

		array(
			'id'     => 'section-header-mobile-end',
			'type'   => 'section',
			'indent' => false,
		),


		array(
			'id'       => 'section-mobile-menu-panel-start',
			'type'     => 'section',
			'title'    => esc_html__( 'Mobile Menu Panel', 'LEVELUP' ),
			'subtitle' => '',
			'indent'   => true,
		),

		array(
			'id'          => 'mobile-menu-background-color',
			'type'        => 'color',
			'transparent' => false,
			'title'       => esc_html__( 'Mobile Menu Background Color', 'LEVELUP' ),
			'subtitle'    => esc_html__( 'Choose a background color for mobile menu panel.', 'LEVELUP' ),
			'default'     => '#ffffff',
		),

		array(
			'id' => 'mobile-menu-background-opacity',
			'type' => 'slider',
			'title' => esc_html__('Mobile Menu Background Opacity', 'LEVELUP'),
			'subtitle'    => esc_html__( 'Use this setting to set the mobile menu background opacity.', 'LEVELUP' ),
			"default" => 100,
			"min" => 0,
			"step" => 1,
			"max" => 100,
			'display_value' => 'text',
			'required'  => array('mobile-menu-background-color', '!=', ''),
		),

		array(
			'id'       => 'header-mobile_menu-animation',
			'type'     => 'button_set',
			'title'    => esc_html__( 'Mobile Menu Panel Behavior', 'LEVELUP' ),
			'options'  => array(
				''           => esc_html__( 'Sliding From Top', 'LEVELUP' ),
				'slideleft'  => esc_html__( 'Slidng From Left', 'LEVELUP' ),
				'slideright' => esc_html__( 'Sliding From Right', 'LEVELUP' ),
				'fadein'     => esc_html__( 'FadeIn', 'LEVELUP' ),
			),
			'subtitle' => esc_html__( 'Use this setting in order to choose the behavior of Mobile Menu Panel.', 'LEVELUP' ),
			'default'  => ''
		),

		array(
			'id' => 'header-mobile_menu-fullwidth',
			'type' => 'switch',
			'title' => esc_html__('Mobile Menu Panel Full-width?', 'LEVELUP'),
			'subtitle' => esc_html__('Use this setting if you want to expand the mobile menu panel to full-width of the screen.', 'LEVELUP'),
			'default' => '0',
			'required' => array( 'header-mobile_menu-animation', '=', array( 'slideleft', 'slideright' ) ),
		),

		array(
			'id'       => 'header-mobile_menu-items-animation',
			'type'     => 'button_set',
			'title'    => esc_html__('Mobile Menu Items Animation', 'LEVELUP'),
			'options' => array(
				'' => esc_html__('None', 'LEVELUP'),
				'slideleft' => esc_html__('Slide Left', 'LEVELUP'),
				'slideright' => esc_html__('Slide Right', 'LEVELUP'),
				'slideup' => esc_html__('Slide Up', 'LEVELUP'),
				'slidedown' => esc_html__('Slide Down', 'LEVELUP'),
				'fadein' => esc_html__('Fade In', 'LEVELUP'),
			),
			'subtitle' => esc_html__('Use this setting for choosing the mode of menu items appearing.', 'LEVELUP'),
			'default' => ''
		),

		array(
			'id' => 'header-mobile_menu-items-cascade_animation',
			'type' => 'switch',
			'title' => esc_html__('Cascade Animations', 'LEVELUP'),
			'subtitle' => esc_html__('Use this setting in order to make the cascading animation of menu items (one after another).', 'LEVELUP'),
			'default' => '1',
			'required' => array( 'header-mobile_menu-items-animation', '!=', '' ),
		),

		array(
			'id'       => 'header-mobile_menu-valign',
			'type'     => 'button_set',
			'title'    => esc_html__('Mobile Menu Items Position', 'LEVELUP'),
			'options' => array(
					'' => esc_html__('Top', 'LEVELUP'),
					'middle' => esc_html__('Middle', 'LEVELUP'),
			),
			'subtitle' => esc_html__('Use this setting in order to indicate the verical position of menu items.', 'LEVELUP'),
			'default' => ''
		),

		array(
			'id'       => 'header-mobile-items-align',
			'type'     => 'button_set',
			'title'    => esc_html__( 'Mobile Menu Items Alignment', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Use this setting to align menu items.', 'LEVELUP' ),
			'options'  => array(
					'left'   => esc_html__( 'Left', 'LEVELUP' ),
					'center' => esc_html__( 'Center', 'LEVELUP' ),
					'right'  => esc_html__( 'Right', 'LEVELUP' ),
			),
			'default'  => 'left',
		),

			array(
			'id' => 'mobile_menu-items-divider',
			'type' => 'switch',
			'title' => esc_html__('Dividers Between Menu Items', 'LEVELUP'),
			'subtitle' => esc_html__('Use this setting in order to Enable/Disable dividers lines between mobile menu items.', 'LEVELUP'),
			'default' => '1'
		),

		array(
			'id' => 'mobile_menu-expand-touch',
			'type' => 'switch',
			'title' => esc_html__('Expand/Collapse Sub-menu by Touching?', 'LEVELUP'),
			'subtitle' => esc_html__('This setting makes the upper menu item (which has sub-menu) responsive to the touch, expand/collapse sub-menu items.', 'LEVELUP'),
			'default' => '0'
		),

		array(
			'id' => 'mobile_menu-font',
			'type' => 'typography',
			'title' => esc_html__('Mobile Menu Items Font', 'LEVELUP'),
			'subtitle' => esc_html__('Set up the font, size and color of mobile menu items. ', 'LEVELUP'),
			'google'   => true,
			'custom_fonts' => true,
			'text-align'   => false,
			'line-height'  => false,
			'letter-spacing'  => false,
			'color'        => true,
			'text-transform' => true,
			'all_styles' => true,
			'default'      => array(
				'font-weight' => '400',
				'font-family' => 'Open Sans',
				'google'      => true,
				'font-size'   => '15px',
			),
		),

		array(
			'id' => 'mobile_menu-items-padding',
			'type' => 'slider',
			'title' => esc_html__('Mobile Menu Items Spacing', 'LEVELUP'),
			'subtitle' => esc_html__('Drag the slider to set up the distance between the mobile menu items.', 'LEVELUP'),
			"default" => 10,
			"min" => 1,
			"step" => 1,
			"max" => 100,
			'display_value' => 'text',
		),

			array(
			'id' => 'mobile_menu-drop-font',
			'type' => 'typography',
			'title' => esc_html__('Mobile Menu Sub-menu Items Font', 'LEVELUP'),
			'subtitle' => esc_html__('Set up the font, size and color of mobile menu sub-menu items.', 'LEVELUP'),
			'google'   => true,
			'custom_fonts' => true,
			'text-align'   => false,
			'line-height'  => false,
			'letter-spacing'  => false,
			'color'        => true,
			'text-transform' => true,
			'all_styles' => true,
			'default'      => array(
					'font-weight' => '400',
					'font-family' => 'Open Sans',
					'google'      => true,
					'font-size'   => '14px',
			),
		),

		array(
			'id' => 'mobile_menu-sub-items-padding',
			'type' => 'slider',
			'title' => esc_html__('Mobile Menu Sub Items Spacing', 'LEVELUP'),
			'subtitle' => esc_html__('Drag the slider to set up the distance between the mobile sub-menu items.', 'LEVELUP'),
			"default" => 10,
			"min" => 1,
			"step" => 1,
			"max" => 100,
			'display_value' => 'text',
		),

		array(
			'id'       => 'header-mobile_menu-elements-valign',
			'type'     => 'button_set',
			'title'    => esc_html__('Position of Additional Elements', 'LEVELUP'),
			'options' => array(
					'' => esc_html__('Default', 'LEVELUP'),
					'bottom' => esc_html__('At Bottom', 'LEVELUP'),
			),
			'subtitle' => esc_html__('Use this setting in order to set the vertical position of such additional elements as social icons and search. The value Default means that Additional Elements will be displayed right after menu items, under them.', 'LEVELUP'),
			'default' => '',
//		    'required' => array('header-mobile_menu-valign', '!=', ''),
		),

		array(
				'id'     => 'section-mobile-menu-panel-end',
				'type'   => 'section',
				'indent' => false,
		),

		array(
				'id'       => 'section-mobile-menu-addelements-start',
				'type'     => 'section',
				'title'    => esc_html__( 'Mobile Menu Additional Elements', 'LEVELUP' ),
				'subtitle' => 'Social icons and search.',
				'indent'   => true,
		),

		array(
		'id'       => 'header-search-mobile-enable',
		'type'     => 'switch',
		'title'    => esc_html__( 'Mobile Search Bar', 'LEVELUP' ),
		'subtitle' => esc_html__( 'Use this setting to enable / disable the Search Bar in the mobile version of the menu. Disabled by default.', 'LEVELUP' ),
		'default'  => '0'
		),

		/*array(
			'id'       => 'header-m-social-show',
			'type'     => 'switch',
			'title'    => esc_html__( 'Header Social Icons', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Use this setting to enable / disable the Header Social Icons in the mobile version of Header. Disabled by default.', 'LEVELUP' ),
			'default'  => '0'
		),*/

		array(
			'id'          => 'mobile-menu-social-color',
			'type'        => 'color',
			'transparent' => false,
			'title'       => esc_html__( 'Mobile Menu Icons Color', 'LEVELUP' ),
			'subtitle'    => esc_html__( 'Choose a color for social icons of mobile menu.', 'LEVELUP' ),
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
			'default'     => '#000000',
		),

		array(
			'id' => 'header-m-social-show',
			'type' => 'button_set',
			'title'    => esc_html__( 'Header Social Icons', 'LEVELUP' ),
			'subtitle' => esc_html__( 'Use this setting to enable / disable the Header Social Icons in the mobile version of Header. Disabled by default.', 'LEVELUP' ),
			'options' => array(
				0 => esc_html__('Disable', 'LEVELUP'),
				1 => esc_html__('Text', 'LEVELUP'),
				'icons' => esc_html__('Icons', 'LEVELUP'),
			),
			'default' => 0,
		),

		array(
			'id'       => 'header-m-social-facebook',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Facebook', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-twitter',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Twitter', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-google-plus',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Google+', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-vimeo',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Vimeo', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),
		array(
			'id'       => 'header-m-social-pinterest',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Pinterest', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-youtube',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Youtube', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-tumblr',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Tumblr', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-dribbble',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Dribbble', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-linkedin',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'LinkedIn', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-rss',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'RSS', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-behance',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Behance', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-instagram',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Instagram', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-github',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'GitHub', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-soundcloud',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'SoundCloud', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-xing',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Xing', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-vk',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'VK', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-wechat',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'WeChat', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-snapchat',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Snapchat', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
			'id'       => 'header-m-social-flickr',
			'type'     => 'checkbox',
			'title'    => esc_html__( 'Flickr', 'LEVELUP' ),
			'default'  => '0',
			'required' => array( 'header-m-social-show', '=', array('1', 'icons') ),
		),

		array(
				'id'     => 'section-mobile-menu-addelements-end',
				'type'   => 'section',
				'indent' => false,
		),

		array(
			'id'       => 'section-mobile-back-to-top-start',
			'type'     => 'section',
			'title'    => esc_html__( 'Back To Top Button', 'LEVELUP' ),
			'subtitle' => '',
			'indent'   => true,
		),

		array(
			'id'       => 'back-to-top-main-mobile-icon',
			'type'     => 'switch',
			'title'    => esc_html__( 'Back To Top Button', 'LEVELUP' ),
			'subtitle' => 'Using this setting you can enable / disable Back To Top Button on mobile.',
			'default'  => '1',
		),

		array(
			'id'       => 'back-to-top-main-mobile-icon-type',
			'type'     => 'image_select',
			'title'    => esc_html__( 'Back To Top Button Type', 'LEVELUP' ),
			'subtitle' => 'Choose button type. When you press the "Back To Top" button, the page scrolls itself up to the very beginning.',
			'options'  => array(
				'rounded' => array(
					'alt' => '0',
					'img' => get_template_directory_uri() . '/inc/admin/assets/images/mobile/backtotop_rounded.png'
				),
				'circle'  => array(
					'alt' => '0',
					'img' => get_template_directory_uri() . '/inc/admin/assets/images/mobile/backtotop_circle.png'
				),
			),
			'default'  => 'rounded',
			'required' => array( 'back-to-top-main-mobile-icon', '=', '1' ),
		),

		array(
			'id'          => 'back-to-top-main-mobile-icon-color',
			'type'        => 'color',
			'title'       => esc_html__( 'Button Color', 'LEVELUP' ),
			'subtitle'    => 'Choose a color for Back To Top Button.',
			'desc'        => '',
			'default'     => '#444',
			'required'    => array( 'back-to-top-main-mobile-icon', '=', '1' ),
			'transparent' => false
		),

		array(
			'id'       => 'back-to-top-main-mobile-icon-color-s',
			'type'     => 'button_set',
			'title'    => esc_html__( 'Color Arrow', 'LEVELUP' ),
			'subtitle' => 'Use this setting to set the color of arrow of Back to Top Button.',
			'options'  => array(
				'light' => esc_html__( 'Light', 'LEVELUP' ),
				'dark'  => esc_html__( 'Dark', 'LEVELUP' ),
			),
			'default'  => 'light',
			'required' => array( 'back-to-top-main-mobile-icon', '=', '1' ),
		),

		array(
			'id'            => 'back-to-top-main-mobile-icon-opacity',
			'type'          => 'slider',
			'title'         => esc_html__( 'Button Opacity', 'LEVELUP' ),
			'subtitle'      => 'Use this setting to set the opacity of Back to Top Button.',
			"default"       => 100,
			"min"           => 0,
			"step"          => 1,
			"max"           => 100,
			'display_value' => 'text',
			'required'      => array( 'back-to-top-main-mobile-icon', '=', '1' ),
		),

		array(
			'id'       => 'back-to-top-main-mobile-icon-shadow',
			'type'     => 'switch',
			'title'    => esc_html__( 'Button Shadow', 'LEVELUP' ),
			'subtitle' => 'Using this setting you can enable / disable Back To Top Button Shadow on mobile.',
			'default'  => '1',
			'required' => array( 'back-to-top-main-mobile-icon', '=', '1' ),
		),

		array(
				'id'     => 'section-mobile-back-to-top-end',
				'type'   => 'section',
				'indent' => false,
		),
	)
) );

LevelupRedux::setSection( $opt_name, array(
    'id' => 'subscriptions',
    'icon'  => 'subscriptions',
    'icon_class' => 'rdy-icon',
    'title' => esc_html__('Contact Form', 'LEVELUP'),
    'fields' => array(

	    array(
		    'id' => 'section-cf7-start',
		    'type' => 'section',
		    'title' => esc_html__('Contact Form 7 Settings', 'LEVELUP'),
		    'subtitle' => '',
		    'indent' => true,
	    ),

/*	    array(
		    'id'       => 'wpcf7-color-lines-style',
		    'type'     => 'button_set',
		    'title'    => esc_html__('Form Fields Border Color', 'LEVELUP'),
		    'subtitle' => esc_html__('Use this setting for select border color scheme to the form fields.', 'LEVELUP'),
		    'options' => array(
				    'dark' => esc_html__('Dark', 'LEVELUP'),
				    'light' => esc_html__('Light', 'LEVELUP'),
		    ),
		    'default' => 'dark'
	    ),
*/
	    array(
		    'id'          => 'wpcf7-color-lines',
		    'type'        => 'color',
		    'title'       => esc_html__( 'Accent Line Color on Hover', 'LEVELUP' ),
		    'subtitle'    => esc_html__( 'Use this setting for choose line color to the form bottom border etc on hover.', 'LEVELUP' ),
		    'desc'        => '',
		    'default'     => '#0099e5',
		    'transparent' => false
	    ),

	    array(
		    'id'          => 'wpcf7-form-field-background_color',
		    'type'        => 'color',
		    'title'       => esc_html__( 'Fields Background Color', 'LEVELUP' ),
		    'default'     => '#ffffff',
		    'transparent' => true,
		    'subtitle'    => esc_html__( 'Select background color.', 'LEVELUP' ),
	    ),

	    array(
		    'id'          => 'wpcf7-form-field-border_color',
		    'type'        => 'color',
		    'title'       => esc_html__( 'Fields Border Color', 'LEVELUP' ),
		    'default'     => '#cccccc',
		    'transparent' => false,
		    'subtitle'    => esc_html__( 'Select border color.', 'LEVELUP' ),
	    ),

	    array(
		    'id'          => 'wpcf7-form-field-text_color',
		    'type'        => 'color',
		    'title'       => esc_html__( 'Fields Text Color', 'LEVELUP' ),
		    'default'     => '#7f7f7f',
		    'transparent' => false,
		    'subtitle'    => esc_html__( 'Select text color.', 'LEVELUP' ),
	    ),

	    array(
		    'id'          => 'wpcf7-form-button_color',
		    'type'        => 'color',
		    'title'       => esc_html__( 'Button Color', 'LEVELUP' ),
		    'default'     => '#0099e5',
		    'transparent' => false,
		    'subtitle'    => esc_html__( 'Select button color.', 'LEVELUP' ),
	    ),

	    array(
		    'id'       => 'wpcf7-submit-border_radius',
		    'type'     => 'button_set',
		    'title'    => esc_html__( 'Border Radius', 'LEVELUP' ),
		    'subtitle' => esc_html__( 'Use this setting to set the rounded corners of the button.', 'LEVELUP' ),
		    'options'  => array(
			    ''      => esc_html__( 'None', 'LEVELUP' ),
			    '4' => esc_html__( '4', 'LEVELUP' ),
			    '30' => esc_html__( '30', 'LEVELUP' ),
		    ),
		    'default'  => '',
	    ),

	    /*array(
		    'id'            => 'wpcf7-form-field-border_size',
		    'type'          => 'slider',
		    'title'         => esc_html__( 'Fields Border Size', 'LEVELUP' ),
		    "default"       => 1,
		    "min"           => 1,
		    "step"          => 1,
		    "max"           => 10,
		    'display_value' => 'text',
	    ),*/

	    array(
		    'id'     => 'section-cf7-end',
		    'type'   => 'section',
		    'indent' => false,
	    ),

	    array(
		    'id'       => 'section-mailchimp-start',
		    'type'     => 'section',
		    'title'    => esc_html__( 'MailChimp Settings', 'LEVELUP' ),
		    'subtitle' => '',
		    'indent'   => true,
	    ),

        array(
            'id' => 'mc4wp-form-button_color',
            'type' => 'color',
            'title' => esc_html__('Button Color', 'LEVELUP'),
            'default' => '#000000',
            'transparent' => false,
            'subtitle' => esc_html__('Select button color.', 'LEVELUP'),
        ),

        array(
            'id' => 'mc4wp-form-button_hover_color',
            'type' => 'color',
            'title' => esc_html__('Button Hover Color', 'LEVELUP'),
            'default' => '#333333',
            'transparent' => false,
            'subtitle' => esc_html__('Select hover background color for button.', 'LEVELUP'),
        ),

        array(
            'id' => 'mc4wp-form-text_color',
            'type' => 'color',
            'title' => esc_html__('Text Color', 'LEVELUP'),
            'default' => '#FFFFFF',
            'transparent' => false,
            'subtitle' => esc_html__('Select button text color.', 'LEVELUP'),
        ),

	    array(
		    'id' => 'section-mailchimp-end',
		    'type' => 'section',
		    'indent' => false,
	    ),

        array(
            'id' => 'section-mailchimp-widget-start',
            'type' => 'section',
            'title' => esc_html__('MailChimp Widget Settings', 'LEVELUP'),
            'subtitle' => '',
            'indent' => true,
        ),

        array(
            'id' => 'mc4wp-widget-form-button_color',
            'type' => 'color',
            'title' => esc_html__('Widget Button Color', 'LEVELUP'),
            'default' => '#000000',
            'transparent' => false,
            'subtitle' => esc_html__('Select button color.', 'LEVELUP'),
        ),

        array(
            'id' => 'mc4wp-widget-form-button_hover_color',
            'type' => 'color',
            'title' => esc_html__('Widget Button Hover Color', 'LEVELUP'),
            'default' => '#333333',
            'transparent' => false,
            'subtitle' => esc_html__('Select hover background color for button.', 'LEVELUP'),
        ),

        array(
            'id' => 'mc4wp-widget-form-text_color',
            'type' => 'color',
            'title' => esc_html__('Widget Text Color', 'LEVELUP'),
            'default' => '#FFFFFF',
            'transparent' => false,
            'subtitle' => esc_html__('Select button text color.', 'LEVELUP'),
        ),

        array(
            'id'       => 'mc4wp-widget-size',
            'type'     => 'button_set',
            'title'    => esc_html__('Widget Form Size', 'LEVELUP'),
            'options'  => array(
                'small' => esc_html__('Small', 'LEVELUP'),
                'medium' => esc_html__('Medium', 'LEVELUP'),
                'large' => esc_html__('Large', 'LEVELUP'),
            ),
            'default'  => 'medium',
        ),

        array(
            'id' => 'section-mailchimp-widget-end',
            'type' => 'section',
            'indent' => false,
        ),


    )
));



/*
 * <--- END SECTIONS
 */